@@ -36,7 +36,8 @@ BehaviorBase::~BehaviorBase() {
 	SetAutoDelete(false);
 	if(started)
 		std::cerr << "Behavior " << getName() << " deleted while running: use 'RemoveReference', not 'delete'" << std::endl;
-	erouter->removeListener(this);
+	if(erouter!=NULL)
+		erouter->removeListener(this);
 	getRegistryInstance().erase(this);
 }
 
@@ -69,9 +70,9 @@ std::set<BehaviorBase*>& BehaviorBase::getRegistryInstance() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.11 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.12 $
  * $State: Exp $
- * $Date: 2006/09/27 21:15:52 $
+ * $Date: 2007/06/14 06:24:03 $
  */
 
