@@ -7,13 +7,13 @@
 #include "Shared/get_time.h"
 #include "Sound/SoundManager.h"
 #include "Events/TextMsgEvent.h"
+#include "Shared/RobotInfo.h"
 #include "Shared/ERS210Info.h"
 #include "Shared/ERS220Info.h"
+#include "Shared/ERS2xxInfo.h"
 #include "Shared/ERS7Info.h"
 #include "Shared/string_util.h"
-#ifndef PLATFORM_APERIOS
-#  include "local/sim/Simulator.h"
-#endif
+#include "Shared/ProjectInterface.h"
 #include <sstream>
 
 Controller * Controller::theOneController=NULL;
@@ -27,7 +27,7 @@ EventBase Controller::selectItem;
 EventBase Controller::cancel;
 
 using namespace string_util;
-
+using namespace std;
 
 void Controller::DoStart() {
 	BehaviorBase::DoStart();
@@ -38,7 +38,7 @@ void Controller::DoStart() {
 	sndman->loadFile(config->controller.cancel_snd);
 	erouter->addListener(this,EventBase::estopEGID);
 	// Turn on wireless
-	gui_comm=wireless->socket(SocketNS::SOCK_STREAM, 2048, 32000);
+	gui_comm=wireless->socket(Socket::SOCK_STREAM, 2048, 32000);
 	wireless->setReceiver(gui_comm->sock, gui_comm_callback);
 	wireless->setDaemon(gui_comm,true);
 	wireless->listen(gui_comm->sock, config->controller.gui_port);
@@ -61,8 +61,10 @@ void Controller::DoStop() {
 	motman->removeMotion(display);
 	display=MotionManager::invalid_MC_ID;
 	//these two lines help prevent residual display in case that was the only MotionCommand using LEDs
+#ifdef TGT_HAS_LEDS
 	for(unsigned int i=LEDOffset; i<LEDOffset+NumLEDs; i++)
 		motman->setOutput(NULL,i,0.f);
+#endif
 	gui_comm->printf("goodbye\n");
 	wireless->setDaemon(gui_comm,false);
 	wireless->close(gui_comm);
@@ -282,38 +284,57 @@ int Controller::console_callback(char *buf, int bytes) {
 	return 0;
 }
 
+/*! Select which model is running and call initButtons with the appropriate button offsets
+ *  This could be somewhat simplified by using capabilities.getButtonOffset(), (wouldn't need
+ *  the ERS2xx case with essentially duplicated ERS210 and ERS220 cases), but this
+ *  style has the advantage that the symbols are checked by the compiler so there's no
+ *  chance of a typo in a button name going unnoticed. */
 void Controller::init() {
-	if(state->robotDesign & WorldState::ERS210Mask) {
-		nextItem=EventBase(EventBase::buttonEGID,ERS210Info::HeadFrButOffset,EventBase::deactivateETID,0);
-		prevItem=EventBase(EventBase::buttonEGID,ERS210Info::HeadBkButOffset,EventBase::deactivateETID,0);
-		nextItemFast=EventBase(EventBase::buttonEGID,ERS210Info::HeadFrButOffset,EventBase::statusETID,666);
-		prevItemFast=EventBase(EventBase::buttonEGID,ERS210Info::HeadBkButOffset,EventBase::statusETID,666);
-		selectItem=EventBase(EventBase::buttonEGID,ERS210Info::ChinButOffset,EventBase::deactivateETID,250);
-		cancel=EventBase(EventBase::buttonEGID,ERS210Info::BackButOffset,EventBase::deactivateETID,250);
-	} else if(state->robotDesign & WorldState::ERS220Mask) {
-		nextItem=EventBase(EventBase::buttonEGID,ERS220Info::TailLeftButOffset,EventBase::deactivateETID,0);
-		prevItem=EventBase(EventBase::buttonEGID,ERS220Info::TailRightButOffset,EventBase::deactivateETID,0);
-		//the 220 doesn't really support the next two because it's using boolean buttons
+	if(TargetName == ERS2xxInfo::TargetName) {
+		// compatability mode, see which of the targets is actually running
+		// Note using ERS2xxInfo namespace to get appropriate offsets!
+		// could remove duplication with "direct" 210/220 cases below by using something like:
+		//   capabilities.getButtonOffset(ERS210Info::outputNames[ERS210Info::fooButOffset])
+		if(RobotName == ERS210Info::TargetName) {
+			initButtons(666,250,ERS2xxInfo::HeadFrButOffset,ERS2xxInfo::HeadBkButOffset,ERS2xxInfo::HeadFrButOffset,ERS2xxInfo::HeadBkButOffset,ERS2xxInfo::ChinButOffset,ERS2xxInfo::BackButOffset);
+		} else if(RobotName == ERS220Info::TargetName) {
+			//the 220 doesn't really support "fast" because it's using boolean buttons
+			//i'm using a "hack" on the 210 because the pressure sensitivity causes status
+			//events to continually be sent but since this is just on/off, it only gets the
+			//activate/deactivate.  To fix this, override nextItemFast and prevItemFast with
+			// timers and do timer management in processEvents()
+			initButtons(666,50,ERS2xxInfo::TailLeftButOffset,ERS2xxInfo::TailRightButOffset,ERS2xxInfo::TailLeftButOffset,ERS2xxInfo::TailRightButOffset,ERS2xxInfo::TailCenterButOffset,ERS2xxInfo::BackButOffset);
+		} else {
+			cerr << "Controller: Unsupported 2xx model '" << RobotName << "'!  Appears to have buttons, but Controller doesn't know how to use them." << endl;
+		}
+	} else if(RobotName == ERS210Info::TargetName) {
+		initButtons(666,250,ERS210Info::HeadFrButOffset,ERS210Info::HeadBkButOffset,ERS210Info::HeadFrButOffset,ERS210Info::HeadBkButOffset,ERS210Info::ChinButOffset,ERS210Info::BackButOffset);
+	} else if(RobotName == ERS220Info::TargetName) {
+		//the 220 doesn't really support "fast" because it's using boolean buttons
 		//i'm using a "hack" on the 210 because the pressure sensitivity causes status
 		//events to continually be sent but since this is just on/off, it only gets the
-		//activate/deactivate.  To fix this, make these timers and do timer management
-		//in processEvents()
-		nextItemFast=EventBase(EventBase::buttonEGID,ERS220Info::TailLeftButOffset,EventBase::statusETID,666);
-		prevItemFast=EventBase(EventBase::buttonEGID,ERS220Info::TailRightButOffset,EventBase::statusETID,666);
-		selectItem=EventBase(EventBase::buttonEGID,ERS220Info::TailCenterButOffset,EventBase::deactivateETID,50);
-		cancel=EventBase(EventBase::buttonEGID,ERS220Info::BackButOffset,EventBase::deactivateETID,50);
-	} else if(state->robotDesign & WorldState::ERS7Mask) {
-		nextItem=EventBase(EventBase::buttonEGID,ERS7Info::FrontBackButOffset,EventBase::deactivateETID,0);
-		prevItem=EventBase(EventBase::buttonEGID,ERS7Info::RearBackButOffset,EventBase::deactivateETID,0);
-		nextItemFast=EventBase(EventBase::buttonEGID,ERS7Info::FrontBackButOffset,EventBase::statusETID,500);
-		prevItemFast=EventBase(EventBase::buttonEGID,ERS7Info::RearBackButOffset,EventBase::statusETID,500);
-		selectItem=EventBase(EventBase::buttonEGID,ERS7Info::MiddleBackButOffset,EventBase::deactivateETID,25);
-		cancel=EventBase(EventBase::buttonEGID,ERS7Info::HeadButOffset,EventBase::deactivateETID,25);
+		//activate/deactivate.  To fix this, override nextItemFast and prevItemFast with
+		// timers and do timer management in processEvents()
+		initButtons(666,50,ERS220Info::TailLeftButOffset,ERS220Info::TailRightButOffset,ERS220Info::TailLeftButOffset,ERS220Info::TailRightButOffset,ERS220Info::TailCenterButOffset,ERS220Info::BackButOffset);
+	} else if(RobotName == ERS7Info::TargetName) {
+		initButtons(500,25,ERS7Info::FrontBackButOffset,ERS7Info::RearBackButOffset,ERS7Info::FrontBackButOffset,ERS7Info::RearBackButOffset,ERS7Info::MiddleBackButOffset,ERS7Info::HeadButOffset);
 	} else {
-		serr->printf("Controller: Unsupported model!\n");
+#ifdef TGT_HAS_BUTTONS
+		cerr << "Controller: Unsupported model '" << RobotName << "'!  Appears to have buttons, but Controller doesn't know how to use them." << endl;
+#endif
 	}
 }
 
+void Controller::initButtons(unsigned fastTime, unsigned downTime, unsigned nextB, unsigned prevB, unsigned nextFastB, unsigned prevFastB, unsigned selectB, unsigned cancelB) {
+	nextItem=EventBase(EventBase::buttonEGID,nextB,EventBase::deactivateETID,0);
+	prevItem=EventBase(EventBase::buttonEGID,prevB,EventBase::deactivateETID,0);
+	nextItemFast=EventBase(EventBase::buttonEGID,nextFastB,EventBase::statusETID,fastTime);
+	prevItemFast=EventBase(EventBase::buttonEGID,prevFastB,EventBase::statusETID,fastTime);
+	selectItem=EventBase(EventBase::buttonEGID,selectB,EventBase::deactivateETID,downTime);
+	cancel=EventBase(EventBase::buttonEGID,cancelB,EventBase::deactivateETID,downTime);
+}
+
+
 bool Controller::select(ControlBase* item, const std::string& name) {
   // Depth first
   const std::vector<ControlBase*>& slots = item->getSlots();
@@ -488,31 +509,31 @@ void Controller::takeLine(const std::string& s) {
 #ifdef PLATFORM_APERIOS
 			serr->printf("!sim command invalid -- not running in simulator!\n");
 #else
-			Simulator::sendCommand(s.substr(offsets[1]));
+			ProjectInterface::sendCommand(s.substr(offsets[1]));
 #endif
 		} else
 			setNext(cmdstack.top()->takeInput(s));
 	}
 }
 
-int Controller::setConfig(const char *str) {
-	char buf[80];
-	strncpy(buf, str, 79);
-	char *value=index(buf, '=');
-	char *key=index(buf, '.');
-	if (key==NULL || value==NULL) return -1;
-	if (key>=value) return -1;
-	*key=0;
-	key++;
-	*value=0;
-	value++;
-	Config::section_t section=config->parseSection(buf);
-	if (section==Config::sec_invalid) return -2;
-	config->setValue(section, key, value, true);
-	//void *val_set=config->setValue(section, key, value, true);
-	// might want to catch setValue's return value and do
-	// something special for some config values?
-	// (such as reboot a subsystem to reload new settings)
+int Controller::setConfig(const std::string& str) {
+	string::size_type eq=str.find('=');
+	if(eq==string::npos)
+		return -2;
+	plist::ObjectBase* entry = config->resolveEntry(string_util::trim(str.substr(0,eq)));
+	if(entry==NULL) {
+		string::size_type p=str.find('.');
+		string sec=string_util::trim(str.substr(0,p));
+		string key=string_util::trim(str.substr(p+1,eq-p-1));
+		string val=string_util::trim(str.substr(eq+1));
+		if(config->setValue(sec,key,val)==NULL)
+			return -2;
+		return 0;
+	}
+	plist::PrimitiveBase* prim = dynamic_cast<plist::PrimitiveBase*>(entry);
+	if(prim==NULL)
+		return -2;
+	prim->set(string_util::trim(str.substr(eq+1)));
 	return 0;
 }
 
@@ -538,8 +559,10 @@ void Controller::deactivate() {
 	//these two lines help prevent residual display in case that was the only MotionCommand using LEDs
 	motman->setPriority(display,MotionManager::kIgnoredPriority);
 	isControlling=false;
+#ifdef TGT_HAS_LEDS
 	for(unsigned int i=LEDOffset; i<LEDOffset+NumLEDs; i++)
 		motman->setOutput(NULL,i,0.f);
+#endif
 	erouter->removeTrapper(this);
 	cmdstack.top()->pause();
 }
@@ -564,8 +587,8 @@ bool Controller::chkCmdStack() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.55 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.64 $
  * $State: Exp $
- * $Date: 2006/09/18 18:08:05 $
+ * $Date: 2007/11/18 06:47:00 $
  */
