@@ -147,17 +147,20 @@ public:
 	static int console_callback(char *buf, int bytes);  //!< called by wireless when someone has entered new data on the tekkotsu console (NOT cin)
 
 protected:
-	//! assigns appropriate values to the static event bases
+	//! calls initButtons with the appropriate button offsets for the host robot model
 	void init();
-	
+
+	//! assigns appropriate values to the static event bases
+	void initButtons(unsigned fastTime, unsigned downTime, unsigned nextB, unsigned prevB, unsigned nextFastB, unsigned prevFastB, unsigned selectB, unsigned cancelB);
+
 	//! called with each line that's entered on the tekkotsu console or from the GUI
 	void takeLine(const std::string& s);
 
 	//! called with slots (options), a name to lookup; will select the named control
-	bool Controller::select(ControlBase* item, const std::string& name);
+	bool select(ControlBase* item, const std::string& name);
 	
 	//! sets a config value - some values may require additional processing (done here) to have the new values take effect
-	int setConfig(const char *str);
+	int setConfig(const std::string& str);
 
 	//! maintains top Control
 	/*! @param next one of: @li NULL: pop() ::cmdstack @li ::cmdstack.top(): nothing @li other address: ::push(@a next)
@@ -221,10 +224,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.37 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.40 $
  * $State: Exp $
- * $Date: 2005/09/01 18:53:06 $
+ * $Date: 2007/06/28 04:36:19 $
  */
 
 #endif
