@@ -54,8 +54,8 @@ public:
 			std::string s("refresh\n");
 			s+=getName()+"\n1\n0\n0\nPower remain: ";
 			s+=tmp;
-			s+="%\nSee console output for details\n";
-			s+="status\nPower remaining: ";
+			s+="%\n0\nSee console output for details\n";
+			s+="status\n1\nPower remaining: ";
 			s+=tmp;
 			s+="%\n";
 			gui_comm->write((const byte*)s.c_str(),s.size());
@@ -68,7 +68,7 @@ public:
 	}
 	//! calls refresh() to redisplay with new information if it's not a vibration event
 	virtual void processEvent(const EventBase& event) {
-		if(event.getSourceID()!=PowerSourceID::VibrationSID)
+		if(event.getSourceID()!=PowerSrcID::VibrationSID)
 			refresh();
 	}
 	virtual ControlBase * doSelect() {
@@ -83,19 +83,19 @@ public:
 		sout->printf("\tCurrent:\t%g\n",state->sensors[PowerCurrentOffset]);
 		sout->printf("\tTemperature:\t%g\n",state->sensors[PowerThermoOffset]);
 		sout->printf("\tFlags:\t");
-		if(state->powerFlags[PowerSourceID::BatteryConnectSID])
+		if(state->powerFlags[PowerSrcID::BatteryConnectSID])
 			sout->printf("BatteryConnect ");
-		if(state->powerFlags[PowerSourceID::DischargingSID])
+		if(state->powerFlags[PowerSrcID::DischargingSID])
 			sout->printf("Discharging ");
-		if(state->powerFlags[PowerSourceID::ChargingSID])
+		if(state->powerFlags[PowerSrcID::ChargingSID])
 			sout->printf("Charging ");
-		if(state->powerFlags[PowerSourceID::ExternalPowerSID])
+		if(state->powerFlags[PowerSrcID::ExternalPowerSID])
 			sout->printf("ExternalPower ");
-		if(state->powerFlags[PowerSourceID::PowerGoodSID])
+		if(state->powerFlags[PowerSrcID::PowerGoodSID])
 			sout->printf("PowerGood ");
-		if(state->powerFlags[PowerSourceID::LowPowerWarnSID])
+		if(state->powerFlags[PowerSrcID::LowPowerWarnSID])
 			sout->printf("LowPowerWarn ");
-		if(state->powerFlags[PowerSourceID::BatteryEmptySID])
+		if(state->powerFlags[PowerSrcID::BatteryEmptySID])
 			sout->printf("BatteryEmpty ");
 		sout->printf("\n");
 		if(display_id!=MotionManager::invalid_MC_ID) {
@@ -111,10 +111,10 @@ public:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.10 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.12 $
  * $State: Exp $
- * $Date: 2005/01/25 20:06:39 $
+ * $Date: 2007/06/05 18:03:24 $
  */
 
 #endif
