@@ -5,7 +5,7 @@
 #include "ControlBase.h"
 #include "Behaviors/BehaviorBase.h"
 #include "Shared/ReferenceCounter.h"
-#include "Shared/Factory.h"
+#include "Shared/Factories.h"
 #include "Shared/debuget.h"
 #include "Events/TextMsgEvent.h"
 
@@ -178,7 +178,7 @@ private:
 
 
 //! Allows proper switching between major behaviors, calling DoStart and DoStop
-template < class B, class Al = Factory< B > >
+template < class B, class Al = typename Factory0Arg<B>::template Factory<B> >
 class BehaviorSwitchControl : public BehaviorSwitchControlBase {
 public:
 	//! constructor, can use this to toggle a single behavior on and off
@@ -237,14 +237,14 @@ protected:
 	virtual void startmine() {
 		if(!retained) {
 			Al allocator;
-			mybeh=allocator.construct();
+			mybeh=allocator();
 			mybeh->setName(getName());
 			if(behgrp!=NULL)
 				behgrp->curBehavior=mybeh;
 		} else {
 			if(mybeh==NULL) {
 				Al allocator;
-				mybeh=allocator.construct();
+				mybeh=allocator();
 				mybeh->setName(getName());
 				mybeh->AddReference();
 			}
@@ -294,10 +294,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.23 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.25 $
  * $State: Exp $
- * $Date: 2006/09/01 18:21:20 $
+ * $Date: 2007/05/22 04:24:26 $
  */
 
 #endif
