@@ -70,14 +70,18 @@ void ControlBase::refresh() {
 		ss << "refresh\n"
 			 << getName() << '\n'
 			 << options.size() << '\n';
-		for(unsigned int i=0; i<options.size(); i++)
+		for(unsigned int i=0; i<options.size(); i++) {
 			if(options[i]==NULL)
-				ss << "0\n0\n----------\n\n";
-			else 
+				ss << "0\n0\n----------\n0\n\n";
+			else {
+				std::string desc = options[i]->getDescription();
 				ss << options[i]->options.size() << '\n'
 					 << (binary_search(hilights.begin(),hilights.end(),i)?1:0) << '\n'
 					 << options[i]->getName() << '\n'
-					 << options[i]->getDescription().c_str() << '\n';
+					 << std::count(desc.begin(),desc.end(),'\n') << '\n'
+					 << desc << '\n';
+			}
+		}
 		//		do {
 		//cout << "Writing " << ss.str().size() << "...";
 		gui_comm->write((const byte*)ss.str().c_str(),ss.str().size());
@@ -207,8 +211,10 @@ ControlBase* ControlBase::doReadStdIn(const std::string& prompt/*=std::string()*
 		return this;
 	} else {
 		//Level 3: GUI
-		if(prompt.size()>0)
-			gui_comm->printf("status\n%s\n",prompt.c_str());
+		if(prompt.size()>0) {
+			unsigned int lines=std::count(prompt.begin(),prompt.end(),'\n');
+			gui_comm->printf("status\n%u\n%s\n",lines,prompt.c_str());
+		}
 		return this;
 	}
 }
@@ -262,12 +268,7 @@ ControlBase* ControlBase::takeInput(const std::string& str) {
 					clearMenu();
 					doRewrite=false;
 				}
-				if(ambiguous)
-					serr->printf("ControlBase(\"%s\")::takeInput(\"%s\") was ambiguous\n",name.c_str(),args[0].c_str());
-				else
-					serr->printf("ControlBase(\"%s\")::takeInput(\"%s\") was not a valid index or option name.\n",name.c_str(),args[0].c_str());
-				refresh();
-				return this;
+				return invalidInput(str,ambiguous);
 			} else if(choice<options.size() && options[choice]!=NULL) {
 				ambiguous=false;
 			} else {
@@ -276,12 +277,7 @@ ControlBase* ControlBase::takeInput(const std::string& str) {
 					clearMenu();
 					doRewrite=false;
 				}
-				if(ambiguous)
-					serr->printf("ControlBase(\"%s\")::takeInput(\"%s\") was ambiguous\n",name.c_str(),args[0].c_str());
-				else
-					serr->printf("ControlBase(\"%s\")::takeInput(\"%d\") is not a valid selection\n",name.c_str(),choice);
-				refresh();
-				return this;
+				return invalidInput(str,ambiguous);
 			}	
 		}
 		//see what we got...
@@ -397,6 +393,15 @@ void ControlBase::clearMenu() {
 	}
 }
 
+ControlBase* ControlBase::invalidInput(const std::string& msg, bool ambiguous) {
+	if(ambiguous)
+		serr->printf("ControlBase(\"%s\")::takeInput(\"%s\") was ambiguous\n",name.c_str(),msg.c_str());
+	else
+		serr->printf("ControlBase(\"%s\")::takeInput(\"%s\") was not a valid index or option name.\n",name.c_str(),msg.c_str());
+	refresh();
+	return this;
+}
+
 float ControlBase::hilightsAvg() const {
 	if(hilights.size()==0)
 		return -1;
@@ -412,9 +417,9 @@ float ControlBase::hilightsAvg() const {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.14 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.16 $
  * $State: Exp $
- * $Date: 2006/09/18 18:07:54 $
+ * $Date: 2007/01/30 22:56:18 $
  */
 
