@@ -68,7 +68,7 @@ public:
 	//! @name Constructors/Destructors
 
 	ControlBase() : name("(null name)"), description(), hilights(), options(), doRewrite(false), display_id(MotionManager::invalid_MC_ID), gui_comm(NULL) {} //!< Contructor
-	ControlBase(const std::string& n) : name(n), description(), hilights(), options(), doRewrite(false), display_id(MotionManager::invalid_MC_ID), gui_comm(NULL) {} //!< Contructor, initializes with a name
+	ControlBase(const std::string& n) : name(n), description((n.size()>16)?n:std::string()), hilights(), options(), doRewrite(false), display_id(MotionManager::invalid_MC_ID), gui_comm(NULL) {} //!< Contructor, initializes with a name
 	ControlBase(const std::string& n, const std::string& d) : name(n), description(d), hilights(), options(), doRewrite(false), display_id(MotionManager::invalid_MC_ID), gui_comm(NULL) {} //!< Contructor, initializes with a name
 
 	//! Destructor
@@ -142,6 +142,11 @@ protected:
 		
 	//! clears the display (if use_VT100 is on)
 	virtual void clearMenu();
+	
+	//! called by takeInput if the input doesn't match any slots or matches multiple slots -- the ControlBase implementation displays an error and returns itself
+	/*! @param msg the input originally sent to takeInput()
+	 *  @param ambiguous true if the input matched more than one item, false if it didn't match any */
+	virtual ControlBase* invalidInput(const std::string& msg, bool ambiguous);
 
 	//! returns the average of the hilighted indicies - used to know to play the "next" sound, or the "prev" sound when the hilight changes
 	float hilightsAvg() const;
@@ -167,9 +172,9 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.22 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.24 $
  * $State: Exp $
- * $Date: 2004/11/04 03:01:31 $
+ * $Date: 2006/10/30 21:26:23 $
  */
 #endif
