@@ -19,12 +19,14 @@ Socket* EventLogger::logSocket=NULL;
 unsigned int EventLogger::logSocketRefCount=0;
 int EventLogger::port=10080;
 EventLogger * EventLogger::theOne=NULL;
+EventLogger::queuedEvents_t EventLogger::queuedEvents;
+EventLogger::transStack_t EventLogger::transStack;
 
 EventLogger::StateMachineListener EventLogger::smProcess;
 
 EventLogger::EventLogger()
 	: ControlBase("Event Logger","Allows you to see/log all of the un-trapped events as they are generated"),
-		logfilePath(), logfile(), verbosity(0), expected(), listen(), queuedEvents() {
+		logfilePath(), logfile(), verbosity(0), listen() {
 	for(unsigned int i=0; i<EventBase::numEGIDs; i++) {
 		std::string tmp=EventBase::EventGeneratorNames[i];
 		pushSlot(new NullControl(("[ ] "+tmp).c_str(),"Show/hide events from "+tmp));
@@ -36,7 +38,7 @@ EventLogger::EventLogger()
 	if(logSocket==NULL) {
 		theOne=this;
 		ASSERT(logSocketRefCount==0,"logSocket is NULL, ref count is non-zero");
-		logSocket=wireless->socket(SocketNS::SOCK_STREAM,1024,1<<15);
+		logSocket=wireless->socket(Socket::SOCK_STREAM,1024,1<<15);
 		wireless->setDaemon(logSocket);
 		wireless->setReceiver(logSocket, callback);
 		wireless->listen(logSocket,port);
@@ -45,7 +47,6 @@ EventLogger::EventLogger()
 }
 
 EventLogger::~EventLogger() {
-	expected.clear();
 	while(!queuedEvents.empty())
 		queuedEvents.pop();
 	clearSlots();
@@ -104,7 +105,6 @@ void EventLogger::processEvent(const EventBase& event) {
 	if(options[EventBase::numEGIDs+2]->getName()[1]=='X')
 		sout->printf("EVENT: %s\n",logdata.c_str());
 	if(logSocket!=NULL && wireless->isConnected(logSocket->sock)) {
-		xmlDoc * doc = xmlNewDoc((const xmlChar*)"1.0");
 		xmlNode * cur = xmlNewNode(NULL,(const xmlChar*)"");
 		xmlSetProp(cur,(const xmlChar*)"type",(const xmlChar*)"log");
 		xmlNode * desc = xmlNewNode(NULL,(const xmlChar*)"param");
@@ -113,7 +113,9 @@ void EventLogger::processEvent(const EventBase& event) {
 		xmlSetProp(desc,(const xmlChar*)"name",(const xmlChar*)"description");
 		xmlSetProp(desc,(const xmlChar*)"value",(const xmlChar*)event.getDescription(true,3).c_str());
 		xmlBuffer* buf=xmlBufferCreate();
+		xmlDoc * doc = xmlNewDoc((const xmlChar*)"1.0");
 		int n=xmlNodeDump(buf,doc,cur,0,1);
+		xmlFreeNode(cur);
 		xmlFreeDoc(doc);
 		byte * nbuf = logSocket->getWriteBuffer(n+1);
 		if(nbuf!=NULL) {
@@ -125,101 +127,79 @@ void EventLogger::processEvent(const EventBase& event) {
 	}
 	checkLogFile();
 	if(logfile)
-		logfile << logdata << endl;
+		logfile << logdata << std::endl;
 }
 
 void EventLogger::logImage(FilterBankGenerator& fbg, unsigned int layer, unsigned int channel, const BehaviorBase* source/*=NULL*/) {
-	if(logSocket!=NULL && wireless->isConnected(logSocket->sock)) {
+	if(logSocket==NULL || !wireless->isConnected(logSocket->sock))
+		return;
 
-		char * binbuf;
-		unsigned int len;
-		if(JPEGGenerator* jpeg=dynamic_cast<JPEGGenerator*>(&fbg)) {
-			binbuf=(char*)jpeg->getImage(layer,channel);
-			len=jpeg->getImageSize(layer,channel);
-		} else {
-			fbg.selectSaveImage(layer,channel);
-			len=fbg.getBinSize();
-			binbuf=new char[len];
-			fbg.saveBuffer(binbuf,len);
-		}
-		string b64buf=base64::encode(binbuf,len);
-		if(binbuf!=(char*)fbg.getImage(layer,channel)) //cached, should be a simple return
-			delete [] binbuf;
-		
-		xmlDoc * doc = xmlNewDoc((const xmlChar*)"1.0");
-		xmlNode * cur = xmlNewNode(NULL,(const xmlChar*)"event");
-		xmlSetProp(cur,(const xmlChar*)"type",(const xmlChar*)"image");
-		if(source!=NULL)
-			xmlSetProp(cur,(const xmlChar*)"sid",(const xmlChar*)source->getName().c_str());
-		char timebuf[20];
-		snprintf(timebuf,20,"%d",get_time());
-		xmlSetProp(cur,(const xmlChar*)"time",(const xmlChar*)timebuf);
-		xmlNewChild(cur,NULL,(const xmlChar*)"image",(const xmlChar*)b64buf.c_str());
-		xmlBuffer* buf=xmlBufferCreate();
-		int n=xmlNodeDump(buf,doc,cur,0,1);
-		xmlFreeDoc(doc);
-		byte * nbuf = logSocket->getWriteBuffer(n+1);
-		if(nbuf!=NULL) {
-			memcpy(nbuf,xmlBufferContent(buf),n);
-			nbuf[n]='\n';
-			logSocket->write(n+1);
-		}
-		xmlBufferFree(buf);
-	}		
+	char * binbuf;
+	unsigned int len;
+	if(JPEGGenerator* jpeg=dynamic_cast<JPEGGenerator*>(&fbg)) {
+		binbuf=(char*)jpeg->getImage(layer,channel);
+		len=jpeg->getImageSize(layer,channel);
+	} else {
+		fbg.selectSaveImage(layer,channel);
+		len=fbg.getBinSize();
+		binbuf=new char[len];
+		fbg.saveBuffer(binbuf,len);
+	}
+	std::string b64buf=base64::encode(binbuf,len);
+	if(binbuf!=(char*)fbg.getImage(layer,channel)) //cached, should be a simple return
+		delete [] binbuf;
+	
+	xmlNode * cur = xmlNewNode(NULL,(const xmlChar*)"event");
+	xmlSetProp(cur,(const xmlChar*)"type",(const xmlChar*)"image");
+	if(source!=NULL)
+		xmlSetProp(cur,(const xmlChar*)"sid",(const xmlChar*)source->getName().c_str());
+	char timebuf[20];
+	snprintf(timebuf,20,"%d",get_time());
+	xmlSetProp(cur,(const xmlChar*)"time",(const xmlChar*)timebuf);
+	xmlNewChild(cur,NULL,(const xmlChar*)"image",(const xmlChar*)b64buf.c_str());
+	queuedEvents.push(cur);
+	if(transStack.empty())
+		dumpQueuedEvents();
 }
 
 void EventLogger::logMessage(std::string msg, const BehaviorBase* source/*=NULL*/, const char* icon/*=NULL*/, unsigned int placement/*=0*/) {
-	if(logSocket!=NULL && wireless->isConnected(logSocket->sock)) {
-		xmlDoc * doc = xmlNewDoc((const xmlChar*)"1.0");
-		xmlNode * cur = xmlNewNode(NULL,(const xmlChar*)"event");
-		xmlSetProp(cur,(const xmlChar*)"type",(const xmlChar*)"userlog");
-		if(source!=NULL)
-			xmlSetProp(cur,(const xmlChar*)"sid",(const xmlChar*)source->getName().c_str());
-		if(icon!=NULL)
-			xmlSetProp(cur,(const xmlChar*)"icon",(const xmlChar*)icon);
-		const unsigned int len=20;
-		char sbuf[len];
-		snprintf(sbuf,len,"%d",placement);
-		xmlSetProp(cur,(const xmlChar*)"voff",(const xmlChar*)sbuf);
-		snprintf(sbuf,len,"%d",get_time());
-		xmlSetProp(cur,(const xmlChar*)"time",(const xmlChar*)sbuf);
-		xmlNodeSetContent(cur,(const xmlChar*)msg.c_str());
-		xmlBuffer* buf=xmlBufferCreate();
-		int n=xmlNodeDump(buf,doc,cur,0,1);
-		xmlFreeDoc(doc);
-		byte * nbuf = logSocket->getWriteBuffer(n+1);
-		if(nbuf!=NULL) {
-			memcpy(nbuf,xmlBufferContent(buf),n);
-			nbuf[n]='\n';
-			logSocket->write(n+1);
-		}
-		xmlBufferFree(buf);
-	}		
+	if(logSocket==NULL || !wireless->isConnected(logSocket->sock))
+		return;
+
+	xmlNode * cur = xmlNewNode(NULL,(const xmlChar*)"event");
+	xmlSetProp(cur,(const xmlChar*)"type",(const xmlChar*)"userlog");
+	if(source!=NULL)
+		xmlSetProp(cur,(const xmlChar*)"sid",(const xmlChar*)source->getName().c_str());
+	if(icon!=NULL)
+		xmlSetProp(cur,(const xmlChar*)"icon",(const xmlChar*)icon);
+	const unsigned int len=20;
+	char sbuf[len];
+	snprintf(sbuf,len,"%d",placement);
+	xmlSetProp(cur,(const xmlChar*)"voff",(const xmlChar*)sbuf);
+	snprintf(sbuf,len,"%d",get_time());
+	xmlSetProp(cur,(const xmlChar*)"time",(const xmlChar*)sbuf);
+	xmlNodeSetContent(cur,(const xmlChar*)msg.c_str());
+	queuedEvents.push(cur);
+	if(transStack.empty())
+		dumpQueuedEvents();
 }
 
 void EventLogger::logWebcam(const BehaviorBase* source/*=NULL*/) {
-	if(logSocket!=NULL && wireless->isConnected(logSocket->sock)) {
-		xmlDoc * doc = xmlNewDoc((const xmlChar*)"1.0");
-		xmlNode * cur = xmlNewNode(NULL,(const xmlChar*)"event");
-		xmlSetProp(cur,(const xmlChar*)"type",(const xmlChar*)"webcam");
-		if(source!=NULL)
-			xmlSetProp(cur,(const xmlChar*)"sid",(const xmlChar*)source->getName().c_str());
-		const unsigned int len=20;
-		char sbuf[len];
-		snprintf(sbuf,len,"%d",get_time());
-		xmlSetProp(cur,(const xmlChar*)"time",(const xmlChar*)sbuf);
-		xmlNodeSetContent(cur,(const xmlChar*)" ");
-		xmlBuffer* buf=xmlBufferCreate();
-		int n=xmlNodeDump(buf,doc,cur,0,1);
-		xmlFreeDoc(doc);
-		byte * nbuf = logSocket->getWriteBuffer(n+1);
-		if(nbuf!=NULL) {
-			memcpy(nbuf,xmlBufferContent(buf),n);
-			nbuf[n]='\n';
-			logSocket->write(n+1);
-		}
-		xmlBufferFree(buf);
-	}		
+	if(logSocket==NULL || !wireless->isConnected(logSocket->sock))
+		return;
+
+	xmlNode * cur = xmlNewNode(NULL,(const xmlChar*)"event");
+	xmlSetProp(cur,(const xmlChar*)"type",(const xmlChar*)"webcam");
+	if(source!=NULL)
+		xmlSetProp(cur,(const xmlChar*)"sid",(const xmlChar*)source->getName().c_str());
+	const unsigned int len=20;
+	char sbuf[len];
+	snprintf(sbuf,len,"%d",get_time());
+	xmlSetProp(cur,(const xmlChar*)"time",(const xmlChar*)sbuf);
+	xmlNodeSetContent(cur,(const xmlChar*)" ");
+	queuedEvents.push(cur);
+	if(transStack.empty())
+		dumpQueuedEvents();
 }
 
 void EventLogger::clearSlots() {
@@ -255,50 +235,53 @@ void EventLogger::checkLogFile() {
 }
 
 
-void EventLogger::spider(const StateNode* n, unsigned int depth/*=0*/) {
+void EventLogger::spider(const StateNode* n, xmlNode* parent/*=NULL*/) {
 	if(n==NULL)
 		return;
 
+	xmlNode * cur = xmlNewNode(NULL,(const xmlChar*)"state");
+	ASSERTRET(cur!=NULL,"EventLogger::spider() could not allocate new xml state node");
+	xmlSetProp(cur,(const xmlChar*)"class",(const xmlChar*)n->getClassName().c_str());
+	xmlSetProp(cur,(const xmlChar*)"id",(const xmlChar*)n->getName().c_str());
+	
 	const std::vector<StateNode*>& subnodes=n->getNodes();
-	if(subnodes.size()==0) {
-		// it's a leaf node, no subnodes or transitions between them
-		indent(depth);
-		logSocket->printf("<state class=\"%s\" id=\"%s\" />\n", n->getClassName().c_str(), n->getName().c_str());
-	} else {
-
-		// first output current node's info
-		indent(depth);
-		logSocket->printf("<state class=\"%s\" id=\"%s\">\n", n->getClassName().c_str(), n->getName().c_str());
+	if(subnodes.size()>0) {
+		// it's not a leaf node, has subnodes and transitions between them
 
 		std::set<const Transition*> transitions;
 		// now recurse on sub-nodes, extracting all of the subnodes transitions
 		for(unsigned int i=0; i<subnodes.size(); i++) {
-			spider(subnodes[i],depth+1);
+			spider(subnodes[i],cur);
 			const std::vector<Transition*>& curt=subnodes[i]->getTransitions();
 			transitions.insert(curt.begin(),curt.end());
 		}
 
 		// now output transitions between subnodes we collected in previous step
 		for(std::set<const Transition*>::const_iterator it=transitions.begin(); it!=transitions.end(); it++) {
-			indent(depth+1);
-			logSocket->printf("<transition class=\"%s\" id=\"%s\">\n", (*it)->getClassName().c_str(), (*it)->getName().c_str());
-			const std::vector<StateNode*>& incoming=(*it)->getSources();
-			for(unsigned int i=0; i<incoming.size(); i++) {
-				indent(depth+2);
-				logSocket->printf("<source>%s</source>\n",incoming[i]->getName().c_str());
+			xmlNode * t = xmlAddChild(cur,xmlNewNode(NULL,(const xmlChar*)"transition"));
+			ASSERTRET(t!=NULL,"EventLogger::spider() could not allocate new xml transition node");
+			xmlSetProp(t,(const xmlChar*)"class",(const xmlChar*)(*it)->getClassName().c_str());
+			xmlSetProp(t,(const xmlChar*)"id",(const xmlChar*)(*it)->getName().c_str());
+			
+			typedef std::vector<StateNode*> statevec_t;
+			const statevec_t& incoming=(*it)->getSources();
+			for(statevec_t::const_iterator nit=incoming.begin(); nit!=incoming.end(); ++nit) {
+				xmlNode * sn = xmlAddChild(t,xmlNewNode(NULL,(const xmlChar*)"source"));
+				ASSERTRET(sn!=NULL,"EventLogger::spider() could not allocate new xml transition source node");
+				xmlNodeSetContent(sn,(const xmlChar*)(*nit)->getName().c_str());
 			}
-			const std::vector<StateNode*>& outgoing=(*it)->getDestinations();
-			for(unsigned int i=0; i<outgoing.size(); i++) {
-				indent(depth+2);
-				logSocket->printf("<destination>%s</destination>\n",outgoing[i]->getName().c_str());
+			const statevec_t& outgoing=(*it)->getDestinations();
+			for(statevec_t::const_iterator nit=outgoing.begin(); nit!=outgoing.end(); ++nit) {
+				xmlNode * sn = xmlAddChild(t,xmlNewNode(NULL,(const xmlChar*)"destination"));
+				ASSERTRET(sn!=NULL,"EventLogger::spider() could not allocate new xml transition source node");
+				xmlNodeSetContent(sn,(const xmlChar*)(*nit)->getName().c_str());
 			}
-			indent(depth+1);
-			logSocket->printf("</transition>\n");
 		}
-
-		indent(depth);
-		logSocket->printf("</state>\n");
 	}
+	if(parent==NULL)
+		dumpNode(cur);
+	else
+		xmlAddChild(parent,cur);
 }
 	
 bool EventLogger::isListening(const StateNode* n) {
@@ -389,13 +372,13 @@ int EventLogger::callback(char *buf, int bytes) {
   return 0;
 }
 
-void EventLogger::processStateMachineEvent(const EventBase& event) {
+void EventLogger::processStateMachineEvent(const EventBase& e) {
 	if(!wireless->isConnected(logSocket->sock) || listen.size()==0)
 		return;
-
-	if(event.getGeneratorID()==EventBase::stateTransitionEGID) {
+	
+	if(e.getGeneratorID()==EventBase::stateTransitionEGID) {
 		bool care=false;
-		const Transition * trans = reinterpret_cast<Transition*>(event.getSourceID());
+		const Transition * trans = reinterpret_cast<Transition*>(e.getSourceID());
 		const std::vector<StateNode*>& incoming=trans->getSources();
 		const std::vector<StateNode*>& outgoing=trans->getDestinations();
 		for(std::vector<StateNode*>::const_iterator it=incoming.begin(); it!=incoming.end() && !care; it++)
@@ -404,62 +387,75 @@ void EventLogger::processStateMachineEvent(const EventBase& event) {
 			care=isListening(*it);
 		if(!care)
 			return;
-
-		if(expected.size()!=0) {
-			queuedEvents.push(event);
+		
+		if(e.getTypeID()==EventBase::activateETID) {
+			xmlNode * root = xmlNewNode(NULL,(const xmlChar*)"event");
+			xmlNode * fire = xmlAddChild(root,xmlNewNode(NULL,(const xmlChar*)"fire"));
+			xmlSetProp(fire,(const xmlChar*)"id",(const xmlChar*)trans->getName().c_str());
+			const unsigned int len=20;
+			char sbuf[len];
+			snprintf(sbuf,len,"%d",e.getTimeStamp());
+			xmlSetProp(fire,(const xmlChar*)"time",(const xmlChar*)sbuf);
+			transStack.push(root);
+			queuedEvents.push(root);
 		} else {
-			logSocket->printf("<event>\n");
-			indent(1);
-			logSocket->printf("<fire id=\"%s\" time=\"%d\" />\n",trans->getName().c_str(),event.getTimeStamp());
-			expected.insert(incoming.begin(),incoming.end());
-			expected.insert(outgoing.begin(),outgoing.end());
-			while(queuedEvents.size()>0) {
-				EventBase qe=queuedEvents.front();
-				queuedEvents.pop();
-				processEvent(qe);
-			}
+			ASSERTRET(!transStack.empty(),"got a transition deactivate that I should care about, but I didn't see the activate");
+			transStack.pop();
+			if(transStack.empty())
+				dumpQueuedEvents();
 		}
-
-	} else if(event.getGeneratorID()==EventBase::stateMachineEGID) {
-		if(event.getTypeID()==EventBase::statusETID)
+		
+	} else if(e.getGeneratorID()==EventBase::stateMachineEGID) {
+		if(e.getTypeID()==EventBase::statusETID)
+			return;
+		const StateNode * beh=reinterpret_cast<StateNode*>(e.getSourceID());
+		if(!isListening(beh))
+			return;
+		if(e.getTypeID()!=EventBase::activateETID && e.getTypeID()!=EventBase::deactivateETID) {
+			serr->printf("WARNING: Unrecognized TypeID %d\n",e.getTypeID());
 			return;
-		const StateNode * beh=reinterpret_cast<StateNode*>(event.getSourceID());
-		expected_t::iterator it=expected.find(beh);
-		char * format;
-		if(isListening(beh)) {
-			if(it==expected.end()) { //if not found
-				if(queuedEvents.size()==0)
-					format="<event><state%s id=\"%s\" time=\"%d\" /></event>\n"; // unexpected
-				else {
-					queuedEvents.push(event);
-					return;
-				}
-			} else
-				format="  <state%s id=\"%s\" time=\"%d\" />\n"; // expected as part of transition
-			if(event.getTypeID()==EventBase::activateETID)
-				logSocket->printf(format,"start",beh->getName().c_str(),event.getTimeStamp());
-			else if(event.getTypeID()==EventBase::deactivateETID)
-				logSocket->printf(format,"stop",beh->getName().c_str(),event.getTimeStamp());
-			else
-				serr->printf("WARNING: Unrecognized TypeID %d\n",event.getTypeID());
 		}
-		if(it!=expected.end()) { //was found
-			expected.erase(it);
-			if(expected.size()==0) {
-				logSocket->printf("</event>\n");
-				while(queuedEvents.size()>0) {
-					EventBase qe=queuedEvents.front();
-					queuedEvents.pop();
-					processEvent(qe);
-				}
-			}
+		
+		xmlNode * root = transStack.empty() ? xmlNewNode(NULL,(const xmlChar*)"event") : transStack.top();
+		const char* sttypestr = (e.getTypeID()==EventBase::activateETID) ? "statestart" : "statestop";
+		xmlNode * st = xmlAddChild(root,xmlNewNode(NULL,(const xmlChar*)sttypestr));
+		xmlSetProp(st,(const xmlChar*)"id",(const xmlChar*)beh->getName().c_str());
+		const unsigned int len=20;
+		char sbuf[len];
+		snprintf(sbuf,len,"%d",e.getTimeStamp());
+		xmlSetProp(st,(const xmlChar*)"time",(const xmlChar*)sbuf);
+		
+		if(transStack.empty()) {
+			queuedEvents.push(root);
+			dumpQueuedEvents();
 		}
-
+		
 	} else {
-		serr->printf("WARNING: Unknown event %s (%s)\n",event.getName().c_str(),event.getDescription().c_str());
+		serr->printf("WARNING: Unknown event %s (%s)\n",e.getName().c_str(),e.getDescription().c_str());
 	}
 }
 
+void EventLogger::dumpQueuedEvents() {
+	xmlDoc * doc = xmlNewDoc((const xmlChar*)"1.0");
+	while(!queuedEvents.empty()) {
+		dumpNode(queuedEvents.front(),doc);
+		queuedEvents.pop();
+	}
+	xmlFreeDoc(doc);
+}
+
+void EventLogger::dumpNode(xmlNode* node, xmlDoc* doc/*=NULL*/) {
+	xmlBuffer* buf=xmlBufferCreate();
+	int n=xmlNodeDump(buf,doc,node,0,1);
+	byte * nbuf = logSocket->getWriteBuffer(n+1);
+	if(nbuf!=NULL) {
+		memcpy(nbuf,xmlBufferContent(buf),n);
+		nbuf[n]='\n';
+		logSocket->write(n+1);
+	}
+	xmlBufferFree(buf);
+	xmlFreeNode(node);
+}
 
 
 
@@ -469,8 +465,8 @@ void EventLogger::processStateMachineEvent(const EventBase& event) {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.22 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.25 $
  * $State: Exp $
- * $Date: 2006/09/18 18:07:54 $
+ * $Date: 2007/11/11 23:57:18 $
  */
