@@ -1,4 +1,6 @@
 #include "FileBrowserControl.h"
+#include "NullControl.h"
+#include "Shared/Config.h"
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <unistd.h>
@@ -39,25 +41,49 @@ ControlBase* FileBrowserControl::doSelect() {
 }
 
 ControlBase * FileBrowserControl::takeInput(const std::string& msg) {
-	if(options.size()==1 && options.front()==NULL)
+	if(msg.size()==0)
+		return this;
+	if(msg.find('/')==string::npos) {
+		if(options.size()==1 && options.front()==NULL)
+			rebuildmenu();
+		return ControlBase::takeInput(msg);
+	} else {
+		string::size_type pos=msg.rfind('/');
+		if(msg[0]=='/') {
+			if(msg.substr(0,root.size())!=root)
+				return this;
+			if(msg.size()>root.size() && msg[root.size()]!='/')
+				return this;
+			paths.clear();
+			if(pos<=root.size())
+				return this;
+			appendPath(msg.substr(root.size(),pos-root.size()));
+		} else {
+			appendPath(msg.substr(0,pos));
+		}
 		rebuildmenu();
-	return ControlBase::takeInput(msg);
+		if(msg.size()>pos+1)
+			return ControlBase::takeInput(msg.substr(pos+1));
+		return this;
+	}
 }
 
 void FileBrowserControl::setRoot(const std::string& path) {
-	root=path;
+	root=config->portPath(path);
 	if(root[root.size()-1]=='/')
 		root.erase(root.size()-1);
 	paths.clear();
 }
 
 
-void FileBrowserControl::setPath(const std::string& path) {
-	for(unsigned int i=0; i<path.size(); i++)
+void FileBrowserControl::appendPath(const std::string& path) {
+	paths.push_back(std::string());
+	for(unsigned int i=0; i<path.size(); i++) {
 		if(path[i]!='/')
 			paths.back().append(1,path[i]);
 		else if(paths.back().size()!=0)
 			paths.push_back(std::string());
+	}
 }
 
 
@@ -107,8 +133,7 @@ void FileBrowserControl::rebuildmenu() {
 	clearSlots();
 	DIR* dir=opendir(makePath().c_str());
 	if(dir==NULL) {
-		pushSlot(new ControlBase("Bad Path"));
-		cout << "bad path: " << makePath() << endl;
+		pushSlot(new NullControl("Bad Path: "+makePath(),makePath(),this));
 		return;
 	}
 	if(paths.size()!=0 && recurse) {
@@ -116,7 +141,7 @@ void FileBrowserControl::rebuildmenu() {
 		std::string path=makePath("..");
 		int err=stat(path.c_str(),&s);
 		if(err==0 && s.st_mode&S_IFDIR)
-			pushSlot(new ControlBase(".."));
+			pushSlot(new NullControl("..","go up a directory level",this));
 	}
 	struct dirent * ent=readdir(dir);
 	while(ent!=NULL) {
@@ -130,18 +155,18 @@ void FileBrowserControl::rebuildmenu() {
 			}
 			if(s.st_mode&S_IFDIR) {
 				if(recurse)
-					pushSlot(new ControlBase(std::string(ent->d_name).append(1,'/')));
+					pushSlot(new NullControl(std::string(ent->d_name).append(1,'/'),makePath(ent->d_name),this));
 			} else {
 				std::string nm=(makePath(ent->d_name));
 				if(match(nm,filter))
-					pushSlot(new ControlBase(ent->d_name));
+					pushSlot(new NullControl(ent->d_name,makePath(ent->d_name),this));
 			}
 		}
 		ent=readdir(dir);
 	}
 	closedir(dir);
 	if(options.size()==0)
-		pushSlot(new ControlBase("[empty directory]"));
+		pushSlot(new NullControl("[empty directory]",makePath(),this));
 	else {
 		hilights.push_back(0);
 		/*	for(unsigned int i=0; i<hilights.size(); i++) {
@@ -160,9 +185,9 @@ void FileBrowserControl::rebuildmenu() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.10 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.12 $
  * $State: Exp $
- * $Date: 2005/02/02 18:20:27 $
+ * $Date: 2007/01/29 01:16:57 $
  */
 
