@@ -27,10 +27,10 @@ public:
 	void setRecurse(bool r) { recurse=r; }                 //!< sets #recurse
 	bool getRecurse() const { return recurse; }            //!< returns #recurse
 
-	void setRoot(const std::string& path);                 //!< sets #root
+	void setRoot(const std::string& path);                 //!< sets #root, clears #paths
 	std::string getRoot() const { return root; }           //!< returns #root
 
-	void setPath(const std::string& path);                 //!< sets #paths
+	void appendPath(const std::string& path);                 //!< adds entries to #paths (location relative to #root)
 	
 	void setFilter(const std::string& filt) {filter=filt;} //!< sets #filter; remember can only use one wildcard, e.g. *.ext or filename.ext or filename*
 	//@}
@@ -72,10 +72,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.10 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.11 $
  * $State: Exp $
- * $Date: 2004/01/14 20:43:44 $
+ * $Date: 2006/10/30 21:26:45 $
  */
 
 #endif
