@@ -10,15 +10,15 @@ class FileInputControl : public FileBrowserControl {
  public:
 	//! Constructor
 	FileInputControl()
-		: FileBrowserControl("Select file","Select a file","/ms"), file(NULL), myfile()
+		: FileBrowserControl("Select file","Select a file","/"), file(NULL), myfile(), acceptNonExistant(false)
 	{}
 
 	//! Constructor
 	FileInputControl(const std::string& nm, const std::string& desc, const std::string& path, std::string* store=NULL)
-		: FileBrowserControl(nm,desc,path), file(store), myfile()
+		: FileBrowserControl(nm,desc,path), file(store), myfile(), acceptNonExistant(false)
 	{}
 
-	//! returns the path to file last selected
+	//! returns the path to file last selected; use takeInput() to assign to this
 	virtual const std::string& getLastInput() { return myfile; }
 
 	//! clears the last input (i.e. so you can easily tell later if new input is entered)
@@ -27,6 +27,11 @@ class FileInputControl : public FileBrowserControl {
 	//! pass pointer to an external string you wish to have set when a file is selected; NULL otherwise
 	virtual void setStore(std::string* store) { file=store; }
 	
+	//! sets #acceptNonExistant
+	virtual void setAcceptNonExistant(bool b) { acceptNonExistant=b; }
+	//! returns #acceptNonExistant
+	virtual bool getAcceptNonExistant() const { return acceptNonExistant; }
+	
 protected:
 	virtual ControlBase* selectedFile(const std::string& f) {
 		myfile=f;
@@ -34,9 +39,15 @@ protected:
 			*file=f;
 		return NULL;
 	}
+	virtual ControlBase* invalidInput(const std::string& msg, bool ambiguous) {
+		if(!acceptNonExistant)
+			return FileBrowserControl::invalidInput(msg,ambiguous);
+		return selectedFile(makePath(msg));
+	}
 
 	std::string* file;  //!< if we're supposed to store in an external string, this will point to it, otherwise NULL
 	std::string myfile; //!< stores last file selected
+	bool acceptNonExistant; //!< if true, will set #file and #myfile to "invalid" inputs as well -- i.e. inputs that don't correspond to any current file (so user can request a new one)
 
 private:
 	FileInputControl(const FileInputControl& ); //!< don't call
@@ -48,10 +59,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.2 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.4 $
  * $State: Exp $
- * $Date: 2004/03/23 00:55:01 $
+ * $Date: 2007/01/29 01:16:57 $
  */
 
 #endif
