@@ -14,15 +14,15 @@ public:
 
 	//!Constructor
 	LoadCalibration(WalkMC::CalibrationParam* calp)
-		: FileBrowserControl("Load Calibration...","",config->portPath(config->motion.root)), cp(calp)
+		: FileBrowserControl("Load Calibration...","",config->motion.root), cp(calp)
 	{ setFilter("*.txt"); }
 	//!Constructor
 	LoadCalibration(const std::string& n,WalkMC::CalibrationParam* calp)
-		: FileBrowserControl(n,"",config->portPath(config->motion.root)), cp(calp)
+		: FileBrowserControl(n,"",config->motion.root), cp(calp)
 	{ setFilter("*.txt"); }
 	//!Constructor
 	LoadCalibration(const std::string& n, const std::string& d,WalkMC::CalibrationParam* calp)
-		: FileBrowserControl(n,d,config->portPath(config->motion.root)), cp(calp)
+		: FileBrowserControl(n,d,config->motion.root), cp(calp)
 	{ setFilter("*.txt"); }
 
 protected:
@@ -86,10 +86,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.5 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.6 $
  * $State: Exp $
- * $Date: 2005/06/06 23:05:51 $
+ * $Date: 2007/01/29 01:16:57 $
  */
 
 #endif
