@@ -7,7 +7,9 @@
 #include "Motion/MMAccessor.h"
 #include "Motion/EmergencyStopMC.h"
 #include "Events/EventRouter.h"
-#include "Motion/LedMC.h"
+#ifdef TGT_HAS_LEDS
+#  include "Motion/LedMC.h"
+#endif
 #include "Sound/SoundManager.h"
 #include <string>
 
@@ -17,7 +19,7 @@ class LoadPostureControl : public FileBrowserControl, public EventListener {
  public:
 	//! Constructor
 	LoadPostureControl(const std::string& n, MotionManager::MC_ID estop_id)
-		: FileBrowserControl(n,"Loads a posture from user-selected file",config->portPath(config->motion.root)),
+		: FileBrowserControl(n,"Loads a posture from user-selected file",config->motion.root),
 			estopid(estop_id), ledid(MotionManager::invalid_MC_ID), file()
 	{
 		setFilter("*.pos");
@@ -27,6 +29,7 @@ class LoadPostureControl : public FileBrowserControl, public EventListener {
 	virtual ~LoadPostureControl() {
 		erouter->removeListener(this);
 		motman->removeMotion(ledid);
+		ledid=MotionManager::invalid_MC_ID;
 	}
 
 	//! only called when e-stop has been turned off and we're waiting to load a file
@@ -55,11 +58,19 @@ protected:
 		} else {
 			//we have to wait for the estop to be turned off
 			sndman->playFile("donkey.wav");
+#ifdef TGT_HAS_LEDS
 			SharedObject<LedMC> led;
 			led->cset(FaceLEDMask,0);
-			led->cycle(BotLLEDMask,1000,3,0,0);
-			led->cycle(BotRLEDMask,1000,3,0,500);
+			unsigned int botl = capabilities.findButtonOffset(ERS210Info::buttonNames[ERS210Info::BotLLEDOffset]);
+			unsigned int botr = capabilities.findButtonOffset(ERS210Info::buttonNames[ERS210Info::BotRLEDOffset]);
+			if(botl==-1U || botr==-1U) {
+				botl=LEDOffset;
+				botr=NumLEDs>1 ? botl+1 : botl;
+			}
+			led->cycle(1<<(botl-LEDOffset),1000,3,0,0);
+			led->cycle(1<<(botr-LEDOffset),1000,3,0,500);
 			ledid=motman->addPersistentMotion(led);
+#endif
 			erouter->addListener(this,EventBase::estopEGID,estopid,EventBase::deactivateETID);
 		}
 		return this;
@@ -75,10 +86,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.18 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.21 $
  * $State: Exp $
- * $Date: 2006/09/18 18:07:54 $
+ * $Date: 2007/08/05 16:16:04 $
  */
 
 #endif
