@@ -12,7 +12,7 @@ class LoadWalkControl : public FileBrowserControl {
 public:
 	//! constructor, pass the MC_ID of the WalkMC which you want to save
 	LoadWalkControl(const std::string& n, MotionManager::MC_ID w)
-		: FileBrowserControl(n,"Loads a set of walk parameters from a file specified by user",config->portPath(config->motion.root)), walk_id(w), thewalk(NULL)
+		: FileBrowserControl(n,"Loads a set of walk parameters from a file specified by user",config->motion.root), walk_id(w), thewalk(NULL)
 	{
 		setFilter("*.prm");
 	}
@@ -57,10 +57,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.11 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.12 $
  * $State: Exp $
- * $Date: 2006/09/09 04:32:17 $
+ * $Date: 2007/01/29 01:16:57 $
  */
 
 #endif
