@@ -24,7 +24,7 @@ public:
 	
 	//! stops listening for power events and sets display to invalid
 	virtual void pause() {
-		erouter->removeListener(this);
+		erouter->remove(this);
 		ControlBase::pause();
 	}
 	//! calls report()
@@ -60,7 +60,7 @@ public:
 		ControlBase::refresh();
 	}
 	virtual void deactivate() {
-		erouter->removeListener(this);
+		erouter->remove(this);
 		ControlBase::deactivate();
 	}
 	//! refresh the control whenever an event is received
@@ -77,10 +77,10 @@ public:
  * @author ejt (UI repackaging)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.4 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.5 $
  * $State: Exp $
- * $Date: 2005/10/25 21:25:33 $
+ * $Date: 2006/11/22 05:19:21 $
  */
 
 #endif
