@@ -10,7 +10,7 @@ class PlaySoundControl : public FileBrowserControl {
  public:
 	//! Constructor
 	PlaySoundControl(const std::string& n)
-		: FileBrowserControl(n,"Plays a sound from a user specified sound file",config->portPath(config->sound.root))
+		: FileBrowserControl(n,"Plays a sound from a user specified sound file",config->sound.root)
 	{
 		setFilter("*.wav");
 	}
@@ -32,10 +32,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.9 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.10 $
  * $State: Exp $
- * $Date: 2006/09/18 18:07:54 $
+ * $Date: 2007/01/29 01:16:57 $
  */
 
 #endif
