@@ -48,9 +48,11 @@ PostureEditor::activate(MotionManager::MC_ID disp_id, Socket * gui) {
 	// start off with current pose
 	pose.takeSnapshot();
 	pose.setWeights(1);
+#ifdef TGT_HAS_LEDS
 	// clear the LEDs though
 	for(unsigned int i=LEDOffset; i<LEDOffset+NumLEDs; i++)
 		pose.setOutputCmd(i,0);
+#endif
 	// add it the motion sequence we'll be using to move to changes
 	SharedObject<SmallMotionSequenceMC> reach;
 	reachID=motman->addPersistentMotion(reach);
@@ -124,11 +126,15 @@ PostureEditor::processEvent(const EventBase& e) {
 			}
 		}
 	} else if(e.getGeneratorID()==EventBase::timerEGID) {
+#ifndef TGT_HAS_LEDS
+		pose.takeSnapshot();
+#else
 		//doing a manual copy instead of just takeSnapshot() so we don't disturb the LED settings
 		for(unsigned int i=0; i<LEDOffset; i++)
 			pose(i).value=state->outputs[i];
 		for(unsigned int i=LEDOffset+NumLEDs; i<NumOutputs; i++)
 			pose(i).value=state->outputs[i];
+#endif
 		if(e.getSourceID()==0) // source==1 indicates it's a forged event sent from refresh -- don't inf. recurse
 			refresh();
 	} else {
@@ -170,8 +176,8 @@ PostureEditor::updatePose(unsigned int delay) {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.20 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.21 $
  * $State: Exp $
- * $Date: 2006/09/09 04:32:18 $
+ * $Date: 2007/11/18 06:47:00 $
  */
