@@ -5,7 +5,12 @@
 #include "FileBrowserControl.h"
 #include "Motion/MotionSequenceMC.h"
 #include "Motion/EmergencyStopMC.h"
-#include "Motion/LedMC.h"
+#include "Shared/RobotInfo.h"
+#ifdef TGT_HAS_LEDS
+#  include "Shared/ERS210Info.h"
+#  include "Motion/LedMC.h"
+#endif
+#include "Events/EventRouter.h"
 #include "Sound/SoundManager.h"
 #include "Motion/MMAccessor.h"
 #include "Shared/TimeET.h"
@@ -28,7 +33,7 @@ class RunSequenceControl : public FileBrowserControl, public EventListener {
 public:
 	//! Constructor, sets filter to *.mot
 	RunSequenceControl(const std::string& n, MotionManager::MC_ID estop_id)
-		: FileBrowserControl(n,"Runs a motion sequence from a user-specified file",config->portPath(config->motion.root)),
+		: FileBrowserControl(n,"Runs a motion sequence from a user-specified file",config->motion.root),
 			estopid(estop_id), ledid(MotionManager::invalid_MC_ID), waitingFile()
 	{
 		setFilter("*.mot");
@@ -38,6 +43,7 @@ public:
 	virtual ~RunSequenceControl() {
 		erouter->removeListener(this);
 		motman->removeMotion(ledid);
+		ledid=MotionManager::invalid_MC_ID;
 	}
 
 	//! only called when e-stop has been turned off and we're waiting to load a file
@@ -45,6 +51,7 @@ public:
 		erouter->removeListener(this);
 		runFile();
 		motman->removeMotion(ledid);
+		ledid=MotionManager::invalid_MC_ID;
 	}
 	
 protected:
@@ -65,11 +72,19 @@ protected:
 		} else {
 			//we have to wait for the estop to be turned off
 			sndman->playFile("donkey.wav");
+#ifdef TGT_HAS_LEDS
 			SharedObject<LedMC> led;
 			led->cset(FaceLEDMask,0);
-			led->cycle(BotLLEDMask,1000,3,0,0);
-			led->cycle(BotRLEDMask,1000,3,0,500);
+			unsigned int botl = capabilities.findButtonOffset(ERS210Info::buttonNames[ERS210Info::BotLLEDOffset]);
+			unsigned int botr = capabilities.findButtonOffset(ERS210Info::buttonNames[ERS210Info::BotRLEDOffset]);
+			if(botl==-1U || botr==-1U) {
+				botl=LEDOffset;
+				botr=NumLEDs>1 ? botl+1 : botl;
+			}
+			led->cycle(1<<(botl-LEDOffset),1000,3,0,0);
+			led->cycle(1<<(botr-LEDOffset),1000,3,0,500);
 			ledid=motman->addPersistentMotion(led);
+#endif
 			erouter->addListener(this,EventBase::estopEGID,estopid,EventBase::deactivateETID);
 		}
 		return this;
@@ -85,10 +100,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.19 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.22 $
  * $State: Exp $
- * $Date: 2006/09/18 18:07:54 $
+ * $Date: 2007/08/05 16:16:04 $
  */
 
 #endif
