@@ -65,7 +65,7 @@ ControlBase* SensorObserverControl::doSelect() {
 	sndman->playFile(config->controller.select_snd);
 	if(wasListening!=(numListeners>0)) {
 		if(numListeners>0)
-			erouter->addListener(this,EventBase::sensorEGID,SensorSourceID::UpdatedSID);
+			erouter->addListener(this,EventBase::sensorEGID,SensorSrcID::UpdatedSID);
 		else
 			erouter->removeListener(this);
 	}
@@ -209,8 +209,8 @@ void SensorObserverControl::RTViewControl::setPeriod(unsigned int x) {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.7 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.8 $
  * $State: Exp $
- * $Date: 2006/10/02 22:11:38 $
+ * $Date: 2007/06/05 18:04:36 $
  */
