@@ -2,7 +2,7 @@
 #ifdef PLATFORM_APERIOS
 #  include <OPENR/OPENRAPI.h>
 #else
-#  include "local/sim/SharedGlobals.h"
+#  include "Shared/ProjectInterface.h"
 #endif
 
 ControlBase * ShutdownControl::doSelect()    {
@@ -10,8 +10,7 @@ ControlBase * ShutdownControl::doSelect()    {
 	OBootCondition bc(0);
 	OPENR::Shutdown(bc);
 #else
-	if(globals!=NULL)
-		globals->signalShutdown();
+	ProjectInterface::sendCommand("quit");
 #endif
 	return NULL;
 }
@@ -21,9 +20,9 @@ ControlBase * ShutdownControl::doSelect()    {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.5 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.6 $
  * $State: Exp $
- * $Date: 2005/08/31 21:55:12 $
+ * $Date: 2007/06/13 18:14:12 $
  */
 
