@@ -27,6 +27,7 @@ ControlBase* StringInputControl::doReadStdIn(const std::string& prompt/*=std::st
 			 << "0\n"
 			 << "0\n"
 			 << "Waiting for input...\n"
+			 << std::count(userPrompt.begin(),userPrompt.end(),'\n') << '\n'
 			 << userPrompt << "\n";
 		gui_comm->write((const byte*)ss.str().c_str(),ss.str().size());
 	}
@@ -42,9 +43,9 @@ ControlBase* StringInputControl::doReadStdIn(const std::string& prompt/*=std::st
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.5 $
- * $State: Rel $
- * $Date: 2003/07/28 05:54:32 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.6 $
+ * $State: Exp $
+ * $Date: 2007/01/30 22:56:18 $
  */
 
