@@ -26,7 +26,7 @@ public:
 	}	
 	
 	//! returns last call to takeInput()
-	virtual const std::string& getLastInput() { return lastInput; }
+	virtual const std::string& getLastInput() const { return lastInput; }
 
 	//! clears the last input (i.e. so you can easily tell later if new input is entered)
 	virtual void clearLastInput() { takeInput(""); }
@@ -44,10 +44,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.5 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.6 $
  * $State: Exp $
- * $Date: 2004/03/23 00:55:01 $
+ * $Date: 2007/01/30 22:56:18 $
  */
 
 #endif
