@@ -12,6 +12,7 @@
 #include "Shared/ERS220Info.h"
 #include "Shared/ERS7Info.h"
 #include "Wireless/Wireless.h"
+#include "Behaviors/Controller.h"
 #include <vector>
 #include <sstream>
 
@@ -40,32 +41,17 @@ class ValueEditControl : public StringInputControl, public EventListener {
 	}
 	//! will increment/decrement the current and then assign it to the target when head buttons pressed
 	virtual void processEvent(const EventBase& e) {
-		if(state->robotDesign&WorldState::ERS210Mask) {
-			switch(e.getSourceID()) {
-			case ERS210Info::HeadFrButOffset: doNextItem(); doSelect(); break;
-			case ERS210Info::HeadBkButOffset: doNextItem(); doSelect(); break;
-			default:
-				serr->printf("*** WARNING ValueEditControl got an unasked for event\n");
-				break;
-			}
-		} else if(state->robotDesign&WorldState::ERS220Mask) {
-			switch(e.getSourceID()) {
-			case ERS220Info::HeadFrButOffset: doNextItem(); doSelect(); break;
-			case ERS220Info::HeadBkButOffset: doNextItem(); doSelect(); break;
-			default:
-				serr->printf("*** WARNING ValueEditControl got an unasked for event\n");
-				break;
-			}
-		} else if(state->robotDesign&WorldState::ERS7Mask) {
-			switch(e.getSourceID()) {
-			case ERS7Info::FrontBackButOffset: doNextItem(); doSelect(); break;
-			case ERS7Info::RearBackButOffset: doNextItem(); doSelect(); break;
-			default:
-				serr->printf("*** WARNING ValueEditControl got an unasked for event\n");
-				break;
-			}
+		if(e==Controller::nextItem) {
+			doNextItem();
+			doSelect();
+		} else if(e==Controller::prevItem) {
+			doPrevItem();
+			doSelect();
+		} else {
+			serr->printf("*** WARNING ValueEditControl got an unasked for event\n");
 		}
 	}
+	
 	//! displays current value
 	virtual void refresh() {
 		//Do console only if GUI is connected
@@ -82,22 +68,8 @@ class ValueEditControl : public StringInputControl, public EventListener {
 
 	//! request to continue receiving events so we can modify the value while running
 	virtual void pause() {
-		unsigned int FrButOffset,BkButOffset;
-		if(state->robotDesign&WorldState::ERS210Mask) {
-			FrButOffset=ERS210Info::HeadFrButOffset;
-			BkButOffset=ERS210Info::HeadBkButOffset;
-		} else if(state->robotDesign&WorldState::ERS220Mask) {
-			FrButOffset=ERS220Info::HeadFrButOffset;
-			BkButOffset=ERS220Info::HeadBkButOffset;
-		} else if(state->robotDesign&WorldState::ERS7Mask) {
-			FrButOffset=ERS7Info::FrontBackButOffset;
-			BkButOffset=ERS7Info::RearBackButOffset;
-		} else {
-			serr->printf("ValueEditControl: Unsupported model!\n");
-			return;
-		}
-		erouter->addListener(this,EventBase(EventBase::buttonEGID,FrButOffset,EventBase::deactivateETID,0));
-		erouter->addListener(this,EventBase(EventBase::buttonEGID,BkButOffset,EventBase::deactivateETID,0));
+		erouter->addListener(this,Controller::nextItem);
+		erouter->addListener(this,Controller::prevItem);
 		//		erouter->addListener(this,EventBase(EventBase::buttonEGID,ChinButOffset,EventBase::deactivateETID,0));
 		StringInputControl::pause();
 	}
@@ -120,13 +92,13 @@ class ValueEditControl : public StringInputControl, public EventListener {
 	}
 	//! adds one to the current value
 	virtual ControlBase * doNextItem() {
-		cur++;
+		cur=(T)(cur+1);
 		refresh();
 		return this;
 	}
 	//! subtracts one from the current value
 	virtual ControlBase * doPrevItem() {
-		cur--;
+		cur=(T)(cur-1);
 		refresh();
 		return this;
 	}
@@ -167,10 +139,10 @@ class ValueEditControl : public StringInputControl, public EventListener {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.15 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.18 $
  * $State: Exp $
- * $Date: 2005/08/07 04:11:03 $
+ * $Date: 2007/06/28 04:36:19 $
  */
 
 #endif
