@@ -12,7 +12,7 @@
 
 using namespace std;
 
-char * WalkCalibration::datanames[WalkCalibration::NUM_SRC] = { "fs","fr","sr","br","bs","rr" };
+const char * WalkCalibration::datanames[WalkCalibration::NUM_SRC] = { "fs","fr","sr","br","bs","rr" };
 
 
 WalkCalibration::WalkCalibration()
@@ -209,9 +209,9 @@ void WalkCalibration::refresh() {
 	ControlBase::refresh();
 	if(gui_comm!=NULL && wireless->isConnected(gui_comm->sock)) {
 		if(status.size()==0)
-			gui_comm->printf("status\n# Samples: fs=%d fr=%d sr=%d br=%d bs=%d r=%d\n",cnts[0], cnts[1], cnts[2], cnts[3], cnts[4], cnts[5]);
+			gui_comm->printf("status\n1\n# Samples: fs=%d fr=%d sr=%d br=%d bs=%d r=%d\n",cnts[0], cnts[1], cnts[2], cnts[3], cnts[4], cnts[5]);
 		else
-			gui_comm->printf("status\n%s\n",status.c_str());
+			gui_comm->printf("status\n%td\n%s\n",std::count(status.begin(),status.end(),'\n'),status.c_str());
 	}
 }
 
@@ -680,7 +680,7 @@ unsigned int WalkCalibration::getSecondIndex(WalkCalibration::dataSource t) {
 	return -1U;
 }
 
-char * WalkCalibration::getIndexName(unsigned int t) {
+const char * WalkCalibration::getIndexName(unsigned int t) {
 	switch(t) {
 	case 0:
 		return "Forward";
@@ -694,7 +694,7 @@ char * WalkCalibration::getIndexName(unsigned int t) {
 	return NULL;
 }
 
-char * WalkCalibration::getFirstMeasure(WalkCalibration::dataSource t) {
+const char * WalkCalibration::getFirstMeasure(WalkCalibration::dataSource t) {
 	switch(t) {
 	case fs:
 		if(isPolar)
@@ -718,7 +718,7 @@ char * WalkCalibration::getFirstMeasure(WalkCalibration::dataSource t) {
 	return NULL;
 }
 
-char * WalkCalibration::getSecondMeasure(WalkCalibration::dataSource t) {
+const char * WalkCalibration::getSecondMeasure(WalkCalibration::dataSource t) {
 	switch(t) {
 	case fs:
 	case bs:
@@ -898,9 +898,9 @@ void WalkCalibration::addSample(std::vector<float*>& dat, float x, float y, floa
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.12 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.14.2.2 $
  * $State: Exp $
- * $Date: 2006/09/18 18:07:54 $
+ * $Date: 2009/02/08 03:34:40 $
  */
 
