@@ -79,9 +79,9 @@ protected:
 	unsigned int getType(); //!< returns current sample type
 	unsigned int getFirstIndex(dataSource t); //!< returns a name index for the first measurement type
 	unsigned int getSecondIndex(dataSource t); //!< returns a name index for the second measurement type
-	char * getIndexName(unsigned int t); //!< returns name for measurement type
-	char * getFirstMeasure(dataSource t); //!< returns name for first measurement type
-	char * getSecondMeasure(dataSource t); //!< returns name for second measurement type
+	const char * getIndexName(unsigned int t); //!< returns name for measurement type
+	const char * getFirstMeasure(dataSource t); //!< returns name for first measurement type
+	const char * getSecondMeasure(dataSource t); //!< returns name for second measurement type
 
 	float arclen(float d, float a, float sign); //!< calculates arc distance corresponding to a displacement and angle, negated if necessary to match @a sign
 	void addSample(); //!< adds data point corresponding to measurements stored in #firstIn and #secondIn
@@ -109,7 +109,7 @@ protected:
 	float secondIn;  //!< the input given for the second measurement
 	std::vector<float*> data[NUM_SRC]; //!< an array of vectors of sample points (one veotor for each of the sample types)
 	unsigned int cnts[NUM_SRC]; //!< count of samples for each sample type (cnts[i] should equal data[i].size())
-	static char * datanames[NUM_SRC]; //!< name for each sample type
+	static const char * datanames[NUM_SRC]; //!< name for each sample type
 
 	std::string status; //!< string to send for ControllerGUI status message (current count of each sample type)
 	
@@ -123,10 +123,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.8 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.8.2.1 $
  * $State: Exp $
- * $Date: 2006/09/16 20:11:49 $
+ * $Date: 2009/02/08 03:34:40 $
  */
 
 #endif
