@@ -29,7 +29,7 @@ public:
 		// creates a PostureMC class to move the joint(s) and adds it to global MotionManager
 		pose_id=motman->addPersistentMotion(SharedObject<PostureMC>());
 		// subscribe to sensor updated events through the global EventRouter
-		erouter->addListener(this,EventBase::sensorEGID,SensorSourceID::UpdatedSID);
+		erouter->addListener(this,EventBase::sensorEGID,SensorSrcID::UpdatedSID);
 	}
 	
 	virtual void DoStop() {
@@ -60,16 +60,16 @@ public:
 			//state is a global instantiation of WorldState, kept up to date by framework;
 			//pressure is in range 0 to 1 - we use the pressure on the front head button here
 			float pressure=0;
-			if(state->robotDesign&WorldState::ERS210Mask) {
-				pressure=state->buttons[ERS210Info::HeadFrButOffset];
+			if(RobotName == ERS210Info::TargetName) {
+				pressure=state->buttons[capabilities.getButtonOffset("HeadFrBut")];
 				std::cout << "HeadFrBut Pressure: " << pressure << std::endl;
-			} else if(state->robotDesign&WorldState::ERS7Mask) {
+			} else if(RobotName == ERS7Info::TargetName) {
 				pressure=state->buttons[ERS7Info::HeadButOffset];
 				std::cout << "HeadBut Pressure: " << pressure << std::endl;
 			} else {
 				//only really works on the ERS-210 or ERS-7 models - the others don't have a proper pressure sensor
 				//(the 220's antenna-thing is close, but doesn't give a continuous range)
-				std::cout << "Unknown model" << std::endl;
+				std::cout << "Unsupported/unknown model" << std::endl;
 				erouter->removeListener(this); // stops getting events (and timers, if we had any)
 				return;
 			}
@@ -83,9 +83,9 @@ public:
 			//let's do the whole thing again with the other head button for the other leg:
 			// (cutting out a some of the intermediary steps this time)
 			joint=RFrLegOffset+RotatorOffset;
-			if(state->robotDesign&WorldState::ERS210Mask)
-				pose_mc->setOutputCmd(joint,outputRanges[joint][MaxRange]*state->buttons[ERS210Info::HeadBkButOffset]);
-			else if(state->robotDesign&WorldState::ERS7Mask) //ERS7 doesn't have another head button, we'll use one of its back buttons
+			if(RobotName == ERS210Info::TargetName)
+				pose_mc->setOutputCmd(joint,outputRanges[joint][MaxRange]*state->buttons[capabilities.getButtonOffset(ERS210Info::buttonNames[ERS210Info::HeadBkButOffset])]);
+			else if(RobotName == ERS7Info::TargetName) //ERS7 doesn't have another head button, we'll use one of its back buttons
 				pose_mc->setOutputCmd(joint,outputRanges[joint][MaxRange]*state->buttons[ERS7Info::FrontBackButOffset]);
 
 			// notice that there's no "check in" for pose_mc
@@ -93,7 +93,7 @@ public:
 
 		} else {
 			//should never happen
-			cout << "Unhandled Event:" << event.getName() << endl;
+			std::cout << "Unhandled Event:" << event.getName() << std::endl;
 		}
 	}
 	
@@ -115,10 +115,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.13 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.17 $
  * $State: Exp $
- * $Date: 2005/06/01 05:47:45 $
+ * $Date: 2007/11/12 18:00:38 $
  */
 
 #endif
