@@ -50,8 +50,8 @@ public:
     StateNode *decide=addNode(new DecideNode("Decide",bandit,left,right));
     StateNode *recoverl=addNode(new OutputNode("\nBadPressLeft",std::cout,wait));
     StateNode *recoverr=addNode(new OutputNode("\nBadPressRight",std::cout,wait));
-    left->addTransition(new SmoothCompareTrans<float>(wait,&state->pidduties[LFrLegOffset+RotatorOffset],CompareTrans<float>::LT,-.07,EventBase(EventBase::sensorEGID,SensorSourceID::UpdatedSID,EventBase::statusETID),.7));
-    right->addTransition(new SmoothCompareTrans<float>(wait,&state->pidduties[RFrLegOffset+RotatorOffset],CompareTrans<float>::LT,-.07,EventBase(EventBase::sensorEGID,SensorSourceID::UpdatedSID,EventBase::statusETID),.7));
+    left->addTransition(new SmoothCompareTrans<float>(wait,&state->pidduties[LFrLegOffset+RotatorOffset],CompareTrans<float>::LT,-.07,EventBase(EventBase::sensorEGID,SensorSrcID::UpdatedSID,EventBase::statusETID),.7));
+    right->addTransition(new SmoothCompareTrans<float>(wait,&state->pidduties[RFrLegOffset+RotatorOffset],CompareTrans<float>::LT,-.07,EventBase(EventBase::sensorEGID,SensorSrcID::UpdatedSID,EventBase::statusETID),.7));
     wait->addTransition(new TimeOutTrans(decide,2000));
     left->addTransition(new TimeOutTrans(recoverl,1500));
     right->addTransition(new TimeOutTrans(recoverr,1500));
@@ -180,7 +180,7 @@ protected:
     virtual void DoStop() {
       erouter->removeListener(this);
       b.reward(reward);
-      cout << endl;
+      std::cout << std::endl;
       reward=false;
       StateNode::DoStop();
     }
@@ -216,10 +216,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.27 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.29 $
  * $State: Exp $
- * $Date: 2006/09/18 18:07:57 $
+ * $Date: 2007/11/12 18:00:38 $
  */
 
 #endif
