@@ -1,9 +1,7 @@
 #include "CameraBehavior.h"
 #include "Events/EventRouter.h"
 #include "Events/TextMsgEvent.h"
-#include "Shared/ERS210Info.h"
-#include "Shared/ERS220Info.h"
-#include "Shared/ERS7Info.h"
+#include "Shared/RobotInfo.h"
 #include "Wireless/Socket.h"
 #include "Shared/WorldState.h"
 #include "Sound/SoundManager.h"
@@ -26,13 +24,9 @@
 void
 CameraBehavior::DoStart() {
 	BehaviorBase::DoStart();
-	if(state->robotDesign&WorldState::ERS210Mask) {
-		camera_click.setSourceID(ERS210Info::HeadFrButOffset);
-	} else if(state->robotDesign&WorldState::ERS220Mask) {
-		camera_click.setSourceID(ERS220Info::HeadFrButOffset);
-	} else if(state->robotDesign&WorldState::ERS7Mask) {
-		camera_click.setSourceID(ERS7Info::HeadButOffset);
-	}
+	if(capabilities.findButtonOffset("HeadBut")!=-1U) // if there is a head button, use it for the trigger
+		camera_click.setSourceID(capabilities.getButtonOffset("HeadBut"));
+	// (otherwise, just stick with the default button 0 as set in camera_click constructor)
 	initIndex();
 	sndman->loadFile("camera.wav");
 	ledID=motman->addPersistentMotion(SharedObject<LedMC>());
@@ -63,11 +57,15 @@ CameraBehavior::processEvent(const EventBase& e) {
 
 	{
 		MMAccessor<LedMC> leds(ledID);
+#if defined(TGT_ERS7) || defined(TGT_ERS210) || defined(TGT_ERS220) || defined(TGT_ERS2xx)
 		leds->cset(FaceLEDMask,2.0/3.0);
 		leds->set(TopBrLEDMask,1);
+#else
+		leds->set(~0,1);
+#endif
 	}
 
-	if(config->vision.rawcam_compression==Config::vision_config::COMPRESS_NONE) {
+	if(config->vision.rawcam.compression==Config::vision_config::RawCamConfig::COMPRESS_NONE) {
 		//this is our own odd little format, would be nice to save a TIFF or something instead
 
 		// open file
@@ -76,7 +74,7 @@ CameraBehavior::processEvent(const EventBase& e) {
 			return;
 
 		//! write actual image data
-		if(config->vision.rawcam_encoding==Config::vision_config::ENCODE_COLOR) {
+		if(config->vision.rawcam.encoding==Config::vision_config::RawCamConfig::ENCODE_COLOR) {
 			FilterBankGenerator * gen=ProjectInterface::defInterleavedYUVGenerator; // just an alias for readability
 			gen->selectSaveImage(ProjectInterface::doubleLayer,InterleavedYUVGenerator::CHAN_YUV);
 			unsigned int len=gen->saveFileStream(f);
@@ -85,9 +83,9 @@ CameraBehavior::processEvent(const EventBase& e) {
 				sndman->playFile(config->controller.error_snd);
 				return;
 			}
-		} else if(config->vision.rawcam_encoding==Config::vision_config::ENCODE_SINGLE_CHANNEL) {
+		} else if(config->vision.rawcam.encoding==Config::vision_config::RawCamConfig::ENCODE_SINGLE_CHANNEL) {
 			FilterBankGenerator * gen=ProjectInterface::defRawCameraGenerator; // just an alias for readability
-			gen->selectSaveImage(ProjectInterface::doubleLayer,config->vision.rawcam_channel);
+			gen->selectSaveImage(ProjectInterface::doubleLayer,config->vision.rawcam.channel);
 			unsigned int len=gen->saveFileStream(f);
 			if(len==0) {
 				serr->printf("Error saving file\n");
@@ -99,15 +97,15 @@ CameraBehavior::processEvent(const EventBase& e) {
 		// close file
 		fclose(f);
 
-	} else if(config->vision.rawcam_compression==Config::vision_config::COMPRESS_JPEG) {
+	} else if(config->vision.rawcam.compression==Config::vision_config::RawCamConfig::COMPRESS_JPEG) {
 		//save a JPEG image
 		JPEGGenerator * jpeg=NULL; // we'll set this to pick between the color jpeg or a single channel grayscale jpeg
 		unsigned int chan=0; // and this will hold the channel to use out of that jpeg generator
-		if(config->vision.rawcam_encoding==Config::vision_config::ENCODE_COLOR)
+		if(config->vision.rawcam.encoding==Config::vision_config::RawCamConfig::ENCODE_COLOR)
 			jpeg=dynamic_cast<JPEGGenerator*>(ProjectInterface::defColorJPEGGenerator);
-		else if(config->vision.rawcam_encoding==Config::vision_config::ENCODE_SINGLE_CHANNEL) {
+		else if(config->vision.rawcam.encoding==Config::vision_config::RawCamConfig::ENCODE_SINGLE_CHANNEL) {
 			jpeg=dynamic_cast<JPEGGenerator*>(ProjectInterface::defGrayscaleJPEGGenerator);
-			chan=config->vision.rawcam_channel;
+			chan=config->vision.rawcam.channel;
 		}
 		if(jpeg!=NULL) {
 			unsigned int tmp_q=jpeg->getQuality(); //temporary storage so we can reset the default
@@ -133,15 +131,15 @@ CameraBehavior::processEvent(const EventBase& e) {
 			jpeg->setQuality(tmp_q);
 		}
 
-	} else if(config->vision.rawcam_compression==Config::vision_config::COMPRESS_PNG) {
-		//save a JPEG image
+	} else if(config->vision.rawcam.compression==Config::vision_config::RawCamConfig::COMPRESS_PNG) {
+		//save a PNG image
 		PNGGenerator * png=NULL; // we'll set this to pick between the color png or a single channel grayscale png
 		unsigned int chan=0; // and this will hold the channel to use out of that png generator
-		if(config->vision.rawcam_encoding==Config::vision_config::ENCODE_COLOR)
+		if(config->vision.rawcam.encoding==Config::vision_config::RawCamConfig::ENCODE_COLOR)
 			png=dynamic_cast<PNGGenerator*>(ProjectInterface::defColorPNGGenerator);
-		else if(config->vision.rawcam_encoding==Config::vision_config::ENCODE_SINGLE_CHANNEL) {
+		else if(config->vision.rawcam.encoding==Config::vision_config::RawCamConfig::ENCODE_SINGLE_CHANNEL) {
 			png=dynamic_cast<PNGGenerator*>(ProjectInterface::defGrayscalePNGGenerator);
-			chan=config->vision.rawcam_channel;
+			chan=config->vision.rawcam.channel;
 		}
 		if(png!=NULL) {
 			// open file
@@ -166,10 +164,21 @@ CameraBehavior::processEvent(const EventBase& e) {
 	{
 		MMAccessor<LedMC> leds(ledID);
 		leds->clear();
+#if defined(TGT_ERS7) || defined(TGT_ERS210) || defined(TGT_ERS220) || defined(TGT_ERS2xx)
 		leds->flash(TopBrLEDMask,700);
 		leds->flash(TopLLEDMask|TopRLEDMask,500);
 		leds->flash(MidLLEDMask|MidRLEDMask,300);
 		leds->flash(BotLLEDMask|BotRLEDMask,100);
+#else
+		if(NumLEDs>3)
+			leds->flash(1<<3,700);
+		if(NumLEDs>2)
+			leds->flash(1<<2,500);
+		if(NumLEDs>1)
+			leds->flash(1<<1,300);
+		if(NumLEDs>0)
+			leds->flash(1<<0,100);
+#endif
 	}
 
 	sout->printf("done\n");
@@ -226,15 +235,14 @@ CameraBehavior::initIndex() {
 	sout->printf("The next saved image will go to %simg%05d\n",path.c_str(),index);
 }
 
-
 /*! @file
  * @brief Implements CameraBehavior, for taking pictures
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.13 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.18 $
  * $State: Exp $
- * $Date: 2006/09/18 18:07:57 $
+ * $Date: 2007/07/16 18:31:40 $
  */
 
