@@ -1,27 +1,15 @@
+#include "Shared/RobotInfo.h"
+#ifdef TGT_HAS_IR_DISTANCE
+
 #include "ExploreMachine.h"
 #include "Behaviors/Nodes/WalkNode.h"
 #include "Behaviors/Transitions/SmoothCompareTrans.h"
 #include "Behaviors/Transitions/TimeOutTrans.h"
-#include "Shared/ERS210Info.h"
-#include "Shared/ERS220Info.h"
-#include "Shared/ERS7Info.h"
 #include "Wireless/Socket.h"
 #include "Shared/WorldState.h"
 
 void ExploreMachine::setup() {
 	//cout << "Explore SETUP " << issetup << "...";
-	unsigned int IRDistOffset;
-	if(state->robotDesign&WorldState::ERS210Mask)
-		IRDistOffset=ERS210Info::IRDistOffset;
-	else if(state->robotDesign&WorldState::ERS220Mask)
-		IRDistOffset=ERS220Info::IRDistOffset;
-	else if(state->robotDesign&WorldState::ERS7Mask)
-		IRDistOffset=ERS7Info::NearIRDistOffset;
-	else {
-		serr->printf("ExploreMachine: Unsupported model!\n");
-		return;
-	}
-
 	SharedObject<WalkMC> walk;
 	walkid=motman->addPersistentMotion(walk);
 
@@ -31,7 +19,7 @@ void ExploreMachine::setup() {
 	start=addNode(turn=new WalkNode(getName()+"::turn",0,0,0.5f));
 	turn->setMC(walkid);
 
-	move->addTransition(new SmoothCompareTrans<float>(turn,&state->sensors[IRDistOffset],CompareTrans<float>::LT,350,EventBase(EventBase::sensorEGID,SensorSourceID::UpdatedSID,EventBase::statusETID),.7));
+	move->addTransition(new SmoothCompareTrans<float>(turn,&state->sensors[IRDistOffset],CompareTrans<float>::LT,350,EventBase(EventBase::sensorEGID,SensorSrcID::UpdatedSID,EventBase::statusETID),.7));
 	turn->addTransition(new TimeOutTrans(move,2000));
 
 	StateNode::setup();
@@ -41,7 +29,7 @@ void ExploreMachine::setup() {
 void ExploreMachine::DoStart() {
 	StateNode::DoStart();
 	start->DoStart();
-	//erouter->addListener(this,EventBase::sensorEGID,SensorSourceID::UpdatedSID);
+	//erouter->addListener(this,EventBase::sensorEGID,SensorSrcID::UpdatedSID);
 	erouter->addListener(this,EventBase::stateMachineEGID,(size_t)turn,EventBase::activateETID);
 }
 
@@ -72,8 +60,10 @@ void ExploreMachine::processEvent(const EventBase& /*e*/) {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.3 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.5 $
  * $State: Exp $
- * $Date: 2005/12/15 18:51:35 $
+ * $Date: 2007/06/26 04:27:43 $
  */
+
+#endif
