@@ -6,6 +6,11 @@
 #include "Behaviors/Nodes/WalkNode.h"
 #include "Motion/MotionManager.h"
 
+#include "Shared/RobotInfo.h"
+#ifndef TGT_HAS_IR_DISTANCE
+#error ExploreMachine requires a distance rangefinder via IRDistOffset
+#endif
+
 //! A state machine for exploring an environment (or searching for an object)
 class ExploreMachine : public StateNode {
 public:
@@ -48,10 +53,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.24 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.25 $
  * $State: Exp $
- * $Date: 2005/12/15 18:51:36 $
+ * $Date: 2007/06/26 04:27:43 $
  */
 
 #endif
