@@ -1,5 +1,5 @@
 //-*-c++-*-
-#ifndef INCLUDED_FollowHeadBehavior_h_
+#if !defined(INCLUDED_FollowHeadBehavior_h_) && defined(TGT_HAS_BUTTONS)
 #define INCLUDED_FollowHeadBehavior_h_
 
 #include "Behaviors/BehaviorBase.h"
@@ -54,10 +54,10 @@ class FollowHeadBehavior : public BehaviorBase {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.5 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.6 $
  * $State: Exp $
- * $Date: 2004/11/11 01:45:36 $
+ * $Date: 2007/03/05 01:19:08 $
  */
 
 #endif
