@@ -23,16 +23,8 @@ class HeadLevelBehavior : public BehaviorBase {
 			head(),
 			head_id(MotionManager::invalid_MC_ID), pid_id(MotionManager::invalid_MC_ID)
 	{
-		if(state->robotDesign & WorldState::ERS7Mask) {
-			head_release.setSourceID(ERS7Info::HeadButOffset);
-			head_lock.setSourceID(ERS7Info::HeadButOffset);
-		} else if(state->robotDesign & WorldState::ERS210Mask) {
-			head_release.setSourceID(ERS210Info::HeadFrButOffset);
-			head_lock.setSourceID(ERS210Info::HeadFrButOffset);
-		} else if(state->robotDesign & WorldState::ERS220Mask) {
-			head_release.setSourceID(ERS220Info::HeadFrButOffset);
-			head_lock.setSourceID(ERS220Info::HeadFrButOffset);
-		}
+		head_release.setSourceID(HeadButOffset);
+		head_lock.setSourceID(HeadButOffset);
 		head.getRegion()->AddReference();
 	}
 	//! destructor
@@ -85,10 +77,10 @@ class HeadLevelBehavior : public BehaviorBase {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.10 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.11 $
  * $State: Exp $
- * $Date: 2004/11/11 01:45:36 $
+ * $Date: 2007/06/26 04:27:43 $
  */
 
 #endif 
