@@ -5,6 +5,9 @@
 #include "Behaviors/BehaviorBase.h"
 #include "Motion/HeadPointerMC.h"
 #include "Events/DataEvent.h"
+#include "Events/EventRouter.h"
+#include "Shared/ODataFormats.h"
+#include "Motion/MMAccessor.h"
 
 //! Turns head to sound source, estimated by average volume difference between left and right ears
 class LookForSoundBehavior : public BehaviorBase {
@@ -51,7 +54,7 @@ public:
 			// If there is sufficient energy coming in
 			if( l+r > sz*1000.){
 				MMAccessor<HeadPointerMC> mc(mc_id);
-				double cur = state->outputs[ERS7Info::HeadOffset+1];
+				double cur = state->outputs[HeadOffset+PanOffset];
 				if( r > 1.3*l)
 					// Move your head righward
 					mc->setJoints( 0, cur-.2*M_PI/(r/l), 0);
@@ -74,10 +77,10 @@ protected:
  * @author Paris Smaragdis (paris AT media mit edu) (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.8 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.9 $
  * $State: Exp $
- * $Date: 2004/12/23 01:47:06 $
+ * $Date: 2007/08/05 16:16:04 $
  */
 
 #endif
