@@ -1,3 +1,6 @@
+#include "Shared/RobotInfo.h"
+#ifdef TGT_HAS_IR_DISTANCE
+
 #include "PaceTargetsMachine.h"
 #include "Behaviors/Transition.h"
 #include "Behaviors/Nodes/WalkToTargetNode.h"
@@ -88,9 +91,10 @@ void PaceTargetsMachine::teardown() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.20 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.22 $
  * $State: Exp $
- * $Date: 2006/09/18 18:07:57 $
+ * $Date: 2007/07/16 18:31:39 $
  */
 
+#endif
