@@ -2,6 +2,11 @@
 #ifndef INCLUDED_PaceTargetsMachine_h_
 #define INCLUDED_PaceTargetsMachine_h_
 
+#include "Shared/RobotInfo.h"
+#ifndef TGT_HAS_IR_DISTANCE
+#error PaceTargetsMachine requires a distance rangefinder via IRDistOffset
+#endif
+
 #include "Behaviors/StateNode.h"
 #include "Shared/ProjectInterface.h"
 
@@ -35,10 +40,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.9 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.10 $
  * $State: Exp $
- * $Date: 2005/01/24 22:23:46 $
+ * $Date: 2007/07/16 18:31:39 $
  */
 
 #endif
