@@ -8,8 +8,6 @@
 #include "IPC/SharedObject.h"
 #include "Motion/MotionManager.h"
 
-using namespace std;
-
 //! A behavior that sets all the pids to zero for the tail and legs servos.
 /*! This should hopefully make the robot quieter and consume less power. */
 class RelaxBehavior : public BehaviorBase {
@@ -50,8 +48,8 @@ protected:
  * @author ejt (Modifications)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.7 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.8 $
  * $State: Exp $
- * $Date: 2005/06/01 05:47:45 $
+ * $Date: 2007/11/11 23:57:18 $
  */
