@@ -14,7 +14,7 @@
  *  up and then played successively once the chin button is released.
  *
  *  Notice that this doesn't preload all needed sounds:\n
- *  - @c barkmed.wav is listed in ms/config/tekkotsu.cfg as a preloaded system sound
+ *  - @c barkmed.wav is listed in ms/config/tekkotsu.xml as a preloaded system sound
  *  - @c growl.wav will be loaded before being played automatically - notice the
  *    hiccup this can cause.
  */
@@ -27,15 +27,11 @@ public:
 			RFr(EventBase::buttonEGID,RFrPawOffset,EventBase::activateETID),
 			LBk(EventBase::buttonEGID,LBkPawOffset,EventBase::activateETID),
 			RBk(EventBase::buttonEGID,RBkPawOffset,EventBase::activateETID),
-			Back(EventBase::buttonEGID,0,EventBase::activateETID)
+			Back(EventBase::buttonEGID,NumButtons-1,EventBase::activateETID)
 	{
-		//different models vary widely in their back buttons
-		if(state->robotDesign & WorldState::ERS210Mask)
-			Back.setSourceID(ERS210Info::BackButOffset);
-		else if(state->robotDesign & WorldState::ERS220Mask)
-			Back.setSourceID(ERS220Info::BackButOffset);
-		else if(state->robotDesign & WorldState::ERS7Mask)
-			Back.setSourceID(ERS7Info::FrontBackButOffset);
+		if(capabilities.getButtonOffset("BackBut")!=-1U)
+			Back.setSourceID(capabilities.getButtonOffset("BackBut"));
+		// otherwise unknown model, just use last button (NumButtons-1, as set in constructor)
 	}
 	
 	
@@ -121,10 +117,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.14 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.17 $
  * $State: Exp $
- * $Date: 2006/09/18 18:07:57 $
+ * $Date: 2007/06/28 04:36:20 $
  */
 
 #endif
