@@ -15,7 +15,7 @@ public:
 	//! opens the head light
 	virtual void DoStart() {
 		BehaviorBase::DoStart();
-		if(state->robotDesign & WorldState::ERS220Mask) {
+		if(RobotName == ERS220Info::TargetName) {
 			SharedObject<PostureMC> pose;
 			pose->setOutputCmd(ERS220Info::RetractableHeadLEDOffset,true);
 			light_id=motman->addPersistentMotion(pose);
@@ -39,10 +39,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.5 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.6 $
  * $State: Exp $
- * $Date: 2005/06/01 05:47:45 $
+ * $Date: 2007/06/26 04:27:43 $
  */
 
 #endif
