@@ -1,3 +1,6 @@
+#include "Shared/RobotInfo.h"
+#ifdef TGT_HAS_IR_DISTANCE
+
 #include "WallTestBehavior.h"
 #include "Shared/newmat/newmat.h"
 #include "Shared/newmat/newmatap.h"
@@ -10,6 +13,8 @@
 #include "Shared/TimeET.h"
 #include <fstream>
 
+using namespace std;
+
 void
 WallTestBehavior::DoStart() {
 	BehaviorBase::DoStart(); // do this first
@@ -89,7 +94,7 @@ WallTestBehavior::processEvent(const EventBase& e) {
 	} else if(e.getSourceID()==0) {
 		// must be a timer event -- SID 0 indicates start of recording
 		// so start subscribing to sensor events
-		erouter->addListener(this,EventBase::sensorEGID,SensorSourceID::UpdatedSID);
+		erouter->addListener(this,EventBase::sensorEGID,SensorSrcID::UpdatedSID);
 
 	} else if(e.getSourceID()==1) {
 		// must be a timer event -- SID 1 indicates stop of recording
@@ -283,3 +288,5 @@ WallTestBehavior::solve2(const std::vector<float>& x, const std::vector<float>&
 	x0=V(1,V.ncols())/V(3,V.ncols());
 	x1=V(2,V.ncols())/V(3,V.ncols());
 }
+
+#endif
