@@ -24,18 +24,18 @@ class karmedbanditExp3 {
 	unsigned int decide() {
 		std::vector<double> p(w.size());
 		double wsum=0;
-		cout << "w =";
+		std::cout << "w =";
 		for(unsigned int i=0; i<w.size(); i++)
-			cout << ' ' << w[i];
-		cout << endl;
+			std::cout << ' ' << w[i];
+		std::cout << std::endl;
 		for(unsigned int i=0; i<w.size(); i++)
 			wsum+=w[i];
 		for(unsigned int i=0; i<w.size(); i++)
 			p[i]=(1-g)*w[i]/wsum+g/w.size();
-		cout << "p =";
+		std::cout << "p =";
 		for(unsigned int i=0; i<w.size(); i++)
-			cout << ' ' << p[i];
-		cout << endl;
+			std::cout << ' ' << p[i];
+		std::cout << std::endl;
 		double psum=0;
 		for(unsigned int i=0; i<w.size(); i++)
 			psum+=p[i];
@@ -53,9 +53,9 @@ class karmedbanditExp3 {
 	void reward(bool r) {
 		if(r) {
 			w[last]*=exp(g/lastp/w.size());
-			cout << "REWARD! :)" << endl;
+			std::cout << "REWARD! :)" << std::endl;
 		} else
-			cout << "no reward. :(" << endl;
+			std::cout << "no reward. :(" << std::endl;
 	}
 	//!resets weights
 	void reset() {
@@ -131,11 +131,11 @@ class karmedbanditExp3_1 {
  * @brief Defines karmedbandit - implements an algorithm which makes decisions regarding an adversarial k-armed bandit
  * @author ejt (Creator)
  *
- * $Author: neilh $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.3 $
- * $State: Rel $
- * $Date: 2003/09/18 22:40:27 $
+ * $Author: ejt $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.4 $
+ * $State: Exp $
+ * $Date: 2007/11/12 18:00:38 $
  */
 
 #endif
