@@ -10,7 +10,7 @@ void EStopControllerBehavior::DoStart() {
 	// We listen to the estop
 	erouter->addListener(this, EventBase::estopEGID);
 	// Turn on wireless
-	cmdsock=wireless->socket(SocketNS::SOCK_STREAM, 300, 300);
+	cmdsock=wireless->socket(Socket::SOCK_STREAM, 300, 300);
 	wireless->setDaemon(cmdsock,true);
 	wireless->setReceiver(cmdsock->sock, callback);
 	wireless->listen(cmdsock->sock, config->main.estopControl_port);
@@ -72,9 +72,9 @@ int EStopControllerBehavior::callback(char *buf, int bytes) {
  * @author tss (Creator)
  * 
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.4 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.5 $
  * $State: Exp $
- * $Date: 2004/10/07 19:07:04 $
+ * $Date: 2007/05/21 20:51:20 $
  */
 
