@@ -41,7 +41,7 @@ public:
 
 	static std::string getClassDescription() {
 		char tmp[20];
-		sprintf(tmp,"%d",config->main.estopControl_port);
+		sprintf(tmp,"%d",*config->main.estopControl_port);
 		return std::string("Listens to estop commands coming in from port ")+tmp;
 	}
 	virtual std::string getDescription() const { return getClassDescription(); }
@@ -66,10 +66,10 @@ private:
  * @author tss (Creator)
  * 
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.5 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.6 $
  * $State: Exp $
- * $Date: 2004/12/10 23:18:10 $
+ * $Date: 2007/01/30 22:56:19 $
  */
 
 #endif 
