@@ -2,6 +2,8 @@
 #include "Behaviors/Controller.h"
 #include "Motion/MMAccessor.h"
 #include "Motion/HeadPointerMC.h"
+#include "Shared/ERS7Info.h"
+#include "Shared/ERS210Info.h"
 
 HeadPointControllerBehavior* HeadPointControllerBehavior::theOne = NULL;
 
@@ -23,6 +25,7 @@ void HeadPointControllerBehavior::runCommand(unsigned char *command) {
 #endif
 	
 	// Find out what type of command this is
+#ifdef TGT_IS_AIBO
 	switch(command[0]) {
 	case CMD_tilt:
 		t = fabs(param)*outputRanges[HeadOffset+TiltOffset][param>0?MaxRange:MinRange];
@@ -34,8 +37,38 @@ void HeadPointControllerBehavior::runCommand(unsigned char *command) {
 		r = fabs(param)*outputRanges[HeadOffset+RollOffset][param>0?MaxRange:MinRange];
 		break;
 	default:
-		cout << "MECHA: unknown command " << command[0] << endl;
+		std::cout << "MECHA: unknown command " << command[0] << std::endl;
 	}
+#else
+	switch(command[0]) {
+		case CMD_tilt: {
+			const char* n = ERS7Info::outputNames[ERS7Info::HeadOffset+ERS7Info::TiltOffset];
+			unsigned int i = capabilities.findOutputOffset(n);
+			if(i!=-1U)
+				t = fabs(param)*outputRanges[i][param>0?MaxRange:MinRange];
+		} break;
+		case CMD_pan: {
+			const char* n = ERS7Info::outputNames[ERS7Info::HeadOffset+ERS7Info::PanOffset];
+			unsigned int i = capabilities.findOutputOffset(n);
+			if(i!=-1U)
+				p = fabs(param)*outputRanges[i][param>0?MaxRange:MinRange];
+		} break;
+		case CMD_roll: {
+			const char* n = ERS7Info::outputNames[ERS7Info::HeadOffset+ERS7Info::NodOffset];
+			unsigned int i = capabilities.findOutputOffset(n);
+			if(i!=-1U)
+				r = fabs(param)*outputRanges[i][param>0?MaxRange:MinRange];
+			else {
+				n = ERS210Info::outputNames[ERS210Info::HeadOffset+ERS210Info::RollOffset];
+				i = capabilities.findOutputOffset(n);
+				if(i!=-1U)
+					r = fabs(param)*outputRanges[i][param>0?MaxRange:MinRange];
+			}
+		} break;
+		default:
+			std::cout << "MECHA: unknown command " << command[0] << std::endl;
+	}
+#endif
 
 	// If the command was a new motion command, apply the
 	// new motion parameters:
@@ -54,11 +87,13 @@ void HeadPointControllerBehavior::DoStart() {
 	// Behavior startup
 	BehaviorBase::DoStart();
 	// Enable head control
-	head_id = motman->addPersistentMotion(SharedObject<HeadPointerMC>());
+	SharedObject<HeadPointerMC> head;
+	head->setHold(false);
+	head_id = motman->addPersistentMotion(head);
 	// Turn on wireless
 	theLastOne=theOne;
 	theOne=this;
-	cmdsock=wireless->socket(SocketNS::SOCK_STREAM, 2048, 2048);
+	cmdsock=wireless->socket(Socket::SOCK_STREAM, 2048, 2048);
 	wireless->setReceiver(cmdsock->sock, mechacmd_callback);
 	wireless->setDaemon(cmdsock,true);
 	wireless->listen(cmdsock->sock, config->main.headControl_port);
@@ -122,9 +157,9 @@ int HeadPointControllerBehavior::mechacmd_callback(char *buf, int bytes) {
  * @author tss (Creator)
  * 
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.10 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.16 $
  * $State: Exp $
- * $Date: 2006/09/10 17:00:43 $
+ * $Date: 2007/11/12 18:00:41 $
  */
 
