@@ -79,7 +79,7 @@ class HeadPointControllerBehavior : public BehaviorBase {
 
 	static std::string getClassDescription() {
 		char tmp[20];
-		sprintf(tmp,"%d",config->main.headControl_port);
+		sprintf(tmp,"%d",*config->main.headControl_port);
 		return std::string("Listens to head control commands coming in from port ")+tmp;
 	}
 	virtual std::string getDescription() const { return getClassDescription(); }
@@ -90,10 +90,10 @@ class HeadPointControllerBehavior : public BehaviorBase {
  * @author tss (Creator)
  * 
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.6 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.7 $
  * $State: Exp $
- * $Date: 2005/09/13 22:10:36 $
+ * $Date: 2007/01/30 22:56:19 $
  */
 
 #endif 
