@@ -13,11 +13,11 @@
 MicrophoneServer* MicrophoneServer::instance = 0;
 const char* const MicrophoneServer::MIC_LOCATOR = "PRM:/r1/c1/c2/c3/m1-Mic:M1";
 
-MicrophoneServer* MicrophoneServer::GetInstance() {
+MicrophoneServer& MicrophoneServer::getInstance() {
 	if (instance == 0) {
 		instance = new MicrophoneServer();
 	}
-	return instance;
+	return *instance;
 }
 
 MicrophoneServer::MicrophoneServer()
@@ -42,7 +42,7 @@ void MicrophoneServer::DoStart() {
 		socket = 0;
 	}
 		
-	socket = wireless->socket(SocketNS::SOCK_STREAM, 512, SEND_BUFFER_SIZE);
+	socket = wireless->socket(Socket::SOCK_STREAM, 512, SEND_BUFFER_SIZE);
 	wireless->setDaemon(socket, true);
 	wireless->listen(socket->sock, config->sound.streaming.mic_port);
 	
