@@ -36,8 +36,8 @@ void
 RawCamBehavior::processEvent(const EventBase& e) {
 	if(!wireless->isConnected(visRaw->sock))
 		return;
-	if(config->vision.rawcam_transport==0 && visRaw->getTransport()==SocketNS::SOCK_STREAM
-		 || config->vision.rawcam_transport==1 && visRaw->getTransport()==SocketNS::SOCK_DGRAM) {
+	if(config->vision.rawcam.transport==0 && visRaw->getTransport()==Socket::SOCK_STREAM
+		 || config->vision.rawcam.transport==1 && visRaw->getTransport()==Socket::SOCK_DGRAM) {
 		//reset the socket
 		closeServer();
 		setupServer();
@@ -49,15 +49,15 @@ RawCamBehavior::processEvent(const EventBase& e) {
 			CameraStreamBehavior::processEvent(e);
 			return;
 		}
-		if ((get_time() - lastProcessedTime) < config->vision.rawcam_interval) {// not enough time has gone by
+		if ((get_time() - lastProcessedTime) < config->vision.rawcam.interval) {// not enough time has gone by
 			return;
 		}
 		/* // turning these off enables individual channel compression
-			if(config->vision.rawcam_compression==Config::vision_config::COMPRESS_NONE && e.getGeneratorID()!=EventBase::visRawCameraEGID)
+			if(config->vision.rawcam.compression==Config::vision_config::COMPRESS_NONE && e.getGeneratorID()!=EventBase::visRawCameraEGID)
 			return;
-			if(config->vision.rawcam_compression==Config::vision_config::COMPRESS_JPEG && e.getGeneratorID()!=EventBase::visJPEGEGID)
+			if(config->vision.rawcam.compression==Config::vision_config::COMPRESS_JPEG && e.getGeneratorID()!=EventBase::visJPEGEGID)
 			return; */
-		if(config->vision.rawcam_encoding==Config::vision_config::ENCODE_COLOR) {
+		if(config->vision.rawcam.encoding==Config::vision_config::RawCamConfig::ENCODE_COLOR) {
 			if(!writeColor(*fbke)) {
 				if(packet) { //packet was opened, need to close it
 					cur=packet; // don't send anything
@@ -66,7 +66,7 @@ RawCamBehavior::processEvent(const EventBase& e) {
 				//error message should already be printed in writeColor
 				//ASSERTRET(false,"serialization failed");
 			}
-		} else if(config->vision.rawcam_encoding==Config::vision_config::ENCODE_SINGLE_CHANNEL) {
+		} else if(config->vision.rawcam.encoding==Config::vision_config::RawCamConfig::ENCODE_SINGLE_CHANNEL) {
 			if(!writeSingleChannel(*fbke)) {
 				if(packet) { //packet was opened, need to close it
 					cur=packet; // don't send anything
@@ -76,7 +76,7 @@ RawCamBehavior::processEvent(const EventBase& e) {
 				//ASSERTRET(false,"serialization failed");
 			}
 		} else {
-			serr->printf("%s: Bad rawcam_encoding setting\n",getName().c_str());
+			serr->printf("%s: Bad rawcam.encoding setting\n",getName().c_str());
 		}
 	} catch(...) {
 		if(packet) { //packet was opened, need to close it
@@ -91,26 +91,26 @@ RawCamBehavior::processEvent(const EventBase& e) {
 }
 
 unsigned int RawCamBehavior::getSourceLayer(unsigned int chan, unsigned int numLayers) {
-	if(config->vision.rawcam_encoding==Config::vision_config::ENCODE_SINGLE_CHANNEL) {
-		if(config->vision.rawcam_channel!=(int)chan)
+	if(config->vision.rawcam.encoding==Config::vision_config::RawCamConfig::ENCODE_SINGLE_CHANNEL) {
+		if(config->vision.rawcam.channel!=(int)chan)
 			return -1U;
-		return numLayers-1-config->vision.rawcam_y_skip;
+		return numLayers-1-config->vision.rawcam.y_skip;
 	}
 	// must be full-color
 	switch(chan) {
 	case RawCameraGenerator::CHAN_Y:
-		if(config->vision.rawcam_compression==Config::vision_config::COMPRESS_JPEG) {
-			if(config->vision.rawcam_y_skip-config->vision.rawcam_uv_skip == 1)
-				return numLayers-1-config->vision.rawcam_uv_skip;
+		if(config->vision.rawcam.compression==Config::vision_config::RawCamConfig::COMPRESS_JPEG) {
+			if(config->vision.rawcam.y_skip-config->vision.rawcam.uv_skip == 1)
+				return numLayers-1-config->vision.rawcam.uv_skip;
 		}
-		return numLayers-1-config->vision.rawcam_y_skip;
+		return numLayers-1-config->vision.rawcam.y_skip;
 	case RawCameraGenerator::CHAN_U:
 	case RawCameraGenerator::CHAN_V:
-		if(config->vision.rawcam_compression==Config::vision_config::COMPRESS_JPEG) {
-			if(config->vision.rawcam_uv_skip-config->vision.rawcam_y_skip == 1)
-				return numLayers-1-config->vision.rawcam_y_skip;
+		if(config->vision.rawcam.compression==Config::vision_config::RawCamConfig::COMPRESS_JPEG) {
+			if(config->vision.rawcam.uv_skip-config->vision.rawcam.y_skip == 1)
+				return numLayers-1-config->vision.rawcam.y_skip;
 		}
-		return numLayers-1-config->vision.rawcam_uv_skip;
+		return numLayers-1-config->vision.rawcam.uv_skip;
 	default: // other channels, i.e. Y-derivatives
 		return -1U;
 	}
@@ -142,25 +142,25 @@ RawCamBehavior::setupServer() {
 	std::vector<std::string> args;
 	args.push_back("raw");
 	char port[50];
-	snprintf(port,50,"%d",config->vision.rawcam_port);
+	snprintf(port,50,"%d",*config->vision.rawcam.port);
 	args.push_back(port);
-	if(config->vision.rawcam_transport==0) {
+	if(config->vision.rawcam.transport==0) {
 		max_buf=UDP_WIRELESS_BUFFER_SIZE;
-		visRaw=wireless->socket(SocketNS::SOCK_DGRAM, 1024, max_buf);
+		visRaw=wireless->socket(Socket::SOCK_DGRAM, 1024, max_buf);
 		args.push_back("udp");
-	} else if(config->vision.rawcam_transport==1) {
+	} else if(config->vision.rawcam.transport==1) {
 		max_buf=TCP_WIRELESS_BUFFER_SIZE;
-		visRaw=wireless->socket(SocketNS::SOCK_STREAM, 1024, max_buf);
+		visRaw=wireless->socket(Socket::SOCK_STREAM, 1024, max_buf);
 		args.push_back("tcp");
 	} else {
-		serr->printf("ERROR: Invalid Config::vision.rawcam_transport: %d\n",config->vision.rawcam_transport);
+		serr->printf("ERROR: Invalid Config::vision.rawcam.transport: %d\n",*config->vision.rawcam.transport);
 		return;
 	}
 	wireless->setDaemon(visRaw,true);
 	wireless->setReceiver(visRaw,networkCallback);
-	wireless->listen(visRaw,config->vision.rawcam_port);
+	wireless->listen(visRaw,config->vision.rawcam.port);
 	
-	Controller::loadGUI("org.tekkotsu.mon.VisionGUI","RawVisionGUI",config->vision.rawcam_port,args);
+	Controller::loadGUI("org.tekkotsu.mon.VisionGUI","RawVisionGUI",*config->vision.rawcam.port,args);
 }
 
 bool
@@ -172,11 +172,13 @@ RawCamBehavior::openPacket(FilterBankGenerator& fbkgen, unsigned int time, unsig
 	ASSERT(cur==NULL,"cur non-NULL");
 	cur=NULL;
 	char * buf=packet=(char*)visRaw->getWriteBuffer(avail);
-	ASSERTRETVAL(packet!=NULL,"dropped frame, network bandwidth is saturated (reduce frame rate or size)",false);
+	ASSERT(packet!=NULL,"dropped frame, network bandwidth is saturated (reduce frame rate or size)");
+	if(packet==NULL)
+		return false;
 	
 	if(!LoadSave::encodeInc("TekkotsuImage",buf,avail,"ran out of space %s:%un",__FILE__,__LINE__)) return false;;
-	if(!LoadSave::encodeInc(config->vision.rawcam_encoding,buf,avail,"ran out of space %s:%un",__FILE__,__LINE__)) return false;;
-	if(!LoadSave::encodeInc(config->vision.rawcam_compression,buf,avail,"ran out of space %s:%un",__FILE__,__LINE__)) return false;;
+	if(!LoadSave::encodeInc(*config->vision.rawcam.encoding,buf,avail,"ran out of space %s:%un",__FILE__,__LINE__)) return false;;
+	if(!LoadSave::encodeInc(*config->vision.rawcam.compression,buf,avail,"ran out of space %s:%un",__FILE__,__LINE__)) return false;;
 
 	if(!LoadSave::encodeInc(fbkgen.getWidth(layer),buf,avail,"ran out of space %s:%un",__FILE__,__LINE__)) return false;;
 	if(!LoadSave::encodeInc(fbkgen.getHeight(layer),buf,avail,"ran out of space %s:%un",__FILE__,__LINE__)) return false;;
@@ -191,12 +193,12 @@ bool
 RawCamBehavior::writeColor(const FilterBankEvent& e) {
 	FilterBankGenerator& fbkgen=*e.getSource();
 
-	unsigned int y_layer=fbkgen.getNumLayers()-1-config->vision.rawcam_y_skip;
-	unsigned int uv_layer=fbkgen.getNumLayers()-1-config->vision.rawcam_uv_skip;
+	unsigned int y_layer=fbkgen.getNumLayers()-1-config->vision.rawcam.y_skip;
+	unsigned int uv_layer=fbkgen.getNumLayers()-1-config->vision.rawcam.uv_skip;
 
-	if(config->vision.rawcam_channel==-1) {
-		if(e.getGeneratorID()==EventBase::visRawCameraEGID && config->vision.rawcam_compression==Config::vision_config::COMPRESS_NONE
-			 || e.getGeneratorID()==EventBase::visJPEGEGID && config->vision.rawcam_compression==Config::vision_config::COMPRESS_JPEG) {
+	if(config->vision.rawcam.channel==-1) {
+		if(e.getGeneratorID()==EventBase::visRawCameraEGID && config->vision.rawcam.compression==Config::vision_config::RawCamConfig::COMPRESS_NONE
+			 || e.getGeneratorID()==EventBase::visJPEGEGID && config->vision.rawcam.compression==Config::vision_config::RawCamConfig::COMPRESS_JPEG) {
 			if(const JPEGGenerator* jgen=dynamic_cast<const JPEGGenerator*>(&fbkgen))
 				if(jgen->getCurrentSourceFormat()==JPEGGenerator::SRC_COLOR)
 					return true;
@@ -212,10 +214,10 @@ RawCamBehavior::writeColor(const FilterBankEvent& e) {
 			if(!LoadSave::encodeInc("blank",cur,avail,"ran out of space %s:%un",__FILE__,__LINE__)) return false;;
 
 			fbkgen.selectSaveImage(uv_layer,RawCameraGenerator::CHAN_U);
-			if(!LoadSave::checkInc(fbkgen.saveBuffer(cur,avail),cur,avail,"image size too large -- may need to set Config::vision.rawcam_transport to TCP and reopen raw cam")) return false;
+			if(!LoadSave::checkInc(fbkgen.saveBuffer(cur,avail),cur,avail,"image size too large -- may need to set Config::vision.rawcam.transport to TCP and reopen raw cam")) return false;
 			
 			fbkgen.selectSaveImage(uv_layer,RawCameraGenerator::CHAN_V);
-			if(!LoadSave::checkInc(fbkgen.saveBuffer(cur,avail),cur,avail,"image size too large -- may need to set Config::vision.rawcam_transport to TCP and reopen raw cam")) return false;
+			if(!LoadSave::checkInc(fbkgen.saveBuffer(cur,avail),cur,avail,"image size too large -- may need to set Config::vision.rawcam.transport to TCP and reopen raw cam")) return false;
 
 			closePacket();
 		}
@@ -229,7 +231,7 @@ RawCamBehavior::writeColor(const FilterBankEvent& e) {
 		small_layer=y_layer;
 	}
 	if(const JPEGGenerator* jgen=dynamic_cast<const JPEGGenerator*>(&fbkgen)) {
-		if(config->vision.rawcam_compression!=Config::vision_config::COMPRESS_JPEG)
+		if(config->vision.rawcam.compression!=Config::vision_config::RawCamConfig::COMPRESS_JPEG)
 			return true;
 		if(jgen->getCurrentSourceFormat()==JPEGGenerator::SRC_COLOR && big_layer-small_layer<2) {
 			openPacket(fbkgen,e.getTimeStamp(),big_layer);
@@ -237,7 +239,7 @@ RawCamBehavior::writeColor(const FilterBankEvent& e) {
 				return false;
 			
 			fbkgen.selectSaveImage(big_layer,0);
-			if(!LoadSave::checkInc(fbkgen.saveBuffer(cur,avail),cur,avail,"image size too large -- may need to set Config::vision.rawcam_transport to TCP and reopen raw cam")) return false;
+			if(!LoadSave::checkInc(fbkgen.saveBuffer(cur,avail),cur,avail,"image size too large -- may need to set Config::vision.rawcam.transport to TCP and reopen raw cam")) return false;
 			
 			closePacket();
 		} else if(jgen->getCurrentSourceFormat()==JPEGGenerator::SRC_GRAYSCALE && big_layer-small_layer>=2) {
@@ -247,12 +249,12 @@ RawCamBehavior::writeColor(const FilterBankEvent& e) {
 			
 			if(big_layer==y_layer) {
 				fbkgen.selectSaveImage(y_layer,RawCameraGenerator::CHAN_Y);
-				if(!LoadSave::checkInc(fbkgen.saveBuffer(cur,avail),cur,avail,"image size too large -- may need to set Config::vision.rawcam_transport to TCP and reopen raw cam")) return false;
+				if(!LoadSave::checkInc(fbkgen.saveBuffer(cur,avail),cur,avail,"image size too large -- may need to set Config::vision.rawcam.transport to TCP and reopen raw cam")) return false;
 			} else {
 				fbkgen.selectSaveImage(uv_layer,RawCameraGenerator::CHAN_U);
-				if(!LoadSave::checkInc(fbkgen.saveBuffer(cur,avail),cur,avail,"image size too large -- may need to set Config::vision.rawcam_transport to TCP and reopen raw cam")) return false;
+				if(!LoadSave::checkInc(fbkgen.saveBuffer(cur,avail),cur,avail,"image size too large -- may need to set Config::vision.rawcam.transport to TCP and reopen raw cam")) return false;
 				fbkgen.selectSaveImage(uv_layer,RawCameraGenerator::CHAN_V);
-				if(!LoadSave::checkInc(fbkgen.saveBuffer(cur,avail),cur,avail,"image size too large -- may need to set Config::vision.rawcam_transport to TCP and reopen raw cam")) return false;
+				if(!LoadSave::checkInc(fbkgen.saveBuffer(cur,avail),cur,avail,"image size too large -- may need to set Config::vision.rawcam.transport to TCP and reopen raw cam")) return false;
 			}
 			
 			if(!opened)
@@ -261,25 +263,25 @@ RawCamBehavior::writeColor(const FilterBankEvent& e) {
 	} else {
 		bool opened=false;
 		
-		if(config->vision.rawcam_compression==Config::vision_config::COMPRESS_NONE || big_layer-small_layer>=2 && big_layer==uv_layer) {
+		if(config->vision.rawcam.compression==Config::vision_config::RawCamConfig::COMPRESS_NONE || big_layer-small_layer>=2 && big_layer==uv_layer) {
 			opened=openPacket(fbkgen,e.getTimeStamp(),big_layer);
 			if(cur==NULL) //error should have been displayed by openPacket
 				return false;
 			fbkgen.selectSaveImage(y_layer,RawCameraGenerator::CHAN_Y);
-			if(!LoadSave::checkInc(fbkgen.saveBuffer(cur,avail),cur,avail,"image size too large -- may need to set Config::vision.rawcam_transport to TCP and reopen raw cam")) return false;
+			if(!LoadSave::checkInc(fbkgen.saveBuffer(cur,avail),cur,avail,"image size too large -- may need to set Config::vision.rawcam.transport to TCP and reopen raw cam")) return false;
 		}
 		
-		if(config->vision.rawcam_compression==Config::vision_config::COMPRESS_NONE || big_layer-small_layer>=2 && big_layer==y_layer) {
+		if(config->vision.rawcam.compression==Config::vision_config::RawCamConfig::COMPRESS_NONE || big_layer-small_layer>=2 && big_layer==y_layer) {
 			opened=openPacket(fbkgen,e.getTimeStamp(),big_layer);
 			if(cur==NULL) //error should have been displayed by openPacket
 				return false;
 			fbkgen.selectSaveImage(uv_layer,RawCameraGenerator::CHAN_U);
-			if(!LoadSave::checkInc(fbkgen.saveBuffer(cur,avail),cur,avail,"image size too large -- may need to set Config::vision.rawcam_transport to TCP and reopen raw cam")) return false;
+			if(!LoadSave::checkInc(fbkgen.saveBuffer(cur,avail),cur,avail,"image size too large -- may need to set Config::vision.rawcam.transport to TCP and reopen raw cam")) return false;
 			fbkgen.selectSaveImage(uv_layer,RawCameraGenerator::CHAN_V);
-			if(!LoadSave::checkInc(fbkgen.saveBuffer(cur,avail),cur,avail,"image size too large -- may need to set Config::vision.rawcam_transport to TCP and reopen raw cam")) return false;
+			if(!LoadSave::checkInc(fbkgen.saveBuffer(cur,avail),cur,avail,"image size too large -- may need to set Config::vision.rawcam.transport to TCP and reopen raw cam")) return false;
 		}
 		
-		if(config->vision.rawcam_compression==Config::vision_config::COMPRESS_NONE || !opened)
+		if(config->vision.rawcam.compression==Config::vision_config::RawCamConfig::COMPRESS_NONE || !opened)
 			closePacket();
 	}
 	
@@ -289,20 +291,20 @@ RawCamBehavior::writeColor(const FilterBankEvent& e) {
 bool
 RawCamBehavior::writeSingleChannel(const FilterBankEvent& e) {
 	FilterBankGenerator& fbkgen=*e.getSource();
-	if( config->vision.rawcam_compression==Config::vision_config::COMPRESS_NONE && e.getGeneratorID()==EventBase::visRawCameraEGID
-			|| config->vision.rawcam_compression==Config::vision_config::COMPRESS_JPEG && e.getGeneratorID()==EventBase::visJPEGEGID )
+	if( config->vision.rawcam.compression==Config::vision_config::RawCamConfig::COMPRESS_NONE && e.getGeneratorID()==EventBase::visRawCameraEGID
+			|| config->vision.rawcam.compression==Config::vision_config::RawCamConfig::COMPRESS_JPEG && e.getGeneratorID()==EventBase::visJPEGEGID )
 		{
 			if(const JPEGGenerator * jgen=dynamic_cast<const JPEGGenerator*>(&fbkgen))
 				if(jgen->getCurrentSourceFormat()!=JPEGGenerator::SRC_GRAYSCALE)
 					return true;
-			unsigned int layer=fbkgen.getNumLayers()-1-config->vision.rawcam_y_skip;
+			unsigned int layer=fbkgen.getNumLayers()-1-config->vision.rawcam.y_skip;
 			
 			openPacket(fbkgen,e.getTimeStamp(),layer);
 			if(cur==NULL) //error should have been displayed by openPacket
 				return false;
 			
-			fbkgen.selectSaveImage(layer,config->vision.rawcam_channel);
-			if(!LoadSave::checkInc(fbkgen.saveBuffer(cur,avail),cur,avail,"image size too large -- may need to set Config::vision.rawcam_transport to TCP and reopen raw cam")) return false;
+			fbkgen.selectSaveImage(layer,config->vision.rawcam.channel);
+			if(!LoadSave::checkInc(fbkgen.saveBuffer(cur,avail),cur,avail,"image size too large -- may need to set Config::vision.rawcam.transport to TCP and reopen raw cam")) return false;
 			
 			closePacket();
 		}
@@ -317,7 +319,7 @@ RawCamBehavior::closePacket() {
 		return;
 	visRaw->write(cur-packet);
 	/*	cout << "used=" << (cur-packet) << "\tavail==" << avail;
-	if(state->robotDesign & WorldState::ERS7Mask)
+	if(RobotName == ERS7Info::TargetName)
 		cout << "\tmax bandwidth=" << (cur-packet)/1024.f*30 << "KB/sec" << endl;
 	else
 		cout << "\tmax bandwidth=" << (cur-packet)/1024.f*24 << "KB/sec" << endl;
@@ -349,9 +351,9 @@ RawCamBehavior::sendCloseConnectionPacket() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.33 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.37 $
  * $State: Exp $
- * $Date: 2006/09/14 18:57:03 $
+ * $Date: 2007/06/26 04:27:44 $
  */
 
