@@ -20,8 +20,8 @@ class FilterBankEvent;
  *
  *  I emphasize: <i>beginning</i> of each Vision packet, <i>before</i> the FilterBankGenerator header. 
  *  - <@c string:"TekkotsuImage">
- *  - <<tt>Config::vision_config::encoding_t</tt>: rawcam_encoding> <i>(expect single or multiple channels, 0 means color (3 channels), 1 means intensity (1 channel))</i>
- *  - <<tt>Config::vision_config::compression_t</tt>: rawcam_compression> <i>(0==none, 1==jpeg, 2==rle)</i>
+ *  - <<tt>Config::vision_config::encoding_t</tt>: rawcam.encoding> <i>(expect single or multiple channels, 0 means color (3 channels), 1 means intensity (1 channel))</i>
+ *  - <<tt>Config::vision_config::compression_t</tt>: rawcam.compression> <i>(0==none, 1==jpeg, 2==rle)</i>
  *  - <@c unsigned @c int: width> <i>(this is the width of the largest channel - note different channels can be sent at different resolutions!  Provides cheap "compression" of chromaticity channels)</i>
  *  - <@c unsigned @c int: height> <i>(similarly, height of largest channel)</i>
  *  - <@c unsigned @c int: timestamp> <i>(time image was taken, milliseconds since boot)</i>
@@ -46,7 +46,11 @@ public:
 	//! destructor
 	~RawCamBehavior() { theOne=NULL; }
 
+#ifdef PLATFORM_APERIOS
 	static const unsigned int TCP_WIRELESS_BUFFER_SIZE=200000; //!< 200000 bytes for use up to 416x320 + 2*208x160 (double res Y, full res UV on ERS-7)
+#else
+	static const unsigned int TCP_WIRELESS_BUFFER_SIZE=901*1024; //!< 900KB for max of full-color 640x480 + 1KB for header
+#endif
 	static const unsigned int UDP_WIRELESS_BUFFER_SIZE=64*1024; //!< 64KB is the max udp packet size
 
 	virtual void DoStart();
@@ -57,7 +61,7 @@ public:
 
 	static std::string getClassDescription() {
 		char tmp[20];
-		snprintf(tmp,20,"%d",config->vision.rawcam_port); tmp[19]='\0';
+		snprintf(tmp,20,"%d",*config->vision.rawcam.port); tmp[19]='\0';
 		return std::string("Forwards images from camera over port ")+tmp;
 	}
 	virtual std::string getDescription() const { return getClassDescription(); }
@@ -101,10 +105,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.18 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.21 $
  * $State: Exp $
- * $Date: 2006/09/16 17:32:38 $
+ * $Date: 2007/06/07 18:24:42 $
  */
 
 #endif
