@@ -35,8 +35,8 @@ void
 SegCamBehavior::processEvent(const EventBase& e) {
 	if(!wireless->isConnected(visRLE->sock))
 		return;
-	if(config->vision.segcam_transport==0 && visRLE->getTransport()==SocketNS::SOCK_STREAM
-		 || config->vision.segcam_transport==1 && visRLE->getTransport()==SocketNS::SOCK_DGRAM) {
+	if(config->vision.segcam.transport==0 && visRLE->getTransport()==Socket::SOCK_STREAM
+		 || config->vision.segcam.transport==1 && visRLE->getTransport()==Socket::SOCK_DGRAM) {
 		closeServer();
 		setupServer();
 		return;
@@ -47,9 +47,9 @@ SegCamBehavior::processEvent(const EventBase& e) {
 			CameraStreamBehavior::processEvent(e);
 			return;
 		}
-		if ((get_time() - lastProcessedTime) < config->vision.segcam_interval) // not enough time has gone by
+		if ((get_time() - lastProcessedTime) < config->vision.segcam.interval) // not enough time has gone by
 			return;
-		if(config->vision.segcam_compression==Config::vision_config::COMPRESS_NONE && e.getGeneratorID()==EventBase::visSegmentEGID) {
+		if(config->vision.segcam.compression==Config::vision_config::SegCamConfig::COMPRESS_NONE && e.getGeneratorID()==EventBase::visSegmentEGID) {
 			if(!writeSeg(*fbke)) {
 				if(packet!=NULL) {
 					cur=packet;
@@ -59,7 +59,7 @@ SegCamBehavior::processEvent(const EventBase& e) {
 				//ASSERTRET(succ,"serialization failed");
 			}
 		}
-		if(config->vision.segcam_compression==Config::vision_config::COMPRESS_RLE && e.getGeneratorID()==EventBase::visRLEEGID) {
+		if(config->vision.segcam.compression==Config::vision_config::SegCamConfig::COMPRESS_RLE && e.getGeneratorID()==EventBase::visRLEEGID) {
 			if(!writeRLE(*fbke)) {
 				if(packet!=NULL) {
 					cur=packet;
@@ -98,25 +98,25 @@ SegCamBehavior::setupServer() {
 	std::vector<std::string> args;
 	args.push_back("rle");
 	char port[50];
-	snprintf(port,50,"%d",config->vision.segcam_port);
+	snprintf(port,50,"%d",*config->vision.segcam.port);
 	args.push_back(port);
-	if(config->vision.segcam_transport==0) {
+	if(config->vision.segcam.transport==0) {
 		max_buf=UDP_WIRELESS_BUFFER_SIZE;
-		visRLE=wireless->socket(SocketNS::SOCK_DGRAM, 1024, max_buf);
+		visRLE=wireless->socket(Socket::SOCK_DGRAM, 1024, max_buf);
 		args.push_back("udp");
-	} else if(config->vision.segcam_transport==1) {
+	} else if(config->vision.segcam.transport==1) {
 		max_buf=TCP_WIRELESS_BUFFER_SIZE;
-		visRLE=wireless->socket(SocketNS::SOCK_STREAM, 1024, max_buf);
+		visRLE=wireless->socket(Socket::SOCK_STREAM, 1024, max_buf);
 		args.push_back("tcp");
 	} else {
-		serr->printf("ERROR: Invalid Config::vision.segcam_transport: %d\n",config->vision.segcam_transport);
+		serr->printf("ERROR: Invalid Config::vision.segcam.transport: %d\n",*config->vision.segcam.transport);
 		return;
 	}
 	wireless->setDaemon(visRLE,true);
 	wireless->setReceiver(visRLE,networkCallback);
-	wireless->listen(visRLE,config->vision.segcam_port);
+	wireless->listen(visRLE,config->vision.segcam.port);
 	
-	Controller::loadGUI("org.tekkotsu.mon.VisionGUI","SegVisionGUI",config->vision.segcam_port,args);
+	Controller::loadGUI("org.tekkotsu.mon.VisionGUI","SegVisionGUI",config->vision.segcam.port,args);
 }
 
 bool
@@ -128,11 +128,13 @@ SegCamBehavior::openPacket(FilterBankGenerator& fbkgen, unsigned int time, unsig
 	ASSERT(cur==NULL,"cur non-NULL");
 	cur=NULL;
 	char * buf=packet=(char*)visRLE->getWriteBuffer(avail);
-	ASSERTRETVAL(packet!=NULL,"dropped frame, network bandwidth is saturated (reduce frame rate or size)",false);
+	ASSERT(packet!=NULL,"dropped frame, network bandwidth is saturated (reduce frame rate or size)");
+	if(packet==NULL)
+		return false;
 	
 	if(!LoadSave::encodeInc("TekkotsuImage",buf,avail,"ran out of space %s:%u\n",__FILE__,__LINE__)) return false;;
-	if(!LoadSave::encodeInc(Config::vision_config::ENCODE_SINGLE_CHANNEL,buf,avail,"ran out of space %s:%u\n",__FILE__,__LINE__)) return false;;
-	if(!LoadSave::encodeInc(Config::vision_config::COMPRESS_RLE,buf,avail,"ran out of space %s:%u\n",__FILE__,__LINE__)) return false;;
+	if(!LoadSave::encodeInc(Config::vision_config::RawCamConfig::ENCODE_SINGLE_CHANNEL,buf,avail,"ran out of space %s:%u\n",__FILE__,__LINE__)) return false;;
+	if(!LoadSave::encodeInc(Config::vision_config::SegCamConfig::COMPRESS_RLE,buf,avail,"ran out of space %s:%u\n",__FILE__,__LINE__)) return false;;
 
 	if(!LoadSave::encodeInc(fbkgen.getWidth(layer),buf,avail,"ran out of space %s:%u\n",__FILE__,__LINE__)) return false;;
 	if(!LoadSave::encodeInc(fbkgen.getHeight(layer),buf,avail,"ran out of space %s:%u\n",__FILE__,__LINE__)) return false;;
@@ -147,7 +149,7 @@ bool
 SegCamBehavior::writeRLE(const FilterBankEvent& e) {
 	FilterBankGenerator& fbkgen=*e.getSource();
 
-	unsigned int layer=fbkgen.getNumLayers()-1-config->vision.segcam_skip;
+	unsigned int layer=fbkgen.getNumLayers()-1-config->vision.segcam.skip;
 	openPacket(fbkgen,e.getTimeStamp(),layer);
 	if(cur==NULL) //error should have been displayed by openPacket
 		return false;
@@ -155,8 +157,8 @@ SegCamBehavior::writeRLE(const FilterBankEvent& e) {
 	RLEGenerator * rle = dynamic_cast<RLEGenerator*>(&fbkgen);
 	ASSERTRETVAL(rle!=NULL,"fbkgen isn't an RLEGenerator",false);
 
-	rle->selectSaveImage(layer,config->vision.segcam_channel);
-	if(!LoadSave::checkInc(rle->saveBuffer(cur,avail),cur,avail,"image size too large -- may need to set Config::vision.segcam_transport to TCP and reopen seg cam")) return false;
+	rle->selectSaveImage(layer,config->vision.segcam.channel);
+	if(!LoadSave::checkInc(rle->saveBuffer(cur,avail),cur,avail,"image size too large -- may need to set Config::vision.segcam.transport to TCP and reopen seg cam")) return false;
 	
 	// send out the color map ourselves (since RLE compression doesn't have a concept of color)
 	const SegmentedColorGenerator * seg = dynamic_cast<const SegmentedColorGenerator*>(rle->getSourceGenerator());
@@ -172,13 +174,13 @@ bool
 SegCamBehavior::writeSeg(const FilterBankEvent& e) {
 	FilterBankGenerator& fbkgen=*e.getSource();
 
-	unsigned int layer=fbkgen.getNumLayers()-1-config->vision.segcam_skip;
+	unsigned int layer=fbkgen.getNumLayers()-1-config->vision.segcam.skip;
 	openPacket(fbkgen,e.getTimeStamp(),layer);
 	if(cur==NULL) //error should have been displayed by openPacket
 		return false;
 	
-	fbkgen.selectSaveImage(layer,config->vision.segcam_channel);
-	if(!LoadSave::checkInc(fbkgen.saveBuffer(cur,avail),cur,avail,"image size too large -- may need to set Config::vision.segcam_transport to TCP and reopen seg cam")) return false;
+	fbkgen.selectSaveImage(layer,config->vision.segcam.channel);
+	if(!LoadSave::checkInc(fbkgen.saveBuffer(cur,avail),cur,avail,"image size too large -- may need to set Config::vision.segcam.transport to TCP and reopen seg cam")) return false;
 	
 	closePacket();
 
@@ -216,9 +218,9 @@ SegCamBehavior::sendCloseConnectionPacket() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.26 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.29 $
  * $State: Exp $
- * $Date: 2006/09/14 18:57:03 $
+ * $Date: 2007/05/21 20:51:20 $
  */
 
