@@ -63,7 +63,11 @@ public:
 	//! destructor
 	~SegCamBehavior() { theOne=NULL; }
 
+#if defined(TGT_ERS210) || defined(TGT_ERS220) || defined(TGT_ERS2xx) || defined(TGT_ERS7)
 	static const unsigned int TCP_WIRELESS_BUFFER_SIZE=85000; //!< 85000 bytes for use up to 416x320 pixels / 8 min expected runs * 5 bytes per run + some padding
+#else
+	static const unsigned int TCP_WIRELESS_BUFFER_SIZE=301*1024; //!< 300KB for use up to 640x480 pixels / 8 min expected runs * 5 bytes per run + some padding
+#endif
 	static const unsigned int UDP_WIRELESS_BUFFER_SIZE=64*1024; //!< 64KB is the max udp packet size
 
 	virtual void DoStart();
@@ -74,7 +78,7 @@ public:
 
 	static std::string getClassDescription() {
 		char tmp[20];
-		snprintf(tmp,20,"%d",config->vision.segcam_port); tmp[19]='\0';
+		snprintf(tmp,20,"%d",*config->vision.segcam.port); tmp[19]='\0';
 		return std::string("Forwards segmented images from camera over port ")+tmp;
 	}
 	virtual std::string getDescription() const { return getClassDescription(); }
@@ -114,10 +118,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.13 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.15 $
  * $State: Exp $
- * $Date: 2006/09/16 20:11:50 $
+ * $Date: 2007/05/01 21:21:07 $
  */
 
 #endif
