@@ -7,11 +7,11 @@
 
 SpeakerServer* SpeakerServer::instance = 0;
 
-SpeakerServer* SpeakerServer::GetInstance() {
+SpeakerServer& SpeakerServer::getInstance() {
 	if (instance == 0) {
 		instance = new SpeakerServer();
 	}
-	return instance;
+	return *instance;
 }
 
 SpeakerServer::SpeakerServer()
@@ -45,7 +45,7 @@ void SpeakerServer::DoStart() {
 	channel = SoundManager::invalid_Play_ID;
 		
 	socket =
-		wireless->socket(SocketNS::SOCK_STREAM, RECEIVE_BUFFER_SIZE + 8, 512);
+		wireless->socket(Socket::SOCK_STREAM, RECEIVE_BUFFER_SIZE + 8, 512);
 	wireless->setReceiver(socket->sock, socket_callback);
 	wireless->setDaemon(socket, true);
 	wireless->listen(socket->sock, config->sound.streaming.speaker_port);
