@@ -27,7 +27,7 @@ public:
 
 	static std::string getClassDescription() {
 		char tmp[20];
-		sprintf(tmp,"%d",config->main.wmmonitor_port);
+		sprintf(tmp,"%d",*config->main.wmmonitor_port);
 		return std::string("Brings up the WatchableMemory GUI on port ")+tmp+std::string(" (connects to WMMonitorBehavior, this just launches the GUI)");
 	}
 	virtual std::string getDescription() const { return getClassDescription(); }
@@ -38,10 +38,10 @@ public:
  * @author ejt (Creator)
  * 
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.3 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.4 $
  * $State: Exp $
- * $Date: 2004/11/11 01:45:36 $
+ * $Date: 2007/01/30 22:56:19 $
  */
 
 #endif 
