@@ -65,7 +65,7 @@ class WMMonitorBehavior : public BehaviorBase {
 		// Behavior startup
 		BehaviorBase::DoStart();
 		// Turn on wireless
-		cmdsock=wireless->socket(SocketNS::SOCK_STREAM, 2048, 8192);
+		cmdsock=wireless->socket(Socket::SOCK_STREAM, 2048, 8192);
 		wireless->setReceiver(cmdsock->sock, wmmonitorcmd_callback);
 		wireless->setDaemon(cmdsock,true); 
 		wireless->listen(cmdsock->sock, config->main.wmmonitor_port);
@@ -100,7 +100,7 @@ class WMMonitorBehavior : public BehaviorBase {
 
 	static std::string getClassDescription() { 
 		char tmp[20];
-		sprintf(tmp,"%d",config->main.wmmonitor_port);
+		sprintf(tmp,"%d",*config->main.wmmonitor_port);
 		return std::string("Bidirectional control communication with WMMonitor on port ")+tmp;
 	}
 	virtual std::string getDescription() const { return getClassDescription(); }
@@ -136,10 +136,10 @@ protected:
  * @author alokl (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.9 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.11 $
  * $State: Exp $
- * $Date: 2004/11/11 01:45:36 $
+ * $Date: 2007/05/21 20:51:20 $
  */
 
 #endif 
