@@ -101,7 +101,7 @@ void WalkControllerBehavior::DoStart() {
 	// Turn on wireless
 	theLastOne=theOne;
 	theOne=this;
-	cmdsock=wireless->socket(SocketNS::SOCK_STREAM, 2048, 2048);
+	cmdsock=wireless->socket(Socket::SOCK_STREAM, 2048, 2048);
 	wireless->setReceiver(cmdsock->sock, mechacmd_callback);
 	wireless->setDaemon(cmdsock,true); 
 	wireless->listen(cmdsock->sock, config->main.walkControl_port);
@@ -167,9 +167,9 @@ int WalkControllerBehavior::mechacmd_callback(char *buf, int bytes) {
  * @author PA Gov. School for the Sciences 2003 Team Project - Haoqian Chen, Yantian Martin, Jon Stahlman (modifications)
  * 
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.12 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.13 $
  * $State: Exp $
- * $Date: 2006/09/18 18:08:07 $
+ * $Date: 2007/05/21 20:51:20 $
  */
 
