@@ -2,8 +2,6 @@
 #ifndef INCLUDED_WalkControllerBehavior_h_
 #define INCLUDED_WalkControllerBehavior_h_
 
-#include <iostream>
-#include "Wireless/Wireless.h"
 #include "Behaviors/BehaviorBase.h"
 #include "Motion/MotionManager.h"
 #include "Motion/WalkMC.h"
@@ -11,6 +9,9 @@
 #include "Events/EventRouter.h"
 #include "Events/EventBase.h"
 #include "Shared/Config.h"
+#include "Wireless/Wireless.h"
+
+#include <iostream>
 
 //! Listens to control commands coming in from the command port for remotely controlling the walk
 /*! The communication protocol is a very simple binary format, shared
@@ -102,7 +103,7 @@ class WalkControllerBehavior : public BehaviorBase {
 
 	static std::string getClassDescription() {
 		char tmp[20];
-		sprintf(tmp,"%d",config->main.walkControl_port);
+		sprintf(tmp,"%d",*config->main.walkControl_port);
 		return std::string("Listens to walk control commands coming in from port ")+tmp;
 	}
 	virtual std::string getDescription() const { return getClassDescription(); }
@@ -115,10 +116,10 @@ class WalkControllerBehavior : public BehaviorBase {
  * @author PA Gov. School for the Sciences 2003 Team Project - Haoqian Chen, Yantian Martin, Jon Stahlman (modifications)
  * 
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.5 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.7 $
  * $State: Exp $
- * $Date: 2005/09/13 22:10:36 $
+ * $Date: 2007/08/28 18:31:15 $
  */
 
 #endif 
