@@ -6,6 +6,9 @@
 #include "Events/EventRouter.h"
 #include "Shared/LoadSave.h"
 
+//! a little trick to get RobotName length under aperios, which has to use a string class instead of char*
+inline size_t strlen(const std::string& st) { return st.size(); }
+
 WorldStateSerializerBehavior::WorldStateSerializerBehavior()
 : BehaviorBase("WorldStateSerializerBehavior"), wsJoints(NULL), wsPIDs(NULL), lastProcessedTime(0)
 {
@@ -15,13 +18,13 @@ void WorldStateSerializerBehavior::DoStart() {
 	BehaviorBase::DoStart(); // do this first
 	
 	const unsigned int transmitPIDSize=(NumPIDJoints*3)*LoadSave::getSerializedSize<float>()+2*LoadSave::getSerializedSize<unsigned int>();
-	wsPIDs=wireless->socket(SocketNS::SOCK_STREAM, 1024, transmitPIDSize*4); // enough for 4 packets queued up
+	wsPIDs=wireless->socket(Socket::SOCK_STREAM, 1024, transmitPIDSize*4); // enough for 4 packets queued up
 	wireless->setDaemon(wsPIDs);
 	wireless->listen(wsPIDs, config->main.wspids_port);
 
 	const size_t robotNameLen=strlen(RobotName)+1; //note the +1 to include '\0' at the end
 	const size_t transmitJointsSize=(NumOutputs+NumSensors+NumButtons+NumPIDJoints)*LoadSave::getSerializedSize<float>()+6*LoadSave::getSerializedSize<unsigned int>()+robotNameLen;
-	wsJoints=wireless->socket(SocketNS::SOCK_STREAM, 1024, transmitJointsSize*4); // enough for 4 packets queued up
+	wsJoints=wireless->socket(Socket::SOCK_STREAM, 1024, transmitJointsSize*4); // enough for 4 packets queued up
 	wireless->setDaemon(wsJoints);
 	wireless->listen(wsJoints, config->main.wsjoints_port);
 		
@@ -125,8 +128,8 @@ void WorldStateSerializerBehavior::processEvent(const EventBase& e) {
 * @author alokl (Creator)
 *
 * $Author: ejt $
-* $Name: tekkotsu-3_0 $
-* $Revision: 1.10 $
+* $Name: tekkotsu-4_0-branch $
+* $Revision: 1.12 $
 * $State: Exp $
-* $Date: 2006/09/19 22:51:38 $
+* $Date: 2007/06/26 04:27:44 $
 */
