@@ -4,6 +4,7 @@
 
 #include "Behaviors/BehaviorBase.h"
 #include "Shared/Config.h"
+#include <string>
 
 class Socket;
 
@@ -38,7 +39,7 @@ public:
 	virtual void processEvent(const EventBase& e); //!< core functionality - performs serialization, sends to sockets
 	static std::string getClassDescription() {
 		char tmp[80];
-		sprintf(tmp,"Sends sensor information to port %d and current pid values to port %d",config->main.wsjoints_port,config->main.wspids_port);
+		sprintf(tmp,"Sends sensor information to port %d and current pid values to port %d",*config->main.wsjoints_port,*config->main.wspids_port);
 		return tmp;
 	}
 	virtual std::string getDescription() const { return getClassDescription(); }
@@ -60,10 +61,16 @@ protected:
 	//! writes @a num copies of T from @a src to @a dst and advances @a dst by @a num * sizeof(T)
 	/*! doesn't do any byte swapping, so this is only used if LoadSave indicates no byte swapping is needed */
 	template<class T>
-	inline static void copy(char **dst, const T * src, int num) {
+	inline static void copy(char **dst, const T * src, size_t num) {
 		memcpy(*dst, src, num*sizeof(T));
 		(*dst) += num*sizeof(T);
 	}
+	
+	//! writes @a num characters from @a src to @a dst and advances @a dst by @a num * sizeof(T)
+	inline static void copy(char **dst, const std::string& src, size_t num) {
+		memcpy(*dst, src.c_str(), num*sizeof(std::string::value_type));
+		(*dst) += num*sizeof(std::string::value_type);
+	}
 
 	Socket *wsJoints; //!< socket for sending current joint data
 	Socket *wsPIDs; //!< socket for sending current PID info
@@ -79,10 +86,10 @@ private:
  * @author alokl (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.8 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.10 $
  * $State: Exp $
- * $Date: 2006/09/09 23:28:59 $
+ * $Date: 2007/06/26 04:27:44 $
  */
 
 #endif
