@@ -6,6 +6,7 @@
 #include "Motion/MotionManager.h"
 #include "Motion/MotionSequenceMC.h"
 #include "Motion/MMAccessor.h"
+#include "Shared/debuget.h"
 
 //! A StateNode for playing a MotionSequence (and looping it if desired)
 /*! Eventually, i'd like to just build the looping functionality into
@@ -131,11 +132,11 @@ typedef MotionSequenceNode<XLargeMotionSequenceMC::CAPACITY> XLargeMotionSequenc
  * @brief Describes MotionSequenceNode, a StateNode for playing a MotionSequence (and looping it if desired)
  * @author ejt (Creator)
  *
- * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.4 $
+ * $Author: dst $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.5 $
  * $State: Exp $
- * $Date: 2006/09/09 04:32:33 $
+ * $Date: 2007/04/07 02:03:43 $
  */
 
 #endif
