@@ -12,7 +12,7 @@ void Transition::fire() {
 	if(sound.size()!=0)
 		sndman->playFile(sound);
 
-	erouter->postEvent(EventBase::stateTransitionEGID,reinterpret_cast<size_t>(this),EventBase::statusETID,0,getName(),1);
+	erouter->postEvent(EventBase::stateTransitionEGID,reinterpret_cast<size_t>(this),EventBase::activateETID,0,getName(),1);
 
 	for(unsigned int i=0; i<srcs.size(); i++)
 		if(srcs[i]->isActive()) //It's usually a bad idea to call DoStop/DoStart when it's already stopped/started...
@@ -21,6 +21,8 @@ void Transition::fire() {
 		if(!dsts[i]->isActive())
 			dsts[i]->DoStart();
 
+	erouter->postEvent(EventBase::stateTransitionEGID,reinterpret_cast<size_t>(this),EventBase::deactivateETID,0,getName(),0);
+	
 	//serr->printf("%s fire() - leave %d\n",getName().c_str(),get_time());
 	RemoveReference();
 }
@@ -46,9 +48,9 @@ std::string Transition::getName() const {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.18 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.19 $
  * $State: Exp $
- * $Date: 2006/09/18 18:08:05 $
+ * $Date: 2007/03/02 17:20:51 $
  */
 
