@@ -33,15 +33,11 @@ public:
 		ASSERTRET(ve!=NULL,"Casting error");
 		float x=ve->getCenterX();
 		float y=ve->getCenterY();
-		unsigned int IRDistOffset=-1U;
+		unsigned int IRDistOffset=::IRDistOffset;
 		//The ERS-7 adds more IR distance sensors, so we have to
-		//break it down by model so we can specify which one
-		if(state->robotDesign & WorldState::ERS210Mask)
-			IRDistOffset=ERS210Info::IRDistOffset;
-		else if(state->robotDesign & WorldState::ERS220Mask)
-			IRDistOffset=ERS220Info::IRDistOffset;
-		else if(state->robotDesign & WorldState::ERS7Mask)
-			IRDistOffset=ERS7Info::NearIRDistOffset;
+		//break it down so we can specify which one
+		if(RobotName == ERS7Info::TargetName)
+			IRDistOffset=(distanceThreshold<350) ? ERS7Info::NearIRDistOffset : ERS7Info::FarIRDistOffset;
 		if(x*x+y*y<0.02f && IRDistOffset!=-1U && state->sensors[IRDistOffset]<distanceThreshold)
 			fire();
 	}
@@ -59,10 +55,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.15 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.16 $
  * $State: Exp $
- * $Date: 2005/06/13 21:22:41 $
+ * $Date: 2007/06/26 04:27:45 $
  */
 
 #endif
