@@ -19,17 +19,21 @@
 
 #include "BrickOps.h" 
 
+using namespace std;
+
 namespace DualCoding {
 
 BlobData::BlobData(ShapeSpace& _space,
 		   const Point &_topLeft, const Point &_topRight,
 		   const Point &_bottomLeft, const Point &_bottomRight,
 		   const float _area, const std::vector<run> &_runvec,
-		   const BlobOrientation_t _orientation, rgb _rgbvalue) :
+		   const BlobOrientation_t _orientation, coordinate_t _assumedHeight,
+		   rgb _rgbvalue) :
   BaseData(_space, getStaticType()),
+  orientation(_orientation), assumedHeight(_assumedHeight),
   topLeft(_topLeft), topRight(_topRight),
   bottomLeft(_bottomLeft), bottomRight(_bottomRight),
-  area(_area), runvec(_runvec), orientation(_orientation)
+  area(_area), runvec(_runvec)
 {
   setColor(_rgbvalue);
 }
@@ -43,12 +47,13 @@ Point BlobData::getCentroid() const {
 }
   
 void BlobData::printParams() const {
-  cout << "Blob"
-       << " tl=" << topLeft.coords
-       << " tr=" << topRight.coords
-       << " bl=" << bottomLeft.coords
-       << " br=" << bottomRight.coords
-       << " area=" << area
+  cout << "Type = " << getTypeName() << "  ID=" << getId() << "  ParentID=" << getParentId() << endl;
+  printf("  color = %d %d %d\n",getColor().red,getColor().green,getColor().blue);
+  cout << "  tl=" << NEWMAT::printmat(topLeft.coords) << endl
+       << "  tr=" << NEWMAT::printmat(topRight.coords) << endl
+       << "  bl=" << NEWMAT::printmat(bottomLeft.coords) << endl
+       << "  br=" << NEWMAT::printmat(bottomRight.coords) << endl
+       << "  area=" << area << ", assumedHeight=" << assumedHeight
        << endl;
 }
 
@@ -77,39 +82,24 @@ Sketch<bool>* BlobData::render() const {
     }
     break;
   case pillar:
-  case pinata:
-    cout << "BlobData::render() : Can't yet render blobs in pillar/pinata orientations" << endl;
+  case poster:
+    cout << "BlobData::render() : Can't yet render blobs in pillar/poster orientations" << endl;
     break;
   }
   return result;
 }
 
 //! Transformations. (Virtual in BaseData.)
-void BlobData::applyTransform(const NEWMAT::Matrix& Tmat) {
-  switch ( orientation ) {
-
-  case groundplane:
-    topLeft.applyTransform(Tmat);
-    topRight.applyTransform(Tmat);
-    bottomLeft.applyTransform(Tmat);
-    bottomRight.applyTransform(Tmat);
-    break;
-
-  case pillar:
-  case pinata:
-    // *** HACK: THIS IS NOT THE RIGHT WAY TO CALCULATE HEIGHT
-    Point height_incr((topLeft-bottomLeft + topRight-bottomRight) / 2);
-    height_incr.coords << 0 << 0;
-    bottomLeft.applyTransform(Tmat);
-    bottomRight.applyTransform(Tmat);
-    topLeft = bottomLeft + height_incr;
-    topRight = bottomRight + height_incr;
-    break;
-  };
+void BlobData::applyTransform(const NEWMAT::Matrix& Tmat, const ReferenceFrameType_t newref) {
+  topLeft.applyTransform(Tmat,newref);
+  topRight.applyTransform(Tmat,newref);
+  bottomLeft.applyTransform(Tmat,newref);
+  bottomRight.applyTransform(Tmat,newref);
 }
 
 void BlobData::projectToGround(const NEWMAT::Matrix& camToBase,
 			       const NEWMAT::ColumnVector& gndplane) {
+  float const camblob_area = area;
   switch ( orientation ) {
   case groundplane:
     topLeft.projectToGround(camToBase,gndplane);
@@ -118,53 +108,42 @@ void BlobData::projectToGround(const NEWMAT::Matrix& camToBase,
     bottomRight.projectToGround(camToBase,gndplane);
     break;
   case pillar:
-  case pinata:
     bottomLeft.projectToGround(camToBase,gndplane);
     bottomRight.projectToGround(camToBase,gndplane);
-    // DST HACK -- hard coded pillar height 100 mm
     topLeft = bottomLeft;
     topRight = bottomRight;
-    topLeft.coords(3) += 100;
-    topRight.coords(3) += 100;
-  }
-  update_derived_properties();
-}
-
-  /*
-void BlobData::projectToGround(int xres, int yres, const NEWMAT::ColumnVector& gndplane) {
-  switch ( orientation ) {
-  case groundplane:
-    topLeft.projectToGround(xres,yres,gndplane);
-    topRight.projectToGround(xres,yres,gndplane);
-    bottomLeft.projectToGround(xres,yres,gndplane);
-    bottomRight.projectToGround(xres,yres,gndplane);
+    topLeft.coords(3) += assumedHeight;
+    topRight.coords(3) += assumedHeight;
+    break;
+  case poster:
+    // create an elevated plane by shifting the ground plane by assumedHeight
+    NEWMAT::ColumnVector elevatedPlane = gndplane;
+    float displacement = assumedHeight * sqrt(elevatedPlane(1) * elevatedPlane(1) + elevatedPlane(2) * elevatedPlane(2) + elevatedPlane(3) * elevatedPlane(3));
+    elevatedPlane(4) += elevatedPlane(3) >= 0 ? displacement : -displacement;
+    
+    // Project the centroid onto the elevated plane and set all 4 points to the new centroid
+    Point centroid = getCentroid();
+    centroid.projectToGround(camToBase, elevatedPlane);
+    bottomLeft = centroid;
+    bottomRight = centroid;
+    topLeft = centroid;
+    topRight = centroid;
     break;
-  case pillar:
-  case pinata:
-    bottomLeft.projectToGround(xres,yres,gndplane);
-    bottomRight.projectToGround(xres,yres,gndplane);
-    // DST HACK -- hard coded pillar height 100 mm
-    topLeft = bottomLeft;
-    topRight = bottomRight;
-    topLeft.coords(3) += 100;
-    topRight.coords(3) += 100;
   }
   update_derived_properties();
+  area = camblob_area;  // stick with cam area for now
 }
-  */
 
 void BlobData::update_derived_properties() {
   switch ( orientation ) {
 
   case groundplane:
-    // DST HACK -- should use the formula for area of a quadrilaterl
-    area = (topRight+bottomRight-topLeft-bottomLeft).coords(1) *
-           (bottomLeft+bottomRight-topLeft-topRight).coords(2) / 4;
-    break;
-
   case pillar:
-  case pinata:
-    // fill this in later
+  case poster:
+    // DST HACK -- should project each run to ground and integrate,
+    // or use the formula for area of a quadrilateral
+    area = fabs((topRight+bottomRight-topLeft-bottomLeft).coords(1)) *
+           fabs((bottomLeft+bottomRight-topLeft-topRight).coords(2)) / 4;
     break;
   }
 }
@@ -194,42 +173,69 @@ bool BlobData::updateParams(const ShapeRoot& other, bool forceUpdate) {
   topRight = (topRight*confidence + other_blob->topRight*other_conf) / sumconf;
   bottomLeft = (bottomLeft*confidence + other_blob->bottomLeft*other_conf) / sumconf;
   bottomRight = (bottomRight*confidence + other_blob->bottomRight*other_conf) / sumconf;
+  float const newArea = (area*confidence + other_blob->area*other_conf) / sumconf;
   update_derived_properties();
+  area = newArea; // fixup because update_derived_properties currently messes up on pillar and poster areas
   return true;
 }
 
+//================================================================
+// Blob extraction
+
 std::vector<Shape<BlobData> >
 BlobData::extractBlobs(const Sketch<bool> &sketch, 
-		       const set<int>& colors, int minarea,
-		       BlobData::BlobOrientation_t orient, 
+		       int minarea,
+		       BlobOrientation_t orient, 
+		       coordinate_t height,
 		       int maxblobs) {
   // We could multiply sketch*color_index to convert to uchar and
   // spare ourselves the for loop that follows for setting blob
   // colors, but this way is actually much faster because we skip all
   // the pixel-wise multiplications.  Casting Sketch<bool> to
   // Sketch<uchar> is done with a simple reinterpret_cast; no copying.
-  std::vector<Shape<BlobData> > result(extractBlobs((Sketch<uchar>&)sketch,colors,minarea,orient,maxblobs));
-  rgb rgbvalue(sketch->getColor());
+  set<color_index> dummyColors;
+  dummyColors.insert(1); // converting bool to uchar always yields color index 1
+  map<color_index,int> minareas;
+  minareas[1] = minarea;
+  map<color_index,BlobOrientation_t> orients;
+  orients[1] = orient;
+  map<color_index,coordinate_t> heights;
+  heights[1] = height;
+  std::vector<Shape<BlobData> > result(extractBlobs((Sketch<uchar>&)sketch,dummyColors,minareas,orients,heights,maxblobs));
+  rgb sketchColor(sketch->getColor());
   for ( std::vector<Shape<BlobData> >::iterator it = result.begin();
 	it != result.end(); it++ )
-    (*it)->setColor(rgbvalue);
+    (*it)->setColor(sketchColor);
   return result;
 }
 
 std::vector<Shape<BlobData> > 
-BlobData::extractBlobs(const Sketch<bool> &sketch, int minarea,
-	     BlobData::BlobOrientation_t orient, int maxblobs) {
+BlobData::extractBlobs(const Sketch<uchar> &sketch,
+		       int minarea,
+		       BlobOrientation_t orient,
+		       coordinate_t height,
+		       int maxblobs) {
   const int numColors = ProjectInterface::getNumColors();
-  set<int> colors;
-  for (int i = 1; i < numColors; i++) colors.insert(i);
-  return extractBlobs(sketch, colors, minarea, orient, maxblobs);
+  set<color_index> colors;
+  map<color_index,int> minareas;
+  map<color_index,BlobOrientation_t> orients;
+  map<color_index,coordinate_t> heights;
+  for (int i = 1; i < numColors; i++) {
+    colors.insert(i);
+    minareas[i] = minarea;
+    orients[i] = orient;
+    heights[i] = height;
+  }
+  return extractBlobs(sketch, colors, minareas, orients, heights, maxblobs);
 }
-  
 
 std::vector<Shape<BlobData> >
 BlobData::extractBlobs(const Sketch<uchar> &sketch, 
-		       const set<int>& colors, int minarea,
-		       BlobData::BlobOrientation_t orient, int maxblobs) {
+		       const std::set<color_index>& colors,
+		       const std::map<color_index,int>& minareas,
+		       const std::map<color_index,BlobOrientation_t>& orients,
+		       const std::map<color_index,coordinate_t>& heights,
+		       int maxblobs) {
   int parent = sketch->getId();
   uchar *pixels = &((*sketch.pixels)[0]);
 
@@ -254,16 +260,19 @@ BlobData::extractBlobs(const Sketch<uchar> &sketch,
   result.clear();
   ShapeSpace &ShS = sketch->getSpace().getDualSpace();
   //  for ( size_t color=1; color < numColors; color++ ) {
-  for (set<int>::const_iterator it = colors.begin();
+  for (set<color_index>::const_iterator it = colors.begin();
        it != colors.end(); it++) {
-    //    const CMVision::region* list_head = ccs[color].list;
-    const CMVision::region* list_head = ccs[*it].list;
+    int const color = *it;
+    const CMVision::region* list_head = ccs[color].list;
     if ( list_head != NULL ) {
-      //      const rgb rgbvalue = ProjectInterface::getColorRGB(color);
-      const rgb rgbvalue = ProjectInterface::getColorRGB(*it);
+      const rgb rgbvalue = ProjectInterface::getColorRGB(color);
+      int const minarea = (minareas.find(color)==minareas.end()) ? 50 : const_cast<map<color_index,int>&>(minareas)[color];
+      BlobOrientation_t const orient = (orients.find(color)==orients.end()) ? 
+	groundplane : const_cast<map<color_index,BlobOrientation_t>&>(orients)[color];
+      coordinate_t const height = (heights.find(color)==heights.end()) ? 0 : const_cast<map<color_index,coordinate_t>&>(heights)[color];
       for (int i=0; list_head!=NULL && i<maxblobs && list_head->area >= minarea;
 	   list_head = list_head->next, i++) {
-	BlobData* blobdat = new_blob(ShS,*list_head, rle_buffer, orient, rgbvalue);
+	BlobData* blobdat = new_blob(ShS,*list_head, rle_buffer, orient, height, rgbvalue);
 	blobdat->setParentId(parent);
 	result.push_back(Shape<BlobData>(blobdat));
       }
@@ -275,20 +284,11 @@ BlobData::extractBlobs(const Sketch<uchar> &sketch,
   return result;
 }
 
-std::vector<Shape<BlobData> > 
-BlobData::extractBlobs(const Sketch<uchar> &sketch, int minarea,
-	     BlobData::BlobOrientation_t orient, int maxblobs) {
-  const int numColors = ProjectInterface::getNumColors();
-  set<int> colors;
-  for (int i = 1; i < numColors; i++) colors.insert(i);
-  return extractBlobs(sketch, colors, minarea, orient, maxblobs);
-}
-
-
 BlobData* BlobData::new_blob(ShapeSpace& space,
 			     const CMVision::region &reg,
-			     const CMVision::run<uchar> *rle_buff, 
-			     const BlobData::BlobOrientation_t orient,
+			     const CMVision::run<CMVision::uchar> *rle_buff, 
+			     const BlobOrientation_t orient,
+			     const coordinate_t height,
 			     const rgb rgbvalue) {
   int const x1 = reg.x1;
   int const y1 = reg.y1;
@@ -312,34 +312,34 @@ BlobData* BlobData::new_blob(ShapeSpace& space,
     return new BlobData(space,
 			Point(x1,y1),Point(x2,y1),
 			Point(x1,y2),Point(x2,y2),
-			reg.area, runvec, orient, rgbvalue);
+			reg.area, runvec, orient, height, rgbvalue);
   else
     return new BlobData(space,
 			Point(x2,y2),Point(x1,y2),
 			Point(x2,y1),Point(x1,y1),
-		      reg.area, runvec, orient, rgbvalue);
+			reg.area, runvec, orient, height, rgbvalue);
 }
 
 
+//================================================================
+// Corner extraction: General call to find the corners of a blob.
+// Used in brick / pyramid extraction
+//
+//
+// Requires the number of corners you expect to find.
+// Currently just uses shape fitting to find the corners
+// Originally used either the derivative or diagonal approaches to finding corners
+//
+// Shape fitting works very well, but is very slow.
+// (no attempt was made to optimize it though)
+//
+// The old diagonal/derivative approach is at the bottom
+// It is much faster, but less robust.
 
+  std::vector<Point> BlobData::findCorners(unsigned int nExpected, 
+					   std::vector<Point>& candidates,
+					   float &bestValue) {
 
-
-
-  // General call to find the corners of a blob.
-  // Used in brick / pyramid extraction
-  //
-  //
-  // Requires the number of corners you expect to find.
-  // Currently just uses shape fitting to find the corners
-  // Originally used either the derivative or diagonal approaches to finding corners
-  //
-  // Shape fitting works very well, but is very slow.
-  // (no attempt was made to optimize it though)
-  //
-  // The old diagonal/derivative approach is at the bottom
-  // It is much faster, but less robust.
-  std::vector<Point> BlobData::findCorners(unsigned int nExpected, std::vector<Point>& candidates, float &bestValue)
-  {
     std::vector<Point> fitCorners = findCornersShapeFit(nExpected, candidates, bestValue);
 
     // debug output
@@ -454,8 +454,6 @@ BlobData* BlobData::new_blob(ShapeSpace& space,
     return fitCorners;
 
 
-
-
     // Old method, used the diagonal and derivative approaches and took the better results
     // Was generally much faster, but broke down in some special cases
     /* 
@@ -905,7 +903,7 @@ BlobData* BlobData::new_blob(ShapeSpace& space,
 
 // Comparison predicates
 
-bool BlobData::areaLessThan::operator() (const Shape<BlobData> &b1, const Shape<BlobData> &b2) const {
+bool BlobData::AreaLessThan::operator() (const Shape<BlobData> &b1, const Shape<BlobData> &b2) const {
       return b1->getArea() < b2->getArea();
 }
 
