@@ -19,6 +19,7 @@
 #include "ShapePoint.h"
 #include "Region.h"
 
+using namespace std;
 
 namespace DualCoding {
 
@@ -96,15 +97,15 @@ BrickData::printParams() const {
 
 
 //! Transformations. (Virtual in BaseData.)
-void BrickData::applyTransform(const NEWMAT::Matrix& Tmat) {
-  GFL.applyTransform(Tmat);
-  GFR.applyTransform(Tmat);
-  GBL.applyTransform(Tmat);
-  GBR.applyTransform(Tmat);
-  TFL.applyTransform(Tmat);
-  TFR.applyTransform(Tmat);
-  TBL.applyTransform(Tmat);
-  TBR.applyTransform(Tmat);
+void BrickData::applyTransform(const NEWMAT::Matrix& Tmat, const ReferenceFrameType_t newref) {
+  GFL.applyTransform(Tmat,newref);
+  GFR.applyTransform(Tmat,newref);
+  GBL.applyTransform(Tmat,newref);
+  GBR.applyTransform(Tmat,newref);
+  TFL.applyTransform(Tmat,newref);
+  TFR.applyTransform(Tmat,newref);
+  TBL.applyTransform(Tmat,newref);
+  TBR.applyTransform(Tmat,newref);
 }
 
 void BrickData::projectToGround(const NEWMAT::Matrix& camToBase,
@@ -129,7 +130,8 @@ void BrickData::projectToGround(const NEWMAT::Matrix& camToBase,
   TBR.setCoords(GBR.coordX(), GBR.coordY(), GBR.coordZ() + BRHeight);
   centroid = (GFL + GFR + GBL + GBR)/4;
   centroid.setCoords(centroid.coordX(), centroid.coordY(), brickHeight/2);
-  std::cout<<"New centroid: ("<<centroid.coordX()<<","<<centroid.coordY()<<","<<centroid.coordZ()<<")\n";
+  centroid.setRefFrameType(egocentric);
+  std::cout << "New centroid: " << centroid << endl;
 
 }
 
