@@ -25,19 +25,19 @@ namespace DualCoding {
   
   void applyGaussian(float x[], float gx[], int len);
 
-  float getBoundingQuadrilateralScore(BlobData &blob, vector<Point>& corners, Sketch<bool> edgeImage, 
+  float getBoundingQuadrilateralScore(BlobData &blob, std::vector<Point>& corners, Sketch<bool> edgeImage, 
 				      int& borderCount, ShapeSpace &space);
 
   float getBoundingQuadrilateralInteriorPointRatio(BlobData &blob, 
-						   vector<Point>& corners, 
+						   std::vector<Point>& corners, 
 						   ShapeSpace &space);
 
-  float getQuadrilateralArea(vector<Point>& corners);
+  float getQuadrilateralArea(std::vector<Point>& corners);
 
-  int countBorderPixelFit(BlobData &blob, const vector<Point> &corners, 
+  int countBorderPixelFit(BlobData &blob, const std::vector<Point> &corners, 
 			  Sketch<bool> edges, ShapeSpace &space);
      
-  int pickMove(vector<float> scores, float weight);
+  int pickMove(std::vector<float> scores, float weight);
 }
 
 #endif /* _BRICK_OPS_H_ */
