@@ -18,6 +18,8 @@
 #include "LineData.h"
 #include "ShapeLine.h"
 
+using namespace std;
+
 namespace DualCoding {
 
 DATASTUFF_CC(LineData);
@@ -181,25 +183,26 @@ bool LineData::isAdmissible() const {
 //! Print information about this shape. (Virtual in BaseData.)
 void LineData::printParams() const {
   cout << "Type = " << getTypeName() << "  ID=" << getId() << "  ParentID=" << getParentId() << endl;
-  cout << "end1{" << end1Pt().coordX() << ", " << end1Pt().coordY()  << "}";
-  cout << " active=" << end1Pt().isActive();
-  cout << " valid=" << end1Pt().isValid() << endl;
+  cout << "  end1{" << end1Pt().coordX() << ", " << end1Pt().coordY()  << "}"
+       << " active=" << end1Pt().isActive()
+       << " valid=" << end1Pt().isValid() << endl;
   
-  cout << "end2{" << end2Pt().coordX() << ", " << end2Pt().coordY() <<  "}";
-  cout << " active=" << end2Pt().isActive();
-  cout << " valid=" << end2Pt().isValid() << std::endl;
+  cout << "  end2{" << end2Pt().coordX() << ", " << end2Pt().coordY() <<  "}"
+       << " active=" << end2Pt().isActive()
+       << " valid=" << end2Pt().isValid() << std::endl;
   
-  cout << "rho_norm=" << rho_norm  << "  theta_norm=" << theta_norm;
-  cout << "  orientation=" << getOrientation() 
-       << "  length=" << getLength() << endl;
+  cout << "  rho_norm=" << rho_norm
+       << ", theta_norm=" << theta_norm
+       << ", orientation=" << getOrientation() 
+       << ", length=" << getLength() << endl;
   
-  printf("color = %d %d %d\n",getColor().red,getColor().green,getColor().blue);
+  printf("  color = %d %d %d\n",getColor().red,getColor().green,getColor().blue);
   
-  cout << "  mobile=" << isMobile() << endl;
-  cout << "  viewable=" << isViewable() << endl;
+  cout << "  mobile=" << getMobile()
+       << ", viewable=" << isViewable() << endl;
   
   vector<float> abc = lineEquation_abc();
-  printf("equ = %f %f %f\n",abc[0],abc[1],abc[2]);
+  printf("  equ = %f %f %f\n",abc[0],abc[1],abc[2]);
 }
 
 void LineData::printEnds() const {
@@ -212,12 +215,12 @@ void LineData::printEnds() const {
 
 
 
-//! Transformations.
-//@{
+// *** Transformations. *** //
+
 //! Apply a transformation to this shape.
-void LineData::applyTransform(const NEWMAT::Matrix& Tmat) {
-  end1Pt().applyTransform(Tmat);
-  end2Pt().applyTransform(Tmat);
+void LineData::applyTransform(const NEWMAT::Matrix& Tmat, const ReferenceFrameType_t newref) {
+  end1Pt().applyTransform(Tmat,newref);
+  end2Pt().applyTransform(Tmat,newref);
   update_derived_properties();
 }
 
@@ -228,8 +231,8 @@ void LineData::projectToGround(const NEWMAT::Matrix& camToBase,
   update_derived_properties();
 }
 
-//! Logical endpoints
-//@{
+
+// *** Logical endpoints *** //
 
 EndPoint& LineData::leftPt() { return end1Pt().isLeftOf(end2Pt()) ? end1_pt : end2_pt; }
 EndPoint& LineData::rightPt() { return end1Pt().isLeftOf(end2Pt()) ? end2_pt : end1_pt; }
@@ -312,6 +315,22 @@ EndPoint& LineData::secondPt(const Shape<LineData> &otherline) const {
     else return otherline->end2Pt();
 }
     
+Shape<PointData> LineData::firstPtShape() {
+  Shape<PointData> result(new PointData(*space, firstPt()));
+  result->setName("firstPt");
+  result->inheritFrom(*this);
+  result->setViewable(false);
+  return result;
+}
+
+Shape<PointData> LineData::secondPtShape() {
+  Shape<PointData> result(new PointData(*space, secondPt()));
+  result->setName("secondPt");
+  result->inheritFrom(*this);
+  result->setViewable(false);
+  return result;
+}
+
 coordinate_t LineData::firstPtCoord() const {
   return  isNotVertical() ?
     const_cast<LineData*>(this)->firstPt().coordX() :
@@ -336,9 +355,8 @@ coordinate_t LineData::secondPtCoord(const Shape<LineData> &otherline) const {
     secondPt(otherline).coordY();
 }
 
-//@}
 
-//! Functions to set endpoints.
+// *** Functions to set endpoints. *** //
 
 void LineData::setEndPts(const EndPoint& _end1_pt, const EndPoint& _end2_pt) {
   end1_pt.setCoords(_end1_pt);
@@ -355,8 +373,7 @@ void LineData::setEndPts(const EndPoint& _end1_pt, const EndPoint& _end2_pt) {
 }
 
 
-//! Properties functions.
-//@{
+// *** Properties functions. *** //
 
 std::pair<float,float> LineData::lineEquation_mb() const {
   float m;
@@ -408,9 +425,8 @@ std::vector<float> LineData::lineEquation_abc_xz() const {
   return(abc);
 
 }
-//@}
 
-  //! Determine parameters a, b, c satisfying the equation ax + by = c.
+//! Determine parameters a, b, c satisfying the equation ax + by = c.
 std::vector<float> LineData::lineEquation_abc() const {
   float dx = end2Pt().coordX() - end1Pt().coordX();
   float dy = end2Pt().coordY() - end1Pt().coordY();
@@ -446,11 +462,10 @@ std::vector<float> LineData::lineEquation_abc() const {
   
   return(abc);
 }
-//@}
 
 
-//! Functions to set values dealing with orientation.
-//@{
+// *** Functions to set values dealing with orientation. *** //
+
 void LineData::update_derived_properties() {
   rho_norm = perpendicularDistanceFrom(origin_pt);
   const vector<float> abc = lineEquation_abc();
@@ -491,8 +506,8 @@ bool LineData::isExactlyPerpendicularTo(Shape<LineData>& other) {
 */
 
 
-//! These functions are true based on line length.
-//@{
+// *** These functions are true based on line length. *** //
+
 bool LineData::isLongerThan(const Shape<LineData>& other) const {
   return length > other->length; }
 
@@ -504,7 +519,6 @@ bool LineData::isShorterThan(const Shape<LineData>& other) const {
 
 bool LineData::isShorterThan(float ref_length) const {
   return length < ref_length; }
-//@}
 
 bool LineData::isBetween(const Point &p, const LineData &other) const {
   if (getOrientation() == other.getOrientation()) { // parallel lines
@@ -527,8 +541,9 @@ bool LineData::isBetween(const Point &p, const LineData &other) const {
   }
 }
 
-//! Check intersection.
-//{
+	
+// ***  Check intersection. *** //
+
 bool
 LineData::intersectsLine(const Shape<LineData>& other) const {
   return intersectsLine(other.getData());
@@ -666,13 +681,13 @@ LineData::intersectionWithLine(const LineData& other,
     float u_b = u_b_numerator / denom;
     
     // If 0 <= u_a <=1  then intersection point is on segment a.
-    if(0.0 <= u_a <=1.0)
+    if(0.0<=u_a && u_a<=1.0)
       intersection_on_this = true;
     else
       intersection_on_this = false;
     
     // If 0 <= u_b <=1  then intersection point is on segment b.
-    if(0.0 <= u_b <=1.0)
+    if(0.0<=u_b && u_b<=1.0)
       intersection_on_other = true;
     else
       intersection_on_other = false;
@@ -682,8 +697,8 @@ LineData::intersectionWithLine(const LineData& other,
   }
 }
 
-//! Distance.
-//{
+
+// *** Distance. *** //
 
 float LineData::perpendicularDistanceFrom(const Point& otherPt) const {
   // NOTE that this formula is rather slow, as it involves the
@@ -704,17 +719,12 @@ float LineData::perpendicularDistanceFrom(const Point& otherPt) const {
   return(d);
 }
 
-//}
 
 
 // ==================================================
 // BEGIN LINE EXTRACTION CODE
 // ==================================================
 
-//!@name Line Extraction.
-//@{
-
-
 #define BEG_DIST_THRESH 2
 #define END_DIST_THRESH 2
 
@@ -731,7 +741,7 @@ Shape<LineData> LineData::extractLine(Sketch<bool>& skeleton,
   ShapeSpace &ShS = SkS.getDualSpace();
 
   // approximate largest skel region with line
-  NEW_SKETCH_N(labels,usint,visops::oldlabelcc(skeleton,visops::EightWayConnect));
+  NEW_SKETCH_N(labels,uint,visops::oldlabelcc(skeleton,visops::EightWayConnect));
   list<Region> regions = Region::extractRegions(labels,EXTRACT_LINE_MIN_AREA);
   if ( regions.empty() ) {
     ShapeRoot invalid; // need to define a named variable to avoid warning on next line
@@ -765,7 +775,7 @@ Shape<LineData> LineData::extractLine(Sketch<bool>& skeleton,
   // cout << "  x_normpoint=" << x_normpoint << "  y_normpoint=" << y_normpoint
   // << "  m=" << m << "  b=" << b <<std::endl;
   
-  NEW_SKETCH_N(skelDist,usint,visops::edist(skeleton));
+  NEW_SKETCH_N(skelDist,uint,visops::edist(skeleton));
   if ( abs(m) <= 1 )  // when |slope| <= 1, scan along x, else scan along y
     extracted_line->scanHorizForEndPts(skelDist,occlusions,m,b);
   else
@@ -802,7 +812,7 @@ Shape<LineData> LineData::splitLine(ShapeSpace &ShS, Region &skelchunk,
 	PointData most_distant_pt(ShS, skelchunk.mostDistantPtFrom(ln));
 	//	cout << "Point of split: " << most_distant_pt.getCentroid() << endl;
 	const Sketch<bool>& point_rendering = most_distant_pt.getRendering();
-	usint const clear_dist = 10;
+	uint const clear_dist = 10;
 	NEW_SKETCH_N(not_too_close, bool, visops::edist(point_rendering) >= clear_dist);
 	skeleton &= not_too_close;
 	return extractLine(skeleton, occlusions);
@@ -813,7 +823,7 @@ Shape<LineData> LineData::splitLine(ShapeSpace &ShS, Region &skelchunk,
   return ShapeRootType(invalid,LineData);
 }
 
-void LineData::scanHorizForEndPts(const Sketch<usint>& skelDist, 
+void LineData::scanHorizForEndPts(const Sketch<uint>& skelDist, 
 				  const Sketch<bool>& occlusions, 
 				  float m, float b) {
   // Scan along the infinite line, looking for segments in the image.
@@ -887,7 +897,7 @@ void LineData::scanHorizForEndPts(const Sketch<usint>& skelDist,
   balanceEndPointHoriz(end2_pt,occlusions,m,b);
 }
 
-void LineData::scanVertForEndPts(const Sketch<usint>& skelDist, 
+void LineData::scanVertForEndPts(const Sketch<uint>& skelDist, 
 				  const Sketch<bool>& occlusions, 
 				  float m, float b) {
   // Scan along the infinite line, looking for segments in the image.
@@ -1021,12 +1031,11 @@ vector<Shape<LineData> > LineData::extractLines(Sketch<bool> const& skel,
 //! Clear out pixels that are on or close to this line.
 void LineData::clearLine(Sketch<bool>& sketch) {
   const Sketch<bool>& line_rendering = getRendering();
-  usint const clear_dist = 5;
+  uint const clear_dist = 5;
   Sketch<bool> not_too_close = (visops::edist(line_rendering) >= clear_dist);
   sketch &= not_too_close;
 } 
 
-//@}
   
 
 // ==================================================
@@ -1356,7 +1365,7 @@ std::vector<Shape<LineData> > LineData::houghTransform(const Sketch<bool>& fat,
     float m = (y1 != 0) ? -(x1/y1) : BIG_SLOPE;
     float b = y1 - m*x1;
     
-    NEW_SKETCH_N(skelDist,usint,visops::edist(skinny));
+    NEW_SKETCH_N(skelDist,uint,visops::edist(skinny));
     if ( abs(m) <= 1 )  // when |slope| <= 1, scan along x, else scan along y
       line->scanHorizForEndPts(skelDist,occlusions,m,b);
     else
@@ -1486,9 +1495,14 @@ bool LineData::ColinearTest::operator() (const Shape<LineData> &line1, const Sha
     abs( line1->getRhoNorm() - line2->getRhoNorm() ) <= dist_tol;
 }
 
-bool LineData::IsHorizontal::operator() (const Shape<LineData> &line) {
+bool LineData::IsHorizontal::operator() (const Shape<LineData> &line) const {
       const AngPi orient = line->getOrientation();
       return  (orient <= threshold) || (orient >= M_PI - threshold);
     }
 
+bool LineData::IsVertical::operator() (const Shape<LineData> &line) const {
+      const AngPi orient = line->getOrientation();
+      return  (orient >= threshold) && (orient <= M_PI - threshold);
+    }
+
 } // namespace
