@@ -9,6 +9,8 @@
 #include "PolygonData.h"
 #include "ShapePolygon.h"
 
+using namespace std;
+
 namespace DualCoding {
 
 DATASTUFF_CC(PolygonData);
@@ -432,13 +434,13 @@ void PolygonData::printParams() const {
     cout << (*it) << endl;
 }
 
-void PolygonData::applyTransform(const NEWMAT::Matrix& Tmat) {
+void PolygonData::applyTransform(const NEWMAT::Matrix& Tmat, const ReferenceFrameType_t newref) {
   for (vector<LineData>::iterator it = edges.begin();
        it != edges.end(); it++)
-    it->applyTransform(Tmat);
+    it->applyTransform(Tmat,newref);
   for (vector<Point>::iterator it = vertices.begin();
        it != vertices.end(); it++)
-    it->applyTransform(Tmat);
+    it->applyTransform(Tmat,newref);
 }
 
 void PolygonData::projectToGround(const NEWMAT::Matrix& camToBase,
@@ -459,7 +461,7 @@ Point PolygonData::getCentroid() const {
 }
 
 
-void PolygonData::setColor(rgb new_color) {
+void PolygonData::setColor(const rgb &new_color) {
   color_rgb = new_color;
   for (vector<LineData>::iterator it = edges.begin();
        it != edges.end(); it++)
@@ -467,41 +469,31 @@ void PolygonData::setColor(rgb new_color) {
   deleteRendering();
 }
 
+void PolygonData::setColor(const color_index cindex) {
+  setColor(ProjectInterface::getColorRGB(cindex));
+}
+
+void PolygonData::setColor(const std::string &color_name) {
+  setColor(ProjectInterface::getColorRGB(color_name));
+}
+
 // helper function to sort lines from longest to shortest
 bool PolygonData::isFirstLineLonger(const Shape<LineData>& ln1,const Shape<LineData>& ln2) { 
   return ln1->isLongerThan(ln2);
 }
 
 Sketch<bool>* PolygonData::render() const {
-  string const result_name = "render(" + getName() + ")";
-  Sketch<bool> canvas(space->getDualSpace(), result_name);
-  canvas = 0;
+  Sketch<bool> *canvas = new Sketch<bool>(space->getDualSpace(),"");
+  (*canvas) = 0;
   const int width = space->getDualSpace().getWidth();
   const int height = space->getDualSpace().getHeight();
   float x1, y1, x2, y2;
   for (vector<LineData>::const_iterator it = edges.begin();
        it != edges.end(); it++) {
     it->setDrawCoords(x1, y1, x2, y2, width, height);
-    it->drawline2d(canvas, (int)x1, (int)y1, (int)x2, (int)y2);
+    it->drawline2d(*canvas, (int)x1, (int)y1, (int)x2, (int)y2);
   }
-  if (!isClosed())
-    return new Sketch<bool>(canvas);
-  NEW_SKETCH_N(borders, bool, visops::zeros(canvas));
-  for (int i = 0; i < width; i++) {
-    borders(i,0) = ! canvas(i,0);
-    borders(i,height-1) = ! canvas(i,height-1);
-  }
-  for (int j = 1; j < height-1; j++) {
-    borders(0,j) = ! canvas(0,j);
-    borders(width-1,j) = ! canvas(width-1,j);
-  }
-  usint const not_reached = usint(-1);
-  NEW_SKETCH_N(bd, usint, visops::bdist(borders, canvas, width*height));
-  bd->inheritFrom(*this);
-  bd->setColorMap(jetMap);
-  NEW_SKETCH(result, bool, bd == not_reached);
-  result->setName(result_name);
-  return new Sketch<bool>(result);
+  return canvas;
 }
 
 //================ Convex Hull ================
