@@ -15,7 +15,7 @@ class Shape<AgentData> : public ShapeRoot {
 public:
   SHAPESTUFF_H(AgentData);
 
-  Shape<AgentData>(ShapeSpace &s, Point centerval=Point(0,0,0)) :
+  Shape<AgentData>(ShapeSpace &s, Point centerval=Point(0,0,0,allocentric)) :
     ShapeRoot(addShape(new AgentData(s,centerval))) { };
 };
 
