@@ -2,7 +2,7 @@
 #ifndef _SHAPELINE_H_
 #define _SHAPELINE_H_
 
-#include "Measures.h"
+#include "Shared/Measures.h"
 #include "ShapeRoot.h"
 #include "LineData.h"
 
@@ -11,6 +11,7 @@ namespace DualCoding {
 class ShapeSpace;
 class Point;
 
+//! Smart pointer to a @a LineData object
 template<> class Shape<LineData> : public ShapeRoot {
 public:
 
