@@ -34,6 +34,12 @@ const char* data_name(int data_type)
   case pyramidDataType:
     return("PyramidData");
     break;
+  case localizationParticleDataType:
+    return("LocalizationParticleData");
+    break;
+  case targetDataType:
+    return("TargetData");
+    break;
   case unknownDataType:
   default:
     return("*Unknown*");
