@@ -24,6 +24,8 @@ enum ShapeType_t {
   blobDataType,
   brickDataType,
   pyramidDataType,
+  localizationParticleDataType,
+  targetDataType,
   
   // this one must always come last
   numDataTypes
