@@ -40,4 +40,13 @@ void SketchDataRoot::N(std::string const &_name) {
   if ( !_name.empty() ) setName(_name);
 }
 
+void SketchDataRoot:: setColor(const std::string &colorname) {
+  setColor(ProjectInterface::getColorRGB(colorname));
+}
+
+void SketchDataRoot::setColor(const color_index cindex) {
+  setColor(ProjectInterface::getColorRGB(cindex));
+}
+
+
 } // namespace
