@@ -16,7 +16,7 @@ class SketchRoot {
   virtual ~SketchRoot() {}
 
   SketchSpace& rootGetSpace() const;
-  const SketchDataRoot& rootGetData() const;
+  const SketchDataRoot* rootGetData() const;
 
   int getNewId() { return ++idCounter; }
 
