@@ -5,13 +5,17 @@ namespace DualCoding {
 //----------------------------------------------------------------
 
 void VisualRoutinesBehavior::DoStart() {
-  BehaviorBase::DoStart();
-  startCrew();
+  if ( !started ) {
+    BehaviorBase::DoStart();
+    startCrew();
+  }
 }
 
 void VisualRoutinesBehavior::DoStop() {
-  stopCrew();
-  BehaviorBase::DoStop();
+  if ( started ) {
+    stopCrew();
+    BehaviorBase::DoStop();
+  }
 }
 
 } // namespace
