@@ -5,13 +5,17 @@ namespace DualCoding {
 //----------------------------------------------------------------
 
 void VisualRoutinesStateNode::DoStart() {
-	StateNode::DoStart();
-	startCrew();
+  if ( !started ) {
+    StateNode::DoStart();
+    startCrew();
+  }
 }
 
 void VisualRoutinesStateNode::DoStop() {
-	stopCrew();
-	StateNode::DoStop();
+  if ( started ) {
+    stopCrew();
+    StateNode::DoStop();
+  }
 }
 
 } // namespace
