@@ -22,34 +22,34 @@ Sketch<bool> zeros(const SketchRoot& other) {
   return result;
 }
 
-Sketch<bool> colormask(const Sketch<uchar>& src, std::string colorname) {
+Sketch<bool> colormask(const Sketch<uchar>& src, const std::string &colorname) {
   return colormask(src, ProjectInterface::getColorIndex(colorname));
 }
 
-Sketch<bool> colormask(const Sketch<uchar>& src, int color_idx) {
-  Sketch<bool> result(src == color_idx);
-  result->setColor(ProjectInterface::getColorRGB(color_idx));
+Sketch<bool> colormask(const Sketch<uchar>& src, color_index cindex) {
+  Sketch<bool> result(src == cindex);
+  result->setColor(ProjectInterface::getColorRGB(cindex));
   return result;
 }
 
-Sketch<usint> bdist(const Sketch<bool>& dest, 
+Sketch<uint> bdist(const Sketch<bool>& dest, 
 			    const Sketch<bool>& obst, 
-			    const int maxdist) {
+			    const uint maxdist) {
   SketchSpace &space = dest->getSpace();
   space.requireIdx4way();
-  Sketch<float> result("bdist("+dest->getName()+","+obst->getName()+")", dest);
-  result = (usint)-1; // 99999999;//FP_INFINITE; // if FP_INFINITE, means dist not calc'd yet for pixel
+  Sketch<uint> result("bdist("+dest->getName()+","+obst->getName()+")", dest);
+  result = maxdist;
   result->setColorMap(jetMapScaled);
   
-  // want to start at the target, and iteratively expand out the frontier
+  // Start at the target and iteratively expand out the frontier
   SketchIndices frontier;
   frontier.addIndices(dest);
   result.setIndices(frontier, 0);
   SketchIndices obstInds;
   obstInds.addIndices(obst);
   SketchIndices newFrontier, oldFrontier;
-  
-  for (float dist = 1; dist < maxdist; dist++) {
+
+  for (uint dist = 1; dist < maxdist; dist++) {
     // newFrontier should become all values adjacent to frontier, not
     // actually in the frontier, not a boundary, or in oldFrontier
     newFrontier = frontier[*space.idxN] + frontier[*space.idxS] 
@@ -67,14 +67,14 @@ Sketch<usint> bdist(const Sketch<bool>& dest,
   return result;
 }
 
-Sketch<usint> edist(const Sketch<bool>& target) {
+Sketch<uint> edist(const Sketch<bool>& target) {
   SketchSpace &space = target->getSpace();
   const int width = space.getWidth();
   const int height = space.getHeight();
-  const usint maxdist = width + height + 1;
+  const uint maxdist = width + height + 1;
   // at the moment doing 4-pass linear Manhattan distance, but should
   // probably use linear-time Euclidean algorithm described in 
-  Sketch<usint> dist("edist("+target->getName()+")", target);
+  Sketch<uint> dist("edist("+target->getName()+")", target);
   dist = maxdist;
   dist->setColorMap(jetMapScaled);
   
@@ -82,16 +82,16 @@ Sketch<usint> edist(const Sketch<bool>& target) {
   for (int j = 0; j < height; j++) {
     for (int i = 0, cur_dist = maxdist; i < width; i++) {
       if (target(i,j) == 1)
-	dist(i,j) = cur_dist = 0;
-      else if (dist(i,j) < cur_dist)
-	cur_dist = dist(i,j);
+				dist(i,j) = cur_dist = 0;
+      else if (dist(i,j) < (uint)cur_dist)
+				cur_dist = dist(i,j);
       else dist(i,j) = cur_dist;
       cur_dist++;
     }
     for (int i = width-1, cur_dist = maxdist; i >= 0; i--) {
       if (target(i,j) == true)
 	dist(i,j) = cur_dist = 0;
-      else if (dist(i,j) < cur_dist)
+      else if (dist(i,j) < (uint)cur_dist)
 	cur_dist = dist(i,j);
       else
 	dist(i,j) = cur_dist;
@@ -102,27 +102,27 @@ Sketch<usint> edist(const Sketch<bool>& target) {
   for (int i = 0; i < width; i++) {
     for (int j = 0, cur_dist = maxdist; j < height; j++) {
       if (target(i,j) == 1)
-	dist(i,j) = cur_dist = 0;
-      else if (dist(i,j) < cur_dist)
-	cur_dist = dist(i,j);
+				dist(i,j) = cur_dist = 0;
+      else if (dist(i,j) < (uint)cur_dist)
+				cur_dist = dist(i,j);
       else
-	dist(i,j) = cur_dist;
+				dist(i,j) = cur_dist;
       cur_dist++;
     }
     for (int j = height-1, cur_dist = maxdist; j  >= 0; j--) {
       if (target(i,j) == 1)
-	dist(i,j) = cur_dist = 0;
-      else if (dist(i,j) < cur_dist)
-	cur_dist = dist(i,j);
+				dist(i,j) = cur_dist = 0;
+      else if (dist(i,j) < (uint)cur_dist)
+				cur_dist = dist(i,j);
       else
-	dist(i,j) = cur_dist;
+				dist(i,j) = cur_dist;
       cur_dist++;
     }
   }
   return dist;
 }
 
-Sketch<usint> labelcc(const Sketch<bool>& sketch, int minarea) {
+Sketch<uint> labelcc(const Sketch<bool>& sketch, int minarea) {
   Sketch<uchar> temp;
   uchar *pixels;
   if ( sizeof(bool) == sizeof(uchar) )
@@ -149,7 +149,7 @@ Sketch<usint> labelcc(const Sketch<bool>& sketch, int minarea) {
   CMVision::MergeRegions(ccs, numColors, rle_buffer);
 
   // extract regions from region list
-  NEW_SKETCH(result, usint, visops::zeros(sketch));
+  NEW_SKETCH_N(result, uint, visops::zeros(sketch));
   result->setColorMap(jetMapScaled);
   const CMVision::region* list_head = ccs[1].list;
   if ( list_head != NULL ) {
@@ -174,19 +174,19 @@ Sketch<usint> labelcc(const Sketch<bool>& sketch, int minarea) {
 }
 
 // written with guidance from this page: http://www.dai.ed.ac.uk/HIPR2/label.htm
-Sketch<usint> oldlabelcc(const Sketch<bool>& source, Connectivity_t connectivity)
+Sketch<uint> oldlabelcc(const Sketch<bool>& source, Connectivity_t connectivity)
 {
   bool conn8 = (connectivity == EightWayConnect);
   const int width = source.width;
   const int height = source.height;
-  Sketch<usint> labels("oldlabelcc("+source->getName()+")",source);
+  Sketch<uint> labels("oldlabelcc("+source->getName()+")",source);
   labels = 0;
   labels->setColorMap(jetMapScaled);
   
   // First scan: Give initial labels and sort connected label classes
   // into equivalence classes using UNION-FIND
   // Doing something similar to tree-based UNION-FIND, without the tree
-  vector<int> eq_classes(500); // vector of equivalence classes for union-find
+  std::vector<int> eq_classes(500); // vector of equivalence classes for union-find
   eq_classes.clear();
   eq_classes.push_back(0); // added just so that indices match up with labels
   int highest_label = 0;
@@ -280,25 +280,25 @@ Sketch<usint> oldlabelcc(const Sketch<bool>& source, Connectivity_t connectivity
   return labels;
 }
 
-Sketch<usint> areacc(const Sketch<bool>& source, Connectivity_t connectivity) {
-  NEW_SKETCH_N(labels, usint, visops::oldlabelcc(source,connectivity));
+Sketch<uint> areacc(const Sketch<bool>& source, Connectivity_t connectivity) {
+  NEW_SKETCH_N(labels, uint, visops::oldlabelcc(source,connectivity));
   return visops::areacc(labels);
 }
 
-Sketch<usint> areacc(const Sketch<usint>& labels) {
-  vector<int> areas(1+labels->max(), 0);
-  for (usint i = 0; i<labels->getNumPixels(); i++)
+Sketch<uint> areacc(const Sketch<uint>& labels) {
+  std::vector<int> areas(1+labels->max(), 0);
+  for (uint i = 0; i<labels->getNumPixels(); i++)
     ++areas[labels[i]];
   areas[0] = 0;
-  Sketch<usint> result("areacc("+labels->getName()+")",labels);
-  for (usint i = 0; i<labels->getNumPixels(); i++)
+  Sketch<uint> result("areacc("+labels->getName()+")",labels);
+  for (uint i = 0; i<labels->getNumPixels(); i++)
     result[i] = areas[labels[i]];
   return result;
 }
 
 Sketch<bool> minArea(const Sketch<bool>& sketch, int minval) {
-  NEW_SKETCH_N(labels, usint, visops::labelcc(sketch));
-  NEW_SKETCH_N(areas, usint, visops::areacc(labels));
+  NEW_SKETCH_N(labels, uint, visops::labelcc(sketch));
+  NEW_SKETCH_N(areas, uint, visops::areacc(labels));
   NEW_SKETCH_N(result, bool, areas >= minval);
   return result;
 }
@@ -314,15 +314,17 @@ Sketch<uchar> neighborSum(const Sketch<bool>& im, Connectivity_t connectivity)
 
   Sketch<uchar> result("neighborSum("+im->getName()+")", im);
   result->setColorMap(jetMapScaled);
-  result  = im[*space.idxN];
-  result += im[*space.idxS];
-  result += im[*space.idxW];
-  result += im[*space.idxE];
-  if (connectivity == EightWayConnect) {
-    result += im[*space.idxNW];
-    result += im[*space.idxNE];
-    result += im[*space.idxSW];
-    result += im[*space.idxSE];
+  for ( unsigned int i = 0; i < im->getNumPixels(); i++ ) {
+    uchar cnt = (uchar)im[(*space.idxN)[i]] +
+      (uchar)im[(*space.idxS)[i]] +
+      (uchar)im[(*space.idxE)[i]] +
+      (uchar)im[(*space.idxW)[i]];
+    if (connectivity == EightWayConnect)
+      cnt += (uchar)im[(*space.idxNE)[i]] +
+	(uchar)im[(*space.idxNW)[i]] +
+	(uchar)im[(*space.idxSE)[i]] +
+	(uchar)im[(*space.idxSW)[i]];
+    result[i] = cnt;
   }
   return result;
 }
@@ -442,21 +444,50 @@ Sketch<bool> versym(const Sketch<bool>& im, int minskip, int maxskip)
 }
 */
 
-Sketch<bool> skel(const Sketch<bool>& im)
-{
+Sketch<bool> skel(const Sketch<bool>& im) {
   NEW_SKETCH_N(result, bool, horsym(im) | versym(im));
   result->setName("skel("+im->getName()+")");
   return result;
 }
 
-Sketch<bool> seedfill(const Sketch<bool>& borders, size_t index)
-{
+Sketch<bool> seedfill(const Sketch<bool>& borders, size_t index) {
   // use four-way connect so thin diagonal line can function as a boundary
-  NEW_SKETCH_N(regions, usint, oldlabelcc(! borders, visops::FourWayConnect));
+  NEW_SKETCH_N(regions, uint, oldlabelcc(! borders, visops::FourWayConnect));
   NEW_SKETCH_N(result, bool, regions == regions->at(index));  // use at() to do bounds checking
   return result;
 }
 
+// helper function called only inside visops::fillExterior
+void fillExteriorHelper(const Sketch<uint> &regions, Sketch<bool> &result, std::vector<bool> &processed, 
+			const int x, const int y) {
+  const uint c = regions(x,y);
+  if ( c > 0 && !processed[c] ) {
+    result |= (regions == c);
+    processed[c] = true;
+  }
+}
+
+Sketch<bool> fillExterior(const Sketch<bool>& borders) {
+  // use four-way connect so thin diagonal line can function as a boundary
+  NEW_SKETCH_N(regions, uint, oldlabelcc(! borders, visops::FourWayConnect));
+  const uint numreg = regions->max();
+  std::vector<bool> processed(numreg+1,false);
+  NEW_SKETCH_N(result, bool, visops::zeros(borders));
+  for ( int x = 0; x < result.width; x++ ) {
+    fillExteriorHelper(regions,result,processed,x,0);
+    fillExteriorHelper(regions,result,processed,x,result.height-1);
+  }
+  for ( int y = 0; y < result.height; y++ ) {
+    fillExteriorHelper(regions,result,processed,0,y);
+    fillExteriorHelper(regions,result,processed,result.width-1,y);
+  }
+  return result;
+}
+
+Sketch<bool> fillInterior(const Sketch<bool>& borders) {
+  return ! (borders | fillExterior(borders));
+}
+
 Sketch<bool> leftHalfPlane(const Shape<LineData> &ln) {
   SketchSpace &SkS = ln->getSpace().getDualSpace();
   //! @todo **** THIS visops::leftHalfPlane CODE NEEDS TO CHECK THE SketchSpace ReferenceFrameType **** BECAUSE "left" MEANS DIFFERENT THINGS IN DIFFERENT FRAMES 
@@ -471,8 +502,10 @@ Sketch<bool> leftHalfPlane(const Shape<LineData> &ln) {
     seed = ( x1 <= 0 ) ? -1 : 0;
   else if ( ln->getOrientation() > M_PI/2 )
     seed =  ( b <= 0) ? -1 : 0;
-  else
-    seed =  ( b < (int)SkS.getHeight() - 1 ) ? (*SkS.idx)(0,SkS.getHeight()-1) : -1;
+  else {
+		int const lim = SkS.getHeight() - 1;
+    seed =  ( b < lim ) ? (int)(*SkS.idx)(0,lim) : -1;
+	}
   if ( seed == -1 ) {
     NEW_SKETCH_N(result, bool, visops::zeros(SkS));
     result->inheritFrom(ln);
@@ -508,8 +541,10 @@ Sketch<bool> topHalfPlane(const Shape<LineData> &ln) {
     seed = ( y1 <= 0 ) ? -1 : 0;
   else if ( ln->getOrientation() > M_PI/2 )
     seed =  ( b <= 0) ? -1 : 0;
-  else
-    seed =  ( int(m*(SkS.getWidth()-1)+b) > 0 ) ? (*SkS.idx)(SkS.getWidth()-1,0) : -1;
+  else {
+		int const lim = SkS.getWidth() - 1;
+    seed =  ( int(m*lim+b) > 0 ) ? (int)(*SkS.idx)(lim,0) : -1;
+	}
   if ( seed == -1 ) {
     NEW_SKETCH_N(result, bool, visops::zeros(SkS));
     result->inheritFrom(ln);
@@ -604,9 +639,9 @@ Sketch<bool> susan_edge_points(const Sketch<uchar>& im, int brightness)
   return result;
 }
 
-Sketch<usint> convolve(const Sketch<uchar> &sketch, Sketch<uchar> &kernel, 
+Sketch<uint> convolve(const Sketch<uchar> &sketch, Sketch<uchar> &kernel, 
 		       int istart, int jstart, int width, int height) {
-  Sketch<usint> result("convolve("+sketch->getName()+")",sketch);
+  Sketch<uint> result("convolve("+sketch->getName()+")",sketch);
   result->setColorMap(jetMapScaled);
   int const di = - (int)(width/2);
   int const dj = - (int)(height/2);
@@ -617,15 +652,15 @@ Sketch<usint> convolve(const Sketch<uchar> &sketch, Sketch<uchar> &kernel,
 	for (int kj=0; kj<height; kj++)
 	  if ( si+di+ki >= 0 && si+di+ki < sketch.width &&
 	       sj+dj+kj >= 0 && sj+dj+kj < sketch.height )
-	    sum += (usint)sketch(si+di+ki,sj+dj+kj) * (usint)kernel(istart+ki,jstart+kj);
+	    sum += (uint)sketch(si+di+ki,sj+dj+kj) * (uint)kernel(istart+ki,jstart+kj);
       result(si,sj) = sum/(width*height);
     }
   return result;      
 }
 
-Sketch<usint> templateMatch(const Sketch<uchar> &sketch, Sketch<uchar> &kernel, 
+Sketch<uint> templateMatch(const Sketch<uchar> &sketch, Sketch<uchar> &kernel, 
 		       int istart, int jstart, int width, int height) {
-  Sketch<usint> result("convolve0("+sketch->getName()+")",sketch);
+  Sketch<uint> result("convolve0("+sketch->getName()+")",sketch);
   result->setColorMap(jetMapScaled);
   int const npix = width * height;
   int const di = - (int)(width/2);
@@ -644,7 +679,7 @@ Sketch<usint> templateMatch(const Sketch<uchar> &sketch, Sketch<uchar> &kernel,
 	  else
 	    sum += k_pix * k_pix;
 	}
-      result(si,sj) =  65535 - usint(sqrt(sum/float(npix)));
+      result(si,sj) =  65535 - uint(sqrt(sum/float(npix)));
     }
   result = result - result->min();
   return result;
