@@ -1,14 +1,24 @@
 #include "EventBase.h"
+#include "EventRouter.h"
 #include <stdio.h>
 #include <sstream>
 #include <libxml/tree.h>
 #include "Shared/debuget.h"
+#include "Events/RemoteRouter.h"
+
+// just to give linkage for the auto register:
+const EventBase::classTypeID_t EventBase::autoRegisterEventBase=getTypeRegistry().registerType<EventBase>(makeClassTypeID("BASE"));
+#include "FilterBankEvent.h"
+const EventBase::classTypeID_t FilterBankEvent::autoRegisterFilterBankEvent=getTypeRegistry().registerType<FilterBankEvent>(makeClassTypeID("FBKE"));
+#include "SegmentedColorFilterBankEvent.h"
+const EventBase::classTypeID_t SegmentedColorFilterBankEvent::autoRegisterSegmentedColorFilterBankEvent=getTypeRegistry().registerType<SegmentedColorFilterBankEvent>(makeClassTypeID("SFBK"));
 
 const char* const EventBase::EventGeneratorNames[numEGIDs] = {
 	"unknownEGID",
 	"aiEGID",
 	"audioEGID",
 	"buttonEGID",
+	"cameraResolutionEGID",
 	"erouterEGID",
 	"estopEGID",
 	"locomotionEGID",
@@ -38,6 +48,7 @@ const char* const EventBase::EventGeneratorNames[numEGIDs] = {
 	"visObjEGID",
 	"wmVarEGID",
 	"worldModelEGID",
+	"remoteStateEGID"
 };
 
 const char* const EventBase::EventTypeNames[numETIDs] = {
@@ -48,14 +59,21 @@ const char* const EventBase::EventTypeNames[numETIDs] = {
 
 const char* const EventBase::EventTypeAbbr[numETIDs] = { "A", "S", "D" };
 
+EventBase::registry_t& EventBase::getTypeRegistry() {
+	static registry_t typeRegistry;
+	return typeRegistry;
+}
+
 EventBase::EventBase()
-	: XMLLoadSave(), stim_id(), magnitude(0), timestamp(get_time()), saveFormat(XML), nameisgen(true), genID(unknownEGID), typeID(statusETID), sourceID((unsigned int)-1), duration(0)
+	: XMLLoadSave(), stim_id(), magnitude(0), timestamp(get_time()), saveFormat(XML),
+	  nameisgen(true), genID(unknownEGID), typeID(statusETID), sourceID((size_t)-1),
+	  hostID(-1), duration(0)
 {
 	genName();
 }
 
-EventBase::EventBase(EventGeneratorID_t gid, unsigned int sid, EventTypeID_t tid, unsigned int dur)
-	: XMLLoadSave(), stim_id(), magnitude(0), timestamp(get_time()), saveFormat(XML), nameisgen(true), genID(gid), typeID(tid), sourceID(sid), duration(dur)
+EventBase::EventBase(EventGeneratorID_t gid, size_t sid, EventTypeID_t tid, unsigned int dur)
+	: XMLLoadSave(), stim_id(), magnitude(0), timestamp(get_time()), saveFormat(XML), nameisgen(true), genID(gid), typeID(tid), sourceID(sid), hostID(-1), duration(dur)
 {
 	genName();
 	if(tid==deactivateETID)
@@ -64,8 +82,8 @@ EventBase::EventBase(EventGeneratorID_t gid, unsigned int sid, EventTypeID_t tid
 		setMagnitude(1.0);
 }
 
-EventBase::EventBase(EventGeneratorID_t gid, unsigned int sid, EventTypeID_t tid, unsigned int dur, const std::string& n)
-	: XMLLoadSave(), stim_id(), magnitude(0), timestamp(get_time()), saveFormat(XML), nameisgen(true), genID(gid), typeID(tid), sourceID(sid), duration(dur)
+EventBase::EventBase(EventGeneratorID_t gid, size_t sid, EventTypeID_t tid, unsigned int dur, const std::string& n)
+	: XMLLoadSave(), stim_id(), magnitude(0), timestamp(get_time()), saveFormat(XML), nameisgen(true), genID(gid), typeID(tid), sourceID(sid), hostID(-1), duration(dur)
 {
 	setName(n);
 	if(tid==deactivateETID)
@@ -74,8 +92,8 @@ EventBase::EventBase(EventGeneratorID_t gid, unsigned int sid, EventTypeID_t tid
 		setMagnitude(1.0);
 }
 
-EventBase::EventBase(EventGeneratorID_t gid, unsigned int sid, EventTypeID_t tid, unsigned int dur, const std::string& n, float mag)
-	: XMLLoadSave(), stim_id(), magnitude(mag), timestamp(get_time()), saveFormat(XML), nameisgen(true), genID(gid), typeID(tid), sourceID(sid), duration(dur)
+EventBase::EventBase(EventGeneratorID_t gid, size_t sid, EventTypeID_t tid, unsigned int dur, const std::string& n, float mag)
+	: XMLLoadSave(), stim_id(), magnitude(mag), timestamp(get_time()), saveFormat(XML), nameisgen(true), genID(gid), typeID(tid), sourceID(sid), hostID(-1), duration(dur)
 {
 	setName(n);
 }
@@ -95,6 +113,12 @@ EventBase::setName(const std::string& sourcename) {
 	stim_id+=sourcename;
 	stim_id+=',';
 	stim_id+=EventTypeAbbr[getTypeID()];
+
+	if (hostID != -1) {
+		stim_id += ',';
+		stim_id += EventRouter::intToStringIP(hostID);
+	}
+	
 	stim_id+=')';
 	nameisgen=false;
 	return *this;
@@ -126,6 +150,7 @@ EventBase::getBinSize() const {
 	used+=getSerializedSize<char>(); //genID is an enum, override to char
 	used+=getSerializedSize<char>(); //typeID is an enum, override to char
 	used+=getSerializedSize(sourceID);
+	used+=getSerializedSize(hostID);
 	used+=getSerializedSize(duration);
 	return used;
 }
@@ -144,7 +169,10 @@ EventBase::loadBinaryBuffer(const char buf[], unsigned int len) {
 	if(!decodeInc(tmp,buf,len)) return 0;
 	typeID=(EventTypeID_t)tmp;
 	if(!decodeInc(sourceID,buf,len)) return 0;
+	if(!decodeInc(hostID,buf,len)) return 0;
 	if(!decodeInc(duration,buf,len)) return 0;
+
+	genName();
 	return origlen-len;	
 }
 
@@ -159,6 +187,7 @@ EventBase::saveBinaryBuffer(char buf[], unsigned int len) const {
 	if(!encodeInc((char)genID,buf,len)) return 0;
 	if(!encodeInc((char)typeID,buf,len)) return 0;
 	if(!encodeInc(sourceID,buf,len)) return 0;
+	if(!encodeInc(hostID,buf,len)) return 0;
 	if(!encodeInc(duration,buf,len)) return 0;
 	return origlen-len;
 }
@@ -178,11 +207,19 @@ void EventBase::loadXML(xmlNode* node) {
 	if(i==numEGIDs)
 		throw bad_format(node,"bad event generator name");
 	genID=static_cast<EventGeneratorID_t>(i);
+	
 	str = xmlGetProp(node,(const xmlChar*)"sid");
 	if(str==NULL)
 		throw bad_format(node,"missing source id");
-	sourceID=atoi((const char*)str);
+	std::stringstream((const char*)str) >> sourceID;
 	xmlFree(str);
+
+	str = xmlGetProp(node,(const xmlChar*)"hid");
+	if(str==NULL)
+		throw bad_format(node,"missing host id");
+	hostID=atoi((const char*)str);
+	xmlFree(str);
+	
 	str = xmlGetProp(node,(const xmlChar*)"etid");
 	if(str==NULL)
 		throw bad_format(node,"missing type id");
@@ -222,8 +259,13 @@ void EventBase::saveXML(xmlNode * node) const {
 	xmlNodeSetName(node,(const xmlChar*)"event");
 	xmlSetProp(node,(const xmlChar*)"egid",(const xmlChar*)EventGeneratorNames[genID]);
 	char buf[20];
+	
 	snprintf(buf,20,"%lu",static_cast<unsigned long>(sourceID));
 	xmlSetProp(node,(const xmlChar*)"sid",(const xmlChar*)buf);
+
+	snprintf(buf,20,"%lu",static_cast<long>(hostID));
+	xmlSetProp(node,(const xmlChar*)"hid",(const xmlChar*)buf);
+	
 	xmlSetProp(node,(const xmlChar*)"etid",(const xmlChar*)EventTypeAbbr[typeID]);
 	snprintf(buf,20,"%u",timestamp);
 	xmlSetProp(node,(const xmlChar*)"time",(const xmlChar*)buf);
@@ -256,9 +298,9 @@ EventBase::genName() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.32 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.37 $
  * $State: Exp $
- * $Date: 2006/09/21 21:26:07 $
+ * $Date: 2007/11/13 04:16:02 $
  */
 
