@@ -4,6 +4,7 @@
 
 #include "Shared/get_time.h"
 #include "Shared/XMLLoadSave.h"
+#include "Shared/FamilyFactory.h"
 #include <string>
 
 //! Forms the basis of communication between modules/behaviors in the framework
@@ -30,7 +31,7 @@
  *  When the generator doesn't have groups of activity with a 'begin' or 'end', it will use #statusETID
  *  for all of its events.  (in other words, not all generators necessarily have to use activate or deactivate)
  *  For example, sensor updates are continuously occuring, so you will only ever see
- *  <center>(EventBase::sensorEGID,SensorSourceID::UpdatedSID,EventBase::statusETID)</center>
+ *  <center>(EventBase::sensorEGID,SensorSrcID::UpdatedSID,EventBase::statusETID)</center>
  *  
  *  The #duration field is also generator specific - some may refer to
  *  the time since the last activation event (e.g. button events)
@@ -82,6 +83,7 @@ class EventBase : public XMLLoadSave {
 		aiEGID,           //!< not being used, yet (might use this when AI makes decisions?)
 		audioEGID,        //!< Sends an event when a sound starts/ends playback, status events as chained sounds end; SID is SoundManager::Play_ID; duration is playtime
 		buttonEGID,       //!< Sends activate event for button down, deactivate for button up.  Status events only for when pressure sensitive buttons' reading changes. (on sensorEGID updates); SIDs are from ButtonOffset_t in the namespace of the target model (e.g. ERS210Info::ButtonOffset_t); duration is button down time
+		cameraResolutionEGID, //!< Sends a status event whenever the camera's resolution changes, such as a different camera than predicted by RobotInfo is being used, or a camera is hotswapped.  SID corresponds to the visOFbkEGID for that camera.
 		erouterEGID,      //!< Sends activate event on first listener, deactivate on last listener, and status on other listener changes.; SID is the generator ID affected
 		estopEGID,        //!< Sends an event when the estop is turned on or off; SID is the MotionManager::MC_ID of the EmergencyStopMC; duration is length of estop activation
 		locomotionEGID,   //!< Sends events regarding transportation in the world; you can/should assume these will all be LocomotionEvent classes; SID is MotionManager::MC_ID of posting MotionCommand; duration is the time since last velocity change of that MC. (You could generate these for things other than walking...)
@@ -93,8 +95,8 @@ class EventBase : public XMLLoadSave {
 		micPitchEGID,       //!< Sends a PitchEvent when a particular frequency is detected; SID is a pointer to the PitchDetector, magnitude is product of amplitude and confidence
 		motmanEGID,       //!< Sends events when a MotionCommand is added or removed, SID is is the MotionManager::MC_ID, duration is always 0; individual MotionCommands may throw status events to signal intermediary status
 		pilotEGID,        //!< Sends events when position of agent is updated or pilot request is completed
-		powerEGID,        //!< Sends events for low power warnings, temperature, etc. see PowerSourceID::PowerSourceID_t
-		sensorEGID,       //!< Sends a status event when new sensor readings are available. see SensorSourceID::SensorSourceID_t
+		powerEGID,        //!< Sends events for low power warnings, temperature, etc. see PowerSrcID::PowerSourceID_t
+		sensorEGID,       //!< Sends a status event when new sensor readings are available. see SensorSrcID::SensorSourceID_t
 		stateMachineEGID, //!< Sends an event upon entering and leaving a StateNode; SID is pointer to the StateNode; duration is always 0; some state will throw a status event when they have completed their task and are now idling
 		stateSignalEGID,  //!< Sends a DataEvent that can be monitored by a SignalTrans for triggering a state transition
 		stateTransitionEGID, //!< Sends an event each time a transition is triggered; SID is a pointer to the transition; type is always status, duration is always 0; guaranteed to occur immediately *before* the transition actually occurs
@@ -111,6 +113,7 @@ class EventBase : public XMLLoadSave {
 		visObjEGID,       //!< Sends VisionObjectEvents for objects detected in camera images; SID is whatever value you gave during setup (typically in StartupBehavior_SetupVision.cc), duration is always 0
 		wmVarEGID,        //!< Sends an event when a watched memory is changed; source id is pointer to WMEntry
 		worldModelEGID,   //!< not being used, yet (for when objects are detected/lost?)
+		remoteStateEGID,  //!< Sent when remote state is updated
 		numEGIDs          //!< the number of generators available
 	};
 
@@ -130,14 +133,23 @@ class EventBase : public XMLLoadSave {
 	
 	//! holds abbreviated string versions of EventTypeID_t
 	static const char* const EventTypeAbbr[numETIDs];
+	
+	//! type used for class ids in the type registry (see getTypeRegistry())
+	typedef unsigned int classTypeID_t;
+	
+	//! type used for the type registry
+	typedef FamilyFactory<EventBase,classTypeID_t> registry_t;
 
+	//! returns a FamilyFactory with which you can look up classTypeID_t's to make new instances from serialized data
+	static registry_t& getTypeRegistry();
+	
 	/*! @name Constructors/Destructors */
 	//! constructor
 	/*! @see EventRouter::postEvent() */
 	EventBase(); 
-	EventBase(EventGeneratorID_t gid, unsigned int sid, EventTypeID_t tid, unsigned int dur=0);
-	EventBase(EventGeneratorID_t gid, unsigned int sid, EventTypeID_t tid, unsigned int dur, const std::string& n);
-	EventBase(EventGeneratorID_t gid, unsigned int sid, EventTypeID_t tid, unsigned int dur, const std::string& n, float mag);
+	EventBase(EventGeneratorID_t gid, size_t sid, EventTypeID_t tid, unsigned int dur=0);
+	EventBase(EventGeneratorID_t gid, size_t sid, EventTypeID_t tid, unsigned int dur, const std::string& n);
+	EventBase(EventGeneratorID_t gid, size_t sid, EventTypeID_t tid, unsigned int dur, const std::string& n, float mag);
 	virtual ~EventBase() {} //!< destructor
 
 	//! allows a copy to be made of an event, supporting polymorphism
@@ -163,12 +175,16 @@ class EventBase : public XMLLoadSave {
 	virtual EventGeneratorID_t getGeneratorID() const { return genID; } /*!< @brief gets the generator ID for this event @see EventGeneratorID_t */
 	virtual EventBase& setGeneratorID(EventGeneratorID_t gid) { genID=gid; genName(); return *this; } /*!< @brief sets the generator ID for this event @see EventGeneratorID_t */
 	
-	virtual unsigned int getSourceID() const { return sourceID; } /*!< @brief gets the source ID for this event @see sourceID */
-	virtual EventBase& setSourceID(unsigned int sid) { sourceID=sid; genName(); return *this; } /*!< @brief sets the source ID for this event @see sourceID */
+	virtual size_t getSourceID() const { return sourceID; } /*!< @brief gets the source ID for this event @see sourceID */
+	virtual EventBase& setSourceID(size_t sid) { sourceID=sid; genName(); return *this; } /*!< @brief sets the source ID for this event @see sourceID */
 	
 	virtual EventTypeID_t getTypeID() const { return typeID; } /*!< @brief gets the type ID @see EventTypeID_t */
 	virtual EventBase& setTypeID(EventTypeID_t tid) { typeID=tid; unsigned int n=strlen(EventTypeAbbr[typeID]); stim_id.replace(stim_id.size()-n-1,n,EventTypeAbbr[typeID]); return *this; } /*!< @brief sets the type ID @see EventTypeID_t */
 
+
+	virtual int getHostID() const { return hostID; }
+	virtual EventBase& setHostID(int host) { hostID = host; genName(); return *this; }
+	
 	virtual unsigned int getDuration() const { return duration; } /*!< @brief gets the time since the beginning of this sequence (the timestamp of the activate event) @see duration */
 	virtual EventBase& setDuration(unsigned int d) { duration = d; return *this; }/*!< @brief sets the time since the beginning of this sequence (the timestamp of the activate event) @see duration */
 
@@ -210,7 +226,7 @@ class EventBase : public XMLLoadSave {
 	 *  framework expansion.  (Thus, user subclasses should contain at least one
 	 *  lower-case letter.)  This code can be used when serializing to allow quick
 	 *  identification of the class type by the receiver. */
-	virtual unsigned int getClassTypeID() const { return makeClassTypeID("BASE"); }
+	virtual classTypeID_t getClassTypeID() const { return autoRegisterEventBase; }
 
 	virtual unsigned int getBinSize() const; //!< should return the minimum size needed if using binary format (i.e. not XML)
 	virtual unsigned int loadBinaryBuffer(const char buf[], unsigned int len); //!< load from binary format
@@ -256,10 +272,15 @@ class EventBase : public XMLLoadSave {
 	
  protected:
 	//! converts the first 4 characters of @a str to an unsigned int, should ensure consistent byte ordering across platforms
-	/*! The numeric value may differ between platforms, but it will be consistent
-	 *  with the IDs on that platform, which is the real key since we aren't doing
-	 *  math, just equality */
-	static unsigned int makeClassTypeID(const char* str) { return *reinterpret_cast<const unsigned int*>(str); }
+	static unsigned int makeClassTypeID(const char* str) {
+#if LOADSAVE_SWAPBYTES
+		unsigned int x;
+		byteswap(x,*reinterpret_cast<const unsigned int*>(str));
+		return x;
+#else
+		return *reinterpret_cast<const unsigned int*>(str);
+#endif
+	}
 
 	std::string stim_id; //!< the name of the event, use the same name consistently or else will be seen as different stimuli
 	float magnitude; //!< the current "strength" of the event/stimuli... MAKE SURE this gets set to ZERO IF event is DEACTIVATE
@@ -276,10 +297,14 @@ class EventBase : public XMLLoadSave {
 													* Source IDs are defined by the generator that made it.  This should
 													* give authors flexibility to design their modules without having to
 													* worry about ID space collision */
+	int hostID;
 	unsigned int duration; /*!< @brief the time since this sequence started (like, how long the
 													*   button has been pressed); not all generators will set this;
 													*   Typically, this would be 0 for activate,
 													*   (activate.timestamp-::get_time()) for status and deactivate */
+
+	//! causes class type id to automatically be regsitered with EventBase's FamilyFactory (getTypeRegistry())
+	static const EventBase::classTypeID_t autoRegisterEventBase;
 };
 
 /*! @file
@@ -287,10 +312,10 @@ class EventBase : public XMLLoadSave {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.50 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.57 $
  * $State: Exp $
- * $Date: 2006/10/03 23:19:23 $
+ * $Date: 2007/11/13 04:16:02 $
  */
 
 #endif
