@@ -50,7 +50,7 @@ EventGeneratorBase::setAutoListen(EventBase::EventGeneratorID_t gid) {
 }
 
 void
-EventGeneratorBase::setAutoListen(EventBase::EventGeneratorID_t gid, unsigned int sid) {
+EventGeneratorBase::setAutoListen(EventBase::EventGeneratorID_t gid, size_t sid) {
 	removeSrcListener();
 	autoListen=true;
 	srcGenID=gid;
@@ -67,7 +67,7 @@ EventGeneratorBase::setAutoListen(EventBase::EventGeneratorID_t gid, unsigned in
 }
 
 void
-EventGeneratorBase::setAutoListen(EventBase::EventGeneratorID_t gid, unsigned int sid, EventBase::EventTypeID_t tid) {
+EventGeneratorBase::setAutoListen(EventBase::EventGeneratorID_t gid, size_t sid, EventBase::EventTypeID_t tid) {
 	removeSrcListener();
 	autoListen=true;
 	srcGenID=gid;
@@ -140,9 +140,9 @@ EventGeneratorBase::removeSrcListener() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.5 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.6 $
  * $State: Exp $
- * $Date: 2006/09/22 22:29:02 $
+ * $Date: 2007/11/13 04:16:02 $
  */
 
