@@ -47,9 +47,9 @@ public:
 	virtual void setGeneratorID(EventBase::EventGeneratorID_t gid) { myGenID=gid; }
 
 	//! return the source ID that will be broadcast on
-	virtual unsigned int getSourceID() const { return mySourceID; }
+	virtual size_t getSourceID() const { return mySourceID; }
 	//! set the source ID that will be broadcast on
-	virtual void setSourceID(unsigned int sid) { mySourceID=sid; }
+	virtual void setSourceID(size_t sid) { mySourceID=sid; }
 
 	//! return true if this generator has listeners
 	virtual bool hasListeners() const;
@@ -71,16 +71,16 @@ public:
 	//! turns on auto listening to make it easier to set up dependancies between vision filters
 	virtual void setAutoListen(EventBase::EventGeneratorID_t gid);
 	//! turns on auto listening to make it easier to set up dependancies between vision filters
-	virtual void setAutoListen(EventBase::EventGeneratorID_t gid, unsigned int sid);
+	virtual void setAutoListen(EventBase::EventGeneratorID_t gid, size_t sid);
 	//! turns on auto listening to make it easier to set up dependancies between vision filters
-	virtual void setAutoListen(EventBase::EventGeneratorID_t gid, unsigned int sid, EventBase::EventTypeID_t tid);
+	virtual void setAutoListen(EventBase::EventGeneratorID_t gid, size_t sid, EventBase::EventTypeID_t tid);
 	//! turns off auto listening
 	virtual void unsetAutoListen();
 
 	//! returns the generator ID that will be listened for (not the generator of the FilterBankEvent to be created - that depends on the subclass)
 	virtual EventBase::EventGeneratorID_t getListenGeneratorID() const { return srcGenID; }
 	//! returns the source ID that will be listened for (not the source of the FilterBankEvent to be created - that depends on the subclass)
-	virtual unsigned int getListenSourceID() const { return srcSourceID; }
+	virtual size_t getListenSourceID() const { return srcSourceID; }
 	//! returns the type ID that will be listened for (not the type of the FilterBankEvent to be created - that depends on the subclass)
 	virtual EventBase::EventTypeID_t getListenTypeID() const { return srcTypeID; }
 
@@ -89,16 +89,16 @@ public:
 protected:
 	//!@name Constructors
 	//!
-	EventGeneratorBase(const std::string& classname, const std::string& instancename, EventBase::EventGeneratorID_t mgid, unsigned int msid)
+	EventGeneratorBase(const std::string& classname, const std::string& instancename, EventBase::EventGeneratorID_t mgid, size_t msid)
 		: BehaviorBase(classname,instancename), myGenID(mgid), mySourceID(msid), autoListen(false), isListening(false), srcGenID(EventBase::numEGIDs), srcSourceID(), srcTypeID(), specificity()
 	{}
-	EventGeneratorBase(const std::string& classname, const std::string& instancename, EventBase::EventGeneratorID_t mgid, unsigned int msid,EventBase::EventGeneratorID_t srcgid)
+	EventGeneratorBase(const std::string& classname, const std::string& instancename, EventBase::EventGeneratorID_t mgid, size_t msid,EventBase::EventGeneratorID_t srcgid)
 		: BehaviorBase(classname,instancename), myGenID(mgid), mySourceID(msid), autoListen(srcgid!=EventBase::numEGIDs), isListening(false), srcGenID(srcgid), srcSourceID(), srcTypeID(), specificity(GENERATOR)
 	{}
-	EventGeneratorBase(const std::string& classname, const std::string& instancename, EventBase::EventGeneratorID_t mgid, unsigned int msid,EventBase::EventGeneratorID_t srcgid, unsigned int srcsid)
+	EventGeneratorBase(const std::string& classname, const std::string& instancename, EventBase::EventGeneratorID_t mgid, size_t msid,EventBase::EventGeneratorID_t srcgid, size_t srcsid)
 		: BehaviorBase(classname,instancename), myGenID(mgid), mySourceID(msid), autoListen(srcgid!=EventBase::numEGIDs), isListening(false), srcGenID(srcgid), srcSourceID(srcsid), srcTypeID(), specificity(SOURCE)
 	{}
-	EventGeneratorBase(const std::string& classname, const std::string& instancename, EventBase::EventGeneratorID_t mgid, unsigned int msid,EventBase::EventGeneratorID_t srcgid, unsigned int srcsid, EventBase::EventTypeID_t srctype)
+	EventGeneratorBase(const std::string& classname, const std::string& instancename, EventBase::EventGeneratorID_t mgid, size_t msid,EventBase::EventGeneratorID_t srcgid, size_t srcsid, EventBase::EventTypeID_t srctype)
 		: BehaviorBase(classname,instancename), myGenID(mgid), mySourceID(msid), autoListen(srcgid!=EventBase::numEGIDs), isListening(false), srcGenID(srcgid), srcSourceID(srcsid), srcTypeID(srctype), specificity(TYPE)
 	{}
 	//@}
@@ -110,11 +110,11 @@ protected:
 	virtual void removeSrcListener();
 
 	EventBase::EventGeneratorID_t myGenID; //!< the generator ID to broadcast on
-	unsigned int mySourceID;     //!< the source ID to broadcast on
+	size_t mySourceID;     //!< the source ID to broadcast on
 	bool autoListen;          //!< if true, will automatically start listening for EventBase(genID,sourceID) events
 	bool isListening;         //!< true if listening triggered by autoListen
 	EventBase::EventGeneratorID_t srcGenID; //!< the generator ID to listen for (typically the source that this filter works on)
-	unsigned int srcSourceID;    //!< the source ID to listen for
+	size_t srcSourceID;    //!< the source ID to listen for
 	EventBase::EventTypeID_t srcTypeID; //!< the type ID to listen for
 	specificity_t specificity; //!< the level of event specificity that is being listened for, so when #autoListen is triggered, we can subscribe to the right level of event stream
 };
@@ -124,10 +124,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.10 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.11 $
  * $State: Exp $
- * $Date: 2005/08/07 04:11:03 $
+ * $Date: 2007/11/13 04:16:02 $
  */
 
 #endif
