@@ -4,12 +4,47 @@
 #include "Shared/ProjectInterface.h"
 #include <algorithm>
 #include "Events/TimerEvent.h"
+#include "EventTranslator.h"
+#include "Events/RemoteRouter.h"
+#include "Events/EventProxy.h"
+
+#include <sstream>
+
+#ifndef PLATFORM_APERIOS
+#  include "IPC/Thread.h"
+#  include "Shared/MarkScope.h"
+#endif
 
 EventRouter * erouter=NULL;
 
 EventRouter::EventRouter()
-	: timers(), trappers(), listeners(), postings()
-{}
+	: proxies(), rrouters(), sck(NULL), nextProxyPort(defaultPort+1),
+	  timers(), trappers(), listeners(), postings()
+{
+	for(unsigned int i=0; i<ProcessID::NumProcesses; ++i) {
+		forwards[i]=NULL;
+	}
+
+}
+
+EventRouter::~EventRouter() {
+	reset();
+	removeAllTimers();
+	for(unsigned int i=0; i<ProcessID::NumProcesses; ++i) {
+		delete forwards[i];
+		forwards[i]=NULL;
+	}
+
+	//Delete all the event proxies
+	printf("Deleting %zu EventProxies and %zu RemoteRouters\n", proxies.size(), rrouters.size());
+	for (std::list<EventProxy *>::iterator pi = proxies.begin(); pi != proxies.end(); pi++)
+		delete *pi;
+	
+	//Delete the remote routers
+	for (std::map<int, RemoteRouter *>::iterator mi = rrouters.begin(); mi != rrouters.end(); mi++)
+		delete (*mi).second;
+	
+}
 
 void EventRouter::postEvent(EventBase* e) { processEvent(*e); delete e; }
 
@@ -71,7 +106,7 @@ void EventRouter::processTimers() {
  *  @param sid the source ID to use on that event (if you need to send more info, send a pointer to a struct of your devising, typecasted as int)
  *  @param delay the delay between the first (and future) calls
  *  @param repeat set to true if you want to keep receiving this event, otherwise it will only send once */
-void EventRouter::addTimer(EventListener* el, unsigned int sid, unsigned int delay, bool repeat) {
+void EventRouter::addTimer(EventListener* el, size_t sid, unsigned int delay, bool repeat) {
 	if(delay==-1U) {
 		removeTimer(el,sid);
 		return;
@@ -101,7 +136,7 @@ void EventRouter::removeTimer(EventListener* el) {
 	timers.erase(std::remove(timers.begin(),timers.end(),(const TimerEntry*)NULL),timers.end());
 }
 
-void EventRouter::removeTimer(EventListener* el, unsigned int sid) {
+void EventRouter::removeTimer(EventListener* el, size_t sid) {
 	for(timer_it_t it=timers.begin(); it!=timers.end(); it++)
 		if((*it)->el==el && (*it)->sid==sid) {
 			delete *it;
@@ -124,7 +159,7 @@ void EventRouter::addListener(EventListener* el, EventBase::EventGeneratorID_t e
 	else
 		postEvent(EventBase(EventBase::erouterEGID,egid,EventBase::statusETID,0,EventBase::EventGeneratorNames[egid],1));
 }
-void EventRouter::addListener(EventListener* el, EventBase::EventGeneratorID_t egid, unsigned int sid) {
+void EventRouter::addListener(EventListener* el, EventBase::EventGeneratorID_t egid, size_t sid) {
 	bool hadListener=hasListeners(egid);
 	for(unsigned int et=0; et<EventBase::numETIDs; et++)
 		listeners.addMapping(el,egid,sid,(EventBase::EventTypeID_t)et);
@@ -133,7 +168,7 @@ void EventRouter::addListener(EventListener* el, EventBase::EventGeneratorID_t e
 	else
 		postEvent(EventBase(EventBase::erouterEGID,egid,EventBase::statusETID,0,EventBase::EventGeneratorNames[egid],1));
 }
-void EventRouter::addListener(EventListener* el, EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid) {
+void EventRouter::addListener(EventListener* el, EventBase::EventGeneratorID_t egid, size_t sid, EventBase::EventTypeID_t etid) {
 	bool hadListener=hasListeners(egid);
 	listeners.addMapping(el,egid,sid,etid);
 	if(!hadListener)
@@ -150,6 +185,146 @@ void EventRouter::addListener(EventListener* el, const EventBase& e) {
 		postEvent(EventBase(EventBase::erouterEGID,e.getGeneratorID(),EventBase::statusETID,0,EventBase::EventGeneratorNames[e.getGeneratorID()],1));
 }
 
+//Start of remote event code------------------
+void EventRouter::addRemoteListener(EventListener* el, int host,
+									EventBase::EventGeneratorID_t egid) {
+	RemoteRouter &rr = remoteRouterForHost(host);
+	addListener(el, egid);
+	rr.addListener(egid);
+}
+
+void EventRouter::addRemoteListener(EventListener* el, int host,
+									EventBase::EventGeneratorID_t egid, size_t sid) {
+	RemoteRouter &rr = remoteRouterForHost(host);
+	addListener(el, egid, sid);
+	rr.addListener(egid, sid);
+}
+
+void EventRouter::addRemoteListener(EventListener* el, int host, const EventBase& e){
+	addRemoteListener(el, host, e.getGeneratorID(), e.getSourceID(), e.getTypeID());
+}
+
+void EventRouter::addRemoteListener(EventListener* el, int host,
+									EventBase::EventGeneratorID_t egid, size_t sid,
+									EventBase::EventTypeID_t etid) {
+	RemoteRouter &rr = remoteRouterForHost(host);
+	addListener(el, egid, sid, etid);
+	rr.addListener(egid, sid, etid);
+}
+
+
+void EventRouter::removeRemoteListener(EventListener* el, int host,
+									   EventBase::EventGeneratorID_t egid) {
+	RemoteRouter &rr = remoteRouterForHost(host);
+	removeListener(el, egid);
+	rr.removeListener(egid);
+}
+
+void EventRouter::removeRemoteListener(EventListener* el, int host,
+									   EventBase::EventGeneratorID_t egid, size_t sid) {
+	RemoteRouter &rr = remoteRouterForHost(host);
+	removeListener(el, egid, sid);
+	rr.removeListener(egid, sid);	
+}
+    
+void EventRouter::removeRemoteListener(EventListener* el, int host,
+									   const EventBase& e) {
+	removeRemoteListener(el, host, e.getGeneratorID(), e.getSourceID(), e.getTypeID());	
+}
+
+void EventRouter::removeRemoteListener(EventListener* el, int host,
+									   EventBase::EventGeneratorID_t egid, size_t sid,
+									   EventBase::EventTypeID_t etid) {
+	RemoteRouter &rr = remoteRouterForHost(host);
+	removeListener(el, egid, sid, etid);
+	rr.removeListener(egid, sid, etid);
+}
+
+
+void EventRouter::requestRemoteStateUpdates(int host, RemoteState::StateType type,
+											unsigned int interval) {
+	RemoteRouter &rr = remoteRouterForHost(host);
+	rr.requestStateUpdates(type, interval);
+}
+
+void EventRouter::stopRemoteStateUpdates(int host, RemoteState::StateType type) {
+	RemoteRouter &rr = remoteRouterForHost(host);
+	rr.stopStateUpdates(type);
+}
+
+RemoteRouter &EventRouter::remoteRouterForHost(int host) {
+	RemoteRouter *rr = rrouters[host];
+	if (rr) {
+		printf("Returning existing remote router for host %s", intToStringIP(host).c_str());
+		return *rr;
+	} else {
+		rrouters[host] = rr = new RemoteRouter(host);
+		printf("Returning new remote router for host %s", intToStringIP(host).c_str());
+		return *rr;
+	}
+}
+
+std::string EventRouter::intToStringIP(int ip) {
+	std::stringstream ret;
+	ret << (ip >> 24 & 0xff) << '.' << (ip >> 16 & 0xff) << '.'
+		<< (ip >> 8 & 0xff) << '.' << (ip >> 0 & 0xff);
+	return ret.str();
+}
+
+int EventRouter::stringToIntIP(std::string ip_str) {
+	std::istringstream sstr;
+	sstr.str(ip_str);
+	int ip = 0, b;
+	char c;
+
+	sstr >> b >> c;
+	ip |= b << 24;
+
+	sstr >> b >> c;
+	ip |= b << 16;
+
+	sstr >> b >> c;
+	ip |= b << 8;
+
+	sstr >> b;
+	ip |= b << 0;
+
+	return ip;
+}
+
+/* This is called in MMCombo.cc on startup. */
+bool EventRouter::serveRemoteEventRequests() {
+	if (sck)
+		return false;
+	sck = wireless->socket(Socket::SOCK_STREAM);
+	wireless->setReceiver(sck, this);
+	wireless->setDaemon(sck, true);
+	wireless->listen(sck, EventRouter::defaultPort);
+	return true;
+}
+
+int EventRouter::processData(char* /* data*/, int bytes) {
+	if (bytes != sizeof(int)) {
+		std::cerr << "Unknown data received" << std::endl;
+		return -1;
+	}
+	
+	int nextPort = nextProxyPort++;
+	std::cout << "Starting EventProxy on port " << nextPort
+		 << " for host " << intToStringIP(sck->getPeerAddress()) << std::endl;
+	proxies.push_back(new EventProxy(nextPort));
+
+	//Send the port to the RemoteRouter
+	sck->write((byte *)&nextPort, sizeof(int));
+
+	//Start listening again
+	wireless->close(sck);
+	
+	return 0;
+}
+
+//End of remote event code
+
 void EventRouter::removeListener(EventListener* el) {
 	for(unsigned int eg=0; eg<EventBase::numEGIDs; eg++) {
 		EventBase::EventGeneratorID_t egid=(EventBase::EventGeneratorID_t)eg;
@@ -171,7 +346,7 @@ void EventRouter::removeListener(EventListener* el, EventBase::EventGeneratorID_
 	else
 		postEvent(EventBase(EventBase::erouterEGID,egid,EventBase::statusETID,0,EventBase::EventGeneratorNames[egid],1));
 }
-void EventRouter::removeListener(EventListener* el, EventBase::EventGeneratorID_t egid, unsigned int sid) {
+void EventRouter::removeListener(EventListener* el, EventBase::EventGeneratorID_t egid, size_t sid) {
 	unsigned int removed=0;
 	for(unsigned int et=0; et<EventBase::numETIDs; et++)
 		removed+=listeners.removeMapping(el,egid,sid,(EventBase::EventTypeID_t)et);
@@ -183,7 +358,7 @@ void EventRouter::removeListener(EventListener* el, EventBase::EventGeneratorID_
 	else
 		postEvent(EventBase(EventBase::erouterEGID,egid,EventBase::statusETID,0,EventBase::EventGeneratorNames[egid],1));
 }
-void EventRouter::removeListener(EventListener* el, EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid) {
+void EventRouter::removeListener(EventListener* el, EventBase::EventGeneratorID_t egid, size_t sid, EventBase::EventTypeID_t etid) {
 	if(!listeners.removeMapping(el,egid,sid,etid))
 		return; //nothing was removed, don't want to clean up or throw an event
 	listeners.clean(egid);
@@ -220,7 +395,7 @@ void EventRouter::addTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egi
 		postEvent(EventBase(EventBase::erouterEGID,egid,EventBase::statusETID,0,EventBase::EventGeneratorNames[egid],1));
 }
 /*! Note that since timers are not broadcast, they cannot be trapped.  Only the EventListener which requested the timer will receive that timer. */
-void EventRouter::addTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egid, unsigned int sid) {
+void EventRouter::addTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egid, size_t sid) {
 	bool hadListener=hasListeners(egid);
 	for(unsigned int et=0; et<EventBase::numETIDs; et++)
 		trappers.addMapping(el,egid,sid,(EventBase::EventTypeID_t)et);
@@ -230,7 +405,7 @@ void EventRouter::addTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egi
 		postEvent(EventBase(EventBase::erouterEGID,egid,EventBase::statusETID,0,EventBase::EventGeneratorNames[egid],1));
 }
 /*! Note that since timers are not broadcast, they cannot be trapped.  Only the EventListener which requested the timer will receive that timer. */
-void EventRouter::addTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid) {
+void EventRouter::addTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egid, size_t sid, EventBase::EventTypeID_t etid) {
 	bool hadListener=hasListeners(egid);
 	trappers.addMapping(el,egid,sid,etid);
 	if(!hadListener)
@@ -264,7 +439,7 @@ void EventRouter::removeTrapper(EventTrapper* el, EventBase::EventGeneratorID_t
 	else
 		postEvent(EventBase(EventBase::erouterEGID,egid,EventBase::statusETID,0,EventBase::EventGeneratorNames[egid],1));
 }
-void EventRouter::removeTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egid, unsigned int sid) {
+void EventRouter::removeTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egid, size_t sid) {
 	int removed=0;
 	for(unsigned int et=0; et<EventBase::numETIDs; et++)
 		removed+=trappers.removeMapping(el,egid,sid,(EventBase::EventTypeID_t)et);
@@ -276,7 +451,7 @@ void EventRouter::removeTrapper(EventTrapper* el, EventBase::EventGeneratorID_t
 	else
 		postEvent(EventBase(EventBase::erouterEGID,egid,EventBase::statusETID,0,EventBase::EventGeneratorNames[egid],1));
 }
-void EventRouter::removeTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid) {
+void EventRouter::removeTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egid, size_t sid, EventBase::EventTypeID_t etid) {
 	if(!trappers.removeMapping(el,egid,sid,etid))
 		return; //nothing was removed, don't want to clean up or throw an event
 	trappers.clean(egid);
@@ -291,12 +466,28 @@ void EventRouter::removeTrapper(EventTrapper* el) {
 		removeTrapper(el,(EventBase::EventGeneratorID_t)eg);
 }
 
+void EventRouter::setForwardingAgent(ProcessID::ProcessID_t proc, EventTranslator* trans) {
+	delete forwards[proc];
+	forwards[proc]=trans;
+}
+
 void EventRouter::processEvent(const EventBase& e) {
+	// check for forwarding *before* the lock
+	ProcessID::ProcessID_t pid=ProcessID::getID();
+	if(forwards[pid]!=NULL) {
+		if(forwards[pid]->trapEvent(e))
+			return;
+	}
+	
+#ifndef PLATFORM_APERIOS
+	static ThreadNS::Lock lk;
+	MarkScope autolock(lk);
+#endif
 	PostingStatus ps(trappers,listeners,e);
 	postings.push(&ps);
 	while(postings.size()>0) {
 #ifdef DEBUG
-		unsigned int presize=postings.size();
+		size_t presize=postings.size();
 		postings.front()->process();
 		ASSERT(postings.size()==0 || postings.size()==presize,"partial queue completion?");
 #else
@@ -367,13 +558,13 @@ EventRouter::EventMapper::EventMapper() {
 			filteredevents[eg][et]=NULL;
 }
 
-void EventRouter::EventMapper::addMapping(void* el, EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid) {
+void EventRouter::EventMapper::addMapping(void* el, EventBase::EventGeneratorID_t egid, size_t sid, EventBase::EventTypeID_t etid) {
 	if(filteredevents[egid][etid]==NULL) //if this is the first subscriber to this EGID and ETID
 		filteredevents[egid][etid]=new SIDtoListenerVectorMap_t(); 
 	SIDtoListenerVectorMap_t::iterator it=filteredevents[egid][etid]->find(sid); // now find subscribers to the source id as well
 	std::vector<void*>* elv=NULL;
 	if(it==filteredevents[egid][etid]->end()) { // if this is the first subscriber to the source ID
-		std::pair<const unsigned int,std::vector<void*> > p(sid,std::vector<void*>());
+		std::pair<const size_t,std::vector<void*> > p(sid,std::vector<void*>());
 		//		p.first=sid; //p.second is a vector, only needs to be constructed
 		filteredevents[egid][etid]->insert(p);
 		elv=&(*filteredevents[egid][etid]->find(sid)).second;
@@ -385,7 +576,7 @@ void EventRouter::EventMapper::addMapping(void* el, EventBase::EventGeneratorID_
 
 bool EventRouter::EventMapper::removeMapping(void* el, EventBase::EventGeneratorID_t egid) {
 	// remove listener from allevents
-	unsigned int numlist=allevents[egid].size();
+	size_t numlist=allevents[egid].size();
 	allevents[egid].erase(std::remove(allevents[egid].begin(),allevents[egid].end(),el),allevents[egid].end());
 	bool hadListener=allevents[egid].size()!=numlist;
 	
@@ -407,7 +598,7 @@ bool EventRouter::EventMapper::removeMapping(void* el, EventBase::EventGenerator
 	return hadListener;
 }
 
-bool EventRouter::EventMapper::removeMapping(void* el, EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid) {
+bool EventRouter::EventMapper::removeMapping(void* el, EventBase::EventGeneratorID_t egid, size_t sid, EventBase::EventTypeID_t etid) {
 	bool hadListener=false;
 	SIDtoListenerVectorMap_t* mapping=filteredevents[egid][etid];
 	if(mapping!=NULL) { // if there are subscribers to this egid/etid
@@ -487,7 +678,7 @@ bool EventRouter::EventMapper::hasMapping(EventBase::EventGeneratorID_t egid) co
 	return false;
 }
 
-bool EventRouter::EventMapper::hasMapping(EventBase::EventGeneratorID_t egid, unsigned int sid) const {
+bool EventRouter::EventMapper::hasMapping(EventBase::EventGeneratorID_t egid, size_t sid) const {
 	if(allevents[egid].size()>0)
 		return true;
 	for(unsigned int et=0; et<EventBase::numETIDs; et++) {
@@ -501,7 +692,7 @@ bool EventRouter::EventMapper::hasMapping(EventBase::EventGeneratorID_t egid, un
 	return false;
 }
 
-bool EventRouter::EventMapper::hasMapping(EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid) const {
+bool EventRouter::EventMapper::hasMapping(EventBase::EventGeneratorID_t egid, size_t sid, EventBase::EventTypeID_t etid) const {
 	if(allevents[egid].size()>0)
 		return true;
 	const SIDtoListenerVectorMap_t* mapping=filteredevents[egid][etid];
@@ -532,7 +723,7 @@ void EventRouter::EventMapper::getMapping(const EventBase& e, std::vector<T*>& l
 		ls.push_back(static_cast<T*>(*elit));
 }
 
-bool EventRouter::EventMapper::verifyMapping(void * listener, EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid) const {
+bool EventRouter::EventMapper::verifyMapping(void * listener, EventBase::EventGeneratorID_t egid, size_t sid, EventBase::EventTypeID_t etid) const {
 	// first check the 'all events' subscribers
 	const std::vector<void*>* elv=&allevents[egid];
 	for(std::vector<void*>::const_iterator elit=elv->begin(); elit!=elv->end(); elit++)
@@ -589,7 +780,7 @@ bool EventRouter::EventMapper::verifyMappingAny(void* listener, EventBase::Event
 	return false;
 }
 
-bool EventRouter::EventMapper::verifyMappingAll(void* listener, EventBase::EventGeneratorID_t egid, unsigned int sid) const {
+bool EventRouter::EventMapper::verifyMappingAll(void* listener, EventBase::EventGeneratorID_t egid, size_t sid) const {
 	// first check the 'all events' subscribers
 	const std::vector<void*>* elv=&allevents[egid];
 	for(std::vector<void*>::const_iterator elit=elv->begin(); elit!=elv->end(); elit++)
@@ -620,7 +811,7 @@ bool EventRouter::EventMapper::verifyMappingAll(void* listener, EventBase::Event
 	return true;
 }
 
-bool EventRouter::EventMapper::verifyMappingAny(void* listener, EventBase::EventGeneratorID_t egid, unsigned int sid) const {
+bool EventRouter::EventMapper::verifyMappingAny(void* listener, EventBase::EventGeneratorID_t egid, size_t sid) const {
 	// first check the 'all events' subscribers
 	const std::vector<void*>* elv=&allevents[egid];
 	for(std::vector<void*>::const_iterator elit=elv->begin(); elit!=elv->end(); elit++)
@@ -650,10 +841,10 @@ bool EventRouter::EventMapper::verifyMappingAny(void* listener, EventBase::Event
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.28 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.32 $
  * $State: Exp $
- * $Date: 2006/09/27 21:15:51 $
+ * $Date: 2007/11/13 04:16:02 $
  */
 
 
@@ -677,8 +868,8 @@ unsigned int EventRouter::numListeners(EventBase::EventGeneratorID_t egid) {
 	return ans;
 }
 
-bool EventRouter::numListeners(EventBase::EventGeneratorID_t egid, unsigned int sid) {
-	unsigned int ans=allevents[egid].size();
+bool EventRouter::numListeners(EventBase::EventGeneratorID_t egid, size_t sid) {
+	size_t ans=allevents[egid].size();
 	for(unsigned int et=0; et<EventBase::numETIDs; et++) {
 		SIDtoListenerVectorMap_t* mapping=filteredevents[egid][et];
 		if(mapping!=NULL) {
@@ -690,7 +881,7 @@ bool EventRouter::numListeners(EventBase::EventGeneratorID_t egid, unsigned int
 	return false;
 }
 
-unsigned int EventRouter::numListeners(EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid) {
+unsigned int EventRouter::numListeners(EventBase::EventGeneratorID_t egid, size_t sid, EventBase::EventTypeID_t etid) {
 	unsigned int ans=allevents[egid].size();
 	SIDtoListenerVectorMap_t* mapping=filteredevents[egid][etid];
 	if(mapping!=NULL) {
