@@ -2,16 +2,27 @@
 #ifndef INCLUDED_EventRouter_h
 #define INCLUDED_EventRouter_h
 
+#include <string>
 #include <vector>
 #include <queue>
 #include <map>
+#include <list>
 #include <algorithm>
 #include "EventListener.h"
 #include "EventTrapper.h"
 #include "Shared/get_time.h"
 #include "Shared/debuget.h"
 #include "Shared/attributes.h"
+#include "IPC/ProcessID.h"
 #include <iostream>
+#include "Shared/RemoteState.h"
+
+#include "Wireless/SocketListener.h"
+#include "Wireless/Socket.h"
+
+class RemoteRouter;
+class EventTranslator;
+class EventProxy;
 
 //! This class will handle distribution of events as well as management of timers
 /*! Classes must inherit from EventListener and/or EventTrapper in order to
@@ -21,7 +32,17 @@
  *  events.  (except if you are posting from within a MotionCommand, in
  *  which case you should use MotionCommand::postEvent() so that it can correctly
  *  handle inter-process communication issues under Aperios (the Aibo's OS) -- under a
- *  Unix-based OS, this wouldn't be necessary.)
+ *  Unix-based OS, this isn't necessary.)  Events posted in non-Main processes
+ *  will be forwarded to Main for processing.
+ *
+ *  Event processing is a serialized operation, meaning only one event is ever being
+ *  processed at a time, and by one listener at a time.  The EventRouter contains its own
+ *  thread lock, so if two threads post events at the same time, the EventRouter
+ *  will handle ensuring mutual exclusion.  Listeners are free to spawn their own
+ *  threads to handle processing or posting events to avoid being dependent on
+ *  other listeners' processing times.  (Note: threads are not available on the Aibo,
+ *  so listeners which wish to run on the Aibo are stuck with a "cooperative"
+ *  multitasking model)
  *
  *  The events available for processing are listed in EventBase::EventGeneratorID_t.
  *  Each generator ID's documentation specifies how to interpret the source ID field, and whether
@@ -89,7 +110,7 @@
  *  <h3>Event processing examples:</h3>
  *
  *  Posting events:
- *  @code
+ *  @codeEventProxy
  *  //method A: basic event posting (EventBase instance is sent)
  *  erouter->postEvent(EventBase::aiEGID, 1234, EventBase::statusETID);
  *
@@ -148,19 +169,19 @@
  *    - <a href="http://www.cs.cmu.edu/~dst/Tekkotsu/Tutorial/events.shtml">David Touretzky's Events Chapter</a>
  *    - <a href="http://www.cs.cmu.edu/afs/cs/academic/class/15494-s06/www/lectures/behaviors.pdf">CMU's Cognitive Robotics course slides</a>
  */
-class EventRouter : public EventListener {
+class EventRouter : public EventListener, public SocketListener {
  public:
 	EventRouter(); //!< Constructs the router
-	virtual ~EventRouter() { reset(); removeAllTimers(); } //!< just calls reset and removeAllTimers()
-	
+	virtual ~EventRouter(); //!< just calls reset and removeAllTimers()
+
 	void reset() { listeners.clear(); trappers.clear(); removeAllTimers(); } //!< erases all listeners, trappers and timers, resets EventRouter
 	
 	
 	//!@name Posting/Processing Events
 	
 	/*!@brief recommended to create and post an event using current buffer setting */
-	void postEvent(EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid, unsigned int dur=0) { processEvent(EventBase(egid,sid,etid,dur)); }
-	void postEvent(EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid, unsigned int dur, const std::string& n, float m) { processEvent(EventBase(egid,sid,etid,dur,n,m)); }
+	void postEvent(EventBase::EventGeneratorID_t egid, size_t sid, EventBase::EventTypeID_t etid, unsigned int dur=0) { processEvent(EventBase(egid,sid,etid,dur)); }
+	void postEvent(EventBase::EventGeneratorID_t egid, size_t sid, EventBase::EventTypeID_t etid, unsigned int dur, const std::string& n, float m) { processEvent(EventBase(egid,sid,etid,dur,n,m)); }
 	//! deprecated -- pass by reference instead;  this version posts the specified event and then deletes it after processing is complete
 	/*! moving to pass by reference instead of pass by pointer to avoid questions about who deletes the event and the event's scope,
 	 *  also keeping the event on the stack is faster by avoiding unnecessary heap operations. */
@@ -177,6 +198,11 @@ class EventRouter : public EventListener {
 	 *  probably a more memnomic interface to use in direct function calls however,
 	 *  so that is the one you should call. */
 	void processEvent(const EventBase& e);
+	
+	//! returns the forwarding agent for a given process/thread group (see #forwards)
+	EventTranslator* getForwardingAgent(ProcessID::ProcessID_t proc) const { return forwards[proc]; }
+	//! sets the forwarding agent for a given process/thread group (see #forwards)
+	void setForwardingAgent(ProcessID::ProcessID_t proc, EventTranslator* trans);
 	//@}
 
 	
@@ -184,16 +210,16 @@ class EventRouter : public EventListener {
 	
 	//! returns true if the specified listener/trapper would receive any events that match the specified criteria
 	bool isListeningAny(EventListener* el, EventBase::EventGeneratorID_t egid) { return listeners.verifyMappingAny(el,egid); }
-	bool isListeningAny(EventListener* el, EventBase::EventGeneratorID_t egid, unsigned int sid) { return listeners.verifyMappingAny(el,egid,sid); }
+	bool isListeningAny(EventListener* el, EventBase::EventGeneratorID_t egid, size_t sid) { return listeners.verifyMappingAny(el,egid,sid); }
 	bool isListeningAll(EventListener* el, EventBase::EventGeneratorID_t egid) { return listeners.verifyMappingAll(el,egid); }
-	bool isListeningAll(EventListener* el, EventBase::EventGeneratorID_t egid, unsigned int sid) { return listeners.verifyMappingAll(el,egid,sid); }
-	bool isListening(EventListener* el, EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid) { return listeners.verifyMapping(el,egid,sid,etid); }
+	bool isListeningAll(EventListener* el, EventBase::EventGeneratorID_t egid, size_t sid) { return listeners.verifyMappingAll(el,egid,sid); }
+	bool isListening(EventListener* el, EventBase::EventGeneratorID_t egid, size_t sid, EventBase::EventTypeID_t etid) { return listeners.verifyMapping(el,egid,sid,etid); }
 	bool isListening(EventListener* el, const EventBase& e) { return listeners.verifyMapping(el,e.getGeneratorID(),e.getSourceID(),e.getTypeID()); }
 	bool isTrappingAny(EventTrapper* el, EventBase::EventGeneratorID_t egid) { return trappers.verifyMappingAny(el,egid); }
-	bool isTrappingAny(EventTrapper* el, EventBase::EventGeneratorID_t egid, unsigned int sid) { return trappers.verifyMappingAny(el,egid,sid); }
+	bool isTrappingAny(EventTrapper* el, EventBase::EventGeneratorID_t egid, size_t sid) { return trappers.verifyMappingAny(el,egid,sid); }
 	bool isTrappingAll(EventTrapper* el, EventBase::EventGeneratorID_t egid) { return trappers.verifyMappingAll(el,egid); }
-	bool isTrappingAll(EventTrapper* el, EventBase::EventGeneratorID_t egid, unsigned int sid) { return trappers.verifyMappingAll(el,egid,sid); }
-	bool isTrapping(EventTrapper* el, EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid) { return trappers.verifyMapping(el,egid,sid,etid); }
+	bool isTrappingAll(EventTrapper* el, EventBase::EventGeneratorID_t egid, size_t sid) { return trappers.verifyMappingAll(el,egid,sid); }
+	bool isTrapping(EventTrapper* el, EventBase::EventGeneratorID_t egid, size_t sid, EventBase::EventTypeID_t etid) { return trappers.verifyMapping(el,egid,sid,etid); }
 	bool isTrapping(EventTrapper* el, const EventBase& e) { return trappers.verifyMapping(el,e.getGeneratorID(),e.getSourceID(),e.getTypeID()); }
 	//@}
 	
@@ -209,8 +235,8 @@ class EventRouter : public EventListener {
 	 * ... if Vision sees a ball in an image, and there's no listeners, does it
 	 * make an event? ;) */
 	bool hasListeners(EventBase::EventGeneratorID_t egid) { return trappers.hasMapping(egid) || listeners.hasMapping(egid); }
-	bool hasListeners(EventBase::EventGeneratorID_t egid, unsigned int sid) { return trappers.hasMapping(egid,sid) || listeners.hasMapping(egid,sid); }
-	bool hasListeners(EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid) { return trappers.hasMapping(egid,sid,etid) || listeners.hasMapping(egid,sid,etid); }
+	bool hasListeners(EventBase::EventGeneratorID_t egid, size_t sid) { return trappers.hasMapping(egid,sid) || listeners.hasMapping(egid,sid); }
+	bool hasListeners(EventBase::EventGeneratorID_t egid, size_t sid, EventBase::EventTypeID_t etid) { return trappers.hasMapping(egid,sid,etid) || listeners.hasMapping(egid,sid,etid); }
 	bool hasListeners(const EventBase& e) { return hasListeners(e.getGeneratorID(),e.getSourceID(),e.getTypeID()); }
 	//@}
 
@@ -218,12 +244,13 @@ class EventRouter : public EventListener {
 	//!@name Timer Management
 	
 	//! adds a timer if it doesn't exist, or resets the timer if it already exists.
-	void addTimer(EventListener* el, unsigned int sid, unsigned int delay, bool repeat=true);
+	void addTimer(EventListener* el, size_t sid, unsigned int delay, bool repeat=true);
 	void addTimer(EventListener* el, const EventBase& e, bool repeat=true) { addTimer(el,e.getSourceID(),e.getDuration(),repeat); } //!< calls the other addTimer() with the event's source id and duration, doesn't check to see if the generator is timerEGID
 	
 	//! clears all pending timers for listener @a el; see remove()
 	void removeTimer(EventListener* el);
-	void removeTimer(EventListener* el, unsigned int sid); //!< clears any pending timers with source id @a sid for listener @a el
+	void removeTimer(EventListener* el, size_t sid); //!< clears any pending timers with source id @a sid for listener @a el
+	void removeTimer(EventListener* el, EventBase& e) { if(e.getGeneratorID()==EventBase::timerEGID) removeTimer(el,e.getSourceID()); } //!< clears any pending timers with source id matching that of @a e, but only if @a e has generator timerEGID
 	void removeAllTimers(); //!< clears all timers for all listeners
 	unsigned int getNextTimer() { return (timers.size()==0 ? -1U : timers.front()->next); } //!< returns time of next timer activation
 	//@}
@@ -233,22 +260,72 @@ class EventRouter : public EventListener {
 	
 	//! Adds a listener for all events from a given event generator
 	void addListener(EventListener* el, EventBase::EventGeneratorID_t egid);
-	void addListener(EventListener* el, EventBase::EventGeneratorID_t egid, unsigned int sid); //!< Adds a listener for all types from a specific source and generator
-	void addListener(EventListener* el, EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid); //!< Adds a listener for a specific source id and type from a given event generator
+	void addListener(EventListener* el, EventBase::EventGeneratorID_t egid, size_t sid); //!< Adds a listener for all types from a specific source and generator
+	void addListener(EventListener* el, EventBase::EventGeneratorID_t egid, size_t sid, EventBase::EventTypeID_t etid); //!< Adds a listener for a specific source id and type from a given event generator
 	void addListener(EventListener* el, const EventBase& e); //!< Uses the generator, source, and type fields of @a e to add a listener for that specific tuple
 
+	
+	//!@name Remote Event/State code
+
+	//! Converts a int representation of an IP to a string
+	static std::string intToStringIP(int ip);
+	//! Converts a string representation of an IP to an int
+	static int stringToIntIP(std::string ip);
+
+	//! Request remote events to be sent to this dog, works like the regular addListeners
+    void addRemoteListener(EventListener* el, int host, EventBase::EventGeneratorID_t egid);
+    void addRemoteListener(EventListener* el, int host, EventBase::EventGeneratorID_t egid, size_t sid);
+    void addRemoteListener(EventListener* el, int host, const EventBase& e);
+    void addRemoteListener(EventListener* el, int host, EventBase::EventGeneratorID_t egid, size_t sid, EventBase::EventTypeID_t etid);
+
+	//! Stop getting remote events from the given dog
+    void removeRemoteListener(EventListener* el, int host, EventBase::EventGeneratorID_t egid);
+    void removeRemoteListener(EventListener* el, int host, EventBase::EventGeneratorID_t egid, size_t sid);
+    void removeRemoteListener(EventListener* el, int host, const EventBase& e);
+    void removeRemoteListener(EventListener* el, int host, EventBase::EventGeneratorID_t egid, size_t sid, EventBase::EventTypeID_t etid);
+
+
+	//! Request remote state updates from the remote dog, every interval ms
+	void requestRemoteStateUpdates(int host, RemoteState::StateType type, unsigned int interval = 500);
+
+	//! Stop getting remote state updates
+	void stopRemoteStateUpdates(int host, RemoteState::StateType type);
+
+	//! This is called once on startup; it tells the EventRouter to listen for incoming requests
+	bool serveRemoteEventRequests();
+
+	//! This handles incomiung connection requests by starting a new EventProxy
+	int processData(char *data, int bytes);
+
+	static const int defaultPort = 2424;
+	
+	protected:
+
+	RemoteRouter &remoteRouterForHost(int host);
+
+	std::list<EventProxy *> proxies;
+
+	std::map<int, RemoteRouter *> rrouters;
+	Socket *sck;
+	int nextProxyPort;
+
+	//!}
+	public:
+
+	
 	//! stops sending ALL events to the listener -- does not remove pending timers however (may need to call removeTimer(el) as well); see remove()
 	void removeListener(EventListener* el); 
 	//! stops sending specified events from the generator to the listener.
 	void removeListener(EventListener* el, EventBase::EventGeneratorID_t egid);
-	void removeListener(EventListener* el, EventBase::EventGeneratorID_t egid, unsigned int sid); //!< stops sending specified events from the generator to the listener.
-	void removeListener(EventListener* el, EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid); //!< stops sending specified events from the generator to the listener.
+	void removeListener(EventListener* el, EventBase::EventGeneratorID_t egid, size_t sid); //!< stops sending specified events from the generator to the listener.
+	void removeListener(EventListener* el, EventBase::EventGeneratorID_t egid, size_t sid, EventBase::EventTypeID_t etid); //!< stops sending specified events from the generator to the listener.
 	void removeListener(EventListener* el, const EventBase& e); //!< Uses the generator, source, and type fields of @a e to remove a listener for that specific tuple
 	
 	//! stops all events and timers, shorthand for removeListener(el) and removeTimer(el); Note that trappers are separate, removeTrapper() is @e not called
 	void remove(EventListener* el) { removeListener(el); removeTimer(el); }
 
 	//@}
+	
 
 	//!@name Trapper Management
 	
@@ -256,27 +333,28 @@ class EventRouter : public EventListener {
 	/*! Note that only the broadcasted timers can be trapped.  The EventListener which requested the timer will receive that timer before any trapping is done. */
 	void addTrapper(EventTrapper* el, const EventBase& e);
 	void addTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egid); //!< Adds a trapper for all events from a given event generator
-	void addTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egid, unsigned int sid);  //!< Adds a trapper for all types from a specific source and generator
-	void addTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid); //!< Adds a trapper for a specific source id and type from a given event generator
+	void addTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egid, size_t sid);  //!< Adds a trapper for all types from a specific source and generator
+	void addTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egid, size_t sid, EventBase::EventTypeID_t etid); //!< Adds a trapper for a specific source id and type from a given event generator
 
 	void addTrapper(EventTrapper* el); //!< adds a trapper for ALL events
 
 	//! stops sending specified events from the generator to the trapper.
 	void removeTrapper(EventTrapper* el, const EventBase& e);
 	void removeTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egid); //!< stops sending specified events from the generator to the trapper.
-	void removeTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egid, unsigned int sid); //!< stops sending specified events from the generator to the trapper.
-	void removeTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid); //!< stops sending specified events from the generator to the trapper.
+	void removeTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egid, size_t sid); //!< stops sending specified events from the generator to the trapper.
+	void removeTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egid, size_t sid, EventBase::EventTypeID_t etid); //!< stops sending specified events from the generator to the trapper.
 
 	void removeTrapper(EventTrapper* el); //!< stops sending ALL events to the trapper
 	//@}
 
  protected:
+
 	//! Contains all the information needed to maintain a timer by the EventRouter
 	struct TimerEntry {
 		//! constructs an entry using the given value for next - useful for with TimerEntryPtrCmp
 		explicit TimerEntry(unsigned int nxt) : el(NULL), sid(0), delay(0), next(nxt), repeat(false) {}
 		//! constructs with the given values, sets next field automatically; see next
-		TimerEntry(EventListener* e, unsigned int s, unsigned int d, bool r) : el(e), sid(s), delay(d), next(get_time()+delay), repeat(r) {}
+		TimerEntry(EventListener* e, size_t s, unsigned int d, bool r) : el(e), sid(s), delay(d), next(get_time()+delay), repeat(r) {}
 		//! just does the default, i'm just being explicit since there's a pointer (no deep copy!)
 		TimerEntry(const TimerEntry& t) : el(t.el), sid(t.sid), delay(t.delay), next(t.next), repeat(t.repeat) {}
 		//! just does the default, i'm just being explicit since there's a pointer (no deep copy!)
@@ -286,7 +364,7 @@ class EventRouter : public EventListener {
 		 *  @param r true if the timer should automatically repeat */
 		void Set(unsigned int d, bool r) { delay=d; repeat=r; next=get_time()+delay; }
 		EventListener* el;  //!< the listener to fire at
-		unsigned int sid;   //!< the source id to fire with
+		size_t sid;   //!< the source id to fire with
 		unsigned int delay; //!< the delay until firing
 		unsigned int next;  //!< the time at which this timer will go off next
 		bool repeat;        //!< if true, will reset after firing, else will be deleted
@@ -334,7 +412,7 @@ class EventRouter : public EventListener {
 		EventMapper();
 
 		void addMapping(void* el, EventBase::EventGeneratorID_t egid) { allevents[egid].push_back(el); } //!< Adds a listener for all events from a given event generator
-		void addMapping(void* el, EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid); //!< Adds a listener for a specific source id and type from a given event generator
+		void addMapping(void* el, EventBase::EventGeneratorID_t egid, size_t sid, EventBase::EventTypeID_t etid); //!< Adds a listener for a specific source id and type from a given event generator
 
 		//! Removes a listener for all events from a given event generator, returns true if something was actually removed
 		/*! Doesn't necessarily remove the vector or mapping if this was the last listener, use clean() to do that */
@@ -342,7 +420,7 @@ class EventRouter : public EventListener {
 
 		//! Removes a listener for a specific source id and type from a given event generator, returns true if something was actually removed
 		/*! Doesn't necessarily remove the vector or mapping if this was the last listener, use clean() to do that */
-		bool removeMapping(void* el, EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid);
+		bool removeMapping(void* el, EventBase::EventGeneratorID_t egid, size_t sid, EventBase::EventTypeID_t etid);
 
 		void clean(); //!<removes empty data structures for all event generators
 		void clean(EventBase::EventGeneratorID_t egid); //!< removes empty data structures associated with a single event generator
@@ -354,8 +432,8 @@ class EventRouter : public EventListener {
 			  ... if Vision sees a ball in an image, and there's no listeners, does it make an event? ;) \n
 			  @return true if it has any listeners, false otherwise */
 		bool hasMapping(EventBase::EventGeneratorID_t egid) const;
-		bool hasMapping(EventBase::EventGeneratorID_t egid, unsigned int sid) const;
-		bool hasMapping(EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid) const;
+		bool hasMapping(EventBase::EventGeneratorID_t egid, size_t sid) const;
+		bool hasMapping(EventBase::EventGeneratorID_t egid, size_t sid, EventBase::EventTypeID_t etid) const;
 		//@}
 
 		//! builds a list of all listeners which should receive the event, templated to typecast the pointers for you
@@ -377,7 +455,7 @@ class EventRouter : public EventListener {
 		 *  that no other listeners have been modified - one listener could cause another
 		 *  to turn off.  If that has happened, we shouldn't send the event, even if it
 		 *  was in the queue originally. */
-		bool verifyMapping(void * listener, EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid) const;
+		bool verifyMapping(void * listener, EventBase::EventGeneratorID_t egid, size_t sid, EventBase::EventTypeID_t etid) const;
 
 		//! Needed to complete EventRouter::isListening suite
 		/*! Only checks #allevents */
@@ -388,15 +466,15 @@ class EventRouter : public EventListener {
 
 		//! Needed to complete EventRouter::isListening suite
 		/*! Checks both #allevents and #filteredevents, must be found in all */
-		bool verifyMappingAll(void * listener, EventBase::EventGeneratorID_t egid, unsigned int sid) const;
+		bool verifyMappingAll(void * listener, EventBase::EventGeneratorID_t egid, size_t sid) const;
 		//! Needed to complete EventRouter::isListening suite
 		/*! Checks both #allevents and #filteredevents, can be found in either */
-		bool verifyMappingAny(void * listener, EventBase::EventGeneratorID_t egid, unsigned int sid) const;
+		bool verifyMappingAny(void * listener, EventBase::EventGeneratorID_t egid, size_t sid) const;
 
 	protected:
-		//! a mapping from source IDs (unsigned ints), each to a vector of pointers to listeners
+		//! a mapping from source IDs (size_t's), each to a vector of pointers to listeners
 		/*! main use in filteredevents @see filteredevents */
-		typedef std::map<unsigned int,std::vector<void*>,std::less<unsigned int> > SIDtoListenerVectorMap_t;
+		typedef std::map<size_t,std::vector<void*>,std::less<size_t> > SIDtoListenerVectorMap_t;
 		
 		//! an array of vectors of pointers to listeners... in other words, a vector of listener pointers for each generator
 		std::vector<void*> allevents[EventBase::numEGIDs];
@@ -431,6 +509,22 @@ class EventRouter : public EventListener {
 		const EventBase& e; //!< the event being processed
 	};
 	std::queue<PostingStatus*> postings; //!< stores calls to post() currently in progress -- may grow if one postEvent() triggers another; this allows us to finish processing of the original postEvent() before starting the second.
+	
+	//! This table will be checked on each processEvent to forward the event to some other destination
+	/*! The main reason for including this functionality is in the uni-process model, we don't want
+	 *  event postings from real time processes like Motion to block on the event queue processing.
+	 *  So with this mechanism we can intercept those events, and queue them in a separate IPC
+	 *  mechanism to be picked up by Main later on.
+	 *
+	 *  This might also be handy for other purposes, such as remote event forwarding over the network...
+	 *
+	 *  If the EventTranslator's trapEvent returns true, then further processing on the event is skipped.
+	 *  (see EventTranslator::setTrapEventValue() )*/
+	EventTranslator* forwards[ProcessID::NumProcesses];
+private:
+  EventRouter(const EventRouter&); //!< don't call this
+  EventRouter& operator=(const EventRouter&); //!< don't call this
+
 };
 
 //! a global router for cross communication, probably the most common usage, although perhaps there may be times you'd rather have multiple event routers for smaller sections
@@ -441,10 +535,10 @@ extern EventRouter * erouter;
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.35 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.42 $
  * $State: Exp $
- * $Date: 2006/10/03 21:09:04 $
+ * $Date: 2007/11/13 04:16:02 $
  */
 
 #endif
