@@ -16,50 +16,44 @@
 
 using namespace std;
 
-EventTranslator::eventLookup_t EventTranslator::eventLookup;
-
-EventTranslator::~EventTranslator() {
-	for(eventLookup_t::iterator it=eventLookup.begin(); it!=eventLookup.end(); ++it)
-		delete (*it).second;
-	eventLookup.clear();
-}
-
 void
 EventTranslator::encodeEvent(const EventBase& event, bool onlyReady/*=false*/) {
 	event.setSaveFormat(EventBase::BINARY);
-	const unsigned int headerlen=sizeof(event.getClassTypeID());
-	const unsigned int bufsize=headerlen+event.getBinSize();
-	char * buf=bufferRequest(bufsize);
+	EventBase::classTypeID_t header=event.getClassTypeID();
+	const unsigned int bufsize=LoadSave::getSerializedSize(header)+event.getBinSize();
+	char * const buf=bufferRequest(bufsize);
 	if(buf==NULL) {
 		cerr << "ERROR: EventTranslator unable to transmit event because requested buffer was NULL" << endl;
 		return;
 	}
-	unsigned int header=event.getClassTypeID();
-	memcpy(buf,&header,headerlen);
-	unsigned int used=event.saveBuffer(buf+headerlen,bufsize-headerlen);
+	char * cur=buf;
+	unsigned int remain=bufsize;
+	if(!LoadSave::encodeInc(header,cur,remain,"Ran out of space encoding event header")) return;
+	unsigned int used=event.saveBuffer(cur,remain);
 	if(used==0) {
-		cerr << "ERROR: EventTranslator unable to transmit event because EventBase::saveBuffer failed (buffer==" << (void*)(buf+headerlen) << ", size==" << bufsize-headerlen << ")" << endl;
+		cerr << "ERROR: EventTranslator unable to transmit event because EventBase::saveBuffer failed (buffer==" << (void*)(cur) << ", size==" << remain << ")" << endl;
 		post(buf,0,onlyReady);
 		return;
 	}
-	post(buf,used,onlyReady);
+	cur+=used;
+	remain-=used;
+	ASSERT(cur-buf==(int)(bufsize-remain),"used count does not match offset");
+	post(buf,bufsize-remain,onlyReady);
 	return;
 }
 
 EventBase*
 EventTranslator::decodeEvent(const char * entry, unsigned int size) {
-	const unsigned int headerlen=sizeof(unsigned int);
-	unsigned int header=0;
-	memcpy(&header,entry,headerlen);
+	EventBase::classTypeID_t header;
+	if(!LoadSave::decodeInc(header,entry,size,"Ran out of space decoding event")) return NULL;
 	//cout << "decodeEvent(" << (void*)entry << ","<< size << ") header is " << header << " (" << entry[0] << entry[1] << entry[2] << entry[3] << ")" << endl;
-	eventLookup_t::iterator it=eventLookup.find(header);
-	if(it==eventLookup.end()) {
+	EventBase* evt=EventBase::getTypeRegistry().create(header);
+	if(evt==NULL) {
 		cerr << "ERROR: EventTranslator unable to translate buffer because header does not match a previously registered class type id" << endl;
 		return NULL;
 	}
-	EventBase* evt=static_cast<EventBase*>((*it).second->constructTemplate());
 	evt->setSaveFormat(EventBase::BINARY);
-	if(evt->loadBuffer(entry+headerlen,size-headerlen)==0) {
+	if(evt->loadBuffer(entry,size)==0) {
 		cerr << "ERROR: EventTranlator unable to translate buffer because data is malformed (EventBase::loadBuffer failed)" << endl;
 		return NULL;
 	}
@@ -85,8 +79,13 @@ IPCEventTranslator::bufferRequest(unsigned int size) {
 }
 
 void
-IPCEventTranslator::post(const char* buf, unsigned int /*size*/, bool onlyReady) {
+IPCEventTranslator::post(const char* buf, unsigned int size, bool onlyReady) {
 	ASSERTRET(curRegion!=NULL,"ERROR: IPCEventTranslator::post(buf,size) was NULL");
+	if(size==0) {
+		curRegion->RemoveReference();
+		curRegion=NULL;
+		return;
+	}
 	if(buf!=curRegion->Base()) {
 		cerr << "ERROR: IPCEventTranslator::post(buf,size) buf does not match value given from previous bufferRequest()" << endl;
 		return;
@@ -128,9 +127,9 @@ IPCEventTranslator::post(const char* buf, unsigned int /*size*/, bool onlyReady)
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.22 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.23 $
  * $State: Exp $
- * $Date: 2006/09/28 21:00:27 $
+ * $Date: 2007/05/21 17:02:39 $
  */
 
