@@ -4,7 +4,6 @@
 
 #include "Events/EventTrapper.h"
 #include "Events/EventListener.h"
-#include "Shared/Factory.h"
 #include <map>
 
 //! EventTranslator receives events from EventRouters in non-Main processes and adds them into a SharedQueue for Main to pick up
@@ -14,7 +13,7 @@ public:
 	EventTranslator() : trapRet(false) {}
 
 	//!destructor
-	virtual ~EventTranslator();
+	virtual ~EventTranslator() {}
 
 	//! Call this with events which should be forwarded to other processes
 	/*! @param event the event to serialize and send
@@ -38,28 +37,11 @@ public:
 	/*! @return the reconstituted event, or NULL if an error occured (malformed data) */
 	static EventBase* decodeEvent(const char* buf, unsigned int size);
 
-	//!This should be called during initialization to register all EventBase subclasses
-	/*! @return true upon success, false if an event matching that prototype's EventBase::getClassTypeID() was already registered */
-	template<class EB>
-	static bool registerPrototype() {
-		EB prototype;
-		eventLookup_t::const_iterator it=eventLookup.find(prototype.getClassTypeID());
-		if(it!=eventLookup.end())
-			return false;
-		eventLookup[prototype.getClassTypeID()]=new Factory<EB>;
-		return true;
-	}
-
 	//! set #trapRet, which can let you decide whether trapped events should be filtered or not
 	virtual void setTrapEventValue(bool v) { trapRet=v; }
 	
 
 protected:
-	//! Shorthand for they type of #eventLookup
-	typedef std::map<unsigned int,FactoryBase*> eventLookup_t;
-	
-	//! Allows quick lookup of event subclasses based on their EventBase::getClassTypeID()
-	static eventLookup_t eventLookup;
 
 	//! Called by encodeEvent() to request a buffer for serializing into, must be at least @a size
 	/*! This buffer will then be sent to post(), which should free
@@ -161,10 +143,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.12 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.13 $
  * $State: Exp $
- * $Date: 2006/09/25 23:28:12 $
+ * $Date: 2007/05/21 17:02:39 $
  */
 
 #endif
