@@ -4,12 +4,13 @@
 
 #include "Events/EventBase.h"
 #include "Vision/FilterBankGenerator.h"
+#include "Shared/Factories.h"
 
 //! This event gives access to a set of image channels at different resolutions, see FilterBankGenerator
 class FilterBankEvent : public EventBase {
 public:
 	//! constructor
-	FilterBankEvent(FilterBankGenerator* creator,EventBase::EventGeneratorID_t gid,unsigned int sid,EventBase::EventTypeID_t tid)
+	FilterBankEvent(FilterBankGenerator* creator,EventBase::EventGeneratorID_t gid,size_t sid,EventBase::EventTypeID_t tid)
 		: EventBase(gid,sid,tid,0,creator->getName()), src(creator)
 	{}
 
@@ -54,12 +55,20 @@ public:
 	//! returns the number of frames processed by the generator, see FilterBankGenerator::framesProcessed
 	inline unsigned int getFramesProcessed() const { return src->getFramesProcessed(); }
 	
+	virtual classTypeID_t getClassTypeID() const { return autoRegisterFilterBankEvent; }
+	
 protected:
 	//! pointer to generator which created this event
 	/*! the generator holds all the actual image data to be more memory efficient */
 	FilterBankGenerator* src;
 
-private:
+	//! causes class type id to automatically be regsitered with EventBase's FamilyFactory (getTypeRegistry())
+	/*! This is instantiated in EventBase.cc to save on file bloat */
+	static const EventBase::classTypeID_t autoRegisterFilterBankEvent;
+	
+	//! default constructor, only intended to be called from the FamilyFactory, followed by a loadXML...
+	FilterBankEvent() : EventBase(), src(NULL) {}
+	friend struct Factory0Arg<EventBase>::Factory<FilterBankEvent>;
 };
 
 /*! @file 
@@ -67,10 +76,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.11 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.13 $
  * $State: Exp $
- * $Date: 2005/06/29 22:03:35 $
+ * $Date: 2007/11/13 04:16:02 $
  */
 
 #endif
