@@ -19,12 +19,12 @@ class LocomotionEvent : public EventBase {
 
 	//! constructor
 	LocomotionEvent() : EventBase(),x(0),y(0),a(0) {}
-	LocomotionEvent(EventGeneratorID_t gid, unsigned int sid, EventTypeID_t tid, unsigned int dur=0) : EventBase(gid,sid,tid,dur),x(0),y(0),a(0) {}
-	LocomotionEvent(EventGeneratorID_t gid, unsigned int sid, EventTypeID_t tid, unsigned int dur, const std::string& n, float mag) : EventBase(gid,sid,tid,dur,n,mag),x(0),y(0),a(0) {}
+	LocomotionEvent(EventGeneratorID_t gid, size_t sid, EventTypeID_t tid, unsigned int dur=0) : EventBase(gid,sid,tid,dur),x(0),y(0),a(0) {}
+	LocomotionEvent(EventGeneratorID_t gid, size_t sid, EventTypeID_t tid, unsigned int dur, const std::string& n, float mag) : EventBase(gid,sid,tid,dur,n,mag),x(0),y(0),a(0) {}
 	virtual EventBase* clone() const { return new LocomotionEvent(*this); }
 	//@}
 
-	virtual unsigned int getClassTypeID() const { return makeClassTypeID("LOCO"); }
+	virtual unsigned int getClassTypeID() const { return autoRegisterLocomotionEvent; }
 
 	//! Allows you to set the new X, Y, and A components
 	LocomotionEvent& setXYA(float X, float Y, float A) {
@@ -42,9 +42,16 @@ class LocomotionEvent : public EventBase {
 	virtual void loadXML(xmlNode* node);
 	virtual void saveXML(xmlNode * node) const;
 
+        //!< Returns true if this event indicates motion has stopped (x,y,a are all zero)
+        virtual bool isStop() const { return x==0 && y==0 && a==0;}
+
 	float x; //!< the new x component (body relative)
 	float y; //!< the new y component (body relative)
 	float a; //!< the new angular component (body relative)
+
+protected:
+	//! causes class type id to automatically be regsitered with EventBase's FamilyFactory (getTypeRegistry())
+	static const EventBase::classTypeID_t autoRegisterLocomotionEvent;
 };
 
 /*! @file
@@ -52,10 +59,10 @@ class LocomotionEvent : public EventBase {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.9 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.12 $
  * $State: Exp $
- * $Date: 2006/09/09 04:32:46 $
+ * $Date: 2007/11/13 04:16:02 $
  */
 
 #endif
