@@ -21,12 +21,12 @@ public:
 	typedef __gnu_cxx::hash_map<const char*, unsigned int, __gnu_cxx::hash<const char*>, hashcmp_eqstr> hashmap; //!< a shorthand for the hash structure that CMVision expects for the color lookups
 
 	//! constructor, to be used when first segmented, later stages should use the other constructor
-	SegmentedColorFilterBankEvent(FilterBankGenerator* creator,EventBase::EventGeneratorID_t gid,unsigned int sid,EventBase::EventTypeID_t tid, FilterBankGenerator* segColorSrc, unsigned int nColors, color_class_state * colorInfos, const hashmap * clrNames)
+	SegmentedColorFilterBankEvent(FilterBankGenerator* creator,EventBase::EventGeneratorID_t gid,size_t sid,EventBase::EventTypeID_t tid, FilterBankGenerator* segColorSrc, unsigned int nColors, color_class_state * colorInfos, const hashmap * clrNames)
 		: FilterBankEvent(creator,gid,sid,tid), segsrc(segColorSrc), numColors(nColors), colors(colorInfos), colorNames(clrNames)
 	{}
 
 	//! constructor, allows you to pass along color information to later stages
-	SegmentedColorFilterBankEvent(FilterBankGenerator* creator,EventBase::EventGeneratorID_t gid,unsigned int sid,EventBase::EventTypeID_t tid, const SegmentedColorFilterBankEvent& segevt )
+	SegmentedColorFilterBankEvent(FilterBankGenerator* creator,EventBase::EventGeneratorID_t gid,size_t sid,EventBase::EventTypeID_t tid, const SegmentedColorFilterBankEvent& segevt )
 		: FilterBankEvent(creator,gid,sid,tid), segsrc(segevt.segsrc), numColors(segevt.numColors), colors(segevt.colors), colorNames(segevt.colorNames)
 	{}
 
@@ -71,13 +71,22 @@ public:
 	//! returns index of color corresponding to a string (uses a fast hash lookup)
 	inline unsigned int getColorIndex(const std::string& name) const { return getColorIndex(name.c_str()); }
 	
+	virtual classTypeID_t getClassTypeID() const { return autoRegisterSegmentedColorFilterBankEvent; }
+	
 protected:
 	//! pointer to generator which did the segmentation and therefore holds the color information
 	FilterBankGenerator* segsrc;
 	unsigned int numColors; //!< number of available colors
-  const color_class_state * colors; //!< array of available colors
-  const hashmap * colorNames; //!< hash map to look up index from name
+	const color_class_state * colors; //!< array of available colors
+	const hashmap * colorNames; //!< hash map to look up index from name
 
+	//! causes class type id to automatically be regsitered with EventBase's FamilyFactory (getTypeRegistry())
+	/*! This is instantiated in EventBase.cc to save on file bloat */
+	static const EventBase::classTypeID_t autoRegisterSegmentedColorFilterBankEvent;
+	
+	//! default constructor, only intended to be called from the FamilyFactory, followed by a loadXML...
+	SegmentedColorFilterBankEvent() : FilterBankEvent(), segsrc(NULL), numColors(), colors(), colorNames() {}
+	friend struct Factory0Arg<EventBase>::Factory<SegmentedColorFilterBankEvent>;
 };
 
 /*! @file 
@@ -85,10 +94,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.4 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.6 $
  * $State: Exp $
- * $Date: 2005/06/29 22:03:35 $
+ * $Date: 2007/11/13 04:16:02 $
  */
 
 #endif
