@@ -2,6 +2,8 @@
 #include <sstream>
 #include <libxml/tree.h>
 
+const EventBase::classTypeID_t TextMsgEvent::autoRegisterTextMsgEvent=getTypeRegistry().registerType<TextMsgEvent>(makeClassTypeID("TXTM"));
+
 std::string
 TextMsgEvent::getDescription(bool showTypeSpecific/*=true*/, unsigned int verbosity/*=0*/) const {
 	if(!showTypeSpecific)
@@ -97,8 +99,8 @@ void TextMsgEvent::saveXML(xmlNode * node) const {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.4 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.5 $
  * $State: Exp $
- * $Date: 2006/09/09 04:32:48 $
+ * $Date: 2007/05/21 17:02:39 $
  */
