@@ -3,7 +3,7 @@
 #include <sstream>
 #include <libxml/tree.h>
 
-// Changed 'getDescription' to show BB and area info in EventLogger. Change functions to add new parameters (BB and area) to buffer
+const EventBase::classTypeID_t VisionObjectEvent::autoRegisterVisionObjectEvent=getTypeRegistry().registerType<VisionObjectEvent>(makeClassTypeID("VISO"));
 
 std::string
 VisionObjectEvent::getDescription(bool showTypeSpecific/*=true*/, unsigned int verbosity/*=0*/) const {
@@ -166,8 +166,8 @@ void VisionObjectEvent::saveXML(xmlNode * node) const {
  * @author Ignacio Herrero Reder &lt; nhr at dte uma es &gt; (VisionObjectInfo Boundary Box - bug 74)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.11 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.12 $
  * $State: Exp $
- * $Date: 2006/09/09 04:32:50 $
+ * $Date: 2007/05/21 17:02:39 $
  */
