@@ -11,7 +11,7 @@ public:
 	/*! @param sid The source ID for the object being detected -- you can define your own values, some are already set in ProjectInterface, but can be reassigned during your project's startup
 	 *  @param tid The type ID for the event
 	 */
-  explicit VisionObjectEvent(unsigned int sid=0,EventTypeID_t tid=EventBase::deactivateETID)
+  explicit VisionObjectEvent(size_t sid=0,EventTypeID_t tid=EventBase::deactivateETID)
 		: EventBase(EventBase::visObjEGID,sid,tid,0),
 			_x1(0),_x2(0),_y1(0),_y2(0), _area(0),
 			_clipLeft(false), _clipRight(false), _clipTop(false), _clipBottom(false),
@@ -29,7 +29,7 @@ public:
 	 *  @param rx The plus/minus range of the x coordinates (generally xres/xres for cameras which are wider than they are high)
 	 *  @param ry The plus/minus range of the y coordinates (camera yres/xres for cameras which are wider than they are high)
 	 */
-  VisionObjectEvent(unsigned int sid, EventTypeID_t tid, float x1, float x2, float y1, float y2,float objarea, float rx, float ry)
+  VisionObjectEvent(size_t sid, EventTypeID_t tid, float x1, float x2, float y1, float y2,float objarea, float rx, float ry)
 		: EventBase(EventBase::visObjEGID,sid,tid,0),
 			_x1(x1),_x2(x2),_y1(y1),_y2(y2), _area(objarea),
 			_clipLeft(_x1<=-rx), _clipRight(_x2>=rx), _clipTop(_y1<=-ry), _clipBottom(_y2>=ry),
@@ -48,7 +48,7 @@ public:
 	 *  @param ry The plus/minus range of the y coordinates (camera yres/xres for cameras which are wider than they are high)
 	 *  @param frame The camera frame number the object was detected in (see #_frame)
 	 */
-  VisionObjectEvent(unsigned int sid, EventTypeID_t tid, float x1, float x2, float y1, float y2, float objarea, float rx, float ry,unsigned int frame)
+  VisionObjectEvent(size_t sid, EventTypeID_t tid, float x1, float x2, float y1, float y2, float objarea, float rx, float ry,unsigned int frame)
 		: EventBase(EventBase::visObjEGID,sid,tid,0),
 			_x1(x1),_x2(x2),_y1(y1),_y2(y2), _area(objarea),
 			_clipLeft(_x1<=-rx), _clipRight(_x2>=rx), _clipTop(_y1<=-ry), _clipBottom(_y2>=ry),
@@ -60,7 +60,7 @@ public:
   
 	virtual EventBase* clone() const { return new VisionObjectEvent(*this); }
 
-	virtual unsigned int getClassTypeID() const { return makeClassTypeID("VISO"); }
+	virtual unsigned int getClassTypeID() const { return autoRegisterVisionObjectEvent; }
 
 	//!@name Attribute Accessors
 	float getLeft() const { return _x1;} //!< returns the initial x (#_x1) coordinate of the Bounding Box (inclusive value)
@@ -75,7 +75,7 @@ public:
 	float getBottom() const { return _y2;} //!< returns the final y (#_y2) coordinate of the Bounding Box (inclusive value)
 	VisionObjectEvent& setBottom(float y2) { _y2=y2; return *this;} //!< sets the final y (#_y2) coordinate of the Bounding Box
 	
-	float getObjectArea() const { return _area; } //!< returns the object's #_area within the camera, in squared generalized coordinates.  Multiply by the square of the major camera resolution (normally #RobotInfo::CameraResolutionX if using full resolution) and divide by 4.0 to get pixel area.
+	float getObjectArea() const { return _area; } //!< returns the object's #_area within the camera, in squared generalized coordinates.  Multiply by the square of the major camera resolution (normally RobotInfo::CameraResolutionX if using full resolution) and divide by 4.0 to get pixel area.
 	VisionObjectEvent& setObjectArea(float objarea) { _area=objarea; return *this; } //!< sets the object's #_area within the camera, in squared generalized coordinates (multiply by the major camera resolution to get pixel area)
 	//@}
  
@@ -113,7 +113,7 @@ protected:
 	float _x2;  //!< a value representing location in visual field - from -1 if on the left edge to 1 if it's on the right edge
 	float _y1;  //!< top boundary, in range of @f$ \pm\frac{160}{208} @f$) for ERS-7; actual values vary depending on aspect ratio to keep square coordinates
 	float _y2;  //!< bottom boundary, in approximately @f$ \pm\frac{160}{208} @f$ for ERS-7; actual values vary depending on aspect ratio to keep square coordinates
-	float _area; //!< area of the actual object within bounding box as set by generator, in same units as getBoundaryArea().  Multiply by the square of the major camera resolution (normally #RobotInfo::CameraResolutionX if using full resolution) and divide by 4.0 to get pixel area.
+	float _area; //!< area of the actual object within bounding box as set by generator, in same units as getBoundaryArea().  Multiply by the square of the major camera resolution (normally RobotInfo::CameraResolutionX if using full resolution) and divide by 4.0 to get pixel area.
 	bool _clipLeft;   //!< flag to indicate left boundary is on or beyond the camera image's boundary
 	bool _clipRight;  //!< flag to indicate right boundary is on or beyond the camera image's boundary
 	bool _clipTop;    //!< flag to indicate top boundary is on or beyond the camera image's boundary
@@ -121,6 +121,9 @@ protected:
 	float _xRange; //!< Max range of X dimension (typically 1.0 for AIBO)
 	float _yRange; //!< Max range of Y dimension (typically around 0.8 for AIBO due to camera aspect ratio)
 	unsigned int _frame; //!< Number of frame when the event was generated.
+	
+	//! causes class type id to automatically be regsitered with EventBase's FamilyFactory (getTypeRegistry())
+	static const EventBase::classTypeID_t autoRegisterVisionObjectEvent;
 };
 
 /*! @file
@@ -129,10 +132,10 @@ protected:
  * @author Ignacio Herrero Reder &lt; nhr at dte uma es &gt; (VisionObjectInfo Boundary Box - bug 74, frame number - bug 143)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.18 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.21 $
  * $State: Exp $
- * $Date: 2006/09/09 04:32:50 $
+ * $Date: 2007/11/13 04:16:02 $
  */
 
 #endif
