@@ -8,12 +8,13 @@
 
 #include "ListMemBuf.h"
 #include "RCRegion.h"
+#include "SemaphoreManager.h"
+#include "MutexLock.h"
 #include "Shared/MarkScope.h"
 #include "Shared/attributes.h"
 #include <exception>
 
 #include "Shared/TimeET.h"
-//#include "local/sim/Process.h"
 
 //! Defines the interface for sending new shared memory regions between processes
 /*! This base class holds all of the template-independent code to allow general
@@ -57,9 +58,9 @@ public:
 	typedef unsigned short index_t;
 	
 	
-	//!< add one to the receiver reference count
+	//! add one to the receiver reference count
 	virtual SemaphoreManager::semid_t addReceiver() ATTR_must_check =0;
-	//!< remove one from the receiver reference count
+	//! remove one from the receiver reference count
 	virtual void removeReceiver(SemaphoreManager::semid_t rcvr)=0;
 	//! return the receiver reference count
 	virtual unsigned int getNumReceivers() const { return numReceivers; }
@@ -103,11 +104,13 @@ public:
 	//! do not allow any new messages to be posted
 	virtual void close() { AutoLock autolock(lock); isClosed=true; }
 
+	//! sets #reportDroppings
 	virtual void setReportDroppings(bool report) { reportDroppings=report; }
+	//! gets #reportDroppings
 	virtual bool getReportDroppings() const { return reportDroppings; }
 	
 	
-	//! Each message gets a unique, monotonically increasing serial number; this function returns that number (#serialNumber)
+	//! Each message gets a unique, monotonically increasing serial number; this function returns that number (MessageQueue::serialNumber)
 	virtual unsigned int getMessageSN(index_t msg)=0;
 	
 	//! Checks to see how many messages have been processed (read by all receivers and removed from queue)
@@ -143,12 +146,10 @@ public:
 	//! returns the current overflow policy, see OverflowPolicy_t
 	OverflowPolicy_t getOverflowPolicy() const { return overflowPolicy; }
 	
-	static void setSemaphoreManager(SemaphoreManager* mgr) {
-		semgr=mgr;
-	}
-	static SemaphoreManager* getSemaphoreManager() {
-		return semgr;
-	}
+	//! sets #semgr
+	static void setSemaphoreManager(SemaphoreManager* mgr) { semgr=mgr; }
+	//! gets #semgr
+	static SemaphoreManager* getSemaphoreManager() { return semgr; }
 	
 	//! once called, any messages put into the queue must pass through @a filter first (note: there can only be one filter per process!)
 	/*! if a filter was previously registered, it is replaced with the new @a filter */
@@ -223,7 +224,7 @@ protected:
 		entry() : id(), sn(), numRead(0) { memset(readFlags,0,sizeof(readFlags)); } //!< constructor
 		entry(unsigned int serialNumber, RCRegion* r)
 		: id(r->ID()), sn(serialNumber), numRead(0) { memset(readFlags,0,sizeof(readFlags)); } //!< constructor, pass message info
-		RCRegion::Identifier id; //! the identifier for the shared memory region so that other regions can attach it
+		RCRegion::Identifier id; //!< the identifier for the shared memory region so that other regions can attach it
 		unsigned int sn; //!< serial number for this message (not the same as its index in the queue -- indicies are reused, this id is unique to this message
 		bool readFlags[MAX_RECEIVERS]; //!< a flag for each receiver to indicate if they have read it
 		unsigned int numRead; //!< a count of the number of receivers which have read this message (should always equal sum(readFlags))
@@ -239,7 +240,7 @@ protected:
 	//! the data storage of receiver semaphores
 	rcvrs_t rcvrs;
 
-	//! returns the index within #rcvrs of the receiver id #rcvr
+	//! returns the index within #rcvrs of the receiver id @a rcvr
 	typename rcvrs_t::index_t lookupReceiver(SemaphoreManager::semid_t rcvr) const;
 	
 	//! shorthand for the type of data storage of message entries
@@ -482,10 +483,10 @@ MessageQueue<MAX_UNREAD,MAX_RECEIVERS,MAX_SENDERS>::lookupReceiver(SemaphoreMana
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.30 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.32 $
  * $State: Exp $
- * $Date: 2006/09/19 22:52:01 $
+ * $Date: 2007/11/10 22:58:08 $
  */
 
 #endif //APERIOS check
