@@ -2,10 +2,9 @@
 
 unsigned int MutexLockBase::usleep_granularity=5000;
 
-#ifndef PLATFORM_APERIOS
+#if !defined(PLATFORM_APERIOS) && TEKKOTSU_SHM_STYLE!=NO_SHM
 SemaphoreManager MutexLockBase::preallocated;
 SemaphoreManager* MutexLockBase::semgr=&preallocated;
-ThreadNS::Lock MutexLockBase::thdLocks[SemaphoreManager::MAX_SEM];
 #endif
 
 /*! @file 
@@ -13,8 +12,8 @@ ThreadNS::Lock MutexLockBase::thdLocks[SemaphoreManager::MAX_SEM];
 * @author ejt (Creator), Edward A. Lycklama, Vassos Hadzilacos (paper from which this was based)
 *
 * $Author: ejt $
-* $Name: tekkotsu-3_0 $
-* $Revision: 1.3 $
+* $Name: tekkotsu-4_0-branch $
+* $Revision: 1.5 $
 * $State: Exp $
-* $Date: 2006/05/08 22:07:54 $
+* $Date: 2007/06/14 06:22:29 $
 */
