@@ -9,9 +9,13 @@
 #include <typeinfo>
 
 #ifndef PLATFORM_APERIOS
-#  include <unistd.h>
 #  include "SemaphoreManager.h"
-#  include "Thread.h"
+#  if !defined(MUTEX_LOCK_ET_USE_SOFTWARE_ONLY) && TEKKOTSU_SHM_STYLE==NO_SHM
+#    include "Thread.h"
+#  endif
+#  include "RCRegion.h"
+#  include <unistd.h>
+#  include <pthread.h>
 #endif
 
 // If you want to use the same software-only lock on both
@@ -37,10 +41,13 @@ public:
 	static unsigned int usleep_granularity; //!< the estimated cost in microseconds of usleep call itself -- value passed to usleep will be 10 times this (only used by software lock implementation on non-Aperios)
 
 	//This section is only needed for the non-software-only locks, using the SemaphoreManager
-#ifndef PLATFORM_APERIOS
+#if !defined(PLATFORM_APERIOS) && TEKKOTSU_SHM_STYLE!=NO_SHM
+	//! exception if a lock is created but there aren't any more semaphores available
 	class no_more_semaphores : public std::exception {
 	public:
+		//! constructor
 		no_more_semaphores() throw() : std::exception() {}
+		//! returns a constant message string
 		virtual const char* what() const throw() { return "SemaphoreManager::getSemaphore() returned invalid()"; }
 	};
 	
@@ -55,9 +62,11 @@ public:
 			semgr=mgr;
 		}
 	}
+	//! returns #semgr;
 	static SemaphoreManager* getSemaphoreManager() {
 		return semgr;
 	}
+	//! this should be called if a fork() is about to occur (need to pass notification on to #preallocated)
 	static void aboutToFork() {
 		preallocated.aboutToFork();
 	}
@@ -80,15 +89,101 @@ protected:
 	 *  manager is created.*/
 	static SemaphoreManager preallocated;
 	
-	//! need to have a thread lock available for each semaphore -- have to acquire the corresponding inter-thread lock before you can acquire the inter-process lock
-	static ThreadNS::Lock thdLocks[SemaphoreManager::MAX_SEM];
+#elif TEKKOTSU_SHM_STYLE==NO_SHM
+public:
+	static void aboutToFork() {}
 #endif
 };
 
 
 
 #if !defined(PLATFORM_APERIOS) && !defined(MUTEX_LOCK_ET_USE_SOFTWARE_ONLY)
-#include "SemaphoreManager.h"
+#if TEKKOTSU_SHM_STYLE==NO_SHM
+
+//! Implements a mutual exclusion lock using pthread mutex
+/*! Use this to prevent more than one thread from accessing a data structure
+*  at the same time (which often leads to unpredictable and unexpected results)
+*
+*  The template parameter is not used (only needed if compiling with IPC enabled)
+*
+*  Locks in this class can be recursive or non-recursive, depending
+*  whether you call releaseAll() or unlock().  If you lock 5 times, then
+*  you need to call unlock() 5 times as well before it will be
+*  unlocked.  However, if you lock 5 times, just one call to releaseAll()
+*  will undo all 5 levels of locking.
+*
+*  Just remember, unlock() releases one level.  But releaseAll() completely unlocks.
+*
+*  Note that there is no check that the thread doing the unlocking is the one
+*  that actually has the lock.  Be careful about this.
+*/
+template<unsigned int num_doors>
+class MutexLock : public MutexLockBase {
+public:
+	//! constructor, gets a new semaphore from the semaphore manager
+	MutexLock() : owner_index(NO_OWNER), thdLock() {}
+	
+	//! destructor, releases semaphore back to semaphore manager
+	~MutexLock() {
+		if(owner_index!=NO_OWNER) {
+			owner_index=NO_OWNER;
+			while(thdLock.getLockLevel()>0)
+				thdLock.unlock();
+		}
+	}
+	
+	//! blocks until lock is achieved.  This is done efficiently using a SysV style semaphore
+	/*! You should pass some process-specific ID number as the input - just
+	 *  make sure no other process will be using the same value. */
+	void lock(int id) {
+		thdLock.lock();
+		if(owner_index!=static_cast<unsigned>(id))
+			owner_index=id;
+	}
+	
+	//! attempts to get a lock, returns true if it succeeds
+	/*! You should pass some process-specific ID number as the input - just
+	 *  make sure no other process will be using the same value.*/
+	bool try_lock(int id) {
+		if(!thdLock.trylock())
+			return false;
+		owner_index=id;
+		return true;
+	}
+	
+	//! releases one recursive lock-level from whoever has the current lock
+	inline void unlock() {
+		if(thdLock.getLockLevel()<=0)
+			std::cerr << "Warning: MutexLock::unlock caused underflow" << std::endl;
+		if(thdLock.getLockLevel()<=1)
+			owner_index=NO_OWNER;
+		thdLock.unlock();
+	}
+	
+	//! completely unlocks, regardless of how many times a recursive lock has been obtained
+	void releaseAll() {
+		owner_index=NO_OWNER;
+		while(thdLock.getLockLevel()>0)
+			thdLock.unlock();
+	}
+	
+	//! returns the lockcount
+	unsigned int get_lock_level() const { return thdLock.getLockLevel(); }
+	
+	//! returns the current owner's id
+	inline int owner() const { return owner_index; }
+	
+protected:
+	friend class MarkScope;
+	virtual void useResource(Resource::Data&) { lock(ProcessID::getID()); }
+	virtual void releaseResource(Resource::Data&) { unlock(); }
+	
+	unsigned int owner_index; //!< holds the tekkotsu process id of the current lock owner
+	ThreadNS::Lock thdLock; //!< all the actual implementation is handed off to the thread lock
+};
+
+#else /* IPC Lock using Semaphores*/
+#  include "SemaphoreManager.h"
 
 //! Implements a mutual exclusion lock using semaphores (SYSV style through SemaphoreManager)
 /*! Use this to prevent more than one process from accessing a data structure
@@ -119,8 +214,8 @@ template<unsigned int num_doors>
 class MutexLock : public MutexLockBase {
 public:
 	//! constructor, gets a new semaphore from the semaphore manager
-	MutexLock()
-		: sem(semgr->getSemaphore()), owner_index(NO_OWNER)
+	MutexLock() : MutexLockBase(), 
+		sem(semgr->getSemaphore()), owner_index(NO_OWNER), owner_thread()
 	{
 		if(sem==semgr->invalid())
 			throw no_more_semaphores();
@@ -128,8 +223,8 @@ public:
 	}
 	
 	//! constructor, use this if you already have a semaphore id you want to use from semaphore manager
-	MutexLock(SemaphoreManager::semid_t semid)
-		: sem(semid), owner_index(NO_OWNER)
+	MutexLock(SemaphoreManager::semid_t semid) : MutexLockBase(), 
+		sem(semid), owner_index(NO_OWNER), owner_thread()
 	{
 		if(sem==semgr->invalid())
 			throw no_more_semaphores();
@@ -138,29 +233,25 @@ public:
 	
 	//! destructor, releases semaphore back to semaphore manager
 	~MutexLock() {
+		owner_index=NO_OWNER;
 		if(semgr!=NULL && !semgr->hadFault())
 			semgr->releaseSemaphore(sem);
 		else
 			std::cerr << "Warning: MutexLock leaked semaphore " << sem << " because SemaphoreManager is NULL" << std::endl;
-		if(owner_index!=NO_OWNER) {
-			owner_index=NO_OWNER;
-			while(thdLocks[sem].getLockLevel()>0)
-				thdLocks[sem].unlock();
-		}
 	}
 	
 	//! blocks until lock is achieved.  This is done efficiently using a SysV style semaphore
 	/*! You should pass some process-specific ID number as the input - just
 	 *  make sure no other process will be using the same value. */
 	void lock(int id) {
-		thdLocks[sem].lock();
-		if(owner_index!=static_cast<unsigned>(id)) {
+		if(owner_index!=static_cast<unsigned>(id) || !isOwnerThread()) {
 			//have to wait and then claim lock
 			if(semgr!=NULL && !semgr->hadFault()) {
 				semgr->testZero_add(sem,1);
 			} else
 				std::cerr << "Warning: MutexLock assuming lock of " << sem << " because SemaphoreManager is NULL" << std::endl;
 			owner_index=id;
+			owner_thread=pthread_self();
 		} else {
 			//we already have lock, add one to its lock level
 			if(semgr!=NULL && !semgr->hadFault())
@@ -174,23 +265,21 @@ public:
 	/*! You should pass some process-specific ID number as the input - just
 	 *  make sure no other process will be using the same value.*/
 	bool try_lock(int id) {
-		if(!thdLocks[sem].trylock())
-			return false;
 		if(semgr==NULL || semgr->hadFault()) {
 			std::cerr << "Warning: MutexLock assuming try_lock success of " << sem << " because SemaphoreManager is NULL" << std::endl;
 			owner_index=id;
 			return true;
 		}
-		if(owner()==id) {
+		if(owner()==id && isOwnerThread()) {
 			//we already have lock, add one to its lock level
 			semgr->raise(sem,1);
 			return true;
 		} else {
 			if(semgr->testZero_add(sem,1,false)) {
 				owner_index=id;
+				owner_thread=pthread_self();
 				return true;
 			} else {
-				thdLocks[sem].unlock();
 				return false;
 			}
 		}
@@ -201,20 +290,17 @@ public:
 		if(semgr==NULL || semgr->hadFault()) {
 			std::cerr << "Warning: MutexLock assuming unlock of " << sem << " from " << owner_index << " because SemaphoreManager is NULL" << std::endl;
 			owner_index=NO_OWNER;
-			thdLocks[sem].unlock();
 			return;
 		}
 		if(semgr->getValue(sem)<=0) {
 			std::cerr << "Warning: MutexLock::unlock caused underflow" << std::endl;
 			owner_index=NO_OWNER;
-			thdLocks[sem].unlock();
 			return;
 		}
 		if(semgr->getValue(sem)==1)
 			owner_index=NO_OWNER;
 		if(!semgr->lower(sem,1,false))
 			std::cerr << "Warning: MutexLock::unlock caused strange underflow" << std::endl;
-		thdLocks[sem].unlock();
 	}
 	
 	//! completely unlocks, regardless of how many times a recursive lock has been obtained
@@ -225,8 +311,6 @@ public:
 			return;
 		}
 		semgr->setValue(sem,0);
-		while(thdLocks[sem].getLockLevel()>0)
-			thdLocks[sem].unlock();
 	}
 	
 	//! returns the lockcount
@@ -241,6 +325,11 @@ public:
 	inline int owner() const { return owner_index; }
 	
 protected:
+	//! returns true if the current thread is the one which owns the lock
+	bool isOwnerThread() {
+		pthread_t cur=pthread_self();
+		return pthread_equal(cur,owner_thread);
+	}
 	friend class MarkScope;
 	virtual void useResource(Resource::Data&) {
 		lock(ProcessID::getID());
@@ -251,11 +340,17 @@ protected:
 	
 	SemaphoreManager::semid_t sem; //!< the SysV semaphore number
 	unsigned int owner_index; //!< holds the tekkotsu process id of the current lock owner
+	pthread_t owner_thread; //!< holds a thread id for the owner thread
+	
+private:
+	MutexLock(const MutexLock& ml); //!< copy constructor, do not call
+	MutexLock& operator=(const MutexLock& ml); //!< assignment, do not call
 };
 
 
 
 
+#endif /* uni-process or (potentially) multi-process lock? */
 #else //SOFTWARE ONLY mutual exclusion, used on Aperios, or if MUTEX_LOCK_ET_USE_SOFTWARE_ONLY is defined
 
 
@@ -584,10 +679,10 @@ MutexLock<num_doors>::forget(int id) { //not tested thoroughly (or at all?)
  * @author ejt (Creator), Edward A. Lycklama, Vassos Hadzilacos (paper from which this was based)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.16 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.20 $
  * $State: Exp $
- * $Date: 2006/08/11 21:51:40 $
+ * $Date: 2007/11/10 22:58:08 $
  */
 
 #endif
