@@ -8,7 +8,7 @@
 #include <sys/stat.h>
 #include <errno.h>
 
-#if TEKKOTSU_SHM_STYLE!=SYSV_SHM && TEKKOTSU_SHM_STYLE!=POSIX_SHM
+#if TEKKOTSU_SHM_STYLE!=SYSV_SHM && TEKKOTSU_SHM_STYLE!=POSIX_SHM && TEKKOTSU_SHM_STYLE!=NO_SHM
 #  error Unknown TEKKOTSU_SHM_STYLE setting
 #endif
 
@@ -29,16 +29,15 @@ pid_t RCRegion::rootPID(::getpid());
 
 using namespace std;
 
-typedef MarkScope AutoLock;
-
 #if TEKKOTSU_SHM_STYLE==SYSV_SHM
 key_t RCRegion::nextKey=1024;
-#elif TEKKOTSU_SHM_STYLE==POSIX_SHM
+#elif TEKKOTSU_SHM_STYLE==POSIX_SHM || TEKKOTSU_SHM_STYLE==NO_SHM
 key_t RCRegion::nextKey=0;
 #endif
 
 RCRegion::attachedRegions_t RCRegion::attachedRegions;
 bool RCRegion::isFaultShutdown=false;
+bool RCRegion::multiprocess=true;
 ThreadNS::Lock* RCRegion::staticLock=NULL;
 
 
@@ -55,6 +54,11 @@ RCRegion::ConflictResolutionStrategy RCRegion::conflictStrategy=RCRegion::RENAME
 //mitigate this)
 RCRegion::ConflictResolutionStrategy RCRegion::conflictStrategy=RCRegion::REPLACE;
 
+#elif TEKKOTSU_SHM_STYLE==NO_SHM
+//with shared memory disabled, a conflict indicates we're reusing the same name... this is probably
+//a bug, so we should fail-fast
+RCRegion::ConflictResolutionStrategy RCRegion::conflictStrategy=RCRegion::EXIT;
+
 #endif
 
 RCRegion * RCRegion::attach(const Identifier& rid) {
@@ -70,7 +74,7 @@ RCRegion * RCRegion::attach(const Identifier& rid) {
 }
 
 void RCRegion::AddReference() {
-	AutoLock autolock(*lock);
+	MarkScope l(getStaticLock());
 	//cout << "AddReference " << id.shmid << ' ' << ProcessID::getID();
 	references[ProcessID::getID()]++;
 	references[ProcessID::NumProcesses]++;
@@ -82,78 +86,80 @@ void RCRegion::AddReference() {
 
 void RCRegion::RemoveReference() {
 	//cout << "RemoveReference " << id.key << ' ' << ProcessID::getID();
-	//if(MutexLockBase::getSemaphoreManager()!=NULL) //check in case this region contained the mutexman and SharedObject just destructed it
-	lock->lock(ProcessID::getID());
-	if(references[ProcessID::getID()] == 0) {
-		cerr << "Warning: RCRegion reference count underflow on " << id.key << " by " << ProcessID::getID() << "!  ";
-		for(unsigned int i=0; i<ProcessID::NumProcesses+1; i++)
-			cerr << ' ' << references[i];
-		cerr << endl;
-		return;
-	}
-	bool wasLastProcRef=(--references[ProcessID::getID()] == 0);
-	bool wasLastAnyRef=(--references[ProcessID::NumProcesses] == 0);
-	ASSERT(wasLastProcRef || !wasLastAnyRef,"global reference decremented beyond process reference");
-	//if(MutexLockBase::getSemaphoreManager()!=NULL)
-	/*if(isFaultShutdown) {
-		cerr << "Process " << ProcessID::getID() << " dereferenced " << id.key << ".  Counts are now:";
-		for(unsigned int i=0; i<ProcessID::NumProcesses+1; i++)
-			cerr << ' ' << references[i];
-		cerr << endl;
-	}*/
 	ThreadNS::Lock * old=NULL;
-	if(!wasLastProcRef) {
-		lock->unlock();
-	} else {
+	{
 		MarkScope l(getStaticLock());
-		//cout << " detach";
-		if(wasLastAnyRef)
-			lock->~MutexLock<ProcessID::NumProcesses>();
-		else
-			lock->unlock();
-		lock=NULL;
+		if(references[ProcessID::getID()] == 0) {
+			cerr << "Warning: RCRegion reference count underflow on " << id.key << " by " << ProcessID::getID() << "!  ";
+			for(unsigned int i=0; i<ProcessID::NumProcesses+1; i++)
+				cerr << ' ' << references[i];
+			cerr << endl;
+			return;
+		}
+		bool wasLastProcRef=(--references[ProcessID::getID()] == 0);
+		bool wasLastAnyRef=(--references[ProcessID::NumProcesses] == 0);
+		ASSERT(wasLastProcRef || !wasLastAnyRef,"global reference decremented beyond process reference");
+#if TEKKOTSU_SHM_STYLE==NO_SHM
+		wasLastProcRef=wasLastAnyRef;
+#else
+		if(!multiprocess)
+			wasLastProcRef=wasLastAnyRef;
+#endif
+		/*if(isFaultShutdown) {
+			cerr << "Process " << ProcessID::getID() << " dereferenced " << id.key << ".  Counts are now:";
+			for(unsigned int i=0; i<ProcessID::NumProcesses+1; i++)
+				cerr << ' ' << references[i];
+			cerr << endl;
+		}*/
+		if(wasLastProcRef) {
+			//cout << " detach";
 #if TEKKOTSU_SHM_STYLE==SYSV_SHM
-		if(shmdt(base)<0)
-			perror("Warning: Region detach");
-		base=NULL;
-		references=NULL;
-		if(wasLastAnyRef) {
-			//cout << " delete" << endl;
-			if(shmctl(id.shmid,IPC_RMID,NULL)<0)
-				perror("Warning: Region delete");
-		}
+			if(shmdt(base)<0)
+				perror("Warning: Region detach");
+			base=NULL;
+			references=NULL;
+			if(wasLastAnyRef) {
+				//cout << " delete" << endl;
+				if(shmctl(id.shmid,IPC_RMID,NULL)<0)
+					perror("Warning: Region delete");
+			}
 #elif TEKKOTSU_SHM_STYLE==POSIX_SHM
-		if(munmap(base,calcRealSize(id.size))<0) {
-			perror("Warning: Shared memory unmap (munmap)");
-		}
-		base=NULL;
-		references=NULL;
-		if(wasLastAnyRef) {
-			//cout << " delete" << endl;
-			if(!unlinkRegion()) {
-				int err=errno;
-				if(isFaultShutdown && (err==EINVAL || err==ENOENT))
-					//On a fault shutdown, we initially try to unlink everything right away,
-					// so an error now is just confirmation that it worked
-					cerr << "Region " << id.key << " appears to have been successfully unlinked" << endl;
-				else {
-					cerr << "Warning: Shared memory unlink of region " << id.key << " returned " << strerror(err);
-					if(err==EINVAL || err==ENOENT)
-						cerr << "\n         May have already been unlinked by a dying process.";
-					cerr << endl;
-				}
-			} else if(isFaultShutdown)
-				//That shouldn't have succeeded on a faultShutdown...
-				cerr << "Region " << id.key << " appears to have been successfully unlinked (nonstandard)" << endl;
-		}
+			if(munmap(base,calcRealSize(id.size))<0) {
+				perror("Warning: Shared memory unmap (munmap)");
+			}
+			base=NULL;
+			references=NULL;
+			if(wasLastAnyRef) {
+				//cout << " delete" << endl;
+				if(!unlinkRegion()) {
+					int err=errno;
+					if(isFaultShutdown && (err==EINVAL || err==ENOENT))
+						//On a fault shutdown, we initially try to unlink everything right away,
+						// so an error now is just confirmation that it worked
+						cerr << "Region " << id.key << " appears to have been successfully unlinked" << endl;
+					else {
+						cerr << "Warning: Shared memory unlink of region " << id.key << " returned " << strerror(err);
+						if(err==EINVAL || err==ENOENT)
+							cerr << "\n         May have already been unlinked by a dying process.";
+						cerr << endl;
+					}
+				} else if(isFaultShutdown)
+					//That shouldn't have succeeded on a faultShutdown...
+					cerr << "Region " << id.key << " appears to have been successfully unlinked (nonstandard)" << endl;
+			}
+#elif TEKKOTSU_SHM_STYLE==NO_SHM
+			delete base;
+			base=NULL;
+			references=NULL;
 #else
 #  error "Unknown TEKKOTSU_SHM_STYLE setting"
 #endif
-		delete this;
-		if(attachedRegions.size()==0 && !isFaultShutdown) {
-			//was last attached region, clean up lock for good measure
-			old=staticLock;
-			staticLock=NULL;
+			delete this;
+			if(attachedRegions.size()==0 && !isFaultShutdown) {
+				//was last attached region, clean up lock for good measure
+				old=staticLock;
+				staticLock=NULL;
+			}
 		}
 	}
 	delete old;
@@ -161,7 +167,7 @@ void RCRegion::RemoveReference() {
 }
 
 void RCRegion::AddSharedReference() {
-	AutoLock autolock(*lock);
+	MarkScope l(getStaticLock());
 	//cout << "AddSharedReference " << id.shmid << ' ' << ProcessID::getID();
 	references[ProcessID::NumProcesses]++;
 	//cout << " counts are now:";
@@ -171,7 +177,7 @@ void RCRegion::AddSharedReference() {
 }
 
 void RCRegion::RemoveSharedReference() {
-	AutoLock autolock(*lock);
+	MarkScope l(getStaticLock());
 	//cout << "RemoveSharedReference " << id.shmid << ' ' << ProcessID::getID();
 	if(references[ProcessID::NumProcesses]==0) {
 		cerr << "Warning: RCRegion shared reference count underflow on " << id.key << " by " << ProcessID::getID() << "!  ";
@@ -287,14 +293,14 @@ unsigned int RCRegion::calcRealSize(unsigned int size) {
 
 ThreadNS::Lock& RCRegion::getStaticLock() {
 	if(staticLock==NULL)
-		staticLock=new ThreadNS::Lock();
+		staticLock=new ThreadNS::Lock;
 	return *staticLock;
 }
 
 #if TEKKOTSU_SHM_STYLE==SYSV_SHM
 
 void RCRegion::init(size_t sz, key_t sug_key, bool create) {
-	ThreadNS::Lock l(getStaticLock());
+	MarkScope l(getStaticLock());
 	id.size=sz;
 	sz=calcRealSize(sz);
 	if(create) {
@@ -362,11 +368,8 @@ void RCRegion::init(size_t sz, key_t sug_key, bool create) {
 			perror("Region delete");
 		exit(EXIT_FAILURE);
 	}
-	lock=reinterpret_cast<MutexLock<ProcessID::NumProcesses>*>(base+sz-sizeof(MutexLock<ProcessID::NumProcesses>));
 	references=reinterpret_cast<unsigned int*>(base+sz-extra);
 	if(create) {
-		new (lock) MutexLock<ProcessID::NumProcesses>;
-		AutoLock autolock(*lock,ProcessID::getID());
 		for(unsigned int i=0; i<ProcessID::NumProcesses+1; i++)
 			references[i]=0;
 	}
@@ -520,11 +523,8 @@ void RCRegion::init(size_t sz, const std::string& name, bool create) {
 	if(close(fd)<0) {
 		perror("Warning: Closing temporary file descriptor from shm_open");
 	}
-	lock=reinterpret_cast<MutexLock<ProcessID::NumProcesses>*>(base+sz-sizeof(MutexLock<ProcessID::NumProcesses>));
 	references=reinterpret_cast<unsigned int*>(base+sz-extra);
 	if(create) {
-		new (lock) MutexLock<ProcessID::NumProcesses>;
-		AutoLock autolock(*lock);
 		for(unsigned int i=0; i<ProcessID::NumProcesses+1; i++)
 			references[i]=0;
 	}
@@ -532,6 +532,78 @@ void RCRegion::init(size_t sz, const std::string& name, bool create) {
 	attachedRegions[id.key]=this;
 }
 
+#elif TEKKOTSU_SHM_STYLE==NO_SHM
+
+void RCRegion::init(size_t sz, const std::string& name, bool create) {
+	MarkScope l(getStaticLock());
+	id.size=sz; //size of requested region
+	sz=calcRealSize(sz); //add some additional space for region lock and reference counts
+	if(name.size()>=MAX_NAME_LEN)
+		cerr << "*** WARNING RCRegion named " << name << " will be clipped to " << name.substr(0,MAX_NAME_LEN-1) << endl;
+	strncpy(id.key,name.c_str(),MAX_NAME_LEN-1);
+	id.key[MAX_NAME_LEN-1]='\0';
+	if(create) {
+		static unsigned int renameSN=0;
+		switch(conflictStrategy) {
+			case RENAME: {
+				if(attachedRegions.find(id.key)==attachedRegions.end())
+					break;
+				char origName[MAX_NAME_LEN];
+				strncpy(origName,id.key,MAX_NAME_LEN);
+				do {
+					int err=errno;
+					if(err!=EEXIST) {
+						cerr << "ERROR: Opening new region " << id.key << ": " << strerror(err) << " (shm_open)" << endl;
+						exit(EXIT_FAILURE);
+					}
+					unsigned int p=snprintf(id.key,MAX_NAME_LEN,"%s-%d",origName,++renameSN);
+					if(p>=MAX_NAME_LEN) {
+						cerr << "ERROR: conflicted key " << origName << ", attempting to rename, but generated name is too long" << endl;
+						exit(EXIT_FAILURE);
+					}
+					//id.key[MAX_NAME_LEN-1]='\0';
+#ifdef DEBUG
+					cerr << "Warning: conflicted key " << origName << ", attempting to rename as " << id.key << "\n"
+						<< "         (may have been leftover from a previous crash)" << endl;
+#endif
+				} while(attachedRegions.find(id.key)!=attachedRegions.end());
+				break;
+			}
+			case REPLACE: {
+				if(attachedRegions.find(id.key)==attachedRegions.end())
+					break;
+#ifdef DEBUG
+				cerr << "Warning: conflicted key " << id.key << ", attempting to replace" << endl;
+#endif
+			}
+				//note fall-through from REPLACE into EXIT - only try delete once, and then recreate and exit if it fails again
+			case EXIT: {
+				if(attachedRegions.find(id.key)!=attachedRegions.end()) {
+					cerr << "ERROR: Opening new region " << id.key << ": conflicted with existing region." << endl;
+					exit(EXIT_FAILURE);
+				}
+			}
+		}
+		base=new char[sz];
+	} else {
+		attachedRegions_t::const_iterator it=attachedRegions.find(id.key);
+		ASSERT(it==attachedRegions.end(),"attachment not found with disabled shared mem (TEKKOTSU_SHM_STYLE==NO_SHM)");
+		if(it==attachedRegions.end()) {
+			base=new char[sz];
+		} else {
+			base=it->second->base;
+		}
+	}
+	references=reinterpret_cast<unsigned int*>(base+sz-extra);
+	if(create) {
+		for(unsigned int i=0; i<ProcessID::NumProcesses+1; i++)
+			references[i]=0;
+	}
+	AddReference();
+	attachedRegions[id.key]=this;
+}
+
+
 #else
 #  error "Unknown TEKKOTSU_SHM_STYLE setting"
 #endif
@@ -561,10 +633,10 @@ protected:
 * @author ejt (Creator)
 *
 * $Author: ejt $
-* $Name: tekkotsu-3_0 $
-* $Revision: 1.10 $
+* $Name: tekkotsu-4_0-branch $
+* $Revision: 1.14 $
 * $State: Exp $
-* $Date: 2006/08/15 21:45:36 $
+* $Date: 2007/06/28 04:34:36 $
 */
 
 #endif
