@@ -17,22 +17,36 @@ EmergencyStopMC::EmergencyStopMC()
 {
 	for(unsigned int i=0; i<NumPIDJoints; i++)
 		piddutyavgs[i]=0;
-	if(state->robotDesign&WorldState::ERS210Mask) {
-		ledengine.cycle(ERS210Info::TlRedLEDMask,period,1,0,period/2);
-		ledengine.cycle(ERS210Info::TlBluLEDMask,period,1);
-	} else if(state->robotDesign&WorldState::ERS220Mask) {
-		ledengine.cycle(ERS220Info::TailCenterLEDMask, period, 2.0f, -.5f, (int)(period * 0/5.5));
-		ledengine.cycle(ERS220Info::TailLeftLEDMask|ERS220Info::TailRightLEDMask,   period, 2.0f, -.5f, (int)(period * 1/5.5));
-		ledengine.cycle(ERS220Info::BackLeft3LEDMask|ERS220Info::BackRight1LEDMask, period, 2.0f, -.5f, (int)(period * 2/5.5));
-		ledengine.cycle(ERS220Info::BackLeft2LEDMask|ERS220Info::BackRight2LEDMask, period, 2.0f, -.5f, (int)(period * 3/5.5));
-		ledengine.cycle(ERS220Info::BackLeft1LEDMask|ERS220Info::BackRight3LEDMask, period, 2.0f, -.5f, (int)(period * 4/5.5));
-	} else if(state->robotDesign&WorldState::ERS7Mask) {
-		ledengine.cycle(1<<(ERS7Info::MdBackColorLEDOffset-LEDOffset),2*period/3,.15,.15/2-.5,0);
+#ifdef TGT_HAS_LEDS
+	if(RobotName == ERS210Info::TargetName) {
+		int red=capabilities.getOutputOffset(ERS210Info::outputNames[ERS210Info::TlRedLEDOffset]) - LEDOffset;
+		int blue=capabilities.getOutputOffset(ERS210Info::outputNames[ERS210Info::TlBluLEDOffset]) - LEDOffset;
+		ledengine.cycle((1<<red),period,1,0,period/2);
+		ledengine.cycle((1<<blue),period,1);
+	} else if(RobotName == ERS220Info::TargetName) {
+		int tl=capabilities.getOutputOffset(ERS220Info::outputNames[ERS220Info::TailLeftLEDOffset]) - LEDOffset;
+		int tc=capabilities.getOutputOffset(ERS220Info::outputNames[ERS220Info::TailCenterLEDOffset]) - LEDOffset;
+		int tr=capabilities.getOutputOffset(ERS220Info::outputNames[ERS220Info::TailRightLEDOffset]) - LEDOffset;
+		int bl1=capabilities.getOutputOffset(ERS220Info::outputNames[ERS220Info::BackLeft1LEDOffset]) - LEDOffset;
+		int bl2=capabilities.getOutputOffset(ERS220Info::outputNames[ERS220Info::BackLeft2LEDOffset]) - LEDOffset;
+		int bl3=capabilities.getOutputOffset(ERS220Info::outputNames[ERS220Info::BackLeft3LEDOffset]) - LEDOffset;
+		int br1=capabilities.getOutputOffset(ERS220Info::outputNames[ERS220Info::BackRight1LEDOffset]) - LEDOffset;
+		int br2=capabilities.getOutputOffset(ERS220Info::outputNames[ERS220Info::BackRight2LEDOffset]) - LEDOffset;
+		int br3=capabilities.getOutputOffset(ERS220Info::outputNames[ERS220Info::BackRight3LEDOffset]) - LEDOffset;
+		ledengine.cycle((1<<tc), period, 2.0f, -.5f, (int)(period * 0/5.5));
+		ledengine.cycle((1<<tl)|(1<<tr),   period, 2.0f, -.5f, (int)(period * 1/5.5));
+		ledengine.cycle((1<<bl3)|(1<<br1), period, 2.0f, -.5f, (int)(period * 2/5.5));
+		ledengine.cycle((1<<bl2)|(1<<br2), period, 2.0f, -.5f, (int)(period * 3/5.5));
+		ledengine.cycle((1<<bl1)|(1<<br3), period, 2.0f, -.5f, (int)(period * 4/5.5));
+	} else if(RobotName == ERS7Info::TargetName) {
+		int mb=capabilities.getOutputOffset(ERS7Info::outputNames[ERS7Info::MdBackColorLEDOffset]) - LEDOffset;
+		ledengine.cycle((1<<mb),2*period/3,.15,.15/2-.5,0);
 	} else {
-		serr->printf("Emergency Stop: unknown model\n");
+		serr->printf("Emergency Stop: unknown model, no LED special effects\n");
 		ledengine.cycle(1<<(NumLEDs-1),period,1,0,period/2);
 		ledengine.cycle(1<<(NumLEDs-2),period,1);
 	}
+#endif
 	defaultMaxSpeed(.15);
 	takeSnapshot();
 }
@@ -59,8 +73,10 @@ int EmergencyStopMC::updateOutputs() {
 		if(!dirty)
 			return 0;
 		if(curt>=timeoflastrelease) {
+#ifdef TGT_HAS_LEDS
 			for(unsigned int i=LEDOffset; i<LEDOffset+NumLEDs; i++)
 				motman->setOutput(this,i,0.f); //blank out LEDs to avoid residual background display
+#endif
 			dirty=false;
 			return 0;
 		}
@@ -91,8 +107,10 @@ int EmergencyStopMC::updateOutputs() {
 			}
 		}
 	}
+#ifdef TGT_HAS_LEDS
 	ledengine.updateLEDs(&cmds[LEDOffset]);
-	if(state->robotDesign&WorldState::ERS7Mask) {
+#endif
+	if(RobotName == ERS7Info::TargetName) {
 		//a special Battlestar Galactica inspired effect for the ERS-7
 		static float acts[5];
 		static bool wasPaused=false;
@@ -112,15 +130,21 @@ int EmergencyStopMC::updateOutputs() {
 		// w is used to fade out LEDs when releasing estop
 		float w = (paused || curt>=timeoflastrelease) ? 1 : (static_cast<float>(timeoflastrelease-curt)/FADE_OUT_TIME);
 		for(int i=0; i<5; i++) {
-			imp[i]=exp(invsigma*(t-i-2)*(t-i-2))*w;
-			acts[i]+=amp*imp[i];
+			float p=invsigma*(t-i-2)*(t-i-2);
+			if(p>-10) { // only bother with impulse if big enough
+				// (in particular, saw exp returning -inf instead of 0 for <-85... bug in libm?)
+				imp[i]=expf(p)*w;
+				acts[i]+=amp*imp[i];
+			} else {
+				imp[i]=0;
+			}
 			acts[i]*=gamma*w;
 		}
-		cmds[ERS7Info::FaceLEDPanelOffset+ 6].value=acts[0]/2+imp[0];
-		cmds[ERS7Info::FaceLEDPanelOffset+ 8].value=acts[1]/2+imp[1];
-		cmds[ERS7Info::FaceLEDPanelOffset+10].value=acts[2]/2+imp[2];
-		cmds[ERS7Info::FaceLEDPanelOffset+ 9].value=acts[3]/2+imp[3];
-		cmds[ERS7Info::FaceLEDPanelOffset+ 7].value=acts[4]/2+imp[4];
+		cmds[ERS7Info::FaceLEDPanelOffset+ 6]=acts[0]/2+imp[0];
+		cmds[ERS7Info::FaceLEDPanelOffset+ 8]=acts[1]/2+imp[1];
+		cmds[ERS7Info::FaceLEDPanelOffset+10]=acts[2]/2+imp[2];
+		cmds[ERS7Info::FaceLEDPanelOffset+ 9]=acts[3]/2+imp[3];
+		cmds[ERS7Info::FaceLEDPanelOffset+ 7]=acts[4]/2+imp[4];
 	}
 	int changed=PostureMC::updateOutputs();
 	dirty=(curt<timeoflastrelease);
@@ -146,12 +170,12 @@ void EmergencyStopMC::setStopped(bool p, bool sound) {
 				freezeJoints();
 				if(sound)
 					sndman->playFile(config->motion.estop_on_snd);
-				cout << "*** PAUSED ***" << endl;
+				std::cout << "*** PAUSED ***" << std::endl;
 			} else {
 				releaseJoints();
 				if(sound)
 					sndman->playFile(config->motion.estop_off_snd);
-				cout << "*** UNPAUSED ***" << endl;
+				std::cout << "*** UNPAUSED ***" << std::endl;
 			}
 		}
 	}
@@ -166,20 +190,43 @@ void EmergencyStopMC::freezeJoints() {
 	}
 	for(unsigned int i=0; i<NumPIDJoints; i++)
 		piddutyavgs[i]=0; //or: state->pidduties[i];
+#ifdef TGT_HAS_WHEELS
+	//Wheels need to be set to 0 in e-stop mode
+	for(unsigned int i=WheelOffset; i<WheelOffset+NumWheels; i++) {
+	  cmds[i].value = 0.0;
+	  curPositions[i] = 0;
+	}
+#endif
+#ifndef TGT_HAS_LEDS
+	// no LEDs, just go all the way through in one pass...
+	for(unsigned int i=0; i<NumOutputs; i++)
+		cmds[i].weight=1;
+#else
 	for(unsigned int i=0; i<LEDOffset; i++)
 		cmds[i].weight=1;
 	for(unsigned int i=LEDOffset; i<LEDOffset+NumLEDs; i++)
 		cmds[i].unset(); // let other commands' LEDs "show through"
 	for(unsigned int i=LEDOffset+NumLEDs; i<NumOutputs; i++)
 		cmds[i].weight=1;
-	if(state->robotDesign&WorldState::ERS210Mask) {
-		cmds[ERS210Info::TlRedLEDOffset].set(0,.5);
-		cmds[ERS210Info::TlBluLEDOffset].set(0,.5);
-	} else if(state->robotDesign&WorldState::ERS220Mask) {
-		for(unsigned int i = 0; i < NumLEDs; i++)
-			if((ERS220Info::TailLEDMask|ERS220Info::BackLEDMask) & (1 << i))
-				cmds[LEDOffset + i].set(0, .5);
-	} else if(state->robotDesign&WorldState::ERS7Mask) {
+	if(RobotName == ERS210Info::TargetName) {
+		int red=capabilities.getOutputOffset(ERS210Info::outputNames[ERS210Info::TlRedLEDOffset]);
+		int blue=capabilities.getOutputOffset(ERS210Info::outputNames[ERS210Info::TlBluLEDOffset]);
+		cmds[red].set(0,.5);
+		cmds[blue].set(0,.5);
+	} else if(RobotName == ERS220Info::TargetName) {
+		int tl=capabilities.getOutputOffset(ERS220Info::outputNames[ERS220Info::TailLeftLEDOffset]);
+		int tc=capabilities.getOutputOffset(ERS220Info::outputNames[ERS220Info::TailCenterLEDOffset]);
+		int tr=capabilities.getOutputOffset(ERS220Info::outputNames[ERS220Info::TailRightLEDOffset]);
+		int bl1=capabilities.getOutputOffset(ERS220Info::outputNames[ERS220Info::BackLeft1LEDOffset]);
+		int bl2=capabilities.getOutputOffset(ERS220Info::outputNames[ERS220Info::BackLeft2LEDOffset]);
+		int bl3=capabilities.getOutputOffset(ERS220Info::outputNames[ERS220Info::BackLeft3LEDOffset]);
+		int br1=capabilities.getOutputOffset(ERS220Info::outputNames[ERS220Info::BackRight1LEDOffset]);
+		int br2=capabilities.getOutputOffset(ERS220Info::outputNames[ERS220Info::BackRight2LEDOffset]);
+		int br3=capabilities.getOutputOffset(ERS220Info::outputNames[ERS220Info::BackRight3LEDOffset]);
+		cmds[tl].set(0, .5); cmds[tc].set(0, .5); cmds[tr].set(0, .5);
+		cmds[bl1].set(0, .5); cmds[bl2].set(0, .5); cmds[bl3].set(0, .5);
+		cmds[br1].set(0, .5); cmds[br2].set(0, .5); cmds[br3].set(0, .5);
+	} else if(RobotName == ERS7Info::TargetName) {
 		cmds[ERS7Info::MdBackColorLEDOffset].set(0,.5);
 		for(int i=6; i<6+5; i++)
 			cmds[ERS7Info::FaceLEDPanelOffset+i].set(0,0.5);
@@ -187,6 +234,7 @@ void EmergencyStopMC::freezeJoints() {
 		cmds[LEDOffset+NumLEDs-1].set(0,.5);
 		cmds[LEDOffset+NumLEDs-2].set(0,.5);
 	}
+#endif
 	postEvent(EventBase(EventBase::estopEGID,getID(),EventBase::activateETID,0));
 	timeoflastfreeze=get_time();
 }
@@ -200,14 +248,18 @@ void EmergencyStopMC::releaseJoints() {
 }
 
 bool EmergencyStopMC::trigger() {
-	WorldState * st=WorldState::getCurrent(); // this is need because trigger is a static, so it doesn't access the Motion
-	if(st->robotDesign&WorldState::ERS210Mask)
-		return st->button_times[ERS210Info::BackButOffset];
-	if(st->robotDesign&WorldState::ERS220Mask)
-		return st->button_times[ERS220Info::BackButOffset];
-	if(st->robotDesign&WorldState::ERS7Mask)
+	WorldState * st=WorldState::getCurrent(); // this is need because trigger is a static, so it doesn't have access to the MC 'state' instance
+	if(RobotName == ERS210Info::TargetName)
+		return st->button_times[capabilities.getButtonOffset(ERS210Info::buttonNames[ERS210Info::BackButOffset])];
+	if(RobotName == ERS220Info::TargetName)
+		return st->button_times[capabilities.getButtonOffset(ERS220Info::buttonNames[ERS220Info::BackButOffset])];
+	if(RobotName == ERS7Info::TargetName)
 		return st->button_times[ERS7Info::FrontBackButOffset]+st->button_times[ERS7Info::MiddleBackButOffset]+st->button_times[ERS7Info::RearBackButOffset];
-	serr->printf("EmergencyStopMC: unsupported model!\n");
+#ifdef TGT_HAS_BUTTONS
+	// depending on platform, RobotName may be either char* or string
+	std::string tmpName = RobotName; // convert to consistent form so we can printf it...
+	serr->printf("EmergencyStopMC: %s unsupported model!\n",tmpName.c_str());
+#endif
 	return false;
 }
 
@@ -216,9 +268,9 @@ bool EmergencyStopMC::trigger() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.30 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.40 $
  * $State: Exp $
- * $Date: 2006/09/18 18:08:01 $
+ * $Date: 2007/11/18 06:47:03 $
  */
 
