@@ -1,5 +1,3 @@
-#include <math.h>
-
 #include "HeadPointerMC.h"
 #include "Kinematics.h"
 #include "Shared/debuget.h"
@@ -7,9 +5,12 @@
 #include "MotionManager.h"
 #include "Shared/Config.h"
 #include "Wireless/Socket.h"
+#include "Shared/ERS7Info.h"
+#include "Shared/ERS210Info.h"
+#include <math.h>
 
 HeadPointerMC::HeadPointerMC()
-	: MotionCommand(), dirty(true), hold(true), tolerance(.05),
+	: MotionCommand(), dirty(true), hold(true), tolerance(.05), // if change default tolerance, update documentation in header
 		targetReached(true), targetTimestamp(0), timeout(2000), 
 	  headkin(::config->motion.makePath(::config->motion.kinematics),"Camera")
 {
@@ -19,37 +20,78 @@ HeadPointerMC::HeadPointerMC()
 }
 
 void HeadPointerMC::freezeMotion() {
+#ifdef TGT_HAS_HEAD
 	for(unsigned int i=0; i<NumHeadJoints; i++)
 		headTargets[i]=headCmds[i].value;
 	dirty=false;
+#endif
 }
 
 void HeadPointerMC::takeSnapshot() {
+#ifdef TGT_HAS_HEAD
 	for(unsigned int i=0; i<NumHeadJoints; i++)
 		headTargets[i]=headCmds[i].value=state->outputs[HeadOffset+i];
 	dirty=true;
+#endif
 }
 
 void HeadPointerMC::defaultMaxSpeed(float x/*=1*/) {
-	maxSpeed[TiltOffset]=config->motion.max_head_tilt_speed*FrameTime*x/1000;
-	maxSpeed[PanOffset]=config->motion.max_head_pan_speed*FrameTime*x/1000;
-	maxSpeed[RollOffset]=config->motion.max_head_roll_speed*FrameTime*x/1000;
+#ifdef TGT_HAS_HEAD
+	const char* n = ERS7Info::outputNames[ERS7Info::HeadOffset+ERS7Info::TiltOffset];
+	unsigned int i = capabilities.findOutputOffset(n);
+	if(i!=-1U)
+		maxSpeed[i-HeadOffset]=config->motion.max_head_tilt_speed*FrameTime*x/1000;
+	n = ERS7Info::outputNames[ERS7Info::HeadOffset+ERS7Info::PanOffset];
+	i = capabilities.findOutputOffset(n);
+	if(i!=-1U)
+		maxSpeed[i-HeadOffset]=config->motion.max_head_pan_speed*FrameTime*x/1000;
+	n = ERS7Info::outputNames[ERS7Info::HeadOffset+ERS7Info::NodOffset];
+	i = capabilities.findOutputOffset(n);
+	if(i!=-1U)
+		maxSpeed[i-HeadOffset]=config->motion.max_head_roll_speed*FrameTime*x/1000;
+	n = ERS210Info::outputNames[ERS210Info::HeadOffset+ERS210Info::RollOffset];
+	i = capabilities.findOutputOffset(n);
+	if(i!=-1U)
+		maxSpeed[i-HeadOffset]=config->motion.max_head_roll_speed*FrameTime*x/1000;
+#endif
 }
 
 void HeadPointerMC::setWeight(float w) {
+#ifdef TGT_HAS_HEAD
 	for(unsigned int x=0; x<NumHeadJoints; x++)
 		headCmds[x].weight=w;
 	markDirty();
+#endif
 }
 
-void HeadPointerMC::setJoints(float j1, float j2, float j3) {
-	headTargets[TiltOffset]=clipAngularRange(HeadOffset+TiltOffset,j1);
-	headTargets[PanOffset]=clipAngularRange(HeadOffset+PanOffset,j2);
-	headTargets[RollOffset]=clipAngularRange(HeadOffset+RollOffset,j3);
+void HeadPointerMC::setJoints(float tilt1, float pan, float tilt2) {
+#ifdef TGT_HAS_HEAD
+#ifdef TGT_IS_AIBO
+	headTargets[TiltOffset]=clipAngularRange(HeadOffset+TiltOffset,tilt1);
+	headTargets[PanOffset]=clipAngularRange(HeadOffset+PanOffset,pan);
+	headTargets[NodOffset]=clipAngularRange(HeadOffset+NodOffset,tilt2);
+#else
+	const char* n = ERS7Info::outputNames[ERS7Info::HeadOffset+ERS7Info::TiltOffset];
+	unsigned int i = capabilities.findOutputOffset(n);
+	if(i!=-1U)
+		headTargets[i-HeadOffset]=clipAngularRange(i,tilt1);
+	n = ERS7Info::outputNames[ERS7Info::HeadOffset+ERS7Info::PanOffset];
+	i = capabilities.findOutputOffset(n);
+	if(i!=-1U)
+		headTargets[i-HeadOffset]=clipAngularRange(i,pan);
+	n = ERS7Info::outputNames[ERS7Info::HeadOffset+ERS7Info::NodOffset];
+	i = capabilities.findOutputOffset(n);
+	if(i!=-1U)
+		headTargets[i-HeadOffset]=clipAngularRange(i,tilt2);
+#endif
 	markDirty();
+#endif
 }
 
 bool HeadPointerMC::lookAtPoint(float x, float y, float z) {
+#ifndef TGT_HAS_HEAD
+	return false;
+#else
 	NEWMAT::ColumnVector Pobj(4),Plink(4);
 	Pobj(1)=x; Pobj(2)=y; Pobj(3)=z; Pobj(4)=1;
 	Plink=0; Plink(3)=1;
@@ -80,9 +122,13 @@ bool HeadPointerMC::lookAtPoint(float x, float y, float z) {
 	//	float theta2 = acos(poE2(3)/sqrt(poE2(1)*poE2(1)+poE2(2)*poE2(2)+poE2(3)*poE2(3)));
 	//	cout << " theta2: " << mathutils::rad2deg(theta2) << " degrees\n";
 	return isReachable(Pobj);
+#endif
 }
 	
 bool HeadPointerMC::lookAtPoint(float x, float y, float z, float d) {
+#ifndef TGT_HAS_HEAD
+	return false;
+#else
 	NEWMAT::ColumnVector Pobj(4),Plink(4);
 	Pobj(1)=x; Pobj(2)=y; Pobj(3)=z; Pobj(4)=1;
 	Plink=0; Plink(3)=d; Plink(4)=1;
@@ -92,9 +138,13 @@ bool HeadPointerMC::lookAtPoint(float x, float y, float z, float d) {
 		setJointValue(i,headkin.get_q(2+i));
 	//	return conv;
 	return isReachable(Pobj);
+#endif
 }
 	
 bool HeadPointerMC::lookInDirection(float x, float y, float z) {
+#ifndef TGT_HAS_HEAD
+	return false;
+#else
 	NEWMAT::ColumnVector Pobj(4),Plink(4);
 	Pobj(1)=x; Pobj(2)=y; Pobj(3)=z; Pobj(4)=0;
 	Plink=0; Plink(3)=1;
@@ -104,6 +154,7 @@ bool HeadPointerMC::lookInDirection(float x, float y, float z) {
 		setJointValue(i,headkin.get_q(2+i));
 	//	return conv;
 	return isReachable(Pobj);
+#endif
 }
 
 
@@ -111,6 +162,7 @@ int HeadPointerMC::updateOutputs() {
 	int tmp=isDirty();
 	if(tmp || hold) {
 		dirty=false;
+#ifdef TGT_HAS_HEAD
 		for(unsigned int i=0; i<NumHeadJoints; i++) {
 			if(maxSpeed[i]<=0) {
 				headCmds[i].value=headTargets[i];
@@ -135,6 +187,7 @@ int HeadPointerMC::updateOutputs() {
 					dirty=true;
 			}
 		}
+#endif
 		if(!dirty && !targetReached) {
 			postEvent(EventBase(EventBase::motmanEGID,getID(),EventBase::statusETID));
 			targetReached=true;
@@ -145,6 +198,9 @@ int HeadPointerMC::updateOutputs() {
 }
 
 int HeadPointerMC::isAlive() {
+#ifndef TGT_HAS_HEAD
+	return false;
+#else
 	if(dirty || !targetReached)
 		return true;
 	if(targetReached && (!hold || get_time()-targetTimestamp>timeout)) { //prevents a conflicted HeadPointerMC's from fighting forever
@@ -159,16 +215,22 @@ int HeadPointerMC::isAlive() {
 			maxdiff=diff;
 	}
 	return (maxdiff>tolerance);
+#endif
 }
 
 void HeadPointerMC::markDirty() {
 	dirty=true;
 	targetReached=false;
+#ifdef TGT_HAS_HEAD
 	for(unsigned int i=0; i<NumHeadJoints; i++)
 		headCmds[i].value=motman->getOutputCmd(HeadOffset+i).value; //not state->outputs[HeadOffset+i]; - see function documentation
+#endif
 }
 
 bool HeadPointerMC::ensureValidJoint(unsigned int& i) {
+#ifndef TGT_HAS_HEAD
+	serr->printf("ERROR: HeadPointerMC received a joint index of %d on headless target.\n",i);
+#else
 	if(i<NumHeadJoints)
 		return true;
 	if(i>=HeadOffset && i<HeadOffset+NumHeadJoints) {
@@ -182,6 +244,7 @@ bool HeadPointerMC::ensureValidJoint(unsigned int& i) {
 	serr->printf("ERROR: HeadPointerMC received a joint index of %d (HeadOffset%+d).\n",i,i-HeadOffset);
 	serr->printf("ERROR: This does not appear to be a head joint.  HeadPointerMC only controls\n");
 	serr->printf("       head joints, and assumes its arguments are relative to HeadOffset\n");
+#endif
 	return false;
 }
 
@@ -190,10 +253,8 @@ bool HeadPointerMC::ensureValidJoint(unsigned int& i) {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.25 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.29 $
  * $State: Exp $
- * $Date: 2006/08/31 21:42:02 $
+ * $Date: 2007/11/18 06:47:03 $
  */
-
-
