@@ -1,9 +1,10 @@
 //-*-c++-*-
 #ifndef INCLUDED_HeadPointerMC_h
 #define INCLUDED_HeadPointerMC_h
+
+#include "Shared/RobotInfo.h"
 #include "MotionCommand.h"
 #include "OutputCmd.h"
-#include "Shared/RobotInfo.h"
 #include "Shared/mathutils.h"
 #include "roboop/robot.h"
 
@@ -62,20 +63,32 @@ public:
 	//! Sets the weight values for all the neck joints
 	void setWeight(float w);
 	
-	//! Directly sets the neck values (all values in radians)
-	/*! @param j1 value for first neck joint (tilt on all ERS models)
-	 *  @param j2 value for second neck joint (pan on all ERS models)
-	 *  @param j3 value for third neck joint (nod on ERS-7, roll on ERS-2xx) */
-	void setJoints(float j1, float j2, float j3);
+	//! Request a set of neck joint values
+	/*! Originally this corresponded directly to the neck joints of the aibo, however
+	 *  on other platforms it will use capabilties mapping to try to set correspnding joints if available.
+	 *  (we're not doing kinematics here, trying to set joint values directly.  If your
+	 *  want a more generic/abstract interface, use lookAtPoint()/lookInDirection().
+	 *
+	 *  Note that for a "pan-tilt" camera, you actually want to set the @em last two parameters,
+	 *  @em not the first two!
+	 * 
+	 *  @param tilt value - this is an initial rotation about the camera x axis
+	 *  @param pan value - this is a rotation about the camera y axis
+	 *  @param tilt2 value - a second rotation about the camera x axis ("nod")
+	 *
+	 *  On ERS-210 and 220, the tilt2 is actually a roll about camera z (ugly, but no one's using those anymore, so moot issue) */
+	void setJoints(float tilt, float pan, float tilt2);
 	
 	//! Directly set a single neck joint value
 	/*! @param i joint offset relative to HeadOffset (i.e. one of TPROffset_t)
 	 *  @param value the value to be assigned to join @a i, in radians */
 	void setJointValue(unsigned int i, float value) {
+#ifdef TGT_HAS_HEAD
 		if(!ensureValidJoint(i))
 			return;
 		headTargets[i]=clipAngularRange(HeadOffset+i,value);
 		markDirty();
+#endif
 	}
 	
 	//! Returns the target value of joint @a i.  Use this if you want to know the current @b commanded joint value; To get the current joint @b position, look in WorldState::outputs
@@ -169,7 +182,7 @@ public:
 
 	bool dirty;                          //!< true if a change has been made since last call to updateJointCmds()
 	bool  hold;                          //!< if set to true, the posture will be kept active; otherwise joints will be marked unused after each posture is achieved (as if the posture was pruned); set through setHold()
-	float tolerance;                     //!< when autopruning, if the maxdiff() of this posture and the robot's current position is below this value, isAlive() will be false, defaults to 0.01 (5.7 degree error)
+	float tolerance;                     //!< when autopruning, if the maxdiff() of this posture and the robot's current position is below this value, isAlive() will be false, defaults to 0.05 radian (2.86 degree error)
 	bool targetReached;                  //!< false if the head is still moving towards its target
 	unsigned int targetTimestamp;        //!< time at which the targetReached flag was set
 	unsigned int timeout;                //!< number of milliseconds to wait before giving up on a target that should have already been reached, a value of -1U will try forever
@@ -184,11 +197,10 @@ public:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.25 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.30 $
  * $State: Exp $
- * $Date: 2006/09/26 19:29:40 $
+ * $Date: 2007/11/19 21:45:25 $
  */
 
 #endif
-
