@@ -64,6 +64,7 @@ void Kinematics::initStatics() {
 				roconfig->select_string(section,"chain",chain);
 				roconfig->select_int(section,"link",ip.second.link);
 				roconfig->select_string(section,"name",ip.first);
+				ip.first.erase(ip.first.find_last_not_of('~')+1); // strip old-style '~' padding at end of output names
 				for(ip.second.chain=0; ip.second.chain<(::config->motion.kinematic_chains.size()); ip.second.chain++)
 					if(::config->motion.kinematic_chains[ip.second.chain]==chain)
 						break;
@@ -390,6 +391,7 @@ Kinematics::getJointInterestPoint(unsigned int joint, const std::string& name) {
 	ans.Release(); return ans;
 }
 
+#ifdef TGT_HAS_LEGS
 void
 Kinematics::calcLegHeights(const NEWMAT::ColumnVector& down, float heights[NumLegs]) {
 #ifndef THREADSAFE_KINEMATICS
@@ -597,6 +599,20 @@ Kinematics::calculateGroundPlane(const NEWMAT::ColumnVector& down) {
 	p.Release(); return p;
 }
 
+#else // NO LEGS -- constant ground plane
+
+NEWMAT::ReturnMatrix
+Kinematics::calculateGroundPlane() {
+	return calculateGroundPlane(pack(0,0,-1));
+}
+
+NEWMAT::ReturnMatrix
+Kinematics::calculateGroundPlane(const NEWMAT::ColumnVector& /*down*/) {
+	return pack(0,0,1,0); // flat x-y plane through the origin
+}
+
+#endif
+
 NEWMAT::ReturnMatrix
 Kinematics::projectToPlane(unsigned int j, const NEWMAT::ColumnVector& r_j,
                            unsigned int b, const NEWMAT::ColumnVector& p_b,
@@ -663,9 +679,9 @@ Kinematics::update(unsigned int c, unsigned int l) {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.35 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.37 $
  * $State: Exp $
- * $Date: 2006/09/09 04:32:53 $
+ * $Date: 2007/09/26 23:12:05 $
  */
 
