@@ -203,6 +203,7 @@ public:
 
 
 
+#ifdef TGT_HAS_LEGS
 	//! Calculate the leg heights along a given "down" vector (0 is level with base frame)
 	/*! This can be based on either the gravity vector from accelerometer readings,
 	 *  or if that may be unreliable due to being in motion, you could do some basic
@@ -216,6 +217,7 @@ public:
 	 *  @note on Aibo platforms, if packing accelerometer readings, don't forget to negate the "left" accelerometer!
 	 *  @return index of leg which is highest in reference to gravity vector */
 	LegOrder_t findUnusedLeg(const NEWMAT::ColumnVector& down);
+#endif
 
 	//! Find the ground plane by fitting a plane to the lowest 3 interest points
 	/*! This function merely calls the other version of calculateGroundPlane with the current
@@ -367,15 +369,15 @@ protected:
 	struct hashstring {
 		//! hashes a string by multiplying current total by 5, add new character
 		/*! not my idea, this is what the STL library does for char*, i've just reimplemented it for strings */
-		size_t operator()(const string& s) const {
+		size_t operator()(const std::string& s) const {
 			unsigned long h=0;
-			for(string::size_type x=s.size(); x!=0; x--)
+			for(std::string::size_type x=s.size(); x!=0; x--)
 				h=h*5+s[x];
 			return (size_t)h;
 		}
 	};
 	//! we'll be using the hash_map to store named interest points
-	typedef __gnu_cxx::hash_map<const string,InterestPoint,hashstring> InterestPointMap;
+	typedef __gnu_cxx::hash_map<const std::string,InterestPoint,hashstring> InterestPointMap;
 	//! these interest points are shared by all Kinematics classes (i.e. all PostureEngines)
 	/*! this is to reduce initialization time, but does mean one robot can't do
 	 *  kinematic calculations regarding a different model robot...  */
@@ -390,10 +392,10 @@ extern Kinematics * kine;
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.36 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.38 $
  * $State: Exp $
- * $Date: 2006/09/16 17:32:39 $
+ * $Date: 2007/11/11 23:57:23 $
  */
 
 #endif
