@@ -5,35 +5,22 @@
 #include "Shared/ERS220Info.h"
 #include "Shared/ERS7Info.h"
 
+#ifdef TGT_HAS_LED_PANEL
 /*! This is "Mimic the number" style */
-const LEDBitMask_t LedEngine::ERS210numMasks[11] = {
-	ERS210Info::BotRLEDMask|ERS210Info::BotLLEDMask|ERS210Info::TopBrLEDMask, //0
-	
-	ERS210Info::BotLLEDMask|ERS210Info::MidLLEDMask|ERS210Info::TopLLEDMask,  //1
-	
-	ERS210Info::BotRLEDMask|ERS210Info::BotLLEDMask|ERS210Info::TopLLEDMask|ERS210Info::TopBrLEDMask, //2
-	
-	ERS210Info::BotRLEDMask|ERS210Info::BotLLEDMask|ERS210Info::MidRLEDMask|ERS210Info::TopLLEDMask
-	|ERS210Info::TopBrLEDMask, //3
-	
-	ERS210Info::BotLLEDMask|ERS210Info::MidLLEDMask|ERS210Info::TopRLEDMask|ERS210Info::TopLLEDMask,  //4
-
-	ERS210Info::BotRLEDMask|ERS210Info::BotLLEDMask|ERS210Info::TopRLEDMask|ERS210Info::TopBrLEDMask, //5
-
-	ERS210Info::BotRLEDMask|ERS210Info::BotLLEDMask|ERS210Info::MidRLEDMask|ERS210Info::MidLLEDMask
-	|ERS210Info::TopRLEDMask|ERS210Info::TopBrLEDMask, //6
-
-	ERS210Info::BotLLEDMask|ERS210Info::MidLLEDMask|ERS210Info::TopLLEDMask|ERS210Info::TopBrLEDMask,  //7
-
-	ERS210Info::BotRLEDMask|ERS210Info::BotLLEDMask|ERS210Info::MidRLEDMask|ERS210Info::MidLLEDMask
-	|ERS210Info::TopRLEDMask|ERS210Info::TopLLEDMask|ERS210Info::TopBrLEDMask, //8
-
-	ERS210Info::BotLLEDMask|ERS210Info::MidLLEDMask|ERS210Info::TopRLEDMask|ERS210Info::TopLLEDMask
-	|ERS210Info::TopBrLEDMask,  //9
-
-	ERS210Info::BotLLEDMask //.
+const LEDBitMask_t LedEngine::defaultMimicNumMasks[11] = {
+	BotRLEDMask|BotLLEDMask|TopBrLEDMask, //0
+	BotLLEDMask|MidLLEDMask|TopLLEDMask,  //1
+	BotRLEDMask|BotLLEDMask|TopLLEDMask|TopBrLEDMask, //2
+	BotRLEDMask|BotLLEDMask|MidRLEDMask|TopLLEDMask|TopBrLEDMask, //3
+	BotLLEDMask|MidLLEDMask|TopRLEDMask|TopLLEDMask,  //4
+	BotRLEDMask|BotLLEDMask|TopRLEDMask|TopBrLEDMask, //5
+	BotRLEDMask|BotLLEDMask|MidRLEDMask|MidLLEDMask|TopRLEDMask|TopBrLEDMask, //6
+	BotLLEDMask|MidLLEDMask|TopLLEDMask|TopBrLEDMask,  //7
+	BotRLEDMask|BotLLEDMask|MidRLEDMask|MidLLEDMask|TopRLEDMask|TopLLEDMask|TopBrLEDMask, //8
+	BotLLEDMask|MidLLEDMask|TopRLEDMask|TopLLEDMask|TopBrLEDMask,  //9
+	BotLLEDMask //.
 };
-/*! This is "Count the dots" style */
+/*! This is "Count the dots" style specialized for the ERS-220 */
 const LEDBitMask_t LedEngine::ERS220numMasks[11] = {
 	ERS220Info::ModeLEDMask, //0
 
@@ -82,7 +69,7 @@ const LEDBitMask_t LedEngine::ERS7numMasks[11] = {
 	(ERS7Info::FaceLEDPanelMask<< 1) //.
 };
 */
-/*! This is "Count the dots" style */
+/*! This is "Count the dots" style specialized for the ERS-7 */
 const LEDBitMask_t LedEngine::ERS7numMasks[11] = {
 	0, //0
 	(ERS7Info::FaceLEDPanelMask<<11), //1
@@ -114,6 +101,22 @@ const LEDBitMask_t LedEngine::ERS7numMasks[11] = {
 
 	(ERS7Info::FaceLEDPanelMask<< 1) //.
 };
+#endif // has led panel
+
+/*! This is "Count the dots" style */
+const LEDBitMask_t LedEngine::defaultCountNumMasks[11] = {
+	(1<<0)|(1<<8), //0
+	(1<<0), //1
+	(1<<0)|(1<<1), //2
+	(1<<0)|(1<<1)|(1<<2), //3
+	(1<<0)|(1<<1)|(1<<2)|(1<<3), //4
+	(1<<0)|(1<<1)|(1<<2)|(1<<3)|(1<<4), //5
+	(1<<0)|(1<<1)|(1<<2)|(1<<3)|(1<<4)|(1<<5), //6
+	(1<<0)|(1<<1)|(1<<2)|(1<<3)|(1<<4)|(1<<5)|(1<<6), //7
+	(1<<0)|(1<<1)|(1<<2)|(1<<3)|(1<<4)|(1<<5)|(1<<6)|(1<<7), //8
+	(1<<0)|(1<<1)|(1<<2)|(1<<3)|(1<<4)|(1<<5)|(1<<6)|(1<<7)|(1<<8), //9
+	(1<<1)|(1<<3)|(1<<5)|(1<<7) //.
+};
 
 
 LedEngine::LedEngine() : dirty(true), numCycling(0), nextFlashEnd((unsigned int)-1) {
@@ -144,10 +147,12 @@ int LedEngine::isDirty() {
 int LedEngine::updateLEDs(const MotionCommand* caller, LEDBitMask_t mask/*=AllLEDMask*/) {
 	unsigned int t = get_time();
 	if (t>nextFlashEnd) recalcFlashEnd();
+#ifdef TGT_HAS_LEDS
 	for(unsigned int i=0; i<NumLEDs; i++)
 		if((mask>>i)&1)
 			for(unsigned int f=0; f<NumFrames; f++)
 				motman->setOutput(caller, i+LEDOffset,calcValue(i,t+f*FrameTime),f);
+#endif
 	bool tmp=dirty;
 	dirty = numCycling>0;
 	return tmp;
@@ -289,11 +294,13 @@ void LedEngine::extendFlash(unsigned int ms) {
 void LedEngine::displayNumber(int x, numStyle_t style) {
 	switch(style) {
 	case onedigit: {
-		const LEDBitMask_t * numMasks=ERS210numMasks; //Default to 210's mask on new models - might not have as many LEDs
-		WorldState * st=WorldState::getCurrent();
-		if(st->robotDesign & WorldState::ERS220Mask)
+#ifdef TGT_HAS_LED_PANEL
+		const LEDBitMask_t * numMasks=defaultCountNumMasks;
+		if(RobotName == ERS210Info::TargetName)
+			numMasks=defaultMimicNumMasks;
+		else if(RobotName == ERS220Info::TargetName)
 			numMasks=ERS220numMasks;
-		if(st->robotDesign & WorldState::ERS7Mask)
+		else if(RobotName == ERS7Info::TargetName)
 			numMasks=ERS7numMasks;
 		if(x>9 || x<-9) {
 			ccycle(FaceLEDMask&~TopBrLEDMask,333,10,-5);
@@ -306,8 +313,25 @@ void LedEngine::displayNumber(int x, numStyle_t style) {
 			} else
 				set(numMasks[x],1);
 		}
+#elif defined(TGT_HAS_LEDS)
+		if(NumLEDs<9)
+			return;
+		const LEDBitMask_t * numMasks=defaultCountNumMasks;
+		if(x>9 || x<-9) {
+			ccycle(~(1<<(NumLEDs-1)),333,10,-5);
+			infos[NumLEDs-1].value=x<0?1:0;
+		} else {
+			clear();
+			if(x<0) {
+				set(numMasks[-x],1);
+				infos[NumLEDs-1].value=infos[NumLEDs-1].value*.5+.25;
+			} else
+				set(numMasks[x],1);
+		}
+#endif
 		} break;
 	case twodigit:
+#ifdef TGT_HAS_LED_PANEL
 		if(x>99 || x<-99) {
 			ccycle(FaceLEDMask&~TopBrLEDMask,333,10,-5);
 			infos[TopBrLEDOffset-LEDOffset].value=x<0?1:0;
@@ -317,9 +341,25 @@ void LedEngine::displayNumber(int x, numStyle_t style) {
 				infos[TopBrLEDOffset-LEDOffset].value=1;
 				x=-x;
 			}
-			setOneOfTwo(x%10,BotLLEDOffset-LEDOffset,MidLLEDOffset-LEDOffset,TopLLEDOffset-LEDOffset);
 			setOneOfTwo(x/10,BotRLEDOffset-LEDOffset,MidRLEDOffset-LEDOffset,TopRLEDOffset-LEDOffset);
+			setOneOfTwo(x%10,BotLLEDOffset-LEDOffset,MidLLEDOffset-LEDOffset,TopLLEDOffset-LEDOffset);
 		}
+#elif defined(TGT_HAS_LEDS)
+		if(NumLEDs<3)
+			return;
+		if(x>99 || x<-99) {
+			ccycle(~(1<<(NumLEDs-1)),333,10,-5);
+			infos[NumLEDs-1].value=x<0?1:0;
+		} else {
+			clear();
+			if(x<0) {
+				infos[NumLEDs-1].value=1;
+				x=-x;
+			}
+			setOneOfTwo(x/10,NumLEDs-3,NumLEDs-2,NumLEDs-1);
+			setOneOfTwo(x%10,2,1,0);
+		}
+#endif
 		break;
 	}
 }
@@ -328,7 +368,7 @@ void LedEngine::setOneOfTwo(unsigned int x, unsigned int low, unsigned int mid,
 		return;
 	float bg = ((x-1)/3)/3.0;
 	float fg = bg+.333333333;
-	if(WorldState::getCurrent()->robotDesign & WorldState::ERS7Mask)
+	if(RobotName == ERS7Info::TargetName)
 		bg*=bg; // dim the background a bit more on ERS7
 	switch(x%3) {
 	case 1:
@@ -351,6 +391,7 @@ void LedEngine::setOneOfTwo(unsigned int x, unsigned int low, unsigned int mid,
 
 void LedEngine::displayPercent(float x, percentStyle_t left_style, percentStyle_t right_style) {
 	clear();
+#ifdef TGT_HAS_LED_PANEL
 	if(x<0) {
 		set(FaceLEDMask,.25);
 		return;
@@ -369,6 +410,26 @@ void LedEngine::displayPercent(float x, percentStyle_t left_style, percentStyle_
 		setColumn(x,BotLLEDMask,MidLLEDMask,TopLLEDMask,TopBrLEDMask);
 	if(right_style==minor)
 		setColumn(x,BotRLEDMask,MidRLEDMask,TopRLEDMask,TopBrLEDMask);
+#else
+	if(x<0) {
+		set(~0,.25);
+		return;
+	}
+	if(x>1) {
+		set(~0,.75);
+		return;
+	}
+	if(left_style==major)
+		setColumn(x,3,2,1,0);
+	if(right_style==major)
+		setColumn(x,NumLEDs-4,NumLEDs-3,NumLEDs-2,NumLEDs-1);
+	x*=4;
+	x-=(int)x;
+	if(left_style==minor)
+		setColumn(x,3,2,1,0);
+	if(right_style==minor)
+		setColumn(x,NumLEDs-4,NumLEDs-3,NumLEDs-2,NumLEDs-1);
+#endif
 }
 
 void LedEngine::setColumn(float x, unsigned int low, unsigned int mid, unsigned int high, unsigned int top) {
@@ -405,8 +466,8 @@ void LedEngine::setColumn(float x, unsigned int low, unsigned int mid, unsigned
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.18 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.23 $
  * $State: Exp $
- * $Date: 2006/08/22 22:23:04 $
+ * $Date: 2007/11/18 06:47:03 $
  */
