@@ -115,16 +115,33 @@ class LedEngine {
 	void extendFlash(unsigned int ms);
 
 	//!returns the current setting of the LED specified by @a led_id (the value you passed in set())
-	float getSetting(LEDOffset_t led_id) { return infos[led_id-LEDOffset].value; }
+	float getSetting(LEDOffset_t led_id) {
+#ifndef TGT_HAS_LEDS
+		(void)led_id; // avoid unused argument warning
+		return 0;
+#else
+		return infos[led_id-LEDOffset].value;
+#endif
+	}
 	//!returns the current value of the LED specified by @a led_id (the value being expressed - may change if cycling for instance)
-	float getValue(LEDOffset_t led_id,unsigned int planahead=0) { return calcValue(led_id-LEDOffset,get_time()+planahead); }
+	float getValue(LEDOffset_t led_id,unsigned int planahead=0) {
+#ifndef TGT_HAS_LEDS
+		(void)led_id; (void)planahead; // avoid unused argument warnings
+		return 0;
+#else
+		return calcValue(led_id-LEDOffset,get_time()+planahead);
+#endif
+	}
 	
+#ifdef TGT_HAS_LED_PANEL
 	//!holds a series of bit masks for the onedigit style of numerical display (-9:9 and '.')
 	/*!the hope is that these actually resemble the shapes of the numbers so people can
-	 * recognize them more easily - without converting base 2 in their heads. */
-	static const LEDBitMask_t ERS210numMasks[11];
+	 * recognize them more easily - without counting or converting base 2 in their heads. */
+	static const LEDBitMask_t defaultMimicNumMasks[11];
 	static const LEDBitMask_t ERS220numMasks[11]; //!< bit masks for the ondigit style of numberical display - just count the LEDs on the head
-	static const LEDBitMask_t ERS7numMasks[11]; //!< writes a number on the display
+	static const LEDBitMask_t ERS7numMasks[11]; //!< bit masks for the ondigit style of numberical display - just count the LEDs on the head
+#endif
+	static const LEDBitMask_t defaultCountNumMasks[11]; //!< bit masks for the ondigit style of numberical display - just count the LEDs on the head
 	//!Use these to specify a style for displaying numbers using displayNumber()
 	enum numStyle_t {
 		onedigit, //!< can display a number -9 thru 9, using the current robot model's numMask.  For negative numbers, blinks the top bar - fast if it's supposed to be on, slow if it would otherwise be off
@@ -211,10 +228,10 @@ class LedEngine {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.28 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.30 $
  * $State: Exp $
- * $Date: 2006/10/03 22:30:36 $
+ * $Date: 2007/11/18 06:47:03 $
  */
 
 #endif
