@@ -28,9 +28,11 @@ class LedMC : public MotionCommand, public LedEngine {
   //! updates the cmds from LedEngine::updateLEDs()
   virtual int updateOutputs() {
     updateLEDFrames(cmds);
+#ifdef TGT_HAS_LEDS
     for(unsigned int i=0; i<NumLEDs; i++)
       if(cmds[i][0].weight!=0)
 				motman->setOutput(this,i+LEDOffset,cmds[i]);
+#endif
     if (nextFlashEnd < (unsigned int)-1)  // do we have a flash in progress?
       notified=false;
     else if (notified == false) {  // flash has ended (nextFlashEnd == -1), but notice not yet sent
@@ -46,10 +48,14 @@ class LedMC : public MotionCommand, public LedEngine {
 
   //! Sets the JointCmd::weight of the LEDs specified by @a leds to @a weight
   void setWeights(LEDBitMask_t leds, float weight) {
+#ifndef TGT_HAS_LEDS
+		(void)leds; (void)weight; // avoid unused argument warnings
+#else
     for(unsigned int i=0; i<NumLEDs; i++)
       if((leds>>i)&1)
 	for(unsigned int f=0; f<NumFrames; f++)
 	  cmds[i][f].weight=weight;
+#endif
   }
 
 protected:
@@ -62,10 +68,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.9 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.10 $
  * $State: Exp $
- * $Date: 2006/09/19 05:40:08 $
+ * $Date: 2007/11/18 06:47:03 $
  */
 
 #endif
