@@ -1,4 +1,5 @@
 #include "MotionCommand.h"
+#include "MotionManager.h"
 #include "Events/EventTranslator.h"
 #include "Events/EventRouter.h"
 #include <iostream>
@@ -13,16 +14,25 @@ void MotionCommand::postEvent(const EventBase& event) {
 	}
 }
 
+void MotionCommand::resetWheels() {
+#ifdef TGT_HAS_WHEELS
+  //cout << "Resetting " << NumWheels << " wheels" << endl;
+  for (unsigned int i = WheelOffset; i < WheelOffset + NumWheels; i++) {
+    motman->setOutput(this, i, 0.0);
+  }
+#endif
+}
+
 
 
 /*! @file
  * @brief Empty
  * @author ejt (Creator)
  *
- * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.5 $
+ * $Author: kcomer $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.6 $
  * $State: Exp $
- * $Date: 2006/09/11 23:05:11 $
+ * $Date: 2007/11/15 21:31:18 $
  */
 
