@@ -133,7 +133,7 @@ public:
 	virtual void DoStart() { started=true; }
 
 	//! called after this is removed from MotionManager
-	virtual void DoStop() { started=false; clearID(); }
+	virtual void DoStop() { started=false; clearID(); resetWheels(); }
 
 	//! returns true if the MotionCommand is currently running (although it may be overridden by a higher priority MotionCommand)
 	virtual bool isActive() const { return started; }
@@ -162,7 +162,7 @@ protected:
 	 * @param a first value
 	 * @param b second value
 	 * @param x weight of second value as opposed to first
-	 * @return @f$a*(1.0-x)+b*x@f$
+	 * @return @f$ a*(1.0-x)+b*x @f$
 	 * @todo - replace with a more fancy spline based thing? */
 	static inline double interpolate(double a, double b, double x) {
 		return a*(1.0-x)+b*x;
@@ -172,7 +172,7 @@ protected:
 	 * @param a first value
 	 * @param b second value
 	 * @param x weight of second value as opposed to first
-	 * @return @f$a*(1.0-x)+b*x@f$
+	 * @return @f$ a*(1.0-x)+b*x @f$
 	 * @todo - replace with a more fancy spline based thing? */
 	static inline float interpolate(float a, float b, float x) {
 		return a*(1.0-x)+b*x;
@@ -191,6 +191,9 @@ protected:
 	//! calls EventTranslator::trapEvent() directly (avoids needing erouter, which is a non-shared global, causes problems with context, grr, silly OS)
 	void postEvent(const EventBase& event);
 
+        //! This function sets all wheel values to 0
+        void resetWheels();
+
 	EventTranslator * queue; //!< send events using this, instead of posting to the erouter
 
 	int autoprune; //!< default true, autoprune setting, if this is true and isAlive() returns false, MotionManager will attempt to remove the MC automatically
@@ -212,11 +215,11 @@ private:
  * @brief Defines the MotionCommand class, used for creating motions of arbitrary complexity
  * @author ejt (Creator)
  *
- * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.23 $
+ * $Author: kcomer $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.25 $
  * $State: Exp $
- * $Date: 2006/10/04 03:14:56 $
+ * $Date: 2007/11/15 21:31:18 $
  */
 
 #endif
