@@ -14,11 +14,12 @@
 #include "Shared/ERS210Info.h"
 #include "Shared/ERS220Info.h"
 #include "Shared/ERS7Info.h"
+#include "Shared/Config.h"
 
 #include <list>
 
 MotionManager * motman=NULL;
-int MotionManager::_MMaccID=-1U;
+int MotionManager::_MMaccID[ProcessID::NumProcesses];
 EventTranslator* MotionManager::etrans=NULL;
 
 const float MotionManager::kIgnoredPriority    =-1;
@@ -48,13 +49,11 @@ MotionManager::InitAccess(OSubject* subj) {
 		printf("*** ERROR *** attempted to register more accessors with MotionManager than allowed by MAX_ACCESS\n");
 		return;
 	}
-	_MMaccID=numAcc++;
- 	//	cout << "ID is now " << _MMaccID << " of " << numAcc << endl;
-	//	cout << "_MMaccID is " << &_MMaccID << endl;
-	//	cout << "numAcc is " << &numAcc << " from " << this << endl;
-	MMlock.lock(_MMaccID);
+	_MMaccID[ProcessID::getID()]=numAcc++;
+ 	//	cout << "ID is now " << getAccID() << " of " << numAcc << endl;
+	MMlock.lock(getAccID());
 	//	accRegs[accID].init();
-	subjs[_MMaccID]=subj;
+	subjs[getAccID()]=subj;
 	if(cmdlist.size()>0) //Shouldn't happen - busy wait in addMotion
 		cout << "*** WARNING *** MOTIONS ADDED BEFORE ALL INITACCESSED" << endl;
 	MMlock.unlock();
@@ -68,14 +67,12 @@ MotionManager::InitAccess(MessageQueueBase& mcbufq, Resource& behaviorLock) {
 		printf("*** ERROR *** attempted to register more accessors with MotionManager than allowed by MAX_ACCESS\n");
 		return;
 	}
-	_MMaccID=numAcc++;
- 	//	cout << "ID is now " << _MMaccID << " of " << numAcc << endl;
-	//	cout << "_MMaccID is " << &_MMaccID << endl;
-	//	cout << "numAcc is " << &numAcc << " from " << this << endl;
-	MMlock.lock(_MMaccID);
-	subjs[_MMaccID]=&mcbufq;
-	mcrecvs[_MMaccID]=new MessageReceiver(*subjs[_MMaccID],receivedMsg);
-	procLocks[_MMaccID]=&behaviorLock;
+	_MMaccID[ProcessID::getID()]=numAcc++;
+ 	//	cout << "ID is now " << getAccID() << " of " << numAcc << endl;
+	MMlock.lock(getAccID());
+	subjs[getAccID()]=&mcbufq;
+	mcrecvs[getAccID()]=new MessageReceiver(*subjs[getAccID()],receivedMsg);
+	procLocks[getAccID()]=&behaviorLock;
 	if(cmdlist.size()>0) //Shouldn't happen - busy wait in doAddMotion
 		cout << "*** WARNING *** MOTIONS ADDED BEFORE ALL INITACCESSED" << endl;
 	MMlock.unlock();
@@ -88,14 +85,14 @@ MotionManager::RemoveAccess() {
 #ifndef PLATFORM_APERIOS
 	//kill the message receiver before we get the motion manager lock
 	// that way if there's a message pending, it can be processed instead of deadlocking
-	mcrecvs[_MMaccID]->finish();
-	delete mcrecvs[_MMaccID];
-	mcrecvs[_MMaccID]=NULL;
+	mcrecvs[getAccID()]->finish();
+	delete mcrecvs[getAccID()];
+	mcrecvs[getAccID()]=NULL;
 #endif
 	
 	func_begin();
 	for(MC_ID mc_id=cmdlist.begin(); mc_id!=cmdlist.end(); mc_id=cmdlist.next(mc_id)) {
-		if(cmdlist[mc_id].rcr[_MMaccID]!=NULL) {
+		if(cmdlist[mc_id].rcr[getAccID()]!=NULL) {
 			MotionCommand* mc=checkoutMotion(mc_id,true);
 			int found=0;
 			for(unsigned int i=0; i<numAcc; i++) {
@@ -107,13 +104,13 @@ MotionManager::RemoveAccess() {
 #ifdef PLATFORM_APERIOS
 			int refs=1;
 #else
-			int refs=cmdlist[mc_id].rcr[_MMaccID]->NumberOfLocalReference();
+			int refs=cmdlist[mc_id].rcr[getAccID()]->NumberOfLocalReference();
 #endif
 			if(refs>1)
 				cout << "Warning: " << ProcessID::getIDStr() << " still had " <<  refs-1 << " references to motion command " << mc_id << " as it was being dropped (these are now invalid)" << endl;
 			for(int i=0; i<refs; ++i)
-				cmdlist[mc_id].rcr[_MMaccID]->RemoveReference();
-			cmdlist[mc_id].rcr[_MMaccID]=NULL;
+				cmdlist[mc_id].rcr[getAccID()]->RemoveReference();
+			cmdlist[mc_id].rcr[getAccID()]=NULL;
 			if(found==1) {
 				MC_ID p=cmdlist.prev(mc_id);
 				push_free(mc_id); //don't check in -- lock destructor will release the lock as the entry is destructed
@@ -135,7 +132,7 @@ MotionManager::~MotionManager() {
 			MC_ID mc_id=cmdlist.begin();
 			for(unsigned int i=0; i<numAcc; i++)
 				if(cmdlist[mc_id].rcr[i]!=NULL)
-					cout << "MC " << mc_id << " was still referenced by InitAccess caller #" << _MMaccID << endl;
+					cout << "MC " << mc_id << " was still referenced by InitAccess caller #" << getAccID() << endl;
 			push_free(mc_id);
 		}
 		func_end();
@@ -194,7 +191,7 @@ MotionManager::setOutput(const MotionCommand* caller, unsigned int output, const
 	if(output >= NumOutputs)
 		return;
 	unsigned int hasWeight=NumFrames;
-	for(unsigned int i=NumFrames-1; i!=0; i--)
+	for(unsigned int i=NumFrames-1; i!=-1U; i--)
 		if(ocmds[i].weight>0) {
 			hasWeight=i;
 			break;
@@ -417,11 +414,17 @@ MotionManager::getOutputs(float outputs[][NumOutputs]) {
 
 	// now we've got, for each output, a list of requested values sorted by priority
 	// summarize each output
-	for(uint frame=0; frame<NumFrames; frame++)
+	for(uint frame=0; frame<NumFrames; frame++) {
 		for(uint output=0; output<NumOutputs; output++) {
 			cmdstatelist_t& curstatelist=cmdstates[output];
 			float alpha=1;
 			OutputCmd sumcmd;
+			/*if(curstatelist.size()>1) {
+				cout << get_time() << "." << frame << " " << outputNames[output] << ": ";
+				for(cmdstatelist_t::index_t ent=curstatelist.begin(); ent!=curstatelist.end(); ent=curstatelist.next(ent))
+					cout << "  (" << curstatelist[ent].frames[frame].value <<',' << curstatelist[ent].frames[frame].weight << ',' << curstatelist[ent].priority << ')';
+				cout << endl;
+			}*/
 			cmdstatelist_t::index_t ent=curstatelist.begin();
 			while(ent!=curstatelist.end() && alpha>0) {
 				OutputCmd curcmd;
@@ -447,6 +450,9 @@ MotionManager::getOutputs(float outputs[][NumOutputs]) {
 					alpha*=curalpha;
 				}
 			}
+
+			//if(curstatelist.size()>1)
+			//	cout << "   -> " << sumcmd.value/sumcmd.weight << ',' << sumcmd.weight << " @ " << alpha << endl;
 			if(sumcmd.weight>0) {
 				sumcmd.value/=sumcmd.weight;
 				outputs[frame][output]=sumcmd.value;
@@ -455,9 +461,17 @@ MotionManager::getOutputs(float outputs[][NumOutputs]) {
 			if(frame==NumFrames-1)
 				cmds[output]=sumcmd;
 		}
+	}
 	
 	for(uint output=0; output<NumOutputs; output++)
 		cmdSums[output]=outputs[NumFrames-1][output];
+
+	for (uint frame_idx = 0; frame_idx < NumFrames; frame_idx++) {
+		for(uint output=PIDJointOffset; output<PIDJointOffset+NumPIDJoints; output++)
+			outputs[frame_idx][output] = (outputs[frame_idx][output] + config->motion.calibration_offset[output-PIDJointOffset])
+				* config->motion.calibration_scale[output-PIDJointOffset];
+	}
+			
 				
 	// now summarize each output's PID values (for those which use PID control)
 	for(uint output=PIDJointOffset; output<PIDJointOffset+NumPIDJoints; output++) {
@@ -509,33 +523,6 @@ MotionManager::getOutputs(float outputs[][NumOutputs]) {
 	//if(state && state->buttons[LFrPawOffset]) cout << "getAngles-done." << flush;
 }
 
-void
-MotionManager::updateWorldState() {
-	//cout << "updateWorldState" << endl;
-	for(uint output=LEDOffset; output<LEDOffset+NumLEDs; output++)
-		state->outputs[output]=cmdSums[output];
-	for(uint output=BinJointOffset; output<BinJointOffset+NumBinJoints; output++)
-		state->outputs[output]=cmdSums[output];
-
-	// these parts check to see if there are "fake" joints, and sets their "sensed" values
-	// to be the current target value, just in case a behavior is waiting for a non-existant
-	// non-existant joint to move to a certain position.
-	if(state->robotDesign & WorldState::ERS210Mask) {
-		for(uint output=0; output<NumPIDJoints; output++)
-			if(!ERS210Info::IsRealERS210[output])
-				state->outputs[output]=cmdSums[output];
-	} else if(state->robotDesign & WorldState::ERS220Mask) {
-		for(uint output=0; output<NumPIDJoints; output++)
-			if(!ERS220Info::IsRealERS220[output])
-				state->outputs[output]=cmdSums[output];
-	} else if(state->robotDesign & WorldState::ERS7Mask) {
-		for(uint output=0; output<NumPIDJoints; output++)
-			if(!ERS7Info::IsRealERS7[output])
-				state->outputs[output]=cmdSums[output];
-	} else
-		cout << "MotionManager::updateWorldState() - could not detect model" << endl;
-}
-
 /*! This function handles the conversion from the Tekkotsu format (one
  *  regular IEEE float per parameter, to the OPEN-R format (which
  *  takes a specialized, reduced precision floating point number) This
@@ -631,7 +618,7 @@ MotionManager::receivedMsg(const ONotifyEvent& event) {
 bool
 MotionManager::receivedMsg(RCRegion* msg) {
 	try {
-		MarkScope l(*motman->procLocks[_MMaccID]);
+		MarkScope l(*motman->procLocks[getAccID()]);
 		/*MotionManagerMsg * mminfo = reinterpret_cast<MotionManagerMsg*>(msg->Base());
 		if(mminfo->creatorPID==ProcessID::getID())
 			return true; //don't process echos*/
@@ -665,27 +652,27 @@ MotionManager::processMsg(RCRegion * rcr) {
 	}
 	switch(mminfo->type) {
 		case MotionManagerMsg::addMotion: {
-			if(cmdlist[mc_id].rcr[_MMaccID]==NULL) {
+			if(cmdlist[mc_id].rcr[getAccID()]==NULL) {
 				//cout << "receiveMotion()NOW: rcr->NumberOfReference()==" << rcr->NumberOfReference() << endl;
-				cmdlist[mc_id].rcr[_MMaccID]=rcr;
+				cmdlist[mc_id].rcr[getAccID()]=rcr;
 				//cout << "receiveMotion(): rcr->NumberOfReference()==" << rcr->NumberOfReference() << endl;
 				rcr->AddReference();
 				//should be able to do a nice dynamic cast instead of a static one
 				// but it gives NULL for some reason - i blame having to do the fork trick
 				//cout << "Adding mc_id=="<< mc_id << " (and dynamic_cast is still " << dynamic_cast<MotionCommand*>(mminfo) << ")" << endl;
-				cmdlist[mc_id].baseaddrs[_MMaccID]=static_cast<MotionCommand*>(mminfo);
+				cmdlist[mc_id].baseaddrs[getAccID()]=static_cast<MotionCommand*>(mminfo);
 			} else {
 #ifdef PLATFORM_APERIOS
 				// this shouldn't happen on Aperios (no echos), but is normal elsewhere
 				cerr << "WARNING: MotionManager::processMsg addMotion for motion which was already added!" << endl;
 #else
-				ASSERT(cmdlist[mc_id].lastAccessor==(accID_t)-1 || cmdlist[mc_id].baseaddrs[_MMaccID]==static_cast<MotionCommand*>(mminfo),"Baseaddr changed!");
+				ASSERT(cmdlist[mc_id].lastAccessor==(accID_t)-1 || cmdlist[mc_id].baseaddrs[getAccID()]==static_cast<MotionCommand*>(mminfo),"Baseaddr changed!");
 #endif
 			}
 			if(ProcessID::getID()==ProcessID::MotionProcess && cmdlist[mc_id].lastAccessor!=(accID_t)-1) {
 				checkoutMotion(mc_id,true);
 				try {
-					cmdlist[mc_id].baseaddrs[_MMaccID]->DoStart();
+					cmdlist[mc_id].baseaddrs[getAccID()]->DoStart();
 				} catch(const std::exception& ex) {
 					ProjectInterface::uncaughtException(__FILE__,__LINE__,"Occurred during MotionCommand DoStart()",&ex);
 				} catch(...) {
@@ -695,10 +682,10 @@ MotionManager::processMsg(RCRegion * rcr) {
 			}
 		} break;
 		case MotionManagerMsg::deleteMotion: {
-			//cout << "deleteMotion(): cmdlist[mc_id].rcr[_MMaccID]->NumberOfReference()==" << cmdlist[mc_id].rcr[_MMaccID]->NumberOfReference() << endl;
+			//cout << "deleteMotion(): cmdlist[mc_id].rcr[getAccID()]->NumberOfReference()==" << cmdlist[mc_id].rcr[getAccID()]->NumberOfReference() << endl;
 			//cout << "deleting mc_id=="<<mc_id << "..." << flush;
 			ASSERT(cmdlist[mc_id].lastAccessor==(accID_t)-1,"delete motion message for motion command not marked for deletion");
-			if(cmdlist[mc_id].rcr[_MMaccID]==NULL) {
+			if(cmdlist[mc_id].rcr[getAccID()]==NULL) {
 #ifndef PLATFORM_APERIOS
 				// on non-aperios, we get an echo of the remove request, so don't report an error, just ignore it
 				if(mminfo->creatorPID!=ProcessID::getID()) {
@@ -709,7 +696,7 @@ MotionManager::processMsg(RCRegion * rcr) {
 				}
 #endif
 			} else {
-				cmdlist[mc_id].lock.lock(_MMaccID);
+				cmdlist[mc_id].lock.lock(getAccID());
 				int found=0;
 				for(unsigned int i=0; i<numAcc; i++) {
 					if(cmdlist[mc_id].rcr[i]!=NULL) {
@@ -727,9 +714,9 @@ MotionManager::processMsg(RCRegion * rcr) {
 					}
 					cmdlist[mc_id].lastAccessor=(accID_t)-1; // reset inaccessiblity
 				}
-				cmdlist[mc_id].rcr[_MMaccID]->RemoveReference();
-				cmdlist[mc_id].rcr[_MMaccID]=NULL;
-				cmdlist[mc_id].baseaddrs[_MMaccID]=NULL;
+				cmdlist[mc_id].rcr[getAccID()]->RemoveReference();
+				cmdlist[mc_id].rcr[getAccID()]=NULL;
+				cmdlist[mc_id].baseaddrs[getAccID()]=NULL;
 				if(found==1) {
 					push_free(mc_id); //don't unlock -- lock destructor will release the lock as the entry is destructed
 				} else {
@@ -745,7 +732,7 @@ MotionManager::processMsg(RCRegion * rcr) {
 					}
 				}
 			}
-			//cout << "deleteMotion()NOW: cmdlist[mc_id].rcr[_MMaccID]->NumberOfReference()==" << cmdlist[mc_id].rcr[_MMaccID]->NumberOfReference() << endl;
+			//cout << "deleteMotion()NOW: cmdlist[mc_id].rcr[getAccID()]->NumberOfReference()==" << cmdlist[mc_id].rcr[getAccID()]->NumberOfReference() << endl;
 		} break;
 		default:
 			printf("*** WARNING *** unknown MotionManager msg type received\n");
@@ -761,7 +748,7 @@ MotionManager::processMsg(RCRegion * rcr) {
 *  what that true/false was controlling. */
 MotionManager::MC_ID 
 MotionManager::doAddMotion(const SharedObjectBase& sm, bool autoprune, float priority) {
-	MotionCommand * mc = dynamic_cast<MotionCommand*>(reinterpret_cast<MotionManagerMsg*>(sm.data()));
+	MotionCommand * mc = dynamic_cast<MotionCommand*>(static_cast<MotionManagerMsg*>(sm.data()));
 	if(mc==NULL) {
 		cout << "MotionManager::addMotion() - SharedObject does not seem to hold a MotionCommand" << endl;
 		return invalid_MC_ID;
@@ -773,7 +760,7 @@ MotionManager::doAddMotion(const SharedObjectBase& sm, bool autoprune, float pri
 	//cout << cmdlist.size() << " exist..." << endl;
 	//	cout << id << "..." << flush;
 	for(MC_ID it=cmdlist.begin(); it!=cmdlist.end(); it=cmdlist.next(it)) {
-		if(cmdlist[it].baseaddrs[_MMaccID]==mc) {
+		if(cmdlist[it].baseaddrs[getAccID()]==mc) {
 			cerr << "Warning: adding motion command at " << mc << ", is already running in motion manager as MC_ID " << it << endl;
 			return func_end(it);
 		}
@@ -786,12 +773,12 @@ MotionManager::doAddMotion(const SharedObjectBase& sm, bool autoprune, float pri
 	}
 	//cout << "setAdd(" << mc_id << ")" << endl;
 	mc->setAdd(mc_id);
-	cmdlist[mc_id].baseaddrs[_MMaccID]=mc;
-	cmdlist[mc_id].rcr[_MMaccID]=sm.getRegion();
+	cmdlist[mc_id].baseaddrs[getAccID()]=mc;
+	cmdlist[mc_id].rcr[getAccID()]=sm.getRegion();
 	//cout << "addMotion(): sm.getRegion()->NumberOfReference()==" << sm.getRegion()->NumberOfReference() << endl;
-	cmdlist[mc_id].rcr[_MMaccID]->AddReference();
+	cmdlist[mc_id].rcr[getAccID()]->AddReference();
 	//cout << "addMotion()NOW: sm.getRegion()->NumberOfReference()==" << sm.getRegion()->NumberOfReference() << endl;
-	cmdlist[mc_id].lastAccessor=_MMaccID;
+	cmdlist[mc_id].lastAccessor=getAccID();
 	cmdlist[mc_id].priority=priority;
 	try {
 		erouter->postEvent(EventBase::motmanEGID,mc_id,EventBase::activateETID,0);
@@ -805,20 +792,20 @@ MotionManager::doAddMotion(const SharedObjectBase& sm, bool autoprune, float pri
 	OStatus err;
 	/*{
 		unsigned int i=0;
-		for(ObserverConstIterator it=subjs[_MMaccID]->begin();it!=subjs[_MMaccID]->end();it++) {
-			cout << "RemainBuffer("<<i++<<")==" << subjs[_MMaccID]->RemainBuffer(*it) << endl;
+		for(ObserverConstIterator it=subjs[getAccID()]->begin();it!=subjs[getAccID()]->end();it++) {
+			cout << "RemainBuffer("<<i++<<")==" << subjs[getAccID()]->RemainBuffer(*it) << endl;
 		}
-		ASSERT((int)i==subjs[_MMaccID]->NumberOfObservers(),"did I miss an observer?");
+		ASSERT((int)i==subjs[getAccID()]->NumberOfObservers(),"did I miss an observer?");
 	}*/
 	//cout << "Sent at " << get_time() << flush;
-	err=subjs[_MMaccID]->SetData(sm.getRegion());
+	err=subjs[getAccID()]->SetData(sm.getRegion());
 	ASSERT(err==oSUCCESS,"*** ERROR MotionManager: SetData returned " << err);
 	//cout << "addMotion()afterSetData: sm.getRegion()->NumberOfReference()==" << sm.getRegion()->NumberOfReference() << endl;
-	err=subjs[_MMaccID]->NotifyObservers();
+	err=subjs[getAccID()]->NotifyObservers();
 	ASSERT(err==oSUCCESS,"*** ERROR MotionManager: NotifyObservers returned " << err);
 #else //PLATFORM_LOCAL
 	try {
-		subjs[_MMaccID]->sendMessage(sm.getRegion());
+		subjs[getAccID()]->sendMessage(sm.getRegion());
 	} catch(const std::exception& ex) {
 		ProjectInterface::uncaughtException(__FILE__,__LINE__,"Occurred during message sending",&ex);
 	} catch(...) {
@@ -834,18 +821,24 @@ MotionCommand *
 MotionManager::checkoutMotion(MC_ID mcid,bool block) {
 	//cout << "checkout..." << flush;
 	if(mcid>=MAX_MOTIONS || mcid==invalid_MC_ID) {
-		cout << "*** WARNING *** " << ProcessID::getIDStr() << " tried to access invalid mcid " << mcid << endl;
+		cout << "*** ERROR *** " << ProcessID::getIDStr() << " tried to access invalid mcid " << mcid << endl;
 		stacktrace::displayCurrentStackTrace();
 		return NULL;
 	}
-	if(block)
-		cmdlist[mcid].lock.lock(_MMaccID);
-	else
-		if(!cmdlist[mcid].lock.try_lock(_MMaccID))
-			return NULL;
-	if(cmdlist[mcid].lastAccessor==(accID_t)-1) {
+	if(cmdlist[mcid].lastAccessor==(accID_t)-1) { // test both before and after the block
 		cout << "*** WARNING *** " << ProcessID::getIDStr() << " tried to access dead mcid " << mcid << endl;
 		stacktrace::displayCurrentStackTrace();
+		return NULL;
+	}
+	// block would lock up if the motion is dead in the simulator (left in a locked state)
+	if(block)
+		cmdlist[mcid].lock.lock(getAccID());
+	else
+		if(!cmdlist[mcid].lock.try_lock(getAccID()))
+			return NULL;
+	if(cmdlist[mcid].lastAccessor==(accID_t)-1) { // test both before and after the block
+		cout << "*** WARNING *** " << ProcessID::getIDStr() << " tried to access mcid as it was removed " << mcid << endl;
+		stacktrace::displayCurrentStackTrace();
 		cmdlist[mcid].lock.unlock();
 		return NULL;
 	}
@@ -856,14 +849,14 @@ MotionManager::checkoutMotion(MC_ID mcid,bool block) {
 
 MotionCommand *
 MotionManager::convertMotion(MC_ID mc) {
-	MotionCommand * base = cmdlist[mc].baseaddrs[_MMaccID];
+	MotionCommand * base = cmdlist[mc].baseaddrs[getAccID()];
 	//	cout << "base=" << base << "..." << flush;
-	if(cmdlist[mc].lastAccessor!=_MMaccID) {
+	if(cmdlist[mc].lastAccessor!=getAccID()) {
 		//cout << "converting from " << MCRegistrar::getRaw(base) << "..." << flush;
 		//cout << "prev=" << accRegs[cmdlist[mcid].lastAccessor].getReg(base) << "..." << flush;
 		//		accRegs[id].convert(base);
 		//cout << "to=" << MCRegistrar::getRaw(base) << ", " << accRegs[cmdlist[mcid].lastAccessor].getReg(base) << endl;
-		cmdlist[mc].lastAccessor=_MMaccID;
+		cmdlist[mc].lastAccessor=getAccID();
 	}
 	base->setTranslator(etrans);
 #ifdef PLATFORM_APERIOS
@@ -876,8 +869,8 @@ void
 MotionManager::checkinMotion(MC_ID mcid) {
 	if(mcid>=MAX_MOTIONS || mcid==invalid_MC_ID)
 		return;
-	if(cmdlist[mcid].lock.get_lock_level()==1 && cmdlist[mcid].rcr[_MMaccID]!=NULL) { //about to release last lock (and region hasn't been removed)
-		MotionCommand * base = cmdlist[mcid].baseaddrs[_MMaccID];
+	if(cmdlist[mcid].lock.get_lock_level()==1 && cmdlist[mcid].rcr[getAccID()]!=NULL) { //about to release last lock (and region hasn't been removed)
+		MotionCommand * base = cmdlist[mcid].baseaddrs[getAccID()];
 		base->setTranslator(NULL);
 #ifdef PLATFORM_APERIOS
 		base->setWorldState(NULL);
@@ -897,13 +890,13 @@ MotionManager::removeMotion(MC_ID mcid) {
 		func_end();
 		return;
 	}
-	if(cmdlist[mcid].rcr[_MMaccID]==NULL) { 
+	if(cmdlist[mcid].rcr[getAccID()]==NULL) { 
 		cout << "WARNING: removeMotion called for a NULL motion! mc_id="<<mcid<<" process=" << ProcessID::getIDStr() << endl;
 		stacktrace::displayCurrentStackTrace();
 		func_end();
 		return;
 	}
-	cmdlist[mcid].lock.lock(_MMaccID);
+	cmdlist[mcid].lock.lock(getAccID());
 	if(ProcessID::getID()==ProcessID::MotionProcess) {
 		MotionCommand * mc=checkoutMotion(mcid,true);
 		try {
@@ -916,9 +909,9 @@ MotionManager::removeMotion(MC_ID mcid) {
 		checkinMotion(mcid);
 	}
 	cmdlist[mcid].lastAccessor=(accID_t)-1;
-	cmdlist[mcid].rcr[_MMaccID]->RemoveReference();
-	cmdlist[mcid].rcr[_MMaccID]=NULL;
-	cmdlist[mcid].baseaddrs[_MMaccID]=NULL;
+	cmdlist[mcid].rcr[getAccID()]->RemoveReference();
+	cmdlist[mcid].rcr[getAccID()]=NULL;
+	cmdlist[mcid].baseaddrs[getAccID()]=NULL;
 	cmdlist[mcid].lock.unlock();
 	if(ProcessID::getID()==ProcessID::MainProcess) {
 		try {
@@ -933,15 +926,15 @@ MotionManager::removeMotion(MC_ID mcid) {
 	MotionManagerMsg dmsg;
 	dmsg.setDelete(mcid);
 	//cout << "Remove at " << get_time() << flush;
-	subjs[_MMaccID]->SetData(&dmsg,sizeof(dmsg));
-	subjs[_MMaccID]->NotifyObservers();
+	subjs[getAccID()]->SetData(&dmsg,sizeof(dmsg));
+	subjs[getAccID()]->NotifyObservers();
 #else //PLATFORM_LOCAL
 	// local will "echo" the message, so we'll do the actual remove when we get the echo
 	SharedObject<MotionManagerMsg> dmsg;
 	dmsg->setDelete(mcid);
 	//cout << "Remove at " << get_time() << flush;
 	try {
-		subjs[_MMaccID]->sendMessage(dmsg.getRegion());
+		subjs[getAccID()]->sendMessage(dmsg.getRegion());
 	} catch(const std::exception& ex) {
 		ProjectInterface::uncaughtException(__FILE__,__LINE__,"Occurred during message sending",&ex);
 	} catch(...) {
@@ -998,7 +991,7 @@ MotionManager::MC_ID
 MotionManager::skip_ahead(MC_ID mcid) const {
 	// this is in case a new motion has been added, but the current
 	// process hasn't received its own copy yet, so should skip over them
-	while(mcid!=cmdlist.end() && cmdlist[mcid].rcr[_MMaccID]==NULL)
+	while(mcid!=cmdlist.end() && cmdlist[mcid].rcr[getAccID()]==NULL)
 		mcid=cmdlist.next(mcid);
 	return mcid;
 }
@@ -1044,11 +1037,11 @@ MotionManager::OutputState::OutputState(unsigned int /*out*/, float pri, MC_ID m
  * @brief Implements MotionManager, simplifies sharing of MotionCommand's and provides mutual exclusion to their access
  * @author ejt (Creator)
  *
- * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.61 $
+ * $Author: kcomer $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.66 $
  * $State: Exp $
- * $Date: 2006/09/25 23:30:16 $
+ * $Date: 2007/11/15 21:33:05 $
  */
 
 
