@@ -46,6 +46,11 @@ class EventTranslator;
  *  MC_ID id = motman->addPersistentMotion( SharedObject<YourMC>([arg1,...]) [, priority ] );
  *  // then later: motman->removeMotion(id);
  *  @endcode
+ *
+ *  The priority level can be changed later via setPriority(), and there are
+ *  symbolic values defined in #kIgnoredPriority through #kEmergencyPriority
+ *  to give some common guidelines on the magnitudes to use.  The default
+ *  priority level if unspecified is #kStdPriority.
  *  
  *  If you want to do some more initializations not handled by the MotionCommand's
  *  constructor (the @p arg1, @p arg2, ...  params) then you would
@@ -119,8 +124,8 @@ public:
 	void setOutput(const MotionCommand* caller, unsigned int output, const OutputCmd& cmd, const OutputPID& pid); //!< @b LOCKS @b MotionManager Requests a value and PID be set for the specified output
 	void setOutput(const MotionCommand* caller, unsigned int output, const OutputCmd cmd[NumFrames], const OutputPID& pid); //!< @b LOCKS @b MotionManager Requests a value and PID be set for the specified output
 	const OutputCmd& getOutputCmd(unsigned int output) const { return cmds[output]; } //!< Returns the value of the output last sent to the OS.  Note that this will differ from the sensed value in state, even when staying still.  There is no corresponding getOutputPID because this value *will* duplicate the value in state.
-	void setPriority(MC_ID mcid, float p) { cmdlist[mcid].priority=p; }//!< sets the priority level of a MotionCommand
-	float getPriority(MC_ID mcid) const { return cmdlist[mcid].priority; } //!< returns priority level of a MotionCommand
+	void setPriority(MC_ID mcid, float p) { cmdlist[mcid].priority=p; }//!< sets the priority level of a MotionCommand, symbolic values are available to give some guidelines -- see #kIgnoredPriority through #kEmergencyPriority
+	float getPriority(MC_ID mcid) const { return cmdlist[mcid].priority; } //!< returns priority level of a MotionCommand, symbolic values are available to give some guidelines -- see #kIgnoredPriority through #kEmergencyPriority
 	//@}
 
 	//@{
@@ -134,9 +139,9 @@ public:
 	//!@name MotionCommand "Risky"
 	MotionCommand * checkoutMotion(MC_ID mcid,bool block=true); //!< locks the command and possibly performs RTTI conversion; supports recursive calls
 	void checkinMotion(MC_ID mcid); //!< marks a MotionCommand as unused
-	MotionCommand * peekMotion(MC_ID mcid) { return mcid==invalid_MC_ID?NULL:cmdlist[mcid].baseaddrs[_MMaccID]; } //!< allows access to a MotionCommand without checking it out; warning @b never call a function based on this, only access member fields through it
+	MotionCommand * peekMotion(MC_ID mcid) { return mcid==invalid_MC_ID?NULL:cmdlist[mcid].baseaddrs[getAccID()]; } //!< allows access to a MotionCommand without checking it out; warning @b never call a function based on this, only access member fields through it
 	unsigned int checkoutLevel(MC_ID mcid) { return mcid==invalid_MC_ID?0:cmdlist[mcid].lock.get_lock_level(); } //!< returns the number of times @a mcid has been checked out minus the times it's been checked in
-	bool isOwner(MC_ID mcid) { return mcid==invalid_MC_ID?false:(cmdlist[mcid].lock.owner()==_MMaccID); }
+	bool isOwner(MC_ID mcid) { return mcid==invalid_MC_ID?false:(cmdlist[mcid].lock.owner()==getAccID()); }
 	//@}
 
 	//!@name MotionCommand Unsafe
@@ -149,14 +154,13 @@ public:
 	//@}
 
 	//@{
-	void lock()    { MMlock.lock(_MMaccID); } //!< gets an exclusive lock on MotionManager - functions marked @b LOCKS @b MotionManager will cause (and require) this to happen automatically
-	bool trylock() { return MMlock.try_lock(_MMaccID); } //!< tries to get a lock without blocking
+	void lock()    { MMlock.lock(getAccID()); } //!< gets an exclusive lock on MotionManager - functions marked @b LOCKS @b MotionManager will cause (and require) this to happen automatically
+	bool trylock() { return MMlock.try_lock(getAccID()); } //!< tries to get a lock without blocking
 	void unlock() { MMlock.unlock(); } //!< releases a lock on the motion manager
 	//@}
 
 	//@{
 	void getOutputs(float outputs[][NumOutputs]);  //!< @b LOCKS @b MotionManager called by MotionObject to fill in the output values for the next ::NumFrames frames (only MotoObj should call this...)
-	void updateWorldState();                                //!< call this when you want MotionManager to set the WorldState to reflect what things should be for unsensed outputs (LEDs, ears) (only MotoObj should be calling this...)
 #ifdef PLATFORM_APERIOS
 	bool updatePIDs(OPrimitiveID primIDs[NumOutputs]);      //!< call this when you want MotionManager to update modified PID values, returns true if changes made (only MotoObj should be calling this...), see PIDMC for general PID documentation
 #else
@@ -206,7 +210,7 @@ protected:
 
 	typedef unsigned short accID_t; //!< type to use to refer to accessors of MotionManager (or its locks)
 
-	void func_begin() { MMlock.lock(_MMaccID); } //!< called at the begining of many functions to lock MotionManager
+	void func_begin() { MMlock.lock(getAccID()); } //!< called at the begining of many functions to lock MotionManager
 	void func_end() { MMlock.unlock(); } //!< called at the end of a function which called func_begin() to release it
 	template<class T> T func_end(T val) { func_end(); return val; } //!< same as func_end(), except passes return value through
 
@@ -250,11 +254,12 @@ protected:
 #else //PLATFORM_LOCAL
 	//!Storage of each process's attachment of the message queue, used to internally transmit sound buffers to SoundPlay
 	MessageQueueBase * subjs[MAX_ACCESS];
-	MessageReceiver * mcrecvs[MAX_ACCESS];
-	Resource* procLocks[MAX_ACCESS];
+	MessageReceiver * mcrecvs[MAX_ACCESS]; //!< message receivers which watch for incoming motion command regions, or requests to free them
+	Resource* procLocks[MAX_ACCESS]; //!< pointers to per-process thread locks, acquired during message processing from one of #mcrecvs
 #endif
 
-	static int _MMaccID;          //!<Stores the accessor for the current process
+	static int getAccID() { return _MMaccID[ProcessID::getID()]; }
+	static int _MMaccID[ProcessID::NumProcesses]; //!<Stores the accessor id assigned in InitAccess() for each process
 	static EventTranslator* etrans; //!< EventTranslator for sending events to Main -- each process will set the correct value for calls within that process.
 
 private:
@@ -270,10 +275,10 @@ extern MotionManager * motman;
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.37 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.41 $
  * $State: Exp $
- * $Date: 2006/10/03 22:28:15 $
+ * $Date: 2007/11/10 22:58:09 $
  */
 
 #endif
