@@ -8,11 +8,11 @@
 using std::cout;
 using std::endl;
 
-MotionSequenceEngine::Move_idx_t MotionSequenceEngine::invalid_move=-1U;
+MotionSequenceEngine::Move_idx_t MotionSequenceEngine::invalid_move=(MotionSequenceEngine::Move_idx_t)-1;
 
 MotionSequenceEngine::MotionSequenceEngine()
 : LoadSave(), playtime(1), lasttime(0), endtime(0), playspeed(1.0),
-playing(true), hold(true), loadSaveMode(M_PI/180)
+playing(true), hold(true), loadSaveMode(1)
 {
 	for(unsigned int i=0; i<NumOutputs; i++)
 		curstamps[i]=-1U;
@@ -135,7 +135,7 @@ unsigned int MotionSequenceEngine::loadBuffer(const char buf[], unsigned int len
 			}
 		}
 		written=-1;
-		const unsigned int cmdlen=16, arglen=32;
+		const unsigned int cmdlen=64, arglen=32;
 		char command[cmdlen];
 		char arg1[arglen];
 		char arg2[arglen];
@@ -187,7 +187,8 @@ unsigned int MotionSequenceEngine::loadBuffer(const char buf[], unsigned int len
 			} else
 				cout << "*** WARNING could not read file " << arg1 << " for load (loadExplicit only accepts posture files) - line " << linenum << endl;
 		} else if(strcasecmp(command,"degrees")==0) {
-			setSaveDegrees();
+			cout << "*** WARNING 'degrees' is deprecated, please specify all angles as radians" << endl;
+			loadSaveMode=M_PI/180; //setSaveDegrees();
 		} else if(strcasecmp(command,"radians")==0) {
 			setSaveRadians();
 		} else {
@@ -315,6 +316,9 @@ unsigned int MotionSequenceEngine::saveFile(const char filename[]) const {
 	return LoadSave::saveFile(config->motion.makePath(filename).c_str());
 }
 
+/*! @deprecated use radians instead (we don't have a good way to know which output values are angles, and which are 'other', e.g. wheel velocities or LED brightness...) */
+void MotionSequenceEngine::setSaveDegrees() { loadSaveMode=M_PI/180; }
+
 void MotionSequenceEngine::setTime(unsigned int x) {
 	playtime=x;
 	WorldState * st=WorldState::getCurrent();
@@ -365,10 +369,6 @@ void MotionSequenceEngine::setExplicitPose(const PostureEngine& pose) {
 		setOutputCmd(i,pose.getOutputCmd(i));
 }
 
-void MotionSequenceEngine::overlayPose(const PostureEngine& pose) {
-	setPose(pose);
-}
-
 PostureEngine MotionSequenceEngine::getPose() {
 	PostureEngine pose;
 	getPose(pose);
@@ -569,18 +569,21 @@ unsigned int MotionSequenceEngine::readWord(const char buf[], const char * const
 }
 
 unsigned int MotionSequenceEngine::getOutputIndex(const char name[], unsigned int idx) {
+	unsigned int n=strlen(name);
+	while(name[n-1]=='~')
+		--n;
 	if(idx<NumOutputs) {
 		unsigned int startidx=idx;
 		for(;idx<NumOutputs;idx++)
-			if(strcmp(name,outputNames[idx])==0)
+			if(strncmp(name,outputNames[idx],n)==0)
 				return idx;
 		for(idx=0;idx<startidx;idx++)
-			if(strcmp(name,outputNames[idx])==0)
+			if(strncmp(name,outputNames[idx],n)==0)
 				return idx;
 		return NumOutputs;
 	} else {
 		for(idx=0;idx<NumOutputs;idx++)
-			if(strcmp(name,outputNames[idx])==0)
+			if(strncmp(name,outputNames[idx],n)==0)
 				return idx;
 		return idx;
 	}
@@ -591,9 +594,9 @@ unsigned int MotionSequenceEngine::getOutputIndex(const char name[], unsigned in
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.15 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.19 $
  * $State: Exp $
- * $Date: 2006/09/23 19:51:11 $
+ * $Date: 2007/09/26 23:16:49 $
  */
 
