@@ -5,6 +5,7 @@
 #include "Shared/LoadSave.h"
 #include "IPC/ListMemBuf.h"
 #include "PostureEngine.h"
+#include "Shared/attributes.h"
 
 //! A handy class for storing a sequence of keyframed movements
 /*! Each outputs is handled independently.  It's easy to add keyframes
@@ -49,8 +50,6 @@
  *    - '<i>outputname</i><tt> </tt><i>value</i><tt> </tt>[<i>weight</i>]' - sets the specified output to the value - assumes 1 for weight; you can view the list of valid joint names in the outputNames array within the RobotInfo extension namespace for your model.  (e.g. ERS210Info::outputNames[])
  *    - '<tt>load </tt><i>filename</i>' - file can be a posture or another motion sequence (if MS, leaves playhead at end of the motion sequence); see setPose() and overlayMotion()
  *    - '<tt>loadExplicit </tt><i>filename</i>' - file must be a posture, sets position for all outputs, including zero-weighted ones; see setExplicitPose()
- *    - '<tt>degrees</tt>' - all following <i>value</i>s will be interpreted as degrees [default]
- *    - '<tt>radians</tt>' - all following <i>value</i>s will be interpreted as radians
  *    - '<tt>#</tt><i>comment</i>' - a comment line
  *  - Last line: '<tt>\#END</tt>'
  *  
@@ -60,21 +59,20 @@
  *  Example 1: This motion sequence will straighten out the head, panning from right to left.\n
 <table align="center"><tr><td align=left><pre>
 \#MSq 
-degrees 
 
 <i>\# Straighten head</i>
 advanceTime  50 
-NECK:tilt       15 
+NECK:tilt       0.262
 NECK:nod       0 
 
 <i>\# Pan right</i>
 advanceTime  850 
-NECK:pan~       -45 
+NECK:pan~       -0.785 
 
 <i>\# Pan left</i>
 advanceTime  900 
-NECK:pan~       45 
-NECK:tilt       15 
+NECK:pan~       0.785 
+NECK:tilt       0.262 
 NECK:nod       0 
 
 \#END
@@ -92,7 +90,6 @@ NECK:nod       0
  *  head left to right, and @e then pan the tail left to right.\n
 <table align="center"><tr><td align=left><pre>
 \#MSq
-degrees
 
 <i>\# Bring head and tail to neural positions</i>
 advanceTime 50
@@ -103,10 +100,10 @@ TAIL:tilt 0
 
 <i>\# Pan left</i>
 advanceTime 1000
-NECK:pan~ 90
+NECK:pan~ 1.571
 <i>\# Pan right</i>
 advanceTime 1000
-NECK:pan~ -90
+NECK:pan~ -1.571
 
 <i>\# Center head</i>
 <i>\# Update tail time index</i>
@@ -117,10 +114,10 @@ TAIL:pan~ 0
 
 <i>\# Wag left</i>
 advanceTime 500
-TAIL:pan~ 90
+TAIL:pan~ 1.571
 <i>\# Wag right</i>
 advanceTime 500
-TAIL:pan~ -90
+TAIL:pan~ -1.571
 
 \#END 
 </pre></td></tr></table>
@@ -198,7 +195,8 @@ public:
 	virtual unsigned int saveBuffer(char buf[], unsigned int len) const; //!< inherited, saves the motion sequence - will save a flat file - doesn't remember references to other files which were loaded
 	virtual unsigned int loadFile(const char filename[]); //!< inherited, doesn't clear before loading - call clear yourself if you want to reset, otherwise it will overlay.  Leaves playtime at end of load.
 	virtual unsigned int saveFile(const char filename[]) const; //!< inherited, saves the motion sequence - will save a flat file - doesn't remember references to other files which were loaded
-	void setSaveDegrees() { loadSaveMode=M_PI/180; }       //!< will store angles as degrees on future saves
+	//! deprecated, use radians instead; calling this will store angles as degrees on future saves
+	void setSaveDegrees() ATTR_deprecated;
 	bool isSaveDegrees() const { return loadSaveMode!=1; } //!< returns true if will store angles as degrees on future saves
 	void setSaveRadians() { loadSaveMode=1; }              //!< will store angles as radians on future saves
 	bool isSaveRadians() const { return loadSaveMode==1; } //!< returns true if will store angles as degrees on future saves
@@ -214,7 +212,6 @@ public:
 	void setExplicitPose(const PostureEngine& pose); //!< calls setOutputCmd on each of the OutputCmds in @a pose, even if they are zero-weight (can be used to fade joints in/out with other conflicting motions)
 	PostureEngine getPose(); //!< returns the set of OutputCmd's at the current playhead as a PostureEngine
 	void getPose(PostureEngine& pose); //!< stores the set of OutputCmd's at the current playhead into the specified PostureEngine
-	void overlayPose(const PostureEngine& pose) __attribute__((__deprecated__)); //!< deprecated, use setPose instead (what setPose used to do is now setExplicitPose)
 	unsigned int overlayMotion(const std::string& msFile); //!< loads @a msFile from disk and calls overlayMotion(const MotionSequenceEngine&) with it, returns the duration of @a msFile (0 if there was an error)
 	void overlayMotion(const MotionSequenceEngine& ms); //!< applies each keyframe of @a ms to this, leaves playhead at the end (in other words, advances playhead to end of @a ms)
 	void compress(); //!< compresses the sequence by eliminating sequences of moves which are identical
@@ -297,10 +294,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.18 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.19 $
  * $State: Exp $
- * $Date: 2006/10/03 23:01:28 $
+ * $Date: 2007/09/26 22:32:55 $
  */
 
 #endif
