@@ -36,7 +36,7 @@
 
 #include "OldKinematics.h"
 //#include "Wireless/Socket.h"
-#include "Shared/ERS7Info.h"
+#include "Shared/RobotInfo.h"
 
 // #define DEBUG
 
@@ -404,11 +404,11 @@ void GetHeadAngles(double *angles,vector3d target,
 	//but should use tilt too if out of range of nod
 
 	//if we can't pan far enough, change the tilt
-	if(angles[1]<ERS7Info::outputRanges[ERS7Info::HeadOffset+PanOffset][MinRange] || 
-		 angles[1]>ERS7Info::outputRanges[ERS7Info::HeadOffset+PanOffset][MaxRange]
+	if(angles[1]<outputRanges[HeadOffset+PanOffset][MinRange] || 
+		 angles[1]>outputRanges[HeadOffset+PanOffset][MaxRange]
 		 ) {
 		double elv=-atan2(target.x,target.z);
-		elv=bound(elv,ERS7Info::outputRanges[ERS7Info::HeadOffset+TiltOffset][MinRange],ERS7Info::outputRanges[ERS7Info::HeadOffset+TiltOffset][MaxRange]);
+		elv=bound(elv,outputRanges[HeadOffset+TiltOffset][MinRange],outputRanges[HeadOffset+TiltOffset][MaxRange]);
 		angles[0]=elv;
 		if(!getNodAndPan(angles,target))
 			return;
@@ -433,31 +433,31 @@ void GetHeadAngles(double *angles,vector3d target,
 	//   y = ( A^2*h % sqrt(B^2*(A^4+B^2*r^2+A^2*(B^2-h^2+r^2))) ) / (A^2+B^2)
 	// (2 solutions)
 
-	if(angles[2]<ERS7Info::outputRanges[ERS7Info::HeadOffset+NodOffset][MinRange] || 
-		 angles[2]>ERS7Info::outputRanges[ERS7Info::HeadOffset+NodOffset][MaxRange]
+	if(angles[2]<outputRanges[HeadOffset+NodOffset][MinRange] || 
+		 angles[2]>outputRanges[HeadOffset+NodOffset][MaxRange]
 		 ) {
 		double nod;
-		if(angles[2]<ERS7Info::outputRanges[ERS7Info::HeadOffset+NodOffset][MinRange])
-			nod=ERS7Info::outputRanges[ERS7Info::HeadOffset+NodOffset][MinRange];
+		if(angles[2]<outputRanges[HeadOffset+NodOffset][MinRange])
+			nod=outputRanges[HeadOffset+NodOffset][MinRange];
 		else
-			nod=ERS7Info::outputRanges[ERS7Info::HeadOffset+NodOffset][MaxRange];
+			nod=outputRanges[HeadOffset+NodOffset][MaxRange];
 		double rad=hypot(target.x,target.z); // aka 'r'
 		double slope=tan(nod);
 		double intcpt=neck_to_nod.z+nod_to_camera.z/cos(nod); // aka 'h'
 		double A=target.y-neck_to_nod.y;
 		double B=A*slope;
 		double yval;
-		if(angles[2]<ERS7Info::outputRanges[ERS7Info::HeadOffset+NodOffset][MinRange])
+		if(angles[2]<outputRanges[HeadOffset+NodOffset][MinRange])
 			// too low: use the '-' solution so we get the lower intercept:
 			yval = ( A*A*intcpt - sqrt(B*B*(A*A*A*A+B*B*rad*rad+A*A*(B*B-intcpt*intcpt+rad*rad))) ) / (A*A+B*B);
 		else
 			// too high: use the '+' solution so we get the upper intercept:
 			yval = ( A*A*intcpt + sqrt(B*B*(A*A*A*A+B*B*rad*rad+A*A*(B*B-intcpt*intcpt+rad*rad))) ) / (A*A+B*B);
 		angles[0]=atan2(target.z,target.x)-asin(yval/rad);
-		if(angles[0]<ERS7Info::outputRanges[ERS7Info::HeadOffset+TiltOffset][MinRange])
-			angles[0]=ERS7Info::outputRanges[ERS7Info::HeadOffset+TiltOffset][MinRange];
-		else if(angles[0]>ERS7Info::outputRanges[ERS7Info::HeadOffset+TiltOffset][MaxRange])
-			angles[0]=ERS7Info::outputRanges[ERS7Info::HeadOffset+TiltOffset][MaxRange];
+		if(angles[0]<outputRanges[HeadOffset+TiltOffset][MinRange])
+			angles[0]=outputRanges[HeadOffset+TiltOffset][MinRange];
+		else if(angles[0]>outputRanges[HeadOffset+TiltOffset][MaxRange])
+			angles[0]=outputRanges[HeadOffset+TiltOffset][MaxRange];
 		getNodAndPan(angles,target);
 		//sout->printf("rad=%g slope=%g intcpt=%g A=%g B=%g yval=%g tilt=%g\n",rad,slope,intcpt,A,B,yval,angles[0]);
 	}
@@ -603,9 +603,9 @@ void GetHeadPosition(vector3d &location, vector3d &direction, vector3d &up, vect
  * @verbinclude CMPack_license.txt
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.2 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.3 $
  * $State: Exp $
- * $Date: 2006/10/04 02:41:52 $
+ * $Date: 2007/06/26 04:27:45 $
  */
 
