@@ -7,9 +7,14 @@ class OutputCmd {
 public:
 
 	OutputCmd() : value(0), weight(0) {} //!< Constructor
-	OutputCmd(float v) : value(v), weight(1) {} //!< Constructor
+	OutputCmd(float v) : value(v), weight(1) {} //!< Constructor (provides implicit conversion from float)
 	OutputCmd(float v, float w) : value(v), weight(w) {} //!< Constructor
 	OutputCmd(const OutputCmd& a, const OutputCmd& b, float w) : value(a.value*w+b.value*(1-w)), weight(a.weight*w+b.value*(1-w)) {} //!< Constructor, see set(a,b,w)
+	
+	//! assignment from another OutputCmd (just copy everything, straightforward)
+	OutputCmd& operator=(const OutputCmd& oc) { value=oc.value; weight=oc.weight; return *this; }
+	//! assignment from a float, set weight to 1
+	OutputCmd& operator=(float v) { value=v; weight=1; return *this; }
 
 	inline void set(float v, float w=1) { value=v; weight=w; } //!< sets the value to @a v and weight to @a w
 	inline void set(const OutputCmd& a, const OutputCmd& b, float w) { value=a.value*w+b.value*(1-w); weight=a.weight*w+b.weight*(1-w); } //!< sets the value to a weighted average of @a a and @a b (higher @a w, more @a a)
@@ -27,10 +32,10 @@ public:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.3 $
- * $State: Rel $
- * $Date: 2003/09/07 22:14:01 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.4 $
+ * $State: Exp $
+ * $Date: 2007/11/15 05:32:52 $
  */
 
 #endif
