@@ -10,7 +10,66 @@
 class WorldState;
 
 //! A class for storing a set of positions and weights for all the outputs
-/*! Handy for any class which wants to deal with setting joints and postures without writing a custom class
+/*! File Format: ([..] indicates an optional parameter)\n
+ *  - First line: '<tt>\#POS</tt>'
+ *  - Followed by a series of:
+ *    - '<tt>specialize </tt><i>[regex]</i>' - only robots whose model name matches the regular
+ *      expression will attempt to parse lines between this and the next 'specialize' command.  An empty
+ *      (absent) regex matches all robots (equivalent to '<tt>specialize&nbsp;.*</tt>')
+ *    - '<tt>condensed </tt><i>model</i>' - specifies model name for which condensed specifications will be
+ *      interpreted
+ *    - '<tt>verbose</tt>' - switches the load/save format back to "verbose" style, where each output/sensor
+ *      value is listed individually
+ *    - '<tt>&lt;</tt><i>section</i><tt>&gt;</tt> ... <tt>&lt;/</tt><i>section</i><tt>&gt;</tt>' - specifies a
+ *      section for following "verbose" style lines (valid <i>section</i> values listed below)
+ *    - '<i>section</i> <i>value1</i> <i>value2</i> <i>value3</i> ...' - specify all values for a section in
+ *      one line, "condensed" style (valid <i>section</i> values listed below).  Must have a value for every
+ *      item in the section (no extra or missing values)
+ *    - '<i>output-name</i> <i>value</i> <i>[weight]</i>' - specifies an output value, with optional weighting
+ *      value (if no weight specified, '1' is assumed)
+ *  - Last line: '<tt>\#END</tt>'
+ *  
+ *  Note that '=' can be used to separate tokens as well as any whitespace character.
+ *  All angle values should be specified in radians.
+ *
+ *  Valid section names are:
+ *  - <tt>meta-info</tt> - only recognizes two fields: <tt>timestamp</tt> and <tt>framenumber</tt>
+ *  - <tt>outputs</tt> - supports all output names (e.g. ERS7Info::outputNames)
+ *  - <tt>buttons</tt> - supports all button names (e.g. ERS7Info::buttonNames)
+ *  - <tt>sensors</tt> - supports all sensor names (e.g. ERS7Info::sensorNames)
+ *  - <tt>pidduties</tt> - supports output names corresponding to PID joints (this is the "duty cycle" for the joint)
+ *
+ *  Additionally 'weights' can be used as a condensed section name (but not a
+ *  verbose tag-style section, since weights are specified on each line).  The
+ *  'weights' specification must follow the 'outputs' specification to be effective.
+ *
+ *  Data following '\#' is ignored as comments.  Be aware if you
+ *  load the file and then save it again, these comments will be lost.
+ *
+ *  Example 1: Specifies only neck joints, looks forward and up a little
+<table><tr><td align=left><pre>
+\#POS 
+NECK:tilt	0
+NECK:pan	0
+NECK:nod	0.2
+\#END
+</pre></td></tr></table>
+ *  All other, unspecified, joints will be set to weight=0.
+ *
+ *  Example 2: Logged sensor data from an ERS-7 robot
+<table><tr><td align=left><tt>
+\#POS<br>
+condensed ERS-7<br>
+meta-info = 1439041 178803<br>
+outputs = -0.131722 0.148077 1.74592 -0.30276 0.341717 2.13361 -1.03935 0.091124 2.18958 -0.804097 0.034171 1.67458 -0.016362 -0.089143 0.125563 0.407243 -0.054399 -0.064704 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0<br>
+buttons = 0 0 0 0 0 0 0 0 0 1<br>
+sensors = 500 860.139 425 -2.06456 -0.516139 -8.94642 0.99 30.63 2200 8.265 0<br>
+pidduties = -0.164062 0.0878906 0.0957031 0.246094 -0.0195312 -0.0546875 -0.164062 -0.0195312 0.164062 0.0273438 0 -0.0683594 -0.00585938 -0.00390625 0.0820312 -0.0390625 0.015625 0.00390625<br>
+\#END<br>
+</tt></td></tr></table>
+ *  Condensed posture files can still be loaded on other models.  For each entry, RobotInfo::Capabilities will be
+ *  used to map from the model specified by the <tt>condensed</tt> command to the current host.
+ *
  *  @see PostureMC
  *  @see <a href="http://www.cs.cmu.edu/~tekkotsu/Kinematics.html">Tekkotsu's Kinematics page</a>
  *  @see <a href="http://www.cs.cmu.edu/~dst/Tekkotsu/Tutorial/postures.shtml">David Touretzky's "Postures and Motion Sequences" Chapter</a>
@@ -193,6 +252,22 @@ public:
 	//@}
 
 protected:
+	//! enumeration of the different section types that may be used as section tags in verbose mode
+	enum section_t {
+		SECTION_METAINFO, //!< includes timestamp and framenumber
+		SECTION_OUTPUTS, //!< entries corresponding to NumOutputs
+		SECTION_BUTTONS, //!< entries corresponding to NumButtons
+		SECTION_SENSORS, //!< entries corresponding to NumSensors
+		SECTION_PIDDUTIES //!< entries corresponding to NumPIDJoints
+	};
+	//! helper function for loadBuffer, called for each individual line
+	virtual bool loadLine(unsigned int linenum, const std::map<std::string,section_t>& sectionMap, std::vector<std::string>& words, section_t& curSection, Capabilities*& caps, bool& filtered);
+	//! helper function for loadLine, strips trailing '~'s from output names to provide backward compatability (note pass by reference, operates 'in-place' on @a word)
+	/*! (originally, all output names were uniform length and used '~'s as padding... ugh.) */
+	void stripTildes(std::string& word) {
+		word.erase(word.find_last_not_of('~')+1); // if n is npos, npos is -1U, so becomes 0... should be safe :)
+	}
+
 	//all updates come from this posture engine's own state, not WorldState
 	virtual void update(unsigned int c, unsigned int l);
 
@@ -208,10 +283,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.23 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.28 $
  * $State: Exp $
- * $Date: 2006/10/04 02:57:12 $
+ * $Date: 2007/11/11 23:57:23 $
  */
 
 #endif
