@@ -1,6 +1,8 @@
 #include "PostureMC.h"
 #include "Shared/Config.h"
 #include "Shared/WorldState.h"
+#include "Shared/ERS7Info.h"
+#include "Shared/ERS210Info.h"
 
 PostureMC& PostureMC::setDirty(bool d/*=true*/) {
 	dirty=d;
@@ -14,9 +16,28 @@ void PostureMC::defaultMaxSpeed(float x/*=1*/) {
 	for(unsigned int i=0; i<NumOutputs; i++)
 		maxSpeeds[i]=MaxOutputSpeed[i]*FrameTime*x; //MaxOutputsSpeed is rad/ms
 	//respect the config values for the neck joints (which are stored as rad/sec)
+#ifdef TGT_IS_AIBO
 	maxSpeeds[HeadOffset+TiltOffset]=config->motion.max_head_tilt_speed*FrameTime*x/1000; 
 	maxSpeeds[HeadOffset+PanOffset]=config->motion.max_head_pan_speed*FrameTime*x/1000;
 	maxSpeeds[HeadOffset+RollOffset]=config->motion.max_head_roll_speed*FrameTime*x/1000;
+#else
+	const char* n = ERS7Info::outputNames[ERS7Info::HeadOffset+ERS7Info::TiltOffset];
+	unsigned int i = capabilities.findOutputOffset(n);
+	if(i!=-1U)
+		maxSpeeds[i]=config->motion.max_head_tilt_speed*FrameTime*x/1000; 
+	n = ERS7Info::outputNames[ERS7Info::HeadOffset+ERS7Info::PanOffset];
+	i = capabilities.findOutputOffset(n);
+	if(i!=-1U)
+		maxSpeeds[i]=config->motion.max_head_pan_speed*FrameTime*x/1000;
+	n = ERS7Info::outputNames[ERS7Info::HeadOffset+ERS7Info::NodOffset];
+	i = capabilities.findOutputOffset(n);
+	if(i!=-1U)
+		maxSpeeds[i]=config->motion.max_head_roll_speed*FrameTime*x/1000;
+	n = ERS210Info::outputNames[ERS210Info::HeadOffset+ERS210Info::RollOffset];
+	i = capabilities.findOutputOffset(n);
+	if(i!=-1U)
+		maxSpeeds[i]=config->motion.max_head_roll_speed*FrameTime*x/1000;
+#endif
 }
 
 int PostureMC::updateOutputs() {
@@ -84,8 +105,8 @@ void PostureMC::init() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.5 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.6 $
  * $State: Exp $
- * $Date: 2006/08/31 21:48:00 $
+ * $Date: 2007/08/25 03:40:31 $
  */
