@@ -32,16 +32,30 @@ public:
 			return 0;
 
 		// only ERS-210 and ERS-7 have moveable tails
-		unsigned int tail_pan_offset, tail_tilt_offset;
-		if(state->robotDesign & WorldState::ERS210Mask) {
-			tail_pan_offset = ERS210Info::TailOffset+PanOffset;
-			tail_tilt_offset = ERS210Info::TailOffset+TiltOffset;
+		unsigned int tail_pan_offset=-1U, tail_tilt_offset=-1U;
+		if(RobotName == ERS210Info::TargetName) {
+			// might be in 2xx compatability mode, use dynamic lookup
+			unsigned tail = capabilities.getOutputOffset(ERS210Info::outputNames[ERS210Info::TailOffset]);
+			tail_pan_offset = tail+PanOffset;
+			tail_tilt_offset = tail+TiltOffset;
 		}
-		else if(state->robotDesign & WorldState::ERS7Mask) {
+		else if(RobotName == ERS7Info::TargetName) {
+			// no compatability mode, just use direct symbol:
 			tail_pan_offset = ERS7Info::TailOffset+PanOffset;
 			tail_tilt_offset = ERS7Info::TailOffset+TiltOffset;
+		} else {
+			// unknown model, see if we have a tail named after the ERS-210 tail:
+			tail_pan_offset = capabilities.getOutputOffset(ERS210Info::outputNames[ERS210Info::TailOffset+PanOffset]);
+			if(tail_pan_offset!=-1U) {
+				// try the tilt too...
+				tail_tilt_offset = capabilities.getOutputOffset(ERS210Info::outputNames[ERS210Info::TailOffset+TiltOffset]);
+			} else {
+				// maybe just named "tail"?
+				tail_pan_offset = capabilities.getOutputOffset("Tail");
+			}
 		}
-		else return 0;
+		if(tail_pan_offset==-1U)
+			return 0;
 
 		for(unsigned int i=0; i<NumFrames; i++) {
 			float new_pan = sin((2*M_PI*(get_time()+offset+i*FrameTime))/period)*magnitude; //bug fix thanks L.A.Olsson AT herts ac uk
@@ -53,7 +67,8 @@ public:
 			last_pan = new_pan;
 		}
 		motman->setOutput(this,tail_pan_offset,pans);
-		motman->setOutput(this,tail_tilt_offset,tilt);
+		if(tail_tilt_offset!=-1U)
+			motman->setOutput(this,tail_tilt_offset,tilt);
 		return tilt.weight>0?2:1;
 	}
 
@@ -69,12 +84,13 @@ public:
 		float curPos=(get_time()%period)/(float)period;
 		offset=static_cast<unsigned int>((prevPos-curPos)*period);
 	} 
-	unsigned int getPeriod() { return period; } //!< gets the period of time between swings, in milliseconds
+	unsigned int getPeriod() const { return period; } //!< gets the period of time between swings, in milliseconds
 	void setMagnitude(double mag) { magnitude=mag; } //!< sets the magnitude of swings, in radians
-	double getMagnitude() { return magnitude; } //!< gets the magnitude of swings, in radians
+	double getMagnitude() const { return magnitude; } //!< gets the magnitude of swings, in radians
 	void setTilt(double r) { tilt.set(r,1); }  //!< sets the tilt of the tail while wagging, in radians
 	void unsetTilt() { tilt.unset(); } //!< makes the tilt control unspecified, will let something else control tilt
-	double getTilt() { return tilt.value; }  //!< sets the tilt of the tail while wagging, in radians
+	double getTilt() const { return tilt.value; }  //!< gets the tilt of the tail while wagging, in radians
+        double getPan() const { return last_pan; } //!< returns the most recent pan value of the tail while wagging, in radians
 
 	bool getActive() { return active; } //!< returns true if this is currently trying to wag the tail
 
@@ -101,10 +117,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.11 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.14 $
  * $State: Exp $
- * $Date: 2006/02/15 19:14:13 $
+ * $Date: 2007/06/28 04:36:21 $
  */
 
 #endif
