@@ -159,6 +159,7 @@ UPennWalkMC::UPennWalkMC()
 
 void
 UPennWalkMC::SetLegJoints(double * x) {
+#ifdef TGT_HAS_LEGS
 	motman->setOutput(this,LFrLegOffset+RotatorOffset,x[LEG_LEFT_FORE*JointsPerLeg+0]);
 	motman->setOutput(this,LFrLegOffset+ElevatorOffset,x[LEG_LEFT_FORE*JointsPerLeg+1]);
 	motman->setOutput(this,LFrLegOffset+KneeOffset,x[LEG_LEFT_FORE*JointsPerLeg+2]);
@@ -174,6 +175,7 @@ UPennWalkMC::SetLegJoints(double * x) {
 	motman->setOutput(this,RBkLegOffset+RotatorOffset,x[LEG_RIGHT_HIND*JointsPerLeg+0]);
 	motman->setOutput(this,RBkLegOffset+ElevatorOffset,x[LEG_RIGHT_HIND*JointsPerLeg+1]);
 	motman->setOutput(this,RBkLegOffset+KneeOffset,x[LEG_RIGHT_HIND*JointsPerLeg+2]);
+#endif
 }
 
 void
@@ -627,8 +629,8 @@ UPennWalkMC::WalkLegs(double xWalk/*=0.0*/, double yWalk/*=0.0*/, double aWalk/*
  *  ------------------------------------------------------------------------- \n
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.2 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.3 $
  * $State: Exp $
- * $Date: 2006/08/31 21:37:10 $
+ * $Date: 2007/03/23 20:05:37 $
  */
