@@ -132,9 +132,16 @@ int WalkMC::isDirty()
 		return 0;
   if((target_vel_xya.x == 0) && (target_vel_xya.y == 0) && (target_vel_xya.z == 0)) {
 		// we may stopping, but not stopped yet...
-		return ((vel_xya.x != 0) || (vel_xya.y != 0) || (vel_xya.z != 0));
+		if((vel_xya.x == 0) && (vel_xya.y == 0) && (vel_xya.z == 0))
+			return false;
   }
+#ifdef TGT_HAS_LEGS
   return JointsPerLeg*NumLegs;
+#elif defined(TGT_HAS_WHEELS)
+  return NumWheels;
+#else
+	return 0;
+#endif
 }
 // tss "SmoothWalk" addition ends
 
@@ -167,7 +174,7 @@ unsigned int WalkMC::loadBuffer(const char buf[], unsigned int len) {
 	}
 	
 	// Leg parameters
-	for(unsigned int i=0; i<NumLegs; ++i) {
+	for(unsigned int i=0; i<4; ++i) {
 		if(!decodeInc(wp.leg[i].neutral.x,buf,len)) return 0;
 		if(!decodeInc(wp.leg[i].neutral.y,buf,len)) return 0;
 		if(!decodeInc(wp.leg[i].neutral.z,buf,len)) return 0;
@@ -211,7 +218,7 @@ unsigned int WalkMC::saveBuffer(char buf[], unsigned int len) const {
 	unsigned int origlen=len;
 	// Leg parameters
 	if(!saveCreatorInc("WalkMC-2.2",buf,len)) return 0;
-	for(unsigned int i=0; i<NumLegs; ++i) {
+	for(unsigned int i=0; i<4; ++i) {
 		if(!encodeInc(wp.leg[i].neutral.x,buf,len)) return 0;
 		if(!encodeInc(wp.leg[i].neutral.y,buf,len)) return 0;
 		if(!encodeInc(wp.leg[i].neutral.z,buf,len)) return 0;
@@ -269,6 +276,7 @@ void WalkMC::setTargetVelocity(double dx,double dy,double da,int n)
 #endif
 
   target_vel_xya.set(dx,dy,da);
+	//std::cout << "set " << dx << ' ' << dy << ' ' << da << std::endl;
 	// we just modified the target velocity, but we'll hold off on generating
 	// an event until the changes are actually picked up by the motion system
 
@@ -305,11 +313,6 @@ int WalkMC::updateOutputs() {
 	if(!isDirty())
 		return 0;
 
-	if(vel_xya.sqlength()==0) {
-		// we had been stopped - better check someone else didn't move the legs while we weren't using them...
-		resetLegPos(); 
-	}
-
 	unsigned int curT=get_time();
 	if(last_target_vel_xya!=target_vel_xya) {
 		last_target_vel_xya=target_vel_xya;
@@ -320,7 +323,14 @@ int WalkMC::updateOutputs() {
 		travelTime=curT;
 	}
 	
-  float tm = TimeStep * slowmo / 1000;
+#if defined(TGT_HAS_LEGS)
+	
+	if(vel_xya.sqlength()==0) {
+		// we had been stopped - better check someone else didn't move the legs while we weren't using them...
+		resetLegPos(); 
+	}
+	
+	float tm = TimeStep * slowmo / 1000;
 
 	vector3d cal_target_vel_xya(target_vel_xya);
 	if(target_vel_xya.x<0)
@@ -561,15 +571,40 @@ int WalkMC::updateOutputs() {
 	
 	for(unsigned int joint=LegOffset; joint<LegOffset+NumLegJoints; joint++)
 		motman->setOutput(this,joint,cmds[joint]);
-
+	
 	//		cout << "WalkMC-done" << endl;
-  return NumLegs*JointsPerLeg;
+	return NumLegs*JointsPerLeg;
+	
+#elif defined(TGT_HAS_WHEELS)
+	vel_xya=target_vel_xya;
+	float wheelcircum = 2*M_PI*config->motion.wheelRadius;
+	float baserpm = vel_xya.x / wheelcircum;
+	float turnrpm = (vel_xya.z*config->motion.wheelBaseWidth/2) / wheelcircum;
+	float left = baserpm - turnrpm;
+	float right = baserpm + turnrpm;
+	for(unsigned int frame=0; frame<NumFrames; frame++) {
+		cmds[LWheelOffset][frame]=left;
+		cmds[RWheelOffset][frame]=right;
+	}
+	//std::cout << "update " << vel_xya.x << ' ' << vel_xya.y << ' ' << vel_xya.z << " -> " << left << ' ' << right << std::endl;
+	
+	for(unsigned int w=WheelOffset; w<WheelOffset+NumWheels; w++)
+		motman->setOutput(this,w,cmds[w]);
+	
+	//		cout << "WalkMC-done" << endl;
+	return NumWheels;
+	
+#else
+#  warning target has neither legs nor wheels -- WalkMC is a no-op
+	return 0;
+#endif
 }
 
 void WalkMC::resetLegPos() {
 	BodyPosition nextpos;
 	nextpos.loc.set(0,0,wp.body_height);
 	nextpos.angle.set(0,wp.body_angle,0);
+#ifdef TGT_HAS_LEGS
 	for(unsigned int i=0; i<NumLegs; i++) {
 		double tmp[JointsPerLeg];
 		for(unsigned int j=0; j<JointsPerLeg; j++)
@@ -581,6 +616,7 @@ void WalkMC::resetLegPos() {
 			cout << "  ->  " << legpos[i].x << ' ' << legpos[i].y << ' ' << legpos[i].z << endl;
 		*/
 	}
+#endif
 	//cout << "----------------------" << endl;
 }
 
@@ -628,9 +664,9 @@ void WalkMC::applyCalibration(const float mat[3][11], const vector3d& in, vector
  * @verbinclude CMPack_license.txt
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.38 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.42 $
  * $State: Exp $
- * $Date: 2006/09/10 18:48:46 $
+ * $Date: 2007/11/18 06:47:03 $
  */
 
