@@ -98,8 +98,8 @@ public:
 		double body_angle; //!< the angle to hold the body (rad - 0 is level)
 		double hop;  //!< sinusoidal hop amplitude
 		double sway; //!< sinusoidal sway in y direction
-		long period; //!< the time between steps
-		long useDiffDrive; //!< if non-zero, diff-drive style turning is used instead of rotational turning
+		int period; //!< the time between steps
+		int useDiffDrive; //!< if non-zero, diff-drive style turning is used instead of rotational turning
 		float sag; //!< the amount to sagging to account for when a foot is lifted
 		float reserved; //!< just live with it
 	};
@@ -204,8 +204,10 @@ public:
 	virtual void setAccelerationStyle(AccelerationStyle_t acc) { acc_style=acc; } //!< sets #acc_style
 	virtual AccelerationStyle_t getAccelerationStyle() const { return acc_style; } //!< returns #acc_style
 
+#ifdef TGT_HAS_LEGS
 	//! returns the current leg position of leg @a i
 	const vector3d& getLegPosition(LegOrder_t i) const { return legpos[i]; }
+#endif
 
 	struct WalkParam& getWP() { return wp; }; //!< returns the current walk parameter structure
 	struct CalibrationParam& getCP() { return cp; }; //!< returns the current walk calibration parameter
@@ -309,10 +311,10 @@ public:
  * @verbinclude CMPack_license.txt
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.35 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.37 $
  * $State: Exp $
- * $Date: 2006/10/03 21:42:50 $
+ * $Date: 2007/11/13 04:16:03 $
  */
 
 #endif
