@@ -4,6 +4,7 @@
 
 #include "IPC/ListMemBuf.h"
 #include "Shared/LoadSave.h"
+#include "Shared/Config.h"
 
 //! Provides computation and management of a desired path through a series of waypoints
 /*! This is a generalized set of data structures and management code -
@@ -842,10 +843,10 @@ void WaypointEngine<MAX_WAY>::computeNewVelocity(unsigned int /*t*/) {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.13 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.14 $
  * $State: Exp $
- * $Date: 2006/09/09 04:32:58 $
+ * $Date: 2007/03/05 01:19:11 $
  */
 
 #endif
