@@ -62,13 +62,15 @@ Revision_history:
 #include <sstream>
 #endif
 
+using namespace std;
+
 #ifdef use_namespace
 namespace ROBOOP {
   using namespace NEWMAT;
 #endif
 	
 //! @brief RCS/CVS version.
-static const char rcsid[] __UNUSED__ = "$Id: config.cpp,v 1.12 2006/09/25 23:30:32 ejt Exp $";
+static const char rcsid[] __UNUSED__ = "$Id: config.cpp,v 1.14 2007/11/11 23:57:24 ejt Exp $";
 
 Config::Config(const string & filename_, bool doRead/*=false*/)
 //! @brief Constructor.
@@ -113,21 +115,21 @@ short Config::read_conf()
    const char *ptr_filename = filename.c_str(); //transform string to *char
    std::ifstream inconffile(ptr_filename, std::ios::in);
 
+   string temp;
+#ifdef __WATCOMC__
+   char tempo[256], tempo2[256];
+   inconffile.getline(tempo,sizeof(tempo));
+   temp = tempo;
+#else
+   getline(inconffile, temp);
+#endif
    if(inconffile)
    {
-      string temp;
       int tmpPos;
-	map<string,string>* cursection=NULL;
-	string parameter, value;
-#ifdef __WATCOMC__
-      char tempo[256], tempo2[256];
-      inconffile.getline(tempo,sizeof(tempo));
-      temp = tempo;
-#else
-      getline(inconffile, temp);
-#endif
+      map<string,string>* cursection=NULL;
+      string parameter, value;
 
-      while( !inconffile.eof() )
+      while( inconffile )
       {
 	 // Is-it comment line?
          if(temp[0] != '#')
