@@ -49,7 +49,7 @@ namespace ROBOOP {
   using namespace NEWMAT;
 #endif
 	//! @brief RCS/CVS version.
-	static const char header_Control_Select_rcsid[] __UNUSED__ = "$Id: control_select.h,v 1.4 2005/07/26 03:22:08 ejt Exp $";
+	static const char header_Control_Select_rcsid[] __UNUSED__ = "$Id: control_select.h,v 1.5 2007/11/11 23:57:24 ejt Exp $";
 
 	
 #define NONE   0
@@ -99,11 +99,11 @@ class Control_Select
 {
 public:
     Control_Select();
-    Control_Select(const string & filename);
+    Control_Select(const std::string & filename);
     Control_Select(const Control_Select & x);
     Control_Select & operator=(const Control_Select & x);
     int get_dof();
-    void set_control(const string & filename);
+    void set_control(const std::string & filename);
     Proportional_Derivative pd;
     Computed_torque_method ctm;
     Resolved_acc rra;
@@ -111,7 +111,7 @@ public:
 
     short type,            //!< Type of controller: PD, CTM,...
 	  space_type;      //!< JOINT_SPACE or CARTESIAN_SPACE.
-    string ControllerName; //!< Controller name.
+    std::string ControllerName; //!< Controller name.
 private:
     int dof;               //!< Degree of freedom.
 };
