@@ -61,13 +61,16 @@ Revision_history:
 */
 
 #include "gnugraph.h"
+#include <fstream>
+
+using namespace std;
 
 #ifdef use_namespace
 namespace ROBOOP {
   using namespace NEWMAT;
 #endif
 	//! @brief RCS/CVS version.
-	static const char rcsid[] __UNUSED__ = "$Id: gnugraph.cpp,v 1.3 2005/07/26 03:22:08 ejt Exp $";
+	static const char rcsid[] __UNUSED__ = "$Id: gnugraph.cpp,v 1.6 2007/11/14 02:38:24 ejt Exp $";
 
 char *curvetype[] =
    {"lines",
@@ -358,7 +361,7 @@ short IO_matrix_file::write(const vector<Matrix> & data)
 }
 
 
-short IO_matrix_file::write(const vector<Matrix> & data, const vector<string> & title)
+short IO_matrix_file::write(const std::vector<Matrix> & data, const std::vector<std::string> & title)
 /*!
   @brief Write data on disk.
   @param data: Data.
@@ -467,7 +470,7 @@ short IO_matrix_file::read(vector<Matrix> & data)
 }
 
 
-short IO_matrix_file::read(vector<Matrix> & data, vector<string> & data_title)
+short IO_matrix_file::read(std::vector<Matrix> & data, std::vector<std::string> & data_title)
 //! @brief Read one sequence of data per call.
 {
    /*
@@ -537,7 +540,7 @@ short IO_matrix_file::read(vector<Matrix> & data, vector<string> & data_title)
 }
 
 
-short IO_matrix_file::read_all(vector<Matrix> & data, vector<string> & data_title)
+short IO_matrix_file::read_all(std::vector<Matrix> & data, std::vector<std::string> & data_title)
 /*!
   @brief Reads all sequences of data.
   
