@@ -79,7 +79,7 @@ namespace ROBOOP {
   using namespace NEWMAT;
 #endif
 	//! @brief RCS/CVS version.
-	static const char header_gnugraph_rcsid[] __UNUSED__ = "$Id: gnugraph.h,v 1.2 2005/07/26 03:22:09 ejt Exp $";
+	static const char header_gnugraph_rcsid[] __UNUSED__ = "$Id: gnugraph.h,v 1.3 2007/11/11 23:57:24 ejt Exp $";
 
 #define OUT_OF_MEMORY       -1
 #define X_Y_DATA_NO_MATCH   -2
@@ -90,8 +90,8 @@ short set_plot2d(const char *title_graph, const char *x_axis_title, const char *
                  int start_y, int end_y);
 
 short set_plot2d(const char *title_graph, const char *x_axis_title, const char *y_axis_title,
-                 const vector<char *>label, int type, const Matrix &xdata, const Matrix &ydata,
-                 const vector<int> & data_select);
+                 const std::vector<char *>label, int type, const Matrix &xdata, const Matrix &ydata,
+                 const std::vector<int> & data_select);
 
 
 //  interface class for gnuplot
@@ -115,11 +115,11 @@ class Plot2d;
 class GNUcurve {
    friend class Plot2d; //!< Plot2d need access to private data
    Matrix xy;           //!< n x 2 matrix defining the curve */
-   string clabel;       //!< string defining the curve label for the legend
+   std::string clabel;       //!< string defining the curve label for the legend
    int ctype;           //!< curve type: lines, points, linespoints, impulses,
                         //!< dots, steps, boxes
 public:
-   GNUcurve(const Matrix & data, const string & label = "", int type = LINES);
+   GNUcurve(const Matrix & data, const std::string & label = "", int type = LINES);
    GNUcurve(void);
    GNUcurve(const GNUcurve & gnuc);
    GNUcurve & operator=(const GNUcurve & gnuc);
@@ -132,23 +132,23 @@ public:
   @brief 2d plot object.
 */
 class Plot2d {
-   string 
+   std::string 
      title,           //!< Graph title.
      xlabel,          //!< Graph x axis.
      ylabel;          //!< Graph y axis.
-   string gnucommand; //!< GNU plot command.
+   std::string gnucommand; //!< GNU plot command.
    int ncurves;       //!< Number of curves.
    GNUcurve *curves;  //!< Pointer to GNUcurve object.
 public:
    Plot2d(void);
    ~Plot2d(void);
    void dump(void);
-   void settitle(const string & t);
-   void setxlabel(const string & t);
-   void setylabel(const string & t);
-   void addcurve(const Matrix & data, const string & label = "", int type = LINES);
+   void settitle(const std::string & t);
+   void setxlabel(const std::string & t);
+   void setylabel(const std::string & t);
+   void addcurve(const Matrix & data, const std::string & label = "", int type = LINES);
    void gnuplot(void);
-   void addcommand(const string & gcom);
+   void addcommand(const std::string & gcom);
 };
 
 #define IO_COULD_NOT_OPEN_FILE  -1
@@ -164,19 +164,19 @@ public:
 */
 class IO_matrix_file {
 public:
-   IO_matrix_file(const string & filename);
-   short write(const vector<Matrix> & data);
-   short write(const vector<Matrix> & data, const vector<string> & title);
-   short read(vector<Matrix> & data);
-   short read(vector<Matrix> & data, vector<string> & title);
-   short read_all(vector<Matrix> & data, vector<string> & data_title);
+   IO_matrix_file(const std::string & filename);
+   short write(const std::vector<Matrix> & data);
+   short write(const std::vector<Matrix> & data, const std::vector<std::string> & title);
+   short read(std::vector<Matrix> & data);
+   short read(std::vector<Matrix> & data, std::vector<std::string> & title);
+   short read_all(std::vector<Matrix> & data, std::vector<std::string> & data_title);
 private:
    int 
      position_read,       //!< Position to read the file.
      nb_iterations_write, //!< Number of iterations in writing mode.
      nb_iterations_read,  //!< Number of iterations in reading mode.
      nb_element;          //!< Number of elements to read or write.
-   string filename;       //!< File name.
+   std::string filename;       //!< File name.
 };
 
 
@@ -187,13 +187,13 @@ private:
 class Plot_file : public IO_matrix_file, Plot2d
 {
 public:
-   Plot_file(const string & filename);
-   short graph(const string & title_graph, const string & label, const short x,
+   Plot_file(const std::string & filename);
+   short graph(const std::string & title_graph, const std::string & label, const short x,
                const short y, const short x_start, const short y_start,
                const short y_end);
 private:
-   vector<Matrix> data_from_file;  //!< Data file.
-   vector<string> data_title;      //!< Data file title.
+   std::vector<Matrix> data_from_file;  //!< Data file.
+   std::vector<std::string> data_title;      //!< Data file title.
 };
 
 #ifdef use_namespace
