@@ -64,12 +64,14 @@ Revision_history:
 #include "robot.h"
 #include <sstream>
 
+using namespace std;
+
 #ifdef use_namespace
 namespace ROBOOP {
   using namespace NEWMAT;
 #endif
 	//! @brief RCS/CVS version.
-	static const char rcsid[] __UNUSED__ = "$Id: invkine.cpp,v 1.25 2005/07/26 03:22:09 ejt Exp $";
+	static const char rcsid[] __UNUSED__ = "$Id: invkine.cpp,v 1.29 2007/11/16 16:46:45 ejt Exp $";
 
 #define NITMAX 1000  //!< def maximum number of iterations in inv_kin 
 #ifdef USING_FLOAT //from newmat's include.h
@@ -220,7 +222,7 @@ ReturnMatrix Robot_basic::inv_kin_pos(const ColumnVector & Pobj, const int mj, c
   The joint position vector before the inverse kinematics is returned if the 
   algorithm does not converge.
 */
-{
+{	
    ColumnVector qout, dq, q_tmp;
    UpperTriangularMatrix U;
    //int deb=0;
@@ -598,6 +600,10 @@ ReturnMatrix Robot::inv_kin(const Matrix & Tobj, const int mj, const int endlink
       case ERS2XX_HEAD:
       case ERS7_HEAD:
          //no specializations yet... :(
+      case PANTILT:
+      case GOOSENECK:
+      	return inv_kin_goose_neck(Tobj);
+      case CRABARM:
       default:
          return Robot_basic::inv_kin(Tobj, mj, endlink, converge);
    }
@@ -620,6 +626,11 @@ ReturnMatrix Robot::inv_kin_pos(const ColumnVector & Pobj, const int mj, const i
       case RHINO:
       case PUMA:
          //no specializations yet... :(
+       case PANTILT:
+         return inv_kin_pan_tilt(Pobj, converge);
+      case GOOSENECK:
+      	return inv_kin_goose_neck_pos(Pobj);
+      case CRABARM:
       default:
          return Robot_basic::inv_kin_pos(Pobj, mj, endlink, Plink, converge);
    }
@@ -641,13 +652,15 @@ ReturnMatrix Robot::inv_kin_orientation(const Matrix & Robj, const int mj, const
       case RHINO:
       case PUMA:
          //no specializations yet... :(
+      case PANTILT:
+      case GOOSENECK:
+//       return inv_kin_goose_neck_orientation(Robj)
+	  case CRABARM:
       default:
          return Robot_basic::inv_kin_orientation(Robj, mj, endlink, converge);
    }
 }
 
-
-
 ReturnMatrix Robot::inv_kin_rhino(const Matrix & Tobj, bool & converge)
 /*!
   @brief Analytic Rhino inverse kinematics.
@@ -909,7 +922,155 @@ ReturnMatrix Robot::inv_kin_puma(const Matrix & Tobj, bool & converge)
     return qout;
 }
 
+ReturnMatrix Robot::inv_kin_pan_tilt(const ColumnVector & Pobj, bool & converge)
+/*
+	@brief Inverse Kinematics of Pan Tilt Robot
+	@param Pobj: Vector expressing the desired end effector position
+	@param converge: Indicate if the algorithm converge.
+*/
+{
+	//std::cout << "Inv_Kine Pan Tilt!" << std::endl;
+	ColumnVector qout, qtmp,  /* Joint angle vectors */
+				 xyz1, xyz2,  /* Frame 1 and 2 coordinates */
+				 xyz0 = Pobj; /* Base frame coordinates */
+	Matrix 	M01, /* Matrix to convert coordinates from base (frame 0) to frame 1 */
+			M12; /* Matrix to convert coordinates from frame 1 to frame 2 */
+
+	qtmp = get_q();
+	M01 = convertFrame(1,2);
+	//std::cout << "Matrix M01" << std::endl << setw(5) << M01 << std::endl;
+	xyz1 = M01*xyz0;
+	//std::cout << xyz1(1) << " " << xyz1(2) << " " << xyz1(3) << std::endl;
+	qtmp(2)=atan2(xyz1(2),xyz1(1));
+	set_q(qtmp);
+	M12 = convertFrame(2,3);
+	//std::cout << "Matrix M12" << std::endl << setw(5) << M12 << std::endl;
+	xyz2 = M12*xyz1;
+	//std::cout << xyz2(1) << " " << xyz2(2) << " " << xyz2(3) << std::endl;
+	qtmp(3)=atan2(xyz2(2),xyz2(1));
+	set_q(qtmp);
+
+//Now I have to check to see if the angles lie within the ranges of the pan and tilt	
+//If not, set angles to closest min/max value.
+	if( qtmp(2) < links[2].get_theta_min() )
+		qtmp(2) = links[2].get_theta_min();
+	if( qtmp(2) > links[2].get_theta_max() )
+		qtmp(2) = links[2].get_theta_max();
+	if( qtmp(3) < links[3].get_theta_min() )
+		qtmp(3) = links[3].get_theta_min();
+	if( qtmp(3) > links[3].get_theta_max() )
+		qtmp(3) = links[3].get_theta_max();
+	//std::cout << "inv_kin_pan_tilt computed the values:" << endl;	
+	//std::cout << "Pan: "<< qtmp(2) << " Tilt: " << qtmp(3) << std::endl;
+	qout = qtmp;
+	converge=true;
+	return qout;
+}
+
+ReturnMatrix Robot::inv_kin_goose_neck(const Matrix & Tobj)
+/*
+*/
+{
+	//std::cout << "inv_kin_goose_neck was called!" << std::endl;
+	ColumnVector qout, Pobj(3);
+	Real phi;
+	Pobj(1) = Tobj(1,4);
+	Pobj(2) = Tobj(2,4);
+	Pobj(3) = Tobj(3,4);
+	phi = atan2(Tobj(3,3),Tobj(1,3));
+	qout = goose_neck_angles(Pobj, phi);
+	return qout;
+}
+
+ReturnMatrix Robot::inv_kin_goose_neck_pos(const ColumnVector & Pobj)
+/*
+*/
+{
+		//std::cout << "inv_kin_goose_neck_pos was called!" << std::endl;
+	ColumnVector qout;
+	qout = goose_neck_angles(Pobj, -1.57079632679);
+	return qout;
+}
+
+/*ReturnMatrix Robot::inv_kin_goose_neck_orientation(const Matrix & Robj)
+{
+	
+}
+*/
+
+ReturnMatrix Robot::goose_neck_angles(const ColumnVector & Pobj, Real phi)
+/*
+*/
+{
+	Real 	c2, 
+			qp, q1, q2, q3, //phi=-1.57079632679, //phi is the Tool Orientation
+			                                    //this phi puts the tool above the target
+			K1, K2,
+			L1=links[2].get_a(),//Planar Link Lengths
+			L2=links[3].get_a(),
+			L3=links[5].get_d();
+	ColumnVector 	qtmp, qout,
+					xyz0 = Pobj,
+					xyz_t,xyz_w;
+	Matrix 	M01, M12;
+	bool valid;
+	
+	qout = get_q();
+	qtmp = qout;
+	qp = atan2(xyz0(2),xyz0(1));
+	//std::cout << "Neck Pan: " << qp << std::endl;
+	qtmp(2)=qp;
+	set_q(qtmp);	//This will make the base pan
+	
+	M01 = convertFrame(1,2);
+
+	//std::cout << "Matrix M01" << std::endl << setw(5) << M01 << std::endl;
+	xyz_t = M01 * xyz0;  //xyz_t are the tool tip coordinates
+	//std::cout << xyz_t(1) << " " << xyz_t(2) << " " << xyz_t(3) << std::endl;
+	//Compute the wrist position
+	xyz_w = xyz_t; //This makes xyz_w a 4x1 matrix
+	xyz_w(1)=xyz_t(1)-L3*cos(phi);
+	xyz_w(2)=xyz_t(2)-L3*sin(phi);
+	
+	//std::cout << "The wrist is to be placed at (" << xyz_w(1) << "," << xyz_w(2) << ")." << std::endl;
+	
+	c2 = ( ( (xyz_w(1)*xyz_w(1)) + (xyz_w(2)*xyz_w(2)) - ( (L1*L1) + (L2*L2) ) ) / ( 2 * L1 * L2 ) );
+	//std::cout << "Cosine Theta2 is " << c2 << std::endl;
+	
+	if ( (c2*c2) > 1){
+		c2 = sign(c2);
+		valid = false;
+	}
+	else
+		valid = true;
+/*		
+	s2plus = sqrt(1-(c2*c2));
+	std::cout << "Sine Theta2 is " << s2plus << std::endl;
+	q2 = atan2(s2plus,c2);  //Compute q2
+*/
+	q2 = -acos(c2);
+		
+//	K1 = L1 + (L2 * c2);
+//	K2 = L2 * s2plus;
+	
+	K1 = L1 + (L2*cos(q2));
+	K2 = L2 * sin(q2);
+	
+	q1 = atan2(xyz_w(2),xyz_w(1)) - atan2(K2,K1);  //Compute q1
+	
+	q3 = phi - q1 - q2;  //Compute q3
+	//std::cout << "The angles are " << qp << " " << q1 << " " << q2 << " " << q3 << std::endl;
+	qtmp(2)=qp; qtmp(3)=q1; qtmp(4)=q2; qtmp(5)=q3;
+	set_q(qtmp);
+	
+	if(valid)
+		return qtmp;
+	else
+		return qout;
+}
+
 ReturnMatrix Robot::inv_kin_ers_pos(const ColumnVector & Pobj, const int endlink, const ColumnVector& Plink, bool & converge) {
+	//std::cout << "Called inv_kin_ers_pos!" << std::endl;
    bool converges[3];
    
    bool third_invert=(robotType==ERS7_HEAD || robotType==ERS2XX_HEAD);
