@@ -99,6 +99,7 @@ Revision_history:
 #include <sstream>
 #endif
 
+using namespace std;
 
 #ifdef use_namespace
 namespace ROBOOP {
@@ -106,7 +107,7 @@ namespace ROBOOP {
 #endif
 
 //! @brief RCS/CVS version.
-static const char rcsid[] __UNUSED__ = "$Id: robot.cpp,v 1.21 2005/07/26 03:22:08 ejt Exp $";
+static const char rcsid[] __UNUSED__ = "$Id: robot.cpp,v 1.25 2007/11/11 23:57:24 ejt Exp $";
 
 //! @brief Used to initialize a \f$4\times 4\f$ matrix.
 Real fourbyfourident[] = {1.0,0.0,0.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,1.0};
@@ -1408,21 +1409,27 @@ void Robot::robotType_inv_kin()
 
   Identify the inverse kinematics analytic solution
   based on the similarity of the robot DH parameters and
-  the DH parameters of know robots (ex: Puma, Rhino, ...). 
+  the DH parameters of known robots (ex: Puma, Rhino, ...). 
   The inverse kinematics will be based on a numerical
   alogorithm if there is no match .
 */
 {
-	if ( Puma_DH(this))
+	if ( Puma_DH(this) )
 		robotType = PUMA;
-	else if ( Rhino_DH(this))
+	else if ( Rhino_DH(this) )
 		robotType = RHINO;
-	else if ( ERS_Leg_DH(this))
+	else if ( ERS_Leg_DH(this) )
 		robotType = ERS_LEG;
-	else if ( ERS2xx_Head_DH(this))
+	else if ( ERS2xx_Head_DH(this) )
 		robotType = ERS2XX_HEAD;
-	else if ( ERS7_Head_DH(this))
+	else if ( ERS7_Head_DH(this) )
 		robotType = ERS7_HEAD;
+	else if ( PanTilt_DH(this) )
+		robotType = PANTILT;
+	else if ( Goose_Neck_DH(this) )
+		robotType = GOOSENECK;
+	else if ( Crab_Arm_DH(this) )
+		robotType = CRABARM;
 	else
 		robotType = DEFAULT;
 }
@@ -1752,6 +1759,51 @@ bool ERS7_Head_DH(const Robot_basic *robot)
 	return false;
 }
 
+bool PanTilt_DH(const Robot_basic *robot)
+/*
+	@brief Return true if robot is like PanTilt on DH notation
+	
+	Compare the robot DH table with the PanTilt DH table. The function returns
+	true if the two are similar.
+*/
+{
+	if(robot->get_available_dof()==2)
+		for(int i=1; i < robot->get_dof(); i++)
+			if( robot->links[i].get_immobile()==false &&
+			    robot->links[i+1].get_immobile()==false &&
+			    robot->links[i+1].get_alpha() != 0 )
+				return true;
+	return false;
+}
+
+bool Goose_Neck_DH(const Robot_basic *robot)
+/*
+*/
+{
+	if(robot->get_dof()==5)
+		if( robot->links[1].get_alpha() != 0 &&
+		    robot->links[2].get_alpha() == 0 &&
+		    robot->links[3].get_alpha() == 0 &&
+		    robot->links[4].get_immobile() == 1 &&
+		    robot->links[5].get_theta() > 0 )
+			return true;
+	return false;
+}
+
+bool Crab_Arm_DH(const Robot_basic *robot)
+{
+	if(robot->get_available_dof()==5)
+		if( robot->links[1].get_immobile() == 1 && 
+				robot->links[1].get_theta() > 0 && 
+				robot->links[1].get_alpha() > 0 &&
+				robot->links[2].get_alpha() > 0 &&
+				robot->links[3].get_theta() > 0 &&
+				robot->links[4].get_alpha() == 0 && robot->links[4].get_theta() == 0 &&
+				robot->links[5].get_theta() < 0 && robot->links[5].get_alpha() < 0 &&
+				robot->links[6].get_theta() < 0 )
+			return true;
+	return false;
+}
 
 bool Puma_mDH(const Robot_basic *robot)
 /*!
@@ -1768,7 +1820,7 @@ bool Puma_mDH(const Robot_basic *robot)
 	for (int j = 1; j <= 6; j++)      
 	{
 	    if (robot->links[j].get_joint_type())  // All joints are rotoide
-		return false;
+				return false;
 	    a[j] = robot->links[j].get_a();
 	    d[j] = robot->links[j].get_d();
 	    alpha[j] = robot->links[j].get_alpha();
