@@ -123,7 +123,7 @@ namespace ROBOOP {
   using namespace NEWMAT;
 #endif
   //! @brief RCS/CVS version.
-  static const char header_rcsid[] __UNUSED__ = "$Id: robot.h,v 1.19 2005/07/26 03:22:08 ejt Exp $";
+  static const char header_rcsid[] __UNUSED__ = "$Id: robot.h,v 1.21 2007/11/11 23:57:24 ejt Exp $";
 
 
 /*!
@@ -226,7 +226,7 @@ public:
                const bool min_inertial_para = false);
    explicit Robot_basic(const Matrix & initrobot, const Matrix & initmotor,
                const bool dh_parameter = false, const bool min_inertial_para = false);
-   explicit Robot_basic(const Config & robData, const string & robotName,
+   explicit Robot_basic(const Config & robData, const std::string & robotName,
                const bool dh_parameter = false, const bool min_inertial_para = false);
    Robot_basic(const Robot_basic & x);
    virtual ~Robot_basic();
@@ -309,7 +309,7 @@ public:
    ReturnMatrix dtau_dqp(const ColumnVector & q, const ColumnVector & qp);
    virtual ReturnMatrix G() = 0;
    virtual ReturnMatrix C(const ColumnVector & qp) = 0;
-   void error(const string & msg1) const;
+   void error(const std::string & msg1) const;
 
    //! useful for fixing x to be at least min or at most max
    static Real limit_range(Real x, Real min, Real max) { return x>max?max:(x<min?min:x); }
@@ -364,6 +364,9 @@ private:
        ERS_LEG,       //!< AIBO leg
        ERS2XX_HEAD,   //!< AIBO 200 series camera chain (210, 220)
        ERS7_HEAD,     //!< AIBO 7 model camera chain
+       PANTILT,	      //!< PanTilt Camera
+       GOOSENECK,	  //!<GooseNeck
+       CRABARM,	  //!CrabArm
    };
    EnumRobotType robotType; //!< Robot type.
    int dof,                 //!< Degree of freedom.
@@ -389,8 +392,8 @@ public:
    explicit Robot(const Matrix & initrobot);
    explicit Robot(const Matrix & initrobot, const Matrix & initmotor);
    Robot(const Robot & x);
-   explicit Robot(const string & filename, const string & robotName);
-   explicit Robot(const Config & robData, const string & robotName);
+   explicit Robot(const std::string & filename, const std::string & robotName);
+   explicit Robot(const Config & robData, const std::string & robotName);
    ~Robot(){}   //!< Destructor.
    Robot & operator=(const Robot & x);
    virtual void robotType_inv_kin();
@@ -405,6 +408,10 @@ public:
    virtual ReturnMatrix inv_kin_puma(const Matrix & Tobj, bool & converge);
 
    virtual ReturnMatrix inv_kin_ers_pos(const ColumnVector & Pobj, const int endlink, const ColumnVector& Plink, bool & converge);
+   virtual ReturnMatrix inv_kin_pan_tilt(const ColumnVector & Pobj, bool & converge);
+   virtual ReturnMatrix inv_kin_goose_neck(const Matrix & Tobj);
+   virtual ReturnMatrix inv_kin_goose_neck_pos(const ColumnVector & Pobj);
+   virtual ReturnMatrix goose_neck_angles(const ColumnVector & Pobj, Real phi);
 
    virtual ReturnMatrix jacobian(const int ref=0)const { return jacobian(dof,ref); } //!< Jacobian of mobile links expressed at frame ref.
    virtual ReturnMatrix jacobian(const int endlink, const int ref)const;
@@ -451,8 +458,8 @@ public:
    explicit mRobot(const Matrix & initrobot_motor);
    explicit mRobot(const Matrix & initrobot, const Matrix & initmotor);
    mRobot(const mRobot & x);
-   explicit mRobot(const string & filename, const string & robotName);
-   explicit mRobot(const Config & robData, const string & robotName);
+   explicit mRobot(const std::string & filename, const std::string & robotName);
+   explicit mRobot(const Config & robData, const std::string & robotName);
    ~mRobot(){}    //!< Destructor.
    mRobot & operator=(const mRobot & x);
    virtual void robotType_inv_kin();
@@ -504,8 +511,8 @@ public:
    explicit mRobot_min_para(const Matrix & dhinit);
    explicit mRobot_min_para(const Matrix & initrobot, const Matrix & initmotor);
    mRobot_min_para(const mRobot_min_para & x);
-   explicit mRobot_min_para(const string & filename, const string & robotName);
-   explicit mRobot_min_para(const Config & robData, const string & robotName);
+   explicit mRobot_min_para(const std::string & filename, const std::string & robotName);
+   explicit mRobot_min_para(const Config & robData, const std::string & robotName);
    ~mRobot_min_para(){}    //!< Destructor.
    mRobot_min_para & operator=(const mRobot_min_para & x);
    virtual void robotType_inv_kin();
@@ -552,8 +559,11 @@ bool Rhino_DH(const Robot_basic *robot);
 bool ERS_Leg_DH(const Robot_basic *robot);
 bool ERS2xx_Head_DH(const Robot_basic *robot);
 bool ERS7_Head_DH(const Robot_basic *robot);
+bool PanTilt_DH(const Robot_basic *robot);
 bool Puma_mDH(const Robot_basic *robot);
 bool Rhino_mDH(const Robot_basic *robot);
+bool Goose_Neck_DH(const Robot_basic *robot);
+bool Crab_Arm_DH(const Robot_basic *robot);
 
 #ifdef use_namespace
 }
