@@ -37,6 +37,9 @@ Revision_history:
 */
 
 #include "trajectory.h"
+#include <fstream>
+
+using namespace std;
 
 #ifdef use_namespace
 namespace ROBOOP {
@@ -44,7 +47,7 @@ namespace ROBOOP {
 #endif
 
 //! @brief RCS/CVS version.
-static const char rcsid[] __UNUSED__ = "$Id: trajectory.cpp,v 1.5 2005/07/26 03:22:08 ejt Exp $";
+static const char rcsid[] __UNUSED__ = "$Id: trajectory.cpp,v 1.7 2007/11/11 23:57:25 ejt Exp $";
 
 
 Spl_cubic::Spl_cubic(const Matrix & pts)
