@@ -76,7 +76,7 @@ namespace ROBOOP {
 #endif
 
 //! @brief RCS/CVS version.
-static const char header_trajectory_rcsid[] __UNUSED__ = "$Id: trajectory.h,v 1.5 2005/07/26 03:22:09 ejt Exp $";
+static const char header_trajectory_rcsid[] __UNUSED__ = "$Id: trajectory.h,v 1.6 2007/11/11 23:57:25 ejt Exp $";
 
 #define K_ZER0          1
 #define BAD_DATA       -1
@@ -111,7 +111,7 @@ private:
 #define CARTESIAN_SPACE 2
 
 //! @brief Data at control points.
-typedef map< Real, ColumnVector, less< Real > > point_map;
+typedef std::map< Real, ColumnVector, std::less< Real > > point_map;
 
 
 /*!
@@ -122,7 +122,7 @@ class Spl_path : public Spl_cubic
 {
 public:
    Spl_path():Spl_cubic(){};
-   Spl_path(const string & filename);
+   Spl_path(const std::string & filename);
    Spl_path(const Matrix & x);
    Spl_path(const Spl_path & x);
    Spl_path & operator=(const Spl_path & x);
@@ -140,7 +140,7 @@ private:
 
 
 //! @brief Data at control points.
-typedef map< Real, Quaternion, less< Real > > quat_map;
+typedef std::map< Real, Quaternion, std::less< Real > > quat_map;
 
 
 /*!
@@ -151,7 +151,7 @@ class Spl_Quaternion
 {
 public:
    Spl_Quaternion(){}
-   Spl_Quaternion(const string & filename);
+   Spl_Quaternion(const std::string & filename);
    Spl_Quaternion(const quat_map & quat);
    Spl_Quaternion(const Spl_Quaternion & x);
    Spl_Quaternion & operator=(const Spl_Quaternion & x);
@@ -170,11 +170,11 @@ class Trajectory_Select
 {
 public:
     Trajectory_Select();
-    Trajectory_Select(const string & filename);
+    Trajectory_Select(const std::string & filename);
     Trajectory_Select(const Trajectory_Select & x);
     Trajectory_Select & operator=(const Trajectory_Select & x);
 
-    void set_trajectory(const string & filename);
+    void set_trajectory(const std::string & filename);
 
     short type;               //!< Cartesian or joint space
     Spl_path path;            //!< Spl_path instance.
