@@ -77,12 +77,8 @@ namespace ROBOOP {
   using namespace NEWMAT;
 #endif
   //! @brief RCS/CVS version.
-  static const char header_utils_rcsid[] __UNUSED__ = "$Id: utils.h,v 1.5 2005/07/26 03:22:09 ejt Exp $";	
+  static const char header_utils_rcsid[] __UNUSED__ = "$Id: utils.h,v 1.6 2007/11/11 23:57:25 ejt Exp $";	
 	
-#ifndef __WATCOMC__
-using namespace std;
-#endif
-
 #ifndef M_PI
 #define M_PI 3.14159265358979
 #endif
