@@ -42,7 +42,7 @@ class Buffer {
 		//! Tries to fill the buffer from current position up to the limit mark. Advances the position, src and srcLen. Returns true if the buffer has been filled.
 		bool Fill(const char*&src, int& srcLen);
 		//! Tries to fill the buffer from current position up to the limit mark. Advances the position, src and srcLen. Returns true if the buffer has been filled.
-		bool Fill(char*& src, int& srcLen) { return Fill((const char*&) src, srcLen); }
+		bool Fill(char*& src, int& srcLen) { return Fill(const_cast<const char*&>(src), srcLen); }
 		//! Checks whether the buffer is full, that is position == limit.
 		bool IsFull() const { return (position >= limit); }
 	private:
@@ -51,7 +51,7 @@ class Buffer {
 		int limit; //!< Position is the index of the current element in the buffer (used only by buffer filling operations at the moment)
 		int position; //!< Limit is the virtual size of the buffer. Operations such as filling up the buffer, seeking and so on never go over the limit mark of the buffer. 
 		
-		//! returns the lesser of @a or @b
+		//! returns the lesser of @a a or @a b
 		static int min(int a, int b) { return ((a < b) ? a : b); }
 };
 
@@ -62,10 +62,10 @@ class Buffer {
  * Submitted as part of "Full-duplex Audio Streaming" patch
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.3 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.5 $
  * $State: Exp $
- * $Date: 2006/09/16 06:28:08 $
+ * $Date: 2007/11/09 18:08:29 $
  */
 
 #endif
