@@ -2,31 +2,23 @@
 #ifndef INCLUDED_ERS210Info_h
 #define INCLUDED_ERS210Info_h
 
-#include <math.h>
-#ifndef PLATFORM_APERIOS
-typedef unsigned short word; //!< otherwise defined in Types.h
-#else
-#include <Types.h>
-#endif
+#include "CommonERSInfo.h"
 
-#include "CommonInfo.h"
-using namespace RobotInfo;
-
-#if TGT_ERS2xx
-#include "ERS2xxInfo.h"
+// see http://tekkotsu.org/porting.html#configuration for more information on TGT_HAS_* flags
+#if defined(TGT_ERS210)
+#	define TGT_HAS_LEDS 9
+#	define TGT_HAS_BUTTONS 8
+#	define TGT_HAS_IR_DISTANCE 1
 #endif
 
 //! Contains information about the ERS-210 Robot, such as number of joints, PID defaults, timing information, etc.
 namespace ERS210Info {
 
-#if TGT_ERS2xx
-	using namespace ERS2xxInfo;
-#else
 	// *******************************
 	//       ROBOT CONFIGURATION
 	// *******************************
 
-	const char* const RobotName="ERS-210"; //!< the name of the model, to be used for logging and remote GUIs
+	extern const char* const TargetName; //!< the name of the model, to be used for logging and remote GUIs
 
 	const unsigned int FrameTime=8;        //!< time between frames in the motion system (milliseconds)
 	const unsigned int NumFrames=4;        //!< the number of frames per buffer (don't forget also double buffered)
@@ -37,6 +29,12 @@ namespace ERS210Info {
 	//!Corresponds to entries in ERS210Info::PrimitiveName, defined at the end of this file, these are the primary grouping
 	/*!Right now all binary joints are slow, but perhaps this won't always be the case... hence the IsFast/Slow bitmasks to select which type, in order to be more general */
 	//!@name Output Types Information
+	const unsigned NumWheels = 0; //!< no wheels, just legs
+	
+	const unsigned JointsPerArm   =  0; //!< no arms, just legs
+	const unsigned NumArms        =  0; //!< no arms, just legs
+	const unsigned NumArmJoints   =  JointsPerArm*NumArms;
+	
 	const unsigned JointsPerLeg   =  3; //!< The number of joints per leg
 	const unsigned NumLegs        =  4; //!< The number of legs
 	const unsigned NumLegJoints   =  JointsPerLeg*NumLegs; //!< the TOTAL number of joints on ALL legs
@@ -49,7 +47,7 @@ namespace ERS210Info {
 	const unsigned NumLEDs        =  9; //!< The number of LEDs which can be controlled
 	
 	const unsigned NumPIDJoints   = NumLegJoints+NumHeadJoints+NumTailJoints+NumMouthJoints; //!< The number of joints which use PID motion - everything except ears
-	const unsigned NumBinJoints   = NumEarJoints; //!< The number of binary joints - just the ears
+	const unsigned NumBinJoints   = NumEarJoints; //!< The number of binary joints - just the ears (Aperios only)
 	const unsigned NumOutputs     = NumPIDJoints + NumBinJoints + NumLEDs; //!< the total number of outputs
 	const unsigned NumReferenceFrames = NumOutputs + 1 + NumLegs + 1 + 1; //!< for the base, paw, camera, and IR sensor reference frames
 
@@ -64,12 +62,10 @@ namespace ERS210Info {
 	//! true for joints which can be updated every 32 ms (all but the ears)
 	/*! @hideinitializer */
 	const bool IsFastOutput[NumOutputs] = { true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,false,false };
-	//! we need this so you can tell programmatically which joints are "real" and which are "fake" in ERS-2xx target mode
-	/*! @hideinitializer */
-	const bool IsRealERS210[NumOutputs] = { true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true };
 	//@}
-
-
+	
+	
+	
 	// *******************************
 	//         OUTPUT OFFSETS
 	// *******************************
@@ -94,6 +90,29 @@ namespace ERS210Info {
 	const unsigned CameraFrameOffset = PawFrameOffset+NumLegs; //!< Use with kinematics to refer to camera reference frame
 	const unsigned IRFrameOffset = CameraFrameOffset+1; //!< Use with kinematics to refer to infrared (distance) sensor reference frame
 	
+	//! the ordering of legs
+	enum LegOrder_t {
+		LFrLegOrder = 0, //!< left front leg
+		RFrLegOrder,     //!< right front leg
+		LBkLegOrder,     //!< left back leg
+		RBkLegOrder      //!< right back leg
+	};
+	
+	//! The offsets within appendages (the legs)  Note that the ordering matches the actual physical ordering of joints on the appendage (and not that of the head's TPROffset_t's)
+	enum REKOffset_t {
+		RotatorOffset=0, //!< moves leg forward or backward along body
+		ElevatorOffset,  //!< moves leg toward or away from body
+		KneeOffset       //!< moves knee
+	};
+	
+	//! The offsets of appendages with tilt (elevation), pan (heading), and roll or nod joints (i.e. head)  Note that the ordering matches the actual physical ordering of joints on the appendage (and not that of the leg's REKOffset_t's)
+	enum TPROffset_t {
+		TiltOffset = 0, //!< tilt/elevation (vertical)
+		PanOffset,      //!< pan/heading (horizontal)
+		RollOffset,      //!< roll (rotational)
+		NodOffset=RollOffset       //!< nod (second tilt)
+	};
+	
 	//! The offsets of the individual legs
 	enum LegOffset_t {
 		LFrLegOffset = LegOffset+LFrLegOrder*JointsPerLeg, //!< beginning of left front leg
@@ -159,8 +178,9 @@ namespace ERS210Info {
 	const LEDBitMask_t TailLEDMask = TlRedLEDMask|TlBluLEDMask; //!< LEDs on tail
 	const LEDBitMask_t AllLEDMask  = (LEDBitMask_t)~0; //!< selects all of the leds
 	//@}
-
-
+	
+	
+	
 	// *******************************
 	//          INPUT OFFSETS
 	// *******************************
@@ -175,7 +195,7 @@ namespace ERS210Info {
 	 *  Note that the chest (power) button is not a normal button.  It kills
 	 *  power to the motors at a hardware level, and isn't sensed in the
 	 *  normal way.  If you want to know when it is pressed (and you are
-	 *  about to shut down) see PowerSourceID::PauseSID.
+	 *  about to shut down) see PowerSrcID::PauseSID.
 	 *
 	 *  @see WorldState::buttons @see ButtonSourceID_t */
 	enum ButtonOffset_t {
@@ -223,48 +243,64 @@ namespace ERS210Info {
 	//@}
 
 
-	//! The length of the strings used for each of the outputs in outputNames (doesn't include null term)
-	const unsigned outputNameLen = 9;
-	//! A name of uniform length for referring to joints - handy for posture files, etc.
+	//! Names for each of the outputs
 	const char* const outputNames[NumOutputs] = {
 		"LFr:rotor",
 		"LFr:elvtr",
-		"LFr:knee~",
+		"LFr:knee",
 		"RFr:rotor",
 		"RFr:elvtr",
-		"RFr:knee~",
+		"RFr:knee",
 		"LBk:rotor",
 		"LBk:elvtr",
-		"LBk:knee~",
+		"LBk:knee",
 		"RBk:rotor",
 		"RBk:elvtr",
-		"RBk:knee~",
+		"RBk:knee",
 		
 		"NECK:tilt",
-		"NECK:pan~",
+		"NECK:pan",
 		"NECK:roll",
 		
 		"TAIL:tilt",
-		"TAIL:pan~",
+		"TAIL:pan",
 		
-		"MOUTH~~~~",
+		"MOUTH",
 		
-		"LED:botL~",
-		"LED:botR~",
-		"LED:midL~",
-		"LED:midR~",
-		"LED:topL~",
-		"LED:topR~",
+		"LED:botL",
+		"LED:botR",
+		"LED:midL",
+		"LED:midR",
+		"LED:topL",
+		"LED:topR",
 		"LED:topBr",
 		
 		"LED:tlRed",
 		"LED:tlBlu",
 		
-		"EAR:left~",
+		"EAR:left",
 		"EAR:right"
 	};
 	
-
+	
+	//! provides polymorphic robot capability detection/mapping
+	class ERS210Capabilities : public Capabilities {
+	public:
+		//! constructor
+		ERS210Capabilities()
+			: Capabilities(TargetName,NumOutputs,outputNames,NumButtons,buttonNames,NumSensors,sensorNames,PIDJointOffset,NumPIDJoints,LEDOffset,NumLEDs)
+		{
+			// ers-7 button alias
+			buttonToIndex["HeadBut"]=HeadButOffset;
+			// 220 led aliases
+			outputToIndex["LED:bkL1"]=TailLeftLEDOffset;
+			outputToIndex["LED:bkL2"]=TailRightLEDOffset;
+		}
+	};
+	//! allocation declared in RobotInfo.cc
+	extern ERS210Capabilities capabilities;
+	
+	
 	//! the joint identifier strings used to refer to specific joints in OPEN-R (but not needed for others)
 	/*!@showinitializer 
 	 * @warning IMPORTANT!!!!  DO NOT CHANGE THE ORDER OF ITEMS IN THIS TABLE!!!\n
@@ -457,41 +493,39 @@ namespace ERS210Info {
 #undef __RI_RAD_FLAG
 #endif
 
-#endif //TGT_ERS2xx check
-
 	/*! @name CPC IDs
 	 * values defined by OPEN-R, used to interface with lower level OPEN-R code to read sensors - DOESN'T correspond to ERS210Info::PrimitiveName */
-	static const int CPCJointNeckTilt           =  0; // Head
-	static const int CPCJointNeckPan            =  1;
-	static const int CPCJointNeckRoll           =  2;
-	static const int CPCSensorHeadBackPressure  =  3;
-	static const int CPCSensorHeadFrontPressure =  4;
-	static const int CPCSensorPSD               =  5;
-	static const int CPCJointMouth              =  6;
-	static const int CPCSensorChinSwitch        =  7;
-	static const int CPCJointLFRotator          =  8; // Left front leg
-	static const int CPCJointLFElevator         =  9;
-	static const int CPCJointLFKnee             = 10;
-	static const int CPCSensorLFPaw             = 11;
-	static const int CPCJointLHRotator          = 12; // Left hind leg
-	static const int CPCJointLHElevator         = 13;
-	static const int CPCJointLHKnee             = 14;
-	static const int CPCSensorLHPaw             = 15;
-	static const int CPCJointRFRotator          = 16; // Right front leg
-	static const int CPCJointRFElevator         = 17;
-	static const int CPCJointRFKnee             = 18;
-	static const int CPCSensorRFPaw             = 19;
-	static const int CPCJointRHRotator          = 20; // Right hind leg
-	static const int CPCJointRHElevator         = 21;
-	static const int CPCJointRHKnee             = 22;
-	static const int CPCSensorRHPaw             = 23;
-	static const int CPCJointTailPan            = 24; // Tail
-	static const int CPCJointTailTilt           = 25;
-	static const int CPCSensorThermoSensor      = 26;
-	static const int CPCSensorBackSwitch        = 27;
-	static const int CPCSensorAccelFB           = 28; //!< Front-back; see RobotInfo::BAccelOffset 
-	static const int CPCSensorAccelLR           = 29; //!< Left-right; see RobotInfo::LAccelOffset 
-	static const int CPCSensorAccelUD           = 30; //!< Up-down; see RobotInfo::DAccelOffset 
+	const int CPCJointNeckTilt           =  0; // Head
+	const int CPCJointNeckPan            =  1;
+	const int CPCJointNeckRoll           =  2;
+	const int CPCSensorHeadBackPressure  =  3;
+	const int CPCSensorHeadFrontPressure =  4;
+	const int CPCSensorPSD               =  5;
+	const int CPCJointMouth              =  6;
+	const int CPCSensorChinSwitch        =  7;
+	const int CPCJointLFRotator          =  8; // Left front leg
+	const int CPCJointLFElevator         =  9;
+	const int CPCJointLFKnee             = 10;
+	const int CPCSensorLFPaw             = 11;
+	const int CPCJointLHRotator          = 12; // Left hind leg
+	const int CPCJointLHElevator         = 13;
+	const int CPCJointLHKnee             = 14;
+	const int CPCSensorLHPaw             = 15;
+	const int CPCJointRFRotator          = 16; // Right front leg
+	const int CPCJointRFElevator         = 17;
+	const int CPCJointRFKnee             = 18;
+	const int CPCSensorRFPaw             = 19;
+	const int CPCJointRHRotator          = 20; // Right hind leg
+	const int CPCJointRHElevator         = 21;
+	const int CPCJointRHKnee             = 22;
+	const int CPCSensorRHPaw             = 23;
+	const int CPCJointTailPan            = 24; // Tail
+	const int CPCJointTailTilt           = 25;
+	const int CPCSensorThermoSensor      = 26;
+	const int CPCSensorBackSwitch        = 27;
+	const int CPCSensorAccelFB           = 28; //!< Front-back; see RobotInfo::BAccelOffset 
+	const int CPCSensorAccelLR           = 29; //!< Left-right; see RobotInfo::LAccelOffset 
+	const int CPCSensorAccelUD           = 30; //!< Up-down; see RobotInfo::DAccelOffset 
 	//@}
 
 }
@@ -501,10 +535,10 @@ namespace ERS210Info {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.26 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.37 $
  * $State: Exp $
- * $Date: 2006/10/04 02:41:51 $
+ * $Date: 2007/11/09 19:01:14 $
  */
 
 #endif
