@@ -5,31 +5,23 @@
 #ifndef INCLUDED_ERS220Info_h
 #define INCLUDED_ERS220Info_h
 
-#include <math.h>
-#ifndef PLATFORM_APERIOS
-typedef unsigned short word; //!< otherwise defined in Types.h
-#else
-#include <Types.h>
-#endif
+#include "CommonERSInfo.h"
 
-#include "CommonInfo.h"
-using namespace RobotInfo;
-
-#if TGT_ERS2xx
-#include "ERS2xxInfo.h"
+// see http://tekkotsu.org/porting.html#configuration for more information on TGT_HAS_* flags
+#if defined(TGT_ERS220)
+#	define TGT_HAS_LEDS 20
+#	define TGT_HAS_BUTTONS 11
+#	define TGT_HAS_IR_DISTANCE 1
 #endif
 
 //! Contains information about the ERS-220 Robot, such as number of joints, PID defaults, timing information, etc.
 namespace ERS220Info {
 
-#if TGT_ERS2xx
-	using namespace ERS2xxInfo;
-#else
 	// *******************************
 	//       ROBOT CONFIGURATION
 	// *******************************
 
-	const char* const RobotName="ERS-220"; //!< the name of the model, to be used for logging and remote GUIs
+	extern const char* const TargetName; //!< the name of the model, to be used for logging and remote GUIs
 
 	const unsigned int FrameTime=8;        //!< time between frames in the motion system (milliseconds)
 	const unsigned int NumFrames=4;        //!< the number of frames per buffer (don't forget also double buffered)
@@ -40,6 +32,12 @@ namespace ERS220Info {
 	//!Corresponds to entries in ERS220Info::PrimitiveName, defined at the end of this file, these are the primary grouping
 	/*!Right now all binary joints are slow, but perhaps this won't always be the case... hence the IsFast/Slow bitmasks to select which type, in order to be more general */
 	//!@name Output Types Information
+	const unsigned NumWheels = 0; //!< no wheels, just legs
+	
+	const unsigned JointsPerArm   =  0; //!< no arms, just legs
+	const unsigned NumArms        =  0; //!< no arms, just legs
+	const unsigned NumArmJoints   =  JointsPerArm*NumArms;
+	
 	const unsigned JointsPerLeg   =  3; //!< The number of joints per leg
 	const unsigned NumLegs        =  4; //!< The number of legs
 	const unsigned NumLegJoints   =  JointsPerLeg*NumLegs; //!< the TOTAL number of joints on ALL legs
@@ -52,7 +50,7 @@ namespace ERS220Info {
 	const unsigned NumLEDs        = 20; //!< The number of LEDs which can be controlled
 	
 	const unsigned NumPIDJoints   = NumLegJoints+NumHeadJoints+NumTailJoints+NumMouthJoints; //!< The number of joints which use PID motion - everything
-	const unsigned NumBinJoints   = NumEarJoints; //!< The number of binary joints - just the ears (which the 220 doesn't have)
+	const unsigned NumBinJoints   = NumEarJoints; //!< The number of binary joints - just the ears (which the 220 doesn't have) (Aperios only)
 	const unsigned NumOutputs     = NumPIDJoints + NumBinJoints + NumLEDs; //!< the total number of outputs
 	const unsigned NumReferenceFrames = NumOutputs + 1 + NumLegs + 1 + 1; //!< for the base, paw, camera, and IR sensor reference frames
 
@@ -84,25 +82,6 @@ namespace ERS220Info {
 		// for binary joints (none supported/exist on 220)
 	};
 
-	//! we need this so you can tell programmatically which joints are "real" and which are "fake" in ERS-2xx target mode
-	const bool IsRealERS220[NumOutputs] = {
-		// for PID joints
-		true, true, true,
-		true, true, true,
-		true, true, true,
-		true, true, true,
-		true, true, true,
-		// for LEDs
-		true, true, true,           // face left side LEDs x3
-		true, true, true,           // face right side LEDs x3
-		true,                       // head mode LED x1
-		true, true, true,           // back left multi LEDs x3
-		true, true, true,           // back right multi LEDs x3
-		true, true, true,           // tail LEDs x3
-		true, true, true,           // face front LEDs x3
-		true,                       // retractable head light x1
-		// for binary joints (none supported/exist on 220)
-	};
 
 
 	// *******************************
@@ -125,6 +104,29 @@ namespace ERS220Info {
 	const unsigned CameraFrameOffset = PawFrameOffset+NumLegs; //!< Use with kinematics to refer to camera reference frame
 	const unsigned IRFrameOffset = CameraFrameOffset+1; //!< Use with kinematics to refer to infrared (distance) sensor reference frame
 
+	//! the ordering of legs
+	enum LegOrder_t {
+		LFrLegOrder = 0, //!< left front leg
+		RFrLegOrder,     //!< right front leg
+		LBkLegOrder,     //!< left back leg
+		RBkLegOrder      //!< right back leg
+	};
+	
+	//! The offsets within appendages (the legs)  Note that the ordering matches the actual physical ordering of joints on the appendage (and not that of the head's TPROffset_t's)
+	enum REKOffset_t {
+		RotatorOffset=0, //!< moves leg forward or backward along body
+		ElevatorOffset,  //!< moves leg toward or away from body
+		KneeOffset       //!< moves knee
+	};
+	
+	//! The offsets of appendages with tilt (elevation), pan (heading), and roll or nod joints (i.e. head)  Note that the ordering matches the actual physical ordering of joints on the appendage (and not that of the leg's REKOffset_t's)
+	enum TPROffset_t {
+		TiltOffset = 0, //!< tilt/elevation (vertical)
+		PanOffset,      //!< pan/heading (horizontal)
+		RollOffset,      //!< roll (rotational)
+		NodOffset=RollOffset       //!< nod (second tilt)
+	};
+	
 	//! The offsets of the individual legs
 	enum LegOffset_t {
 		LFrLegOffset = LegOffset+LFrLegOrder*JointsPerLeg, //!< beginning of left front leg
@@ -240,8 +242,9 @@ namespace ERS220Info {
 	//! selects all of the leds
 	const LEDBitMask_t AllLEDMask  = (LEDBitMask_t)~0;
 	//@}
-
-
+	
+	
+	
 	// *******************************
 	//          INPUT OFFSETS
 	// *******************************
@@ -256,7 +259,7 @@ namespace ERS220Info {
 	 *  Note that the chest (power) button is not a normal button.  It kills
 	 *  power to the motors at a hardware level, and isn't sensed in the
 	 *  normal way.  If you want to know when it is pressed (and you are
-	 *  about to shut down) see PowerSourceID::PauseSID.
+	 *  about to shut down) see PowerSrcID::PauseSID.
 	 *
 	 *  @see WorldState::buttons @see ButtonSourceID_t */
 	enum ButtonOffset_t {
@@ -307,41 +310,39 @@ namespace ERS220Info {
 	//@}
 
 
-	//! The length of the strings used for each of the outputs in outputNames (doesn't include null term)
-	const unsigned outputNameLen = 9;
-	//! A name of uniform length for referring to joints - handy for posture files, etc.
+	//! Names for each of the outputs
 	const char* const outputNames[NumOutputs] = {
 		"LFr:rotor",
 		"LFr:elvtr",
-		"LFr:knee~",
+		"LFr:knee",
 		"RFr:rotor",
 		"RFr:elvtr",
-		"RFr:knee~",
+		"RFr:knee",
 		"LBk:rotor",
 		"LBk:elvtr",
-		"LBk:knee~",
+		"LBk:knee",
 		"RBk:rotor",
 		"RBk:elvtr",
-		"RBk:knee~",
+		"RBk:knee",
 		
 		"NECK:tilt",
-		"NECK:pan~",
+		"NECK:pan",
 		"NECK:roll",
 		
-		"LED:botL~",
-		"LED:botR~",
-		"LED:midL~",
-		"LED:midR~",
-		"LED:topL~",
-		"LED:topR~",
+		"LED:botL",
+		"LED:botR",
+		"LED:midL",
+		"LED:midR",
+		"LED:topL",
+		"LED:topR",
 		"LED:topBr",
 		
-		"LED:bkL1~",                // "LED:tlBlu" of ERS-210
-		"LED:bkL2~",                // "LED:tlRed" of ERS-210
-		"LED:bkL3~",
-		"LED:bkR3~",
-		"LED:bkR2~",
-		"LED:bkR1~",
+		"LED:bkL1",                // "LED:tlBlu" of ERS-210
+		"LED:bkL2",                // "LED:tlRed" of ERS-210
+		"LED:bkL3",
+		"LED:bkR3",
+		"LED:bkR2",
+		"LED:bkR1",
 		"LED:tailL",
 		"LED:tailC",
 		"LED:tailR",
@@ -351,7 +352,25 @@ namespace ERS220Info {
 		"LED:light",                 // retractable head light
 	};
 	
-
+	
+	//! provides polymorphic robot capability detection/mapping
+	class ERS220Capabilities : public Capabilities {
+	public:
+		//! constructor
+		ERS220Capabilities()
+		: Capabilities(TargetName,NumOutputs,outputNames,NumButtons,buttonNames,NumSensors,sensorNames,PIDJointOffset,NumPIDJoints,LEDOffset,NumLEDs)
+		{
+			// ers-7 button alias
+			buttonToIndex["HeadBut"]=HeadButOffset;
+			// 220 led aliases
+			outputToIndex["LED:tlBlu"]=TlBluLEDOffset;
+			outputToIndex["LED:tlRed"]=TlRedLEDOffset;
+		}
+	};
+	//! allocation declared in RobotInfo.cc
+	extern ERS220Capabilities capabilities;
+	
+	
 	//! the joint identifier strings used to refer to specific joints in OPEN-R (but not needed for others)
 	/*!@showinitializer 
 	 * @warning IMPORTANT!!!!  DO NOT CHANGE THE ORDER OF ITEMS IN THIS TABLE!!!\n
@@ -551,41 +570,39 @@ namespace ERS220Info {
 #undef __RI_RAD_FLAG
 #endif
 
-#endif //TGT_ERS2xx check
-
 	/*! @name CPC IDs
 	 * values defined by OPEN-R, used to interface with lower level OPEN-R code to read sensors - DOESN'T correspond to ERS220Info::PrimitiveName */
-    static const int CPCJointNeckTilt           =  0; // PRM:/r1/c1-Joint2:j1
-    static const int CPCJointNeckPan            =  1; // PRM:/r1/c1/c2-Joint2:j2
-    static const int CPCJointNeckRoll           =  2; // PRM:/r1/c1/c2/c3-Joint2:j3
-    static const int CPCSensorPSD               =  3; // PRM:/r1/c1/c2/c3/p1-Sensor:p1
-    static const int CPCSensorHeadBackPressure  =  4; // PRM:/r1/c1/c2/c3/f1-Sensor:f1
-    static const int CPCSensorHeadFrontPressure =  5; // PRM:/r1/c1/c2/c3/f2-Sensor:f2
-    static const int CPCSensorChinSwitch        =  6; // PRM:/r1/c1/c2/c3/c4/s5-Sensor:s5
-    static const int CPCJointLFRotator          =  7; // PRM:/r2/c1-Joint2:j1
-    static const int CPCJointLFElevator         =  8; // PRM:/r2/c1/c2-Joint2:j2
-    static const int CPCJointLFKnee             =  9; // PRM:/r2/c1/c2/c3-Joint2:j3
-    static const int CPCSensorLFPaw             = 10; // PRM:/r2/c1/c2/c3/c4-Sensor:s4
-    static const int CPCJointLHRotator          = 11; // PRM:/r3/c1-Joint2:j1
-    static const int CPCJointLHElevator         = 12; // PRM:/r3/c1/c2-Joint2:j2
-    static const int CPCJointLHKnee             = 13; // PRM:/r3/c1/c2/c3-Joint2:j3
-    static const int CPCSensorLHPaw             = 14; // PRM:/r3/c1/c2/c3/c4-Sensor:s4
-    static const int CPCJointRFRotator          = 15; // PRM:/r4/c1-Joint2:j1
-    static const int CPCJointRFElevator         = 16; // PRM:/r4/c1/c2-Joint2:j2
-    static const int CPCJointRFKnee             = 17; // PRM:/r4/c1/c2/c3-Joint2:j3
-    static const int CPCSensorRFPaw             = 18; // PRM:/r4/c1/c2/c3/c4-Sensor:s4
-    static const int CPCJointRHRotator          = 19; // PRM:/r5/c1-Joint2:j1
-    static const int CPCJointRHElevator         = 20; // PRM:/r5/c1/c2-Joint2:j2
-    static const int CPCJointRHKnee             = 21; // PRM:/r5/c1/c2/c3-Joint2:j3
-    static const int CPCSensorRHPaw             = 22; // PRM:/r5/c1/c2/c3/c4-Sensor:s4
-    static const int CPCSensorThermoSensor      = 23; // PRM:/r6/t1-Sensor:t1
-    static const int CPCSensorBackSwitch        = 24; // PRM:/r6/s1-Sensor:s1
-    static const int CPCSensorTailLeftSwitch    = 25; // PRM:/r6/s2-Sensor:s2  (ERS-220 only)
-    static const int CPCSensorTailCenterSwitch  = 26; // PRM:/r6/s3-Sensor:s3  (ERS-220 only)
-    static const int CPCSensorTailRightSwitch   = 27; // PRM:/r6/s4-Sensor:s4  (ERS-220 only)
-    static const int CPCSensorAccelFB           = 28; // PRM:/a1-Sensor:a1
-    static const int CPCSensorAccelLR           = 29; // PRM:/a2-Sensor:a2
-    static const int CPCSensorAccelUD           = 30; // PRM:/a3-Sensor:a3
+    const int CPCJointNeckTilt           =  0; // PRM:/r1/c1-Joint2:j1
+    const int CPCJointNeckPan            =  1; // PRM:/r1/c1/c2-Joint2:j2
+    const int CPCJointNeckRoll           =  2; // PRM:/r1/c1/c2/c3-Joint2:j3
+    const int CPCSensorPSD               =  3; // PRM:/r1/c1/c2/c3/p1-Sensor:p1
+    const int CPCSensorHeadBackPressure  =  4; // PRM:/r1/c1/c2/c3/f1-Sensor:f1
+    const int CPCSensorHeadFrontPressure =  5; // PRM:/r1/c1/c2/c3/f2-Sensor:f2
+    const int CPCSensorChinSwitch        =  6; // PRM:/r1/c1/c2/c3/c4/s5-Sensor:s5
+    const int CPCJointLFRotator          =  7; // PRM:/r2/c1-Joint2:j1
+    const int CPCJointLFElevator         =  8; // PRM:/r2/c1/c2-Joint2:j2
+    const int CPCJointLFKnee             =  9; // PRM:/r2/c1/c2/c3-Joint2:j3
+    const int CPCSensorLFPaw             = 10; // PRM:/r2/c1/c2/c3/c4-Sensor:s4
+    const int CPCJointLHRotator          = 11; // PRM:/r3/c1-Joint2:j1
+    const int CPCJointLHElevator         = 12; // PRM:/r3/c1/c2-Joint2:j2
+    const int CPCJointLHKnee             = 13; // PRM:/r3/c1/c2/c3-Joint2:j3
+    const int CPCSensorLHPaw             = 14; // PRM:/r3/c1/c2/c3/c4-Sensor:s4
+    const int CPCJointRFRotator          = 15; // PRM:/r4/c1-Joint2:j1
+    const int CPCJointRFElevator         = 16; // PRM:/r4/c1/c2-Joint2:j2
+    const int CPCJointRFKnee             = 17; // PRM:/r4/c1/c2/c3-Joint2:j3
+    const int CPCSensorRFPaw             = 18; // PRM:/r4/c1/c2/c3/c4-Sensor:s4
+    const int CPCJointRHRotator          = 19; // PRM:/r5/c1-Joint2:j1
+    const int CPCJointRHElevator         = 20; // PRM:/r5/c1/c2-Joint2:j2
+    const int CPCJointRHKnee             = 21; // PRM:/r5/c1/c2/c3-Joint2:j3
+    const int CPCSensorRHPaw             = 22; // PRM:/r5/c1/c2/c3/c4-Sensor:s4
+    const int CPCSensorThermoSensor      = 23; // PRM:/r6/t1-Sensor:t1
+    const int CPCSensorBackSwitch        = 24; // PRM:/r6/s1-Sensor:s1
+    const int CPCSensorTailLeftSwitch    = 25; // PRM:/r6/s2-Sensor:s2  (ERS-220 only)
+    const int CPCSensorTailCenterSwitch  = 26; // PRM:/r6/s3-Sensor:s3  (ERS-220 only)
+    const int CPCSensorTailRightSwitch   = 27; // PRM:/r6/s4-Sensor:s4  (ERS-220 only)
+    const int CPCSensorAccelFB           = 28; // PRM:/a1-Sensor:a1
+    const int CPCSensorAccelLR           = 29; // PRM:/a2-Sensor:a2
+    const int CPCSensorAccelUD           = 30; // PRM:/a3-Sensor:a3
 	//@}
 
 }
@@ -594,11 +611,13 @@ namespace ERS220Info {
  * @brief Defines RobotInfo namespace for ERS-220 models, gives some information about the robot's capabilities, such as joint counts, offsets, names and PID values
  * @author Daishi MORI (Creator)
  *
+ * Mad props to Daishi MORI, the 220 master chief, for porting to the 220 ;)
+ *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.27 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.38 $
  * $State: Exp $
- * $Date: 2006/10/04 02:41:51 $
+ * $Date: 2007/11/09 19:01:14 $
  */
 
 #endif
