@@ -5,15 +5,17 @@
 #ifndef INCLUDED_ERS2xxInfo_h
 #define INCLUDED_ERS2xxInfo_h
 
-#include <math.h>
-#ifndef PLATFORM_APERIOS
-typedef unsigned short word; //!< otherwise defined in Types.h
-#else
-#include <Types.h>
-#endif
+#include "CommonERSInfo.h"
+#include "ERS210Info.h"
+#include "ERS220Info.h"
+#include <iostream>
 
-#include "CommonInfo.h"
-using namespace RobotInfo;
+// see http://tekkotsu.org/porting.html#configuration for more information on TGT_HAS_* flags
+#if defined(TGT_ERS2xx)
+#	define TGT_HAS_LEDS 22
+#	define TGT_HAS_BUTTONS 11
+#	define TGT_HAS_IR_DISTANCE 1
+#endif
 
 //! Contains information about the ERS-2xx series of robot, such as number of joints, PID defaults, timing information, etc.
 /*! This is a compatability mode, which allows dual-booting
@@ -25,7 +27,7 @@ namespace ERS2xxInfo {
 	//       ROBOT CONFIGURATION
 	// *******************************
 
-	const char* const RobotName="ERS-2xx"; //!< the name of the model, to be used for logging and remote GUIs
+	extern const char* const TargetName; //!< the name of the model, to be used for logging and remote GUIs
 
 	const unsigned int FrameTime=8;        //!< time between frames in the motion system (milliseconds)
 	const unsigned int NumFrames=4;        //!< the number of frames per buffer (don't forget also double buffered)
@@ -36,6 +38,12 @@ namespace ERS2xxInfo {
 	//!Corresponds to entries in ERS2xxInfo::PrimitiveName, defined at the end of this file, these are the primary grouping
 	/*!Right now all binary joints are slow, but perhaps this won't always be the case... hence the IsFast/Slow bitmasks to select which type, in order to be more general */
 	//!@name Output Types Information
+	const unsigned NumWheels = 0; //!< no wheels, just legs
+	
+	const unsigned JointsPerArm   =  0; //!< no arms, just legs
+	const unsigned NumArms        =  0; //!< no arms, just legs
+	const unsigned NumArmJoints   =  JointsPerArm*NumArms;
+	
 	const unsigned JointsPerLeg   =  3; //!< The number of joints per leg
 	const unsigned NumLegs        =  4; //!< The number of legs
 	const unsigned NumLegJoints   =  JointsPerLeg*NumLegs; //!< the TOTAL number of joints on ALL legs
@@ -48,7 +56,7 @@ namespace ERS2xxInfo {
 	const unsigned NumLEDs        =  22; //!< The number of LEDs which can be controlled
 	
 	const unsigned NumPIDJoints   = NumLegJoints+NumHeadJoints+NumTailJoints+NumMouthJoints; //!< The number of joints which use PID motion - everything except ears
-	const unsigned NumBinJoints   = NumEarJoints; //!< The number of binary joints - just the ears
+	const unsigned NumBinJoints   = NumEarJoints; //!< The number of binary joints - just the ears (Aperios only)
 	const unsigned NumOutputs     = NumPIDJoints + NumBinJoints + NumLEDs; //!< the total number of outputs
 	const unsigned NumReferenceFrames = NumOutputs + 1 + NumLegs + 1 + 1; //!< for the base, paw, camera, and IR sensor reference frames
 
@@ -83,56 +91,9 @@ namespace ERS2xxInfo {
 		// for binary joints
 		false, false
 	};
-
-	//! we need this so you can tell programmatically which joints are "real" and which are "fake" in compatability mode
-	const bool IsRealERS210[NumOutputs] = {
-		// for PID joints
-		true, true, true, //legs
-		true, true, true,
-		true, true, true,
-		true, true, true,
-		true, true, true, //head
-		true, true,       //tail
-		true,             //mouth
-		// for LEDs
-		true, true, true,           // face left side LEDs x3
-		true, true, true,           // face right side LEDs x3
-		true,                       // head mode LED x1
-		false, false, false,        // back left multi LEDs x3
-		false, false, false,        // back right multi LEDs x3
-		false, false, false,        // tail LEDs x3
-		false, false, false,        // face front LEDs x3
-		false,                      // retractable head light x1
-		true, true,                 // tail red/blue from 210
-		// for binary joints
-		true, true
-	};
-
-	//! we need this so you can tell programmatically which joints are "real" and which are "fake" in compatability mode
-	const bool IsRealERS220[NumOutputs] = {
-		// for PID joints
-		true, true, true, //legs
-		true, true, true,
-		true, true, true,
-		true, true, true,
-		true, true, true, //head
-		false, false,     //tail
-		false,            //mouth
-		// for LEDs
-		true, true, true,           // face left side LEDs x3
-		true, true, true,           // face right side LEDs x3
-		true,                       // head mode LED x1
-		true, true, true,           // back left multi LEDs x3
-		true, true, true,           // back right multi LEDs x3
-		true, true, true,           // tail LEDs x3
-		true, true, true,           // face front LEDs x3
-		true,                       // retractable head light x1
-		false, false,               // tail red/blue from 210
-		// for binary joints
-		false, false
-	};
-
-
+	
+	
+	
 	// *******************************
 	//         OUTPUT OFFSETS
 	// *******************************
@@ -156,6 +117,29 @@ namespace ERS2xxInfo {
 	const unsigned CameraFrameOffset = PawFrameOffset+NumLegs; //!< Use with kinematics to refer to camera reference frame
 	const unsigned IRFrameOffset = CameraFrameOffset+1; //!< Use with kinematics to refer to infrared (distance) sensor reference frame
 
+	//! the ordering of legs
+	enum LegOrder_t {
+		LFrLegOrder = 0, //!< left front leg
+		RFrLegOrder,     //!< right front leg
+		LBkLegOrder,     //!< left back leg
+		RBkLegOrder      //!< right back leg
+	};
+	
+	//! The offsets within appendages (the legs)  Note that the ordering matches the actual physical ordering of joints on the appendage (and not that of the head's TPROffset_t's)
+	enum REKOffset_t {
+		RotatorOffset=0, //!< moves leg forward or backward along body
+		ElevatorOffset,  //!< moves leg toward or away from body
+		KneeOffset       //!< moves knee
+	};
+	
+	//! The offsets of appendages with tilt (elevation), pan (heading), and roll or nod joints (i.e. head)  Note that the ordering matches the actual physical ordering of joints on the appendage (and not that of the leg's REKOffset_t's)
+	enum TPROffset_t {
+		TiltOffset = 0, //!< tilt/elevation (vertical)
+		PanOffset,      //!< pan/heading (horizontal)
+		RollOffset,      //!< roll (rotational)
+		NodOffset=RollOffset       //!< nod (second tilt)
+	};
+	
 	//! The offsets of the individual legs
 	enum LegOffset_t {
 		LFrLegOffset = LegOffset+LFrLegOrder*JointsPerLeg, //!< beginning of left front leg
@@ -275,13 +259,13 @@ namespace ERS2xxInfo {
 	//! selects all of the leds
 	const LEDBitMask_t AllLEDMask  = (LEDBitMask_t)~0;
 	//@}
-
-
+	
+	
+	
 	// *******************************
 	//          INPUT OFFSETS
 	// *******************************
 
-
 	//! The order in which inputs should be stored
 	//!@name Input Offsets
 
@@ -291,7 +275,7 @@ namespace ERS2xxInfo {
 	 *  Note that the chest (power) button is not a normal button.  It kills
 	 *  power to the motors at a hardware level, and isn't sensed in the
 	 *  normal way.  If you want to know when it is pressed (and you are
-	 *  about to shut down) see PowerSourceID::PauseSID.
+	 *  about to shut down) see PowerSrcID::PauseSID.
 	 *
 	 *  @see WorldState::buttons @see ButtonSourceID_t */
 	enum ButtonOffset_t {
@@ -342,46 +326,44 @@ namespace ERS2xxInfo {
 	//@}
 
 
-	//! The length of the strings used for each of the outputs in outputNames (doesn't include null term)
-	const unsigned outputNameLen = 9;
-	//! A name of uniform length for referring to joints - handy for posture files, etc.
+	//! Names for each of the outputs
 	const char* const outputNames[NumOutputs] = {
 		"LFr:rotor",
 		"LFr:elvtr",
-		"LFr:knee~",
+		"LFr:knee",
 		"RFr:rotor",
 		"RFr:elvtr",
-		"RFr:knee~",
+		"RFr:knee",
 		"LBk:rotor",
 		"LBk:elvtr",
-		"LBk:knee~",
+		"LBk:knee",
 		"RBk:rotor",
 		"RBk:elvtr",
-		"RBk:knee~",
+		"RBk:knee",
 		
 		"NECK:tilt",
-		"NECK:pan~",
+		"NECK:pan",
 		"NECK:roll",
 		
 		"TAIL:tilt",
-		"TAIL:pan~",
+		"TAIL:pan",
 		
-		"MOUTH~~~~",
+		"MOUTH",
 		
-		"LED:botL~",
-		"LED:botR~",
-		"LED:midL~",
-		"LED:midR~",
-		"LED:topL~",
-		"LED:topR~",
+		"LED:botL",
+		"LED:botR",
+		"LED:midL",
+		"LED:midR",
+		"LED:topL",
+		"LED:topR",
 		"LED:topBr",
 		
-		"LED:bkL1~",                // "LED:tlBlu" of ERS-210
-		"LED:bkL2~",                // "LED:tlRed" of ERS-210
-		"LED:bkL3~",
-		"LED:bkR3~",
-		"LED:bkR2~",
-		"LED:bkR1~",
+		"LED:bkL1",                // "LED:tlBlu" of ERS-210
+		"LED:bkL2",                // "LED:tlRed" of ERS-210
+		"LED:bkL3",
+		"LED:bkR3",
+		"LED:bkR2",
+		"LED:bkR1",
 		"LED:tailL",
 		"LED:tailC",
 		"LED:tailR",
@@ -393,11 +375,54 @@ namespace ERS2xxInfo {
 		"LED:tlRed",
 		"LED:tlBlu",
 		
-		"EAR:left~",
+		"EAR:left",
 		"EAR:right"
 	};
 	
-
+	
+	//! provides polymorphic robot capability detection/mapping
+	class ERS2xxCapabilities : public Capabilities {
+	public:
+		//! constructor
+		ERS2xxCapabilities()
+		: Capabilities(TargetName,NumOutputs,outputNames,NumButtons,buttonNames,NumSensors,sensorNames,PIDJointOffset,NumPIDJoints,LEDOffset,NumLEDs)
+		{
+			// ers-7 button alias
+			buttonToIndex["HeadBut"]=HeadButOffset;
+#ifdef TGT_ERS2xx
+			if(detectModel() == ERS210Info::TargetName) {
+				fakeOutputs.insert(BackLeft1LEDOffset);
+				fakeOutputs.insert(BackLeft2LEDOffset);
+				fakeOutputs.insert(BackLeft3LEDOffset);
+				fakeOutputs.insert(BackRight3LEDOffset);
+				fakeOutputs.insert(BackRight2LEDOffset);
+				fakeOutputs.insert(BackRight1LEDOffset);
+				fakeOutputs.insert(TailLeftLEDOffset);
+				fakeOutputs.insert(TailCenterLEDOffset);
+				fakeOutputs.insert(TailRightLEDOffset);
+				fakeOutputs.insert(FaceFrontBLEDOffset);
+				fakeOutputs.insert(FaceFrontALEDOffset);
+				fakeOutputs.insert(FaceFrontCLEDOffset);
+				fakeOutputs.insert(RetractableHeadLEDOffset);
+			} else if(detectModel() == ERS220Info::TargetName) {
+				for(unsigned int i=TailOffset; i<TailOffset+NumTailJoints; ++i)
+					fakeOutputs.insert(i);
+				for(unsigned int i=MouthOffset; i<MouthOffset+NumMouthJoints; ++i)
+					fakeOutputs.insert(i);
+				fakeOutputs.insert(TlBluLEDOffset);
+				fakeOutputs.insert(TlRedLEDOffset);
+				for(unsigned int i=EarOffset; i<EarOffset+NumEarJoints; ++i)
+					fakeOutputs.insert(i);
+			} else {
+				std::cerr << "ERS2xxCapabilities running on unknown model!" << std::endl;
+			}
+#endif
+		}
+	};
+	//! allocation declared in RobotInfo.cc
+	extern ERS2xxCapabilities capabilities;
+	
+	
 	//! the joint identifier strings used to refer to specific joints in OPEN-R (but not needed for others)
 	/*!@showinitializer 
 	 * @warning IMPORTANT!!!!  DO NOT CHANGE THE ORDER OF ITEMS IN THIS TABLE!!!\n
@@ -637,10 +662,10 @@ namespace ERS2xxInfo {
  * @author Daishi MORI (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.21 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.32 $
  * $State: Exp $
- * $Date: 2006/10/04 02:41:51 $
+ * $Date: 2007/11/09 19:01:14 $
  */
 
 #endif
