@@ -2,15 +2,14 @@
 #ifndef INCLUDED_ERS7Info_h
 #define INCLUDED_ERS7Info_h
 
-#include <math.h>
-#ifndef PLATFORM_APERIOS
-typedef unsigned short word; //!< otherwise defined in Types.h
-#else
-#include <Types.h>
-#endif
+#include "Shared/CommonERSInfo.h"
 
-#include "CommonInfo.h"
-using namespace RobotInfo;
+// see http://tekkotsu.org/porting.html#configuration for more information on TGT_HAS_* flags
+#if defined(TGT_ERS7)
+#	define TGT_HAS_LEDS 27
+#	define TGT_HAS_BUTTONS 10
+#	define TGT_HAS_IR_DISTANCE 3
+#endif
 
 //! Contains information about the ERS-7 Robot, such as number of joints, PID defaults, timing information, etc.
 /*! 
@@ -29,7 +28,7 @@ These values are formed by specifying a @e section offset, plus a @e specific of
 
 For most joints, the positive direction is "up", and the 0 position yields a forward looking, fully extended standing posture.
 
-- {L,R}{FrBk}LegOffset - #NumLegs combinations, each with #JointsPerLeg items, add #REKOffset_t; see also #LegOffset_t
+- {L,R}{FrBk}LegOffset - #NumLegs combinations, each with #JointsPerLeg items, add REKOffset_t; see also LegOffset_t
   - + #RotatorOffset: positive moves "out", away from body
   - + #ElevatorOffset: positive moves up, away from body
   - + #KneeOffset: positive bends knee (slight negative possible)
@@ -51,7 +50,7 @@ It happens that these joints can also be grouped by the @e type of joint, so the
 - BinJointOffset - #NumBinJoints items, solenoids, such as the ears (if any) which flip between two positions
 - #NumOutputs - total number of outputs available
 
-LEDs are often handled in groups to display patterns.  Some functions take an #LEDBitMask_t
+LEDs are often handled in groups to display patterns.  Some functions take an LEDBitMask_t
 parameter, which allows you to specify a set of several LEDs in a single parameter.  
 For any given LED offset @c fooLEDOffset, the corresponding bitmask constant is @c fooLEDMask.
 Alternatively, you could calculate the bitmask of @c fooLEDOffset by <code>1&lt;&lt;(fooLEDOffset-LEDOffset)</code>.
@@ -64,7 +63,7 @@ namespace ERS7Info {
 	//       ROBOT CONFIGURATION
 	// *******************************
 
-	const char* const RobotName="ERS-7"; //!< the name of the model, to be used for logging and remote GUIs
+	extern const char* const TargetName; //!< the name of the model, to be used for logging and remote GUIs
 
 	const unsigned int FrameTime=8;        //!< time between frames in the motion system (milliseconds)
 	const unsigned int NumFrames=4;        //!< the number of frames per buffer (don't forget also double buffered)
@@ -75,6 +74,12 @@ namespace ERS7Info {
 	//!Corresponds to entries in ERS7Info::PrimitiveName, defined at the end of this file, these are the primary grouping
 	/*!Right now all binary joints are slow, but perhaps this won't always be the case... hence the IsFast/Slow bitmasks to select which type, in order to be more general */
 	//!@name Output Types Information
+	const unsigned NumWheels = 0; //!< no wheels, just legs
+	
+	const unsigned JointsPerArm   =  0; //!< no arms, just legs
+	const unsigned NumArms        =  0; //!< no arms, just legs
+	const unsigned NumArmJoints   =  JointsPerArm*NumArms;
+	
 	const unsigned JointsPerLeg   =  3; //!< The number of joints per leg
 	const unsigned NumLegs        =  4; //!< The number of legs
 	const unsigned NumLegJoints   =  JointsPerLeg*NumLegs; //!< the TOTAL number of joints on ALL legs
@@ -106,15 +111,10 @@ namespace ERS7Info {
 		true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true, //leds
 		true,true //ears
 	};
-	//! we need this so you can tell programmatically which joints are "real" and which are "fake" in a compatability mode
-	/*! @hideinitializer */
-	const bool IsRealERS7[NumOutputs] = { 
-		true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true, //PID joints
-		true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,false, //leds
-		true,true //ears
-	};
 	//@}
-
+	
+	
+	
 	// *******************************
 	//         OUTPUT OFFSETS
 	// *******************************
@@ -141,7 +141,29 @@ namespace ERS7Info {
 	const unsigned FarIRFrameOffset = NearIRFrameOffset+1; //!< Use with kinematics to refer to long-range infrared (distance) sensor reference frame
 	const unsigned ChestIRFrameOffset = FarIRFrameOffset+1; //!< Use with kinematics to refer to chest-mounted infrared (distance) sensor reference frame
 
-
+	//! the ordering of legs
+	enum LegOrder_t {
+		LFrLegOrder = 0, //!< left front leg
+		RFrLegOrder,     //!< right front leg
+		LBkLegOrder,     //!< left back leg
+		RBkLegOrder      //!< right back leg
+	};
+	
+	//! The offsets within appendages (the legs)  Note that the ordering matches the actual physical ordering of joints on the appendage (and not that of the head's TPROffset_t's)
+	enum REKOffset_t {
+		RotatorOffset=0, //!< moves leg forward or backward along body
+		ElevatorOffset,  //!< moves leg toward or away from body
+		KneeOffset       //!< moves knee
+	};
+	
+	//! The offsets of appendages with tilt (elevation), pan (heading), and roll or nod joints (i.e. head)  Note that the ordering matches the actual physical ordering of joints on the appendage (and not that of the leg's REKOffset_t's)
+	enum TPROffset_t {
+		TiltOffset = 0, //!< tilt/elevation (vertical)
+		PanOffset,      //!< pan/heading (horizontal)
+		RollOffset,      //!< roll (rotational)
+		NodOffset=RollOffset       //!< nod (second tilt)
+	};
+	
 	//! The offsets of the individual legs, add #REKOffset_t value to access specific joint
 	/*! @hideinitializer */
 	enum LegOffset_t {
@@ -233,8 +255,9 @@ namespace ERS7Info {
 	//! selects all of the leds
 	const LEDBitMask_t AllLEDMask  = (LEDBitMask_t)~0;
 	//@}
-
-
+	
+	
+	
 	// *******************************
 	//          INPUT OFFSETS
 	// *******************************
@@ -249,7 +272,7 @@ namespace ERS7Info {
 	 *  Note that the chest (power) button is not a normal button.  It kills
 	 *  power to the motors at a hardware level, and isn't sensed in the
 	 *  normal way.  If you want to know when it is pressed (and you are
-	 *  about to shut down) see PowerSourceID::PauseSID.
+	 *  about to shut down) see PowerSrcID::PauseSID.
 	 *
 	 *  @see WorldState::buttons @see ButtonSourceID_t
 	 * @hideinitializer */
@@ -280,6 +303,7 @@ namespace ERS7Info {
 	/*! @see WorldState::sensors[] */
 	enum SensorOffset_t {
 		NearIRDistOffset = 0,  //!< in millimeters, ranges from 50 to 500
+		IRDistOffset=NearIRDistOffset, //!< alias for ERS-2xx's solitary range finder
 		FarIRDistOffset,  //!< in millimeters, ranges from 200 to 1500
 		ChestIRDistOffset,  //!< in millimeters, ranges from 100 to 900
 		BAccelOffset, //!< backward acceleration, in @f$m/s^2@f$, negative if sitting on butt (positive for faceplant)
@@ -302,20 +326,18 @@ namespace ERS7Info {
 	//@}
 
 
-	//! The length of the strings used for each of the outputs in outputNames (doesn't include null term)
-	const unsigned outputNameLen = 9;
-	//! A name of uniform length for referring to joints - handy for posture files, etc.
+	//! Names for each of the outputs
 	const char* const outputNames[NumOutputs] = {
-		"LFr:rotor","LFr:elvtr","LFr:knee~",
-		"RFr:rotor","RFr:elvtr","RFr:knee~",
-		"LBk:rotor","LBk:elvtr","LBk:knee~",
-		"RBk:rotor","RBk:elvtr","RBk:knee~",
+		"LFr:rotor","LFr:elvtr","LFr:knee",
+		"RFr:rotor","RFr:elvtr","RFr:knee",
+		"LBk:rotor","LBk:elvtr","LBk:knee",
+		"RBk:rotor","RBk:elvtr","RBk:knee",
 		
-		"NECK:tilt","NECK:pan~","NECK:nod~",
+		"NECK:tilt","NECK:pan","NECK:nod",
 		
-		"TAIL:tilt",	"TAIL:pan~",
+		"TAIL:tilt",	"TAIL:pan",
 		
-		"MOUTH~~~~",
+		"MOUTH",
 		
 		"LED:headC","LED:headW",
 		"LED:modeR","LED:modeG",
@@ -327,10 +349,44 @@ namespace ERS7Info {
 		"LED:bkRrC","LED:bkRrW",
 		"LED:ABmod",
 		
-		"EAR:left~","EAR:right"
+		"EAR:left","EAR:right"
 	};
 	
-
+	
+	//! provides polymorphic robot capability detection/mapping
+	class ERS7Capabilities : public Capabilities {
+	public:
+		//! constructor
+		ERS7Capabilities()
+		: Capabilities(TargetName,NumOutputs,outputNames,NumButtons,buttonNames,NumSensors,sensorNames,PIDJointOffset,NumPIDJoints,LEDOffset,NumLEDs)
+		{
+			// 2xx button aliases
+			buttonToIndex["HeadFrBut"]=HeadFrButOffset; // aliased to HeadButOffset
+			buttonToIndex["BackBut"]=BackButOffset; //aliased to MiddleBackButOffset
+			// 210 led aliases
+			outputToIndex["LED:botL"]=BotLLEDOffset; // aliased to face panel...
+			outputToIndex["LED:botR"]=BotRLEDOffset;
+			outputToIndex["LED:midL"]=MidLLEDOffset;
+			outputToIndex["LED:midR"]=MidRLEDOffset;
+			outputToIndex["LED:topL"]=TopLLEDOffset;
+			outputToIndex["LED:topR"]=TopRLEDOffset;
+			outputToIndex["LED:topBr"]=TopBrLEDOffset;
+			outputToIndex["LED:tlRed"]=TlRedLEDOffset; // aliased to the red back light
+			outputToIndex["LED:tlBlu"]=TlBluLEDOffset; // aliased to the blue back light
+			// 220 led aliases
+			outputToIndex["LED:bkL1"]=TlBluLEDOffset; // aliased to the blue back light
+			outputToIndex["LED:bkL2"]=TlRedLEDOffset; // aliased to the red back light
+			// 2xx sensor aliases
+			sensorToIndex["IRDist"]=IRDistOffset; // aliased to the near IR sensor
+			
+			// the AB switch is a meta-output, don't tell Aperios about it
+			fakeOutputs.insert(LEDABModeOffset);
+		}
+	};
+	//! allocation declared in RobotInfo.cc
+	extern ERS7Capabilities capabilities;
+	
+	
 	//! the joint identifier strings used to refer to specific joints in OPEN-R (but not needed for others)
 	/*!@showinitializer 
 	 * The offset consts defined in this file correspond to this table and will make life easier
@@ -475,7 +531,7 @@ namespace ERS7Info {
 	#define __RI_RAD_FLAG
 	#endif
 	
-	//! This table holds the software limits of each of the outputs, first index is the output offset, second index is #MinMaxRange_t (i.e. #MinRange or #MaxRange)
+	//! This table holds the software limits of each of the outputs, first index is the output offset, second index is MinMaxRange_t (i.e. MinRange or MaxRange)
 	const double outputRanges[NumOutputs][2] =
 		{
 			{ RAD(-115),RAD(130) },{ RAD(-10),RAD(88) },{ RAD(-25),RAD(122) }, //left front REK
@@ -497,8 +553,8 @@ namespace ERS7Info {
 			{0,1},{0,1} //ears
 		};
 
-	//! This table holds the mechanical limits of each of the outputs, first index is the output offset, second index is #MinMaxRange_t (i.e. #MinRange or #MaxRange)
-	/*! Same as #outputLimits, don't know actual values because they were never specified by Sony */
+	//! This table holds the mechanical limits of each of the outputs, first index is the output offset, second index is MinMaxRange_t (i.e. MinRange or MaxRange)
+	/*! Same as #outputRanges, don't know actual values because they were never specified by Sony */
 	const double mechanicalLimits[NumOutputs][2] =
 		{
 			{ RAD(-115),RAD(130) },{ RAD(-10),RAD(88) },{ RAD(-25),RAD(122) }, //left front REK
@@ -528,40 +584,40 @@ namespace ERS7Info {
 
 	/*! @name CPC IDs
 	 * Values defined by OPEN-R, used to interface with lower level OPEN-R code to read sensors - values @e don't correspond to order of ERS7Info::PrimitiveName */
-	static const int CPCJointMouth      =  0; //!< Mouth                           
-	static const int CPCSwitchChin      =  1; //!< Chin sensor                     
-	static const int CPCJointNeckNod    =  2; //!< Neck tilt2                      
-	static const int CPCSensorHead      =  3; //!< Head sensor                     
-	static const int CPCSensorNearPSD   =  4; //!< Head distance sensor(near)      
-	static const int CPCSensorFarPSD    =  5; //!< Head distance sensor(far)       
-	static const int CPCJointNeckPan    =  6; //!< Neck pan                        
-	static const int CPCJointNeckTilt   =  7; //!< Neck tilt1                      
-	static const int CPCSwitchLFPaw     =  8; //!< Left fore leg  paw sensor       
-	static const int CPCJointLFKnee     =  9; //!< Left fore legJ3                 
-	static const int CPCJointLFElevator = 10; //!< Left fore legJ2                 
-	static const int CPCJointLFRotator  = 11; //!< Left fore legJ1                 
-	static const int CPCSwitchLHPaw     = 12; //!< Left hind leg  paw sensor       
-	static const int CPCJointLHKnee     = 13; //!< Left hind legJ3                 
-	static const int CPCJointLHElevator = 14; //!< Left hind legJ2                 
-	static const int CPCJointLHRotator  = 15; //!< Left hind legJ1                 
-	static const int CPCSwitchRFPaw     = 16; //!< Right fore leg  paw sensor      
-	static const int CPCJointRFKnee     = 17; //!< Right fore legJ3                
-	static const int CPCJointRFElevator = 18; //!< Right fore legJ2                
-	static const int CPCJointRFRotator  = 19; //!< Right fore legJ1                
-	static const int CPCSwitchRHPaw     = 20; //!< Right hind leg  paw sensor      
-	static const int CPCJointRHKnee     = 21; //!< Right hind legJ3                
-	static const int CPCJointRHElevator = 22; //!< Right hind legJ2                
-	static const int CPCJointRHRotator  = 23; //!< Right hind legJ1                
-	static const int CPCJointTailTilt   = 24; //!< Tail tilt                       
-	static const int CPCJointTailPan    = 25; //!< Tail pan                        
-	static const int CPCSensorAccelFB   = 26; //!< Acceleration sensor(front-back) 
-	static const int CPCSensorAccelLR   = 27; //!< Acceleration sensor(right-left) 
-	static const int CPCSensorAccelUD   = 28; //!< Acceleration sensor(up-down)    
-	static const int CPCSensorChestPSD  = 29; //!< Chest distance sensor           
-	static const int CPCSwitchWireless  = 30; //!< Wireless LAN switch             
-	static const int CPCSensorBackRear  = 31; //!< Back sensor(rear)               
-	static const int CPCSensorBackMiddle= 32; //!< Back sensor(middle)             
-	static const int CPCSensorBackFront = 33; //!< Back sensor(front)              
+	const int CPCJointMouth      =  0; //!< Mouth                           
+	const int CPCSwitchChin      =  1; //!< Chin sensor                     
+	const int CPCJointNeckNod    =  2; //!< Neck tilt2                      
+	const int CPCSensorHead      =  3; //!< Head sensor                     
+	const int CPCSensorNearPSD   =  4; //!< Head distance sensor(near)      
+	const int CPCSensorFarPSD    =  5; //!< Head distance sensor(far)       
+	const int CPCJointNeckPan    =  6; //!< Neck pan                        
+	const int CPCJointNeckTilt   =  7; //!< Neck tilt1                      
+	const int CPCSwitchLFPaw     =  8; //!< Left fore leg  paw sensor       
+	const int CPCJointLFKnee     =  9; //!< Left fore legJ3                 
+	const int CPCJointLFElevator = 10; //!< Left fore legJ2                 
+	const int CPCJointLFRotator  = 11; //!< Left fore legJ1                 
+	const int CPCSwitchLHPaw     = 12; //!< Left hind leg  paw sensor       
+	const int CPCJointLHKnee     = 13; //!< Left hind legJ3                 
+	const int CPCJointLHElevator = 14; //!< Left hind legJ2                 
+	const int CPCJointLHRotator  = 15; //!< Left hind legJ1                 
+	const int CPCSwitchRFPaw     = 16; //!< Right fore leg  paw sensor      
+	const int CPCJointRFKnee     = 17; //!< Right fore legJ3                
+	const int CPCJointRFElevator = 18; //!< Right fore legJ2                
+	const int CPCJointRFRotator  = 19; //!< Right fore legJ1                
+	const int CPCSwitchRHPaw     = 20; //!< Right hind leg  paw sensor      
+	const int CPCJointRHKnee     = 21; //!< Right hind legJ3                
+	const int CPCJointRHElevator = 22; //!< Right hind legJ2                
+	const int CPCJointRHRotator  = 23; //!< Right hind legJ1                
+	const int CPCJointTailTilt   = 24; //!< Tail tilt                       
+	const int CPCJointTailPan    = 25; //!< Tail pan                        
+	const int CPCSensorAccelFB   = 26; //!< Acceleration sensor(front-back) 
+	const int CPCSensorAccelLR   = 27; //!< Acceleration sensor(right-left) 
+	const int CPCSensorAccelUD   = 28; //!< Acceleration sensor(up-down)    
+	const int CPCSensorChestPSD  = 29; //!< Chest distance sensor           
+	const int CPCSwitchWireless  = 30; //!< Wireless LAN switch             
+	const int CPCSensorBackRear  = 31; //!< Back sensor(rear)               
+	const int CPCSensorBackMiddle= 32; //!< Back sensor(middle)             
+	const int CPCSensorBackFront = 33; //!< Back sensor(front)              
 	//@}
 
 }
@@ -571,10 +627,10 @@ namespace ERS7Info {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.35 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.47 $
  * $State: Exp $
- * $Date: 2006/10/04 02:41:51 $
+ * $Date: 2007/11/09 19:01:14 $
  */
 
 #endif
