@@ -1,5 +1,5 @@
 //-*-c++-*-
-#ifndef INCLUDED_Factory_h_
+#if 0
 #define INCLUDED_Factory_h_
 
 //! Base class for Factory templated subclasses
@@ -59,10 +59,10 @@ public:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.7 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.8 $
  * $State: Exp $
- * $Date: 2005/07/26 03:11:20 $
+ * $Date: 2007/05/21 17:02:37 $
  */
 
 #endif
