@@ -2,17 +2,23 @@
 #ifndef INCLUDED_LoadSave_h
 #define INCLUDED_LoadSave_h
 
-#include <string>
+#include <cstring>
+#include <malloc.h>
 #include <sys/param.h>
 #include <stdexcept>
 #include <stdarg.h>
-#include "Shared/attributes.h"
+#include "attributes.h"
 
 #ifdef PLATFORM_APERIOS
 //! prototype declared only on PLATFORM_APERIOS; system provides an implementation, but apparently no API declaration
 int vasprintf(char** ret, const char* format, va_list al);
 #endif
 
+/*! @def LOADSAVE_SWAPBYTES
+ *  @brief Set to 0 on platforms which don't actually need to swap bytes, 1 otherwise.  If not set externally, will attempt to auto-detect.
+ *  Swapping is performed to standardize on little-endian byte order.  Mainly because this is what we used on the Aibo, which
+ *  was the most processor-starved platform.  If running embedded on other platforms, you may want to reverse the logic
+ *  for determining whether byte swapping will be performed! */
 #ifndef LOADSAVE_SWAPBYTES
 
 #ifdef BYTE_ORDER
@@ -458,9 +464,9 @@ class LoadSave {
 	//inline static unsigned int encode(const void* x, char buf[], unsigned int cap) throw() { return encode(static_cast<unsigned long long>(x),buf,cap); }
 	//inline static unsigned int decode(void*& x, const char buf[], unsigned int cap) throw() { unsigned long long tmp; unsigned int used=decode(tmp,buf,cap); if(used==0) return 0; x=reinterpret_cast<void*>(tmp); return used; }
 	
-	inline static unsigned int encode(const std::string& x, char buf[], unsigned int cap) throw() { if(cap<sizeof(unsigned int)+x.size()+1) return 0; memcpy(buf+encode(x.size(),buf,cap),x.c_str(),x.size()+1); return x.size()+stringpad; }
+	inline static unsigned int encode(const std::string& x, char buf[], unsigned int cap) throw() { if(cap<sizeof(unsigned int)+x.size()+1) return 0; memcpy(buf+encode(static_cast<unsigned int>(x.size()),buf,cap),x.c_str(),x.size()+1); return x.size()+stringpad; }
 	inline static unsigned int decode(std::string& x, const char buf[], unsigned int cap) throw() { if(cap<sizeof(unsigned int)) return 0; unsigned int sz=0; decode(sz,buf,cap); if(cap<sizeof(unsigned int)+sz+1) return 0; x.assign(buf+sizeof(unsigned int),sz); return x.size()+stringpad; }
-	inline static unsigned int encode(const std::string& x, FILE* f) throw()                 { encode(x.size(),f); return sizeof(unsigned int)+fwrite(x.c_str(),1,sizeof(x)+1,f); }
+	inline static unsigned int encode(const std::string& x, FILE* f) throw()                 { encode(static_cast<unsigned int>(x.size()),f); return sizeof(unsigned int)+fwrite(x.c_str(),1,sizeof(x)+1,f); }
 	inline static unsigned int decode(std::string& x, FILE* f) throw()                       { unsigned int sz=0; decode(sz,f); char *tmp=new char[sz+1]; if(fread(tmp,1,sz+1,f)!=sz+1) { delete [] tmp; return 0; } x.assign(tmp,sz); delete [] tmp; return sz+stringpad; }
 	
 	inline static unsigned int encode(const char* x, char buf[], unsigned int cap) throw()     { unsigned int sz=strlen(x); if(cap<sizeof(unsigned int)+sz+1) return 0; memcpy(buf+encode(sz,buf,cap),x,sz+1); return sz+stringpad; }
@@ -794,10 +800,10 @@ void LoadSave::decodeIncT(T& value, char*& buf, unsigned int& cap, const char* m
  * @author Daniel Höh (Revisor)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.21 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.24.2.1 $
  * $State: Exp $
- * $Date: 2006/10/03 21:11:51 $
+ * $Date: 2009/02/08 03:34:41 $
  */
 
 #endif
