@@ -6,6 +6,12 @@
 
 namespace ProjectInterface {
 
+	//! default implementation used for #sendCommand (just displays a warning and ignores the call)
+	void noSendCommandErr(const std::string& cmd) {
+		serr->printf("command '%s' ignored because no ProjectInterface::sendCommand() is installed\n",cmd.c_str());
+	}
+	void (*sendCommand)(const std::string& cmd)=noSendCommandErr;
+	
 	bool displayException(const char * file, int line, const char * message, const std::exception* ex) {
 		if(file!=NULL) {
 			serr->printf("Exception caught at %s:%d => ",debuget::extractFilename(file),line);
@@ -30,29 +36,37 @@ namespace ProjectInterface {
 	bool (*uncaughtException)(const char * file, int line, const char * message, const std::exception* ex)=&displayException;
 
 	//! default implementation assigned to lookupColorIndexByName(); checks that #defSegmentedColorGenerator is non-NULL and returns getColorIndex on it
-	unsigned int defLookupColorIndexByName(const std::string& name) {
-		if(defSegmentedColorGenerator==NULL)
-			return -1U;
-		return defSegmentedColorGenerator->getColorIndex(name);
+	color_index defLookupColorIndexByName(const std::string& name) {
+	  if(defSegmentedColorGenerator==NULL)
+	    return -1U;
+	  return defSegmentedColorGenerator->getColorIndex(name);
 	}
-	unsigned int (*lookupColorIndexByName)(const std::string& name)=&defLookupColorIndexByName;
+	color_index (*lookupColorIndexByName)(const std::string& name)=&defLookupColorIndexByName;
 	
 	//! default value initially assigned to lookupColorIndexByRgb(); checks that #defSegmentedColorGenerator is non-NULL and returns getColorIndex on it
-	unsigned int defLookupColorIndexByRgb(const rgb rgbval) {
+	color_index defLookupColorIndexByRgb(const rgb rgbval) {
 		if(defSegmentedColorGenerator==NULL)
 			return -1U;
 		return defSegmentedColorGenerator->getColorIndex(rgbval);
 	}
 	//! returns color index for color with specified "representitive" RGB color
-	unsigned int (*lookupColorIndexByRgb)(const rgb rgbval)=&defLookupColorIndexByRgb;
+	color_index (*lookupColorIndexByRgb)(const rgb rgbval)=&defLookupColorIndexByRgb;
 	
 	//! default implementation assigned to lookupColorRGB(); checks that #defSegmentedColorGenerator is non-NULL and returns getColorRGB on it
-	rgb defLookupColorRGB(unsigned int index) {
+	rgb defLookupColorRGB(color_index cindex) {
 		if(defSegmentedColorGenerator==NULL)
 			return rgb();
-		return defSegmentedColorGenerator->getColorRGB(index);
+		return defSegmentedColorGenerator->getColorRGB(cindex);
 	}
-	rgb (*lookupColorRGB)(unsigned int index)=&defLookupColorRGB;
+	rgb (*lookupColorRGB)(color_index cindex)=&defLookupColorRGB;
+
+        //! default implementation assigned to lookupColorName(); checks that #defSegmentedColorGenerator is non-NULL and returns getColorName on it
+        const char* defLookupColorName(color_index cindex) {
+	  if(defSegmentedColorGenerator==NULL)
+	    return NULL;
+	  return defSegmentedColorGenerator->getColorName(cindex);
+	}
+        const char* (*lookupColorName)(color_index cindex)=&defLookupColorName;
 
 	//! default value initially assigned to lookupNumColors(); checks that #defSegmentedColorGenerator is non-NULL and returns getNumColors on it
 	unsigned int defLookupNumColors() {
@@ -63,27 +77,8 @@ namespace ProjectInterface {
 	//! returns the number of indexed colors which are currently defined
 	unsigned int (*lookupNumColors)() = &defLookupNumColors;
 
-	//! displays an rgb value in the form '[r,g,b]'
-	std::ostream& operator<<(std::ostream &os, const rgb &rgbval) {
-		os << "[" << (unsigned int)rgbval.red
-		   << "," << (unsigned int)rgbval.green
-		   << "," << (unsigned int)rgbval.blue
-		   << "]";
-		return os;
-	}
 
-	//! returns @a rgbval in the form 'r g b'
-	std::string toString(const rgb &rgbval) {
-		char buff[15];
-		snprintf(buff,15,"%d %d %d",rgbval.red,rgbval.green,rgbval.blue);
-		return buff;
-	}
-
-
-
-	//! A collection of the various stages of vision processing.  None of these are absolutely required, but are needed to run included demo behaviors and TekkotsuMon modules
-	/*! @name Vision Setup */
-	//! pointer to generator
+	/*** Vision Setup ***/
 	FilterBankGenerator * defRawCameraGenerator=NULL;
 	FilterBankGenerator * defInterleavedYUVGenerator=NULL;
 	JPEGGenerator * defColorJPEGGenerator=NULL;
@@ -93,11 +88,9 @@ namespace ProjectInterface {
 	SegmentedColorGenerator * defSegmentedColorGenerator=NULL;
 	RLEGenerator * defRLEGenerator=NULL;
 	RegionGenerator * defRegionGenerator=NULL;
-	//@}
-
-	//! Default source IDs for the various generators; These are given default values, but you can reassign them if you like.
-	/*! @name Vision SIDs */
-	//! source id for event
+	
+	
+	/*** Vision SIDs ***/
 	unsigned int visRawCameraSID=0;
 
 	unsigned int visInterleaveSID=0;
@@ -118,18 +111,17 @@ namespace ProjectInterface {
 	unsigned int visBlueBallSID=1;
 	unsigned int visGreenBallSID=2;
 	unsigned int visYellowBallSID=3;
-	unsigned int visHandSID=4;
-	//@}
-
-	//! Allows you to request a particular layer abstractly - this isn't used by the framework, just a suggestion for clarity
-	/*! @name Layer Resolutions */
+	unsigned int visOrangeSID=4;
+	unsigned int visHandSID=visOrangeSID;
+	
+	
+	/*** Layer Resolutions ***/
 	unsigned int doubleLayer=5;
 	unsigned int fullLayer=4;
 	unsigned int halfLayer=3;
 	unsigned int quarterLayer=2;
 	unsigned int eighthLayer=1;
 	unsigned int sixteenthLayer=0;
-	//@}
 
 }
 
@@ -138,9 +130,9 @@ namespace ProjectInterface {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.15 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.22 $
  * $State: Exp $
- * $Date: 2006/09/25 23:31:06 $
+ * $Date: 2007/11/11 06:18:35 $
  */
 
