@@ -17,7 +17,7 @@ namespace std {
 }
 
 //! A collection of the global variables which should be set by a project to use the Tekkotsu framework
-/*! This namespace a few variables needed for initialization of the
+/*! This namespace hold a few variables needed for initialization of the
  *  framework, but mainly declares variables which are used by demo
  *  behaviors.  Although the variables are declared here, and
  *  some default values provided, it is up to your project to define
@@ -52,7 +52,12 @@ namespace ProjectInterface {
 	 *  most sense to implement as a static local variable of the function.
 	 *  (Each call should return the same behavior) */
 	BehaviorBase& startupBehavior();
-
+	
+	//! sends a command to the project, allows GUI elements of the framework to send commands to the hardware abstraction layer
+	/*! Generally commands are assumed to be for the Tekkostu HAL command line,
+	 *  and otherwise this will be left NULL. */
+	extern void (*sendCommand)(const std::string& cmd);
+	
 	//! The exception handler for exceptions which have fallen through to base Tekkotsu functions
 	/*! You can override this to install your own handler by assigning a
 	 *  new function.  This defaults to displayException(), which
@@ -76,32 +81,35 @@ namespace ProjectInterface {
 	
 	//! allows you to override how colors are defined -- by default, this will be set to a function which passes the call to defSegmentedColorGenerator
 	/*! As per SegmentedColorGenerator::getColorIndex(), if @a name is not valid, return -1U */
-	extern unsigned int (*lookupColorIndexByName)(const std::string& name);
+	extern color_index (*lookupColorIndexByName)(const std::string& name);
 	//! allows you to override how colors are defined -- by default, this will be set to a function which passes the call to defSegmentedColorGenerator
-        extern unsigned int (*lookupColorIndexByRgb)(const rgb rgbval);
+	extern color_index (*lookupColorIndexByRgb)(const rgb rgbval);
 	//! allows you to override how colors are defined -- by default, this will be set to a function which passes the call to defSegmentedColorGenerator
 	/*! As per SegmentedColorGenerator::getColorRGB(), if @a index is not valid, return black (rgb()) */
-	extern rgb (*lookupColorRGB)(unsigned int index);
+	extern rgb (*lookupColorRGB)(color_index cindex);
+	//! allows you to override how colors are defined -- by default, this will be set to a function which passes the call to defSegmentedColorGenerator
+	/*! As per SegmentedColorGenerator::getColorRGB(), if @a index is not valid, return black (rgb()) */
+	extern const char* (*lookupColorName)(color_index cindex);
 	
 	//! Returns the index corresponding to a color of specified name by calling lookupColorIndexByName()
 	/*! As per SegmentedColorGenerator::getColorIndex(), if @a name is not valid, return -1U */
-	inline unsigned int getColorIndex(const std::string& name) { if(lookupColorIndexByName==NULL) return -1U; return (*lookupColorIndexByName)(name); }
+	inline color_index getColorIndex(const std::string& name) { if(lookupColorIndexByName==NULL) return -1U; return (*lookupColorIndexByName)(name); }
 	//! Returns the index corresponding to an rgb value  by calling lookupColorIndexByRgb()
-        inline unsigned int getColorIndex(const rgb rgbval) { if(lookupColorIndexByRgb==NULL) return -1U; return (*lookupColorIndexByRgb)(rgbval); }
+	inline color_index getColorIndex(const rgb rgbval) { if(lookupColorIndexByRgb==NULL) return -1U; return (*lookupColorIndexByRgb)(rgbval); }
 	//! Returns rgb value corresponding to a color of specified name by calling lookupColorRGB(lookupColorIndexByName())
 	/*! As per SegmentedColorGenerator::getColorRGB(), if @a name is not valid, return black (rgb()) */
 	inline rgb getColorRGB(const std::string& name)  { if(lookupColorIndexByName==NULL || lookupColorRGB==NULL) return rgb(); return (*lookupColorRGB)((*lookupColorIndexByName)(name)); }
 	//! Returns rgb value corresponding to a color of specified name by calling lookupColorRGB()
 	/*! As per SegmentedColorGenerator::getColorRGB(), if @a index is not valid, return black (rgb()) */
-	inline rgb getColorRGB(unsigned int index)  { if(lookupColorRGB==NULL) return rgb(); return (*lookupColorRGB)(index); }
+	inline rgb getColorRGB(color_index cindex)  { if(lookupColorRGB==NULL) return rgb(); return (*lookupColorRGB)(cindex); }
+
+	//! Returns color name corresponding to specified color index by calling lookupColorName()
+	/*! As per SegmentedColorGenerator::getColorName(), if @a index is not valid, return NULL */
+	inline const char* getColorName(color_index cindex) { if(lookupColorName==NULL) return NULL; return (*lookupColorName)(cindex); }
 	
-  extern unsigned int (*lookupNumColors)();
-  //! Returns the number of colors, obtained from defSegmentedColorGenerator
-  inline unsigned int getNumColors() { if (lookupNumColors == NULL) return -1U; return (*lookupNumColors)(); }
-
-  std::ostream& operator<<(std::ostream &os, const rgb &rgbval);
-  std::string toString(const rgb &rgbval);
-
+	extern unsigned int (*lookupNumColors)();
+	//! Returns the number of colors, obtained from defSegmentedColorGenerator
+	inline unsigned int getNumColors() { if (lookupNumColors == NULL) return -1U; return (*lookupNumColors)(); }
 
 	//! A collection of the various stages of vision processing.  None of these are absolutely required, but are needed to run included demo behaviors and TekkotsuMon modules
 	/*! @name Vision Setup */
@@ -119,7 +127,7 @@ namespace ProjectInterface {
 
 	//! Default source IDs for the various generators; These are given default values, but you can reassign them if you like.
 	/*! @name Vision SIDs */
-	//! source id for event
+	//! source id for vision events from the corresponding pipeline stage or object detector
 	extern unsigned int visRawCameraSID;
 	extern unsigned int visInterleaveSID;
 	extern unsigned int visColorJPEGSID;
@@ -133,7 +141,8 @@ namespace ProjectInterface {
 	extern unsigned int visBlueBallSID;
 	extern unsigned int visGreenBallSID;
 	extern unsigned int visYellowBallSID;
-	extern unsigned int visHandSID;
+	extern unsigned int visOrangeSID;
+	extern unsigned int visHandSID; //!< synonym for #visOrangeSID
 	//@}
 
 	//! Allows you to request a particular layer abstractly - this isn't used by the framework, just a suggestion for clarity
@@ -151,11 +160,11 @@ namespace ProjectInterface {
  * @brief Defines ProjectInterface namespace - a collection of the global variables which should be set by a project to use the Tekkotsu framework
  * @author ejt (Creator)
  *
- * $Author: dst $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.13 $
+ * $Author: ejt $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.19 $
  * $State: Exp $
- * $Date: 2006/07/14 06:48:55 $
+ * $Date: 2007/06/13 18:14:14 $
  */
 
 #endif
