@@ -96,7 +96,7 @@ int unrollStackFrame(struct StackFrame* curFrame, struct StackFrame* nextFrame)
 	void* nsp=NULL;
 	machineInstruction * nra=NULL;
 
-#ifdef __i386__
+#if defined(__i386__) || defined(__x86_64__) || defined(__amd64__)
 	if(curFrame==NULL)
 		return 0;
 	curFrame->caller=NULL;
@@ -161,7 +161,7 @@ int unrollStackFrame(struct StackFrame* curFrame, struct StackFrame* nextFrame)
 	if(nextFrame==NULL || curFrame==NULL || curFrame->sp==NULL)
 		return 0;
 	
-#ifdef __pic__
+#ifdef __PIC__
 	ins = reinterpret_cast<machineInstruction*>(curFrame->gp-curFrame->ra);
 #else
 	ins = curFrame->ra;
@@ -222,15 +222,15 @@ int unrollStackFrame(struct StackFrame* curFrame, struct StackFrame* nextFrame)
 	
 	if(ins>=INS_BASE) {
 		if(nsp<=curFrame->sp) {
-#ifdef __pic__
-			fprintf(stderr,"stacktrace::unrollStackFrame(sp=%p,ra=%p,gp=%p) directed to invalid next frame: (sp=%p,ra=%p,gp=%p)\n",curFrame->sp,curFrame->ra,curFrame->gp,nsp,nra,reinterpret_cast<size_t*>(nsp)[4]);
+#ifdef __PIC__
+			fprintf(stderr,"stacktrace::unrollStackFrame(sp=%p,ra=%p,gp=%p) directed to invalid next frame: (sp=%p,ra=%p,gp=%p)\n",curFrame->sp,(void*)curFrame->ra,(void*)curFrame->gp,nsp,nra,(void*)(reinterpret_cast<size_t*>(nsp)[4]));
 #else
-			fprintf(stderr,"stacktrace::unrollStackFrame(sp=%p,ra=%p) directed to invalid next frame: (sp=%p,ra=%p)\n",curFrame->sp,curFrame->ra,nsp,nra);
+			fprintf(stderr,"stacktrace::unrollStackFrame(sp=%p,ra=%p) directed to invalid next frame: (sp=%p,ra=%p)\n",curFrame->sp,(void*)curFrame->ra,nsp,nra);
 #endif
 			return 0;
 		}
 
-#ifdef __pic__
+#ifdef __PIC__
 #  ifdef DEBUG_STACKTRACE
 		if(curFrame->debug)
 			printf("( %p %p %p ) -> { %p %p %p }\n",curFrame->sp,curFrame->ra,curFrame->gp,nsp,nra,reinterpret_cast<size_t*>(nsp)[4]);
@@ -260,11 +260,11 @@ int unrollStackFrame(struct StackFrame* curFrame, struct StackFrame* nextFrame)
 #  endif
 		nextFrame->sp=nsp;
 		nextFrame->ra=nra;
-#endif /* __pic__ */
+#endif /* __PIC__ */
 		curFrame->caller=nextFrame;
 		return 1;
 	}
-#ifdef __pic__
+#ifdef __PIC__
 #  ifdef DEBUG_STACKTRACE
 	if(curFrame->debug)
 		printf("( %p %p %p ) -> { %p %p --- }\n",curFrame->sp,curFrame->ra,curFrame->gp,nsp,nra);
@@ -289,31 +289,40 @@ void getCurrentStackFrame(struct StackFrame* frame) {
 #endif /* __POWERPC__ */
 	
 #if defined(__MIPSEL__) || defined(__MIPS__)
-#ifdef __pic__
+#ifdef __PIC__
 	size_t cgp=0;
 	__asm __volatile__ ("move %0,$gp" : "=r"(cgp) ); //get the gp register so we can compute link addresses
-#endif /* __pic__ */
+#endif /* __PIC__ */
 	__asm __volatile__ ("move %0,$sp" : "=r"(csp) ); // get the current stack pointer
 	__asm __volatile__ ("jal readepc; nop; readepc: move %0,$ra" : "=r"(cra) ); // get the current return address
 #endif /* __MIPSEL__ */
 	
-#ifdef __i386__
+#if defined(__i386__)
 	__asm __volatile__ ("movl %%ebp,%0" : "=m"(csp) ); // get the caller's stack pointer
 	csp++; //go back one to really be a stack pointer
 	//__asm __volatile__ ("movl (%%esp),%0" : "=r"(cra) ); // get the caller's address
 	cra=*((machineInstruction**)csp);
 	csp=((void***)csp)[-1]+1;
 #endif /* __i386__ */
-	
+
+// basically the same as i386, but movq instead of movl, and rbp instead of ebp
+#if defined(__x86_64__) || defined(__amd64__)
+	__asm __volatile__ ("movq %%rbp,%0" : "=m"(csp) ); // get the caller's stack pointer
+	csp++; //go back one to really be a stack pointer
+	//__asm __volatile__ ("movq (%%rsp),%0" : "=r"(cra) ); // get the caller's address
+	cra=*((machineInstruction**)csp);
+	csp=((void***)csp)[-1]+1;
+#endif /* amd64/x86_64 */
+
 	frame->sp=csp;
-#ifdef __pic__
+#if defined(__PIC__) && (defined(__MIPSEL__) || defined(__MIPS__))
 	frame->ra=cgp-reinterpret_cast<size_t>(cra);
 	frame->gp=cgp;
 #else
 	frame->ra=cra;
-#endif /* __pic__ */
+#endif /* __PIC__ */
 
-#ifndef __i386__
+#if !defined(__i386__) && !defined(__x86_64__) && !defined(__amd64__)
 	//with ia-32 it was more convenient to directly provide caller, so don't need to unroll
 	//otherwise we actually want to return *caller's* frame, so unroll once
 	unrollStackFrame(frame,frame);
@@ -405,7 +414,11 @@ static asymbol **syms;		/* Symbol table.  */
 //! attempts to read symbol information and displays stack trace header
 void beginDisplay() {
 #if defined(HAVE_BFD) && HAVE_BFD!=0
+#  ifdef __APPLE__
+	const char* consolation=", try 'atos' to make human-readable backtrace";
+#  else
 	const char* consolation=", try addr2line or trace_lookup";
+#  endif
 	if(bfd_objfile==NULL) {
 		fprintf(stderr,"No symbols are loaded%s.\n",consolation);
 		return;
@@ -474,7 +487,11 @@ void beginDisplay() {
 # ifdef PLATFORM_APERIOS
 	fprintf(stderr,"Run trace_lookup:");
 #  else
+#    ifdef __APPLE__
+	const char* consolation=", try 'atos' to make human-readable backtrace";
+#    else
 	const char* consolation=", try addr2line or trace_lookup";
+#    endif
 	fprintf(stderr,"libBFD unavaible%s:\n",consolation);
 	fprintf(stderr,"Stack trace:");
 #  endif
@@ -626,7 +643,7 @@ void displayStackFrame(unsigned int depth, const struct StackFrame* frame) {
 #else
 void displayStackFrame(unsigned int ST_UNUSED(depth), const struct StackFrame* frame) {
 	ST_BODY_UNUSED(depth);
-	fprintf(stderr," %p",frame->ra);
+	fprintf(stderr," %p",(void*)frame->ra);
 }
 #endif
 
@@ -703,8 +720,8 @@ void displayStackTrace(const struct StackFrame* frame) {
  * @author Stuart Scandrett (original inspiration, Aperios/MIPS stack operations)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.12 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.14.2.1 $
  * $State: Exp $
- * $Date: 2006/09/16 06:28:08 $
+ * $Date: 2009/02/08 03:34:42 $
  */
