@@ -5,7 +5,6 @@
 #include "ERS220Info.h"
 #include "ERS7Info.h"
 #include "Shared/Config.h"
-#include "IPC/ProcessID.h"
 
 #ifdef PLATFORM_APERIOS
 #  include <OPENR/core_macro.h>
@@ -18,26 +17,29 @@
 #  include "Motion/PostureEngine.h"
 #endif
 
+using namespace std;
+
 #define GETD(cpc) (((float)sensor.GetData(cpc)->frame[lastFrame].value) / 1.0E6f) //!< returns value from OPEN-R, converted from micro in int to base in float
 #define GETB(cpc) ((bool)sensor.GetData(cpc)->frame[lastFrame].value) //!< returns value from OPEN-R, as bool
 #define GETSENSOR(cpc) ((float)sensor.GetData(cpc)->frame[lastFrame].value) //!< return value from OPEN-R, as int
 #define GETSIG(cpc) ((word)sensor.GetData(cpc)->frame[lastFrame].signal) //!< returns signal from OPEN-R as word
-#define GETDUTY(cpc) ((float)((OJointValue*)&sensor.GetData(cpc)->frame[lastFrame])->pwmDuty/512.0f) //!< returns duty cycle from OPEN-R as float; -1 (full reverse) to 0 (idle) to 1 (full forward)
+#define GETDUTY(cpc) (((OJointValue*)(void*)&sensor.GetData(cpc)->frame[lastFrame])->pwmDuty/512.0f) //!< returns duty cycle from OPEN-R as float; -1 (full reverse) to 0 (idle) to 1 (full forward)
 
 const double WorldState::g=9.80665;
 const double WorldState::IROORDist = 900.0;
 
 #ifdef PLATFORM_APERIOS
 WorldState ** WorldState::stateLookupMap=NULL;
-#endif
-
 WorldState * state=NULL;
+#else
+WorldStateLookup state;
+#endif
 
 WorldState::WorldState()
 	: alwaysGenerateStatus(false), vel_x(0), vel_y(0), vel_a(0), vel_time(0),
 		robotStatus(0), batteryStatus(0),
 		lastSensorUpdateTime(0), frameNumber(1), framesProcessed(0),
-		robotDesign(0), curtime(0)
+		curtime(0)
 {
 	for(unsigned int i=0; i< NumOutputs; i++)
 		outputs[i]=0;
@@ -47,47 +49,11 @@ WorldState::WorldState()
 		sensors[i]=0;
 	for(unsigned int i=0; i< NumPIDJoints; i++)
 		for(unsigned int j=0; j<3; j++)
-			pids[i][j]=0;
+			pids[i][j]=DefaultPIDs[i][j];
 	for(unsigned int i=0; i< NumPIDJoints; i++)
 		pidduties[i]=0;
-	memset(powerFlags,0,sizeof(unsigned int)*PowerSourceID::NumPowerSIDs);
+	memset(powerFlags,0,sizeof(unsigned int)*PowerSrcID::NumPowerSIDs);
 	memset(button_times,0,sizeof(unsigned int)*NumButtons);
-
-#ifdef PLATFORM_APERIOS
-	//Thanks Daishi:
-	char robotDesignStr[orobotdesignNAME_MAX + 1];
-	memset(robotDesignStr, 0, sizeof(robotDesignStr));
-	if (OPENR::GetRobotDesign(robotDesignStr) != oSUCCESS) {
-		cout << "OPENR::GetRobotDesign() failed." << endl;
-	} else {
-		if(strcmp(robotDesignStr,"ERS-210")==0)
-			robotDesign=ERS210Mask;
-		else if(strcmp(robotDesignStr,"ERS-220")==0)
-			robotDesign=ERS220Mask;
-		else if(strcmp(robotDesignStr,"ERS-7")==0)
-			robotDesign=ERS7Mask;
-		else {
-			cout << "ERROR: Unrecognized model: "<<robotDesignStr<<"\nDoing the best I can by assuming ERS-7..."<<endl;
-			robotDesign=ERS7Mask;
-		}
-	}
-#else
-	//This is only compiled if we're targeting the local platform
-	//In other words, if target model is an AIBO, simulation mode
-# if TGT_ERS220
-	robotDesign=ERS220Mask;
-# elif TGT_ERS210
-	robotDesign=ERS210Mask;
-# elif TGT_ERS2xx
-#   warning "TGT_ERS2xx can't be determined on non-Aperios - defaulting to TGT_ERS210"
-	robotDesign=ERS210Mask;
-# elif TGT_ERS7
-	robotDesign=ERS7Mask;
-# else
-#		warning "TGT_<model> undefined - defaulting to TGT_ERS7"
-	robotDesign=ERS7Mask;
-# endif //model selection
-#endif
 }
 
 #ifdef PLATFORM_APERIOS
@@ -109,7 +75,7 @@ void WorldState::read(OSensorFrameVectorData& sensor, WorldState* lastState, Eve
 		//pid and velocity values will be copied at "completion"
 		robotStatus=lastState->robotStatus;
 		batteryStatus=lastState->batteryStatus;
-		for(unsigned int i=0; i<PowerSourceID::NumPowerSIDs; i++)
+		for(unsigned int i=0; i<PowerSrcID::NumPowerSIDs; i++)
 			powerFlags[i]=lastState->powerFlags[i];
 		
 		//important part -- copy over button_times before calls to chkEvent
@@ -117,7 +83,7 @@ void WorldState::read(OSensorFrameVectorData& sensor, WorldState* lastState, Eve
 			button_times[i]=lastState->button_times[i];
 	}
 	
-	if(robotDesign&ERS210Mask) {
+	if(RobotName == ERS210Info::TargetName) {
 		outputs[LFrLegOffset + RotatorOffset   ] = GETD(ERS210Info::CPCJointLFRotator);
 		outputs[LFrLegOffset + ElevatorOffset  ] = GETD(ERS210Info::CPCJointLFElevator);
 		outputs[LFrLegOffset + KneeOffset      ] = GETD(ERS210Info::CPCJointLFKnee);
@@ -154,16 +120,27 @@ void WorldState::read(OSensorFrameVectorData& sensor, WorldState* lastState, Eve
 		pidduties[HeadOffset+PanOffset ] = GETDUTY(ERS210Info::CPCJointNeckPan);
 		pidduties[HeadOffset+RollOffset] = GETDUTY(ERS210Info::CPCJointNeckRoll);
 
-		outputs[ERS210Info::TailOffset+TiltOffset] = GETD(ERS210Info::CPCJointTailTilt);
-		outputs[ERS210Info::TailOffset+PanOffset]  = GETD(ERS210Info::CPCJointTailPan);
-		pidduties[ERS210Info::TailOffset+TiltOffset] = GETDUTY(ERS210Info::CPCJointTailTilt);
-		pidduties[ERS210Info::TailOffset+PanOffset]  = GETDUTY(ERS210Info::CPCJointTailPan);
+#ifdef TGT_ERS210
+		unsigned tail = ERS210Info::TailOffset;
+		unsigned mouth = ERS210Info::MouthOffset;
+#elif defined(TGT_ERS2xx)
+		unsigned tail = ERS2xxInfo::TailOffset;
+		unsigned mouth = ERS2xxInfo::MouthOffset;
+#else
+		unsigned tail = capabilities.getOutputOffset(ERS210Info::outputNames[ERS210Info::TailOffset]);
+		unsigned mouth = capabilities.getOutputOffset(ERS210Info::outputNames[ERS210Info::MouthOffset]);
+#endif
+		outputs[tail+TiltOffset] = GETD(ERS210Info::CPCJointTailTilt);
+		outputs[tail+PanOffset]  = GETD(ERS210Info::CPCJointTailPan);
+		pidduties[tail+TiltOffset] = GETDUTY(ERS210Info::CPCJointTailTilt);
+		pidduties[tail+PanOffset]  = GETDUTY(ERS210Info::CPCJointTailPan);
 		
-		outputs[ERS210Info::MouthOffset] = GETD(ERS210Info::CPCJointMouth);
-		pidduties[ERS210Info::MouthOffset] = GETDUTY(ERS210Info::CPCJointMouth);
+		outputs[mouth] = GETD(ERS210Info::CPCJointMouth);
+		pidduties[mouth] = GETDUTY(ERS210Info::CPCJointMouth);
 
 		if(lastState!=NULL && lastState!=this) {
 			// Copy over new buttons
+			// ERS2xx happens to match ERS210 offsets for buttons, so nothing special needed...
 			buttons[ERS210Info::LFrPawOffset]=GETB(ERS210Info::CPCSensorLFPaw);
 			buttons[ERS210Info::RFrPawOffset]=GETB(ERS210Info::CPCSensorRFPaw);
 			buttons[ERS210Info::LBkPawOffset]=GETB(ERS210Info::CPCSensorLHPaw);
@@ -202,7 +179,7 @@ void WorldState::read(OSensorFrameVectorData& sensor, WorldState* lastState, Eve
 	}
 
 	// (ERS-220 only)
-	if(robotDesign&ERS220Mask) {
+	if(RobotName == ERS220Info::TargetName) {
 		outputs[LFrLegOffset + RotatorOffset   ] = GETD(ERS220Info::CPCJointLFRotator);
 		outputs[LFrLegOffset + ElevatorOffset  ] = GETD(ERS220Info::CPCJointLFElevator);
 		outputs[LFrLegOffset + KneeOffset      ] = GETD(ERS220Info::CPCJointLFKnee);
@@ -241,6 +218,7 @@ void WorldState::read(OSensorFrameVectorData& sensor, WorldState* lastState, Eve
 
 		if(lastState!=NULL && lastState!=this) {
 			// Copy over new buttons
+			// ERS2xx happens to match ERS220 offsets for buttons, so nothing special needed...
 			buttons[ERS220Info::LFrPawOffset]=GETB(ERS220Info::CPCSensorLFPaw);
 			buttons[ERS220Info::RFrPawOffset]=GETB(ERS220Info::CPCSensorRFPaw);
 			buttons[ERS220Info::LBkPawOffset]=GETB(ERS220Info::CPCSensorLHPaw);
@@ -285,7 +263,7 @@ void WorldState::read(OSensorFrameVectorData& sensor, WorldState* lastState, Eve
 	}
 
 	// (ERS-7 only)
-	if(robotDesign&ERS7Mask) {
+	if(RobotName == ERS7Info::TargetName) {
 		outputs[LFrLegOffset + RotatorOffset   ] = GETD(ERS7Info::CPCJointLFRotator);
 		outputs[LFrLegOffset + ElevatorOffset  ] = GETD(ERS7Info::CPCJointLFElevator);
 		outputs[LFrLegOffset + KneeOffset      ] = GETD(ERS7Info::CPCJointLFKnee);
@@ -379,68 +357,71 @@ void WorldState::read(OSensorFrameVectorData& sensor, WorldState* lastState, Eve
 	lastSensorUpdateTime=curtime;
 	frameNumber=newFrameNumber;
 	framesProcessed=(lastState!=NULL?lastState->framesProcessed:framesProcessed)+1;
-	for(unsigned int i=0; i<evtBuf.size(); i++)
-		er->postEvent(evtBuf[i]);
-	
 	
 	//Apply sensor calibrations (currently only joint positions - perhaps IR as well?)
+	/*
 	for(unsigned int i=0; i<NumPIDJoints; i++)
 		outputs[PIDJointOffset+i]*=config->motion.calibration[i];
+	*/
+	applyCalibration();
+
+	for(unsigned int i=0; i<evtBuf.size(); i++)
+		er->postEvent(evtBuf[i]);
 
 	//this version of read doesn't post the sensor update event -- the caller should do that
 	//this event gets posted by MMCombo only if there's no back log on the interprocess event queue (don't want to stack these up for sensor frames missed by main)
-	//er->postEvent(EventBase::sensorEGID,SensorSourceID::UpdatedSID,EventBase::statusETID,dif,"SensorSouceID::UpdatedSID",1);
+	//er->postEvent(EventBase::sensorEGID,SensorSrcID::UpdatedSID,EventBase::statusETID,dif,"SensorSouceID::UpdatedSID",1);
 }
 
 /*! This will cause events to be posted */
 void WorldState::read(const OPowerStatus& power, EventRouter* er) {
-	std::string actnames[PowerSourceID::NumPowerSIDs];
-	std::string denames[PowerSourceID::NumPowerSIDs];
-	unsigned int actmasks[PowerSourceID::NumPowerSIDs];
-	memset(actmasks,0,sizeof(unsigned int)*PowerSourceID::NumPowerSIDs);
+	std::string actnames[PowerSrcID::NumPowerSIDs];
+	std::string denames[PowerSrcID::NumPowerSIDs];
+	unsigned int actmasks[PowerSrcID::NumPowerSIDs];
+	memset(actmasks,0,sizeof(unsigned int)*PowerSrcID::NumPowerSIDs);
 
 	//RobotStatus
-	chkPowerEvent(PowerSourceID::PauseSID,          power.robotStatus,orsbPAUSE,                        "Pause",actnames,denames,actmasks);
-	chkPowerEvent(PowerSourceID::MotorPowerSID,     power.robotStatus,orsbMOTOR_POWER,                  "MotorPower",actnames,denames,actmasks);
-	chkPowerEvent(PowerSourceID::VibrationSID,      power.robotStatus,orsbVIBRATION_DETECT,             "Vibration",actnames,denames,actmasks);
-	chkPowerEvent(PowerSourceID::ExternalPortSID,   power.robotStatus,orsbEX_PORT_CONNECTED,            "ExternalPort",actnames,denames,actmasks);
-	chkPowerEvent(PowerSourceID::StationConnectSID, power.robotStatus,orsbSTATION_CONNECTED,            "StationConnect",actnames,denames,actmasks);
-	chkPowerEvent(PowerSourceID::ExternalPowerSID,  power.robotStatus,orsbEX_POWER_CONNECTED,           "ExternalPower",actnames,denames,actmasks);
-	chkPowerEvent(PowerSourceID::BatteryConnectSID, power.robotStatus,orsbBATTERY_CONNECTED,            "BatteryConnect",actnames,denames,actmasks);
-	chkPowerEvent(PowerSourceID::ChargingSID,       power.robotStatus,orsbBATTERY_CHARGING,             "BatteryCharging",actnames,denames,actmasks);
-	chkPowerEvent(PowerSourceID::BatteryFullSID,    power.robotStatus,orsbBATTERY_CAPACITY_FULL,        "BatteryFull",actnames,denames,actmasks);
-	chkPowerEvent(PowerSourceID::LowPowerWarnSID,   power.robotStatus,orsbBATTERY_CAPACITY_LOW,         "BatteryLow",actnames,denames,actmasks);
-	chkPowerEvent(PowerSourceID::OverChargedSID,    power.robotStatus,orsbBATTERY_OVER_CURRENT,         "BatteryOverCurrent",actnames,denames,actmasks);
-	chkPowerEvent(PowerSourceID::OverheatingSID,    power.robotStatus,orsbBATTERY_OVER_TEMP_DISCHARGING,"BatteryOverTempDischarge",actnames,denames,actmasks);
-	chkPowerEvent(PowerSourceID::OverheatingSID,    power.robotStatus,orsbBATTERY_OVER_TEMP_CHARGING,   "BatteryOverTempCharge",actnames,denames,actmasks);
-	chkPowerEvent(PowerSourceID::ErrorSID,          power.robotStatus,orsbBATTERY_ERROR_OF_CHARGING,    "BatteryChargeError",actnames,denames,actmasks);
-	chkPowerEvent(PowerSourceID::ErrorSID,          power.robotStatus,orsbERROR_OF_PLUNGER,             "PlungerError",actnames,denames,actmasks);
-	chkPowerEvent(PowerSourceID::PowerGoodSID,      power.robotStatus,orsbOPEN_R_POWER_GOOD,            "PowerGood",actnames,denames,actmasks);
-	chkPowerEvent(PowerSourceID::ErrorSID,          power.robotStatus,orsbERROR_OF_FAN,                 "FanError",actnames,denames,actmasks);
-	chkPowerEvent(PowerSourceID::DataFromStationSID,power.robotStatus,orsbDATA_STREAM_FROM_STATION,     "DataFromStation",actnames,denames,actmasks);
-	chkPowerEvent(PowerSourceID::RegisterUpdateSID, power.robotStatus,orsbREGISTER_UPDATED_BY_STATION,  "RegisterUpdate",actnames,denames,actmasks);
-	chkPowerEvent(PowerSourceID::ErrorSID,          power.robotStatus,orsbRTC_ERROR,                    "RTCError",actnames,denames,actmasks);
-	chkPowerEvent(PowerSourceID::RTCSID,            power.robotStatus,orsbRTC_OVERFLOW,                 "RTCOverflow",actnames,denames,actmasks);
-	chkPowerEvent(PowerSourceID::RTCSID,            power.robotStatus,orsbRTC_RESET,                    "RTCReset",actnames,denames,actmasks);
-	chkPowerEvent(PowerSourceID::RTCSID,            power.robotStatus,orsbRTC_SET,                      "RTCSet",actnames,denames,actmasks);
-	chkPowerEvent(PowerSourceID::SpecialModeSID,    power.robotStatus,orsbSPECIAL_MODE,                 "SpecialMode",actnames,denames,actmasks);
-	chkPowerEvent(PowerSourceID::BMNDebugModeSID,   power.robotStatus,orsbBMN_DEBUG_MODE,               "BMNDebugMode",actnames,denames,actmasks);
-	chkPowerEvent(PowerSourceID::ChargerStatusSID,  power.robotStatus,orsbCHARGER_STATUS,               "ChargerStatus",actnames,denames,actmasks);
-	chkPowerEvent(PowerSourceID::PlungerSID,        power.robotStatus,orsbPLUNGER,                      "Plunger",actnames,denames,actmasks);
-	chkPowerEvent(PowerSourceID::SuspendedSID,      power.robotStatus,orsbSUSPENDED,                    "Suspended",actnames,denames,actmasks);
+	chkPowerEvent(PowerSrcID::PauseSID,          power.robotStatus,orsbPAUSE,                        "Pause",actnames,denames,actmasks);
+	chkPowerEvent(PowerSrcID::MotorPowerSID,     power.robotStatus,orsbMOTOR_POWER,                  "MotorPower",actnames,denames,actmasks);
+	chkPowerEvent(PowerSrcID::VibrationSID,      power.robotStatus,orsbVIBRATION_DETECT,             "Vibration",actnames,denames,actmasks);
+	chkPowerEvent(PowerSrcID::ExternalPortSID,   power.robotStatus,orsbEX_PORT_CONNECTED,            "ExternalPort",actnames,denames,actmasks);
+	chkPowerEvent(PowerSrcID::StationConnectSID, power.robotStatus,orsbSTATION_CONNECTED,            "StationConnect",actnames,denames,actmasks);
+	chkPowerEvent(PowerSrcID::ExternalPowerSID,  power.robotStatus,orsbEX_POWER_CONNECTED,           "ExternalPower",actnames,denames,actmasks);
+	chkPowerEvent(PowerSrcID::BatteryConnectSID, power.robotStatus,orsbBATTERY_CONNECTED,            "BatteryConnect",actnames,denames,actmasks);
+	chkPowerEvent(PowerSrcID::ChargingSID,       power.robotStatus,orsbBATTERY_CHARGING,             "BatteryCharging",actnames,denames,actmasks);
+	chkPowerEvent(PowerSrcID::BatteryFullSID,    power.robotStatus,orsbBATTERY_CAPACITY_FULL,        "BatteryFull",actnames,denames,actmasks);
+	chkPowerEvent(PowerSrcID::LowPowerWarnSID,   power.robotStatus,orsbBATTERY_CAPACITY_LOW,         "BatteryLow",actnames,denames,actmasks);
+	chkPowerEvent(PowerSrcID::OverChargedSID,    power.robotStatus,orsbBATTERY_OVER_CURRENT,         "BatteryOverCurrent",actnames,denames,actmasks);
+	chkPowerEvent(PowerSrcID::OverheatingSID,    power.robotStatus,orsbBATTERY_OVER_TEMP_DISCHARGING,"BatteryOverTempDischarge",actnames,denames,actmasks);
+	chkPowerEvent(PowerSrcID::OverheatingSID,    power.robotStatus,orsbBATTERY_OVER_TEMP_CHARGING,   "BatteryOverTempCharge",actnames,denames,actmasks);
+	chkPowerEvent(PowerSrcID::ErrorSID,          power.robotStatus,orsbBATTERY_ERROR_OF_CHARGING,    "BatteryChargeError",actnames,denames,actmasks);
+	chkPowerEvent(PowerSrcID::ErrorSID,          power.robotStatus,orsbERROR_OF_PLUNGER,             "PlungerError",actnames,denames,actmasks);
+	chkPowerEvent(PowerSrcID::PowerGoodSID,      power.robotStatus,orsbOPEN_R_POWER_GOOD,            "PowerGood",actnames,denames,actmasks);
+	chkPowerEvent(PowerSrcID::ErrorSID,          power.robotStatus,orsbERROR_OF_FAN,                 "FanError",actnames,denames,actmasks);
+	chkPowerEvent(PowerSrcID::DataFromStationSID,power.robotStatus,orsbDATA_STREAM_FROM_STATION,     "DataFromStation",actnames,denames,actmasks);
+	chkPowerEvent(PowerSrcID::RegisterUpdateSID, power.robotStatus,orsbREGISTER_UPDATED_BY_STATION,  "RegisterUpdate",actnames,denames,actmasks);
+	chkPowerEvent(PowerSrcID::ErrorSID,          power.robotStatus,orsbRTC_ERROR,                    "RTCError",actnames,denames,actmasks);
+	chkPowerEvent(PowerSrcID::RTCSID,            power.robotStatus,orsbRTC_OVERFLOW,                 "RTCOverflow",actnames,denames,actmasks);
+	chkPowerEvent(PowerSrcID::RTCSID,            power.robotStatus,orsbRTC_RESET,                    "RTCReset",actnames,denames,actmasks);
+	chkPowerEvent(PowerSrcID::RTCSID,            power.robotStatus,orsbRTC_SET,                      "RTCSet",actnames,denames,actmasks);
+	chkPowerEvent(PowerSrcID::SpecialModeSID,    power.robotStatus,orsbSPECIAL_MODE,                 "SpecialMode",actnames,denames,actmasks);
+	chkPowerEvent(PowerSrcID::BMNDebugModeSID,   power.robotStatus,orsbBMN_DEBUG_MODE,               "BMNDebugMode",actnames,denames,actmasks);
+	chkPowerEvent(PowerSrcID::ChargerStatusSID,  power.robotStatus,orsbCHARGER_STATUS,               "ChargerStatus",actnames,denames,actmasks);
+	chkPowerEvent(PowerSrcID::PlungerSID,        power.robotStatus,orsbPLUNGER,                      "Plunger",actnames,denames,actmasks);
+	chkPowerEvent(PowerSrcID::SuspendedSID,      power.robotStatus,orsbSUSPENDED,                    "Suspended",actnames,denames,actmasks);
 
 	//BatteryStatus
-	chkPowerEvent(PowerSourceID::ErrorSID,        power.batteryStatus,obsbERROR_CODE_MASK,             "BatteryError",actnames,denames,actmasks);
-	chkPowerEvent(PowerSourceID::BatteryEmptySID, power.batteryStatus,obsbFULLY_DISCHARGED,            "FullyDischarged",actnames,denames,actmasks);
-	chkPowerEvent(PowerSourceID::BatteryFullSID,  power.batteryStatus,obsbFULLY_CHARGED,               "FullyCharged",actnames,denames,actmasks);
-	chkPowerEvent(PowerSourceID::DischargingSID,  power.batteryStatus,obsbDISCHARGING,                 "Discharging",actnames,denames,actmasks);
-	chkPowerEvent(PowerSourceID::BatteryInitSID,  power.batteryStatus,obsbINITIALIZED,                 "BatteryInit",actnames,denames,actmasks);
-	chkPowerEvent(PowerSourceID::LowPowerWarnSID, power.batteryStatus,obsbREMAINING_TIME_ALARM,        "RemainingTimeAlarm",actnames,denames,actmasks);
-	chkPowerEvent(PowerSourceID::LowPowerWarnSID, power.batteryStatus,obsbREMAINING_CAPACITY_ALARM,    "RemainingCapacityAlarm",actnames,denames,actmasks);
-	chkPowerEvent(PowerSourceID::TermDischargeSID,power.batteryStatus,obsbTERMINATED_DISCHARGING_ALARM,"TermDischargeAlarm",actnames,denames,actmasks);
-	chkPowerEvent(PowerSourceID::OverheatingSID,  power.batteryStatus,obsbOVER_TEMP_ALARM,             "OverTempAlarm",actnames,denames,actmasks);
-	chkPowerEvent(PowerSourceID::TermChargeSID,   power.batteryStatus,obsbTERMINATED_CHARGING_ALARM,   "TermChargeAlarm",actnames,denames,actmasks);
-	chkPowerEvent(PowerSourceID::OverChargedSID,  power.batteryStatus,obsbOVER_CHARGED_ALARM,          "OverChargeAlarm",actnames,denames,actmasks);
+	chkPowerEvent(PowerSrcID::ErrorSID,        power.batteryStatus,obsbERROR_CODE_MASK,             "BatteryError",actnames,denames,actmasks);
+	chkPowerEvent(PowerSrcID::BatteryEmptySID, power.batteryStatus,obsbFULLY_DISCHARGED,            "FullyDischarged",actnames,denames,actmasks);
+	chkPowerEvent(PowerSrcID::BatteryFullSID,  power.batteryStatus,obsbFULLY_CHARGED,               "FullyCharged",actnames,denames,actmasks);
+	chkPowerEvent(PowerSrcID::DischargingSID,  power.batteryStatus,obsbDISCHARGING,                 "Discharging",actnames,denames,actmasks);
+	chkPowerEvent(PowerSrcID::BatteryInitSID,  power.batteryStatus,obsbINITIALIZED,                 "BatteryInit",actnames,denames,actmasks);
+	chkPowerEvent(PowerSrcID::LowPowerWarnSID, power.batteryStatus,obsbREMAINING_TIME_ALARM,        "RemainingTimeAlarm",actnames,denames,actmasks);
+	chkPowerEvent(PowerSrcID::LowPowerWarnSID, power.batteryStatus,obsbREMAINING_CAPACITY_ALARM,    "RemainingCapacityAlarm",actnames,denames,actmasks);
+	chkPowerEvent(PowerSrcID::TermDischargeSID,power.batteryStatus,obsbTERMINATED_DISCHARGING_ALARM,"TermDischargeAlarm",actnames,denames,actmasks);
+	chkPowerEvent(PowerSrcID::OverheatingSID,  power.batteryStatus,obsbOVER_TEMP_ALARM,             "OverTempAlarm",actnames,denames,actmasks);
+	chkPowerEvent(PowerSrcID::TermChargeSID,   power.batteryStatus,obsbTERMINATED_CHARGING_ALARM,   "TermChargeAlarm",actnames,denames,actmasks);
+	chkPowerEvent(PowerSrcID::OverChargedSID,  power.batteryStatus,obsbOVER_CHARGED_ALARM,          "OverChargeAlarm",actnames,denames,actmasks);
 	
 	sensors[PowerRemainOffset] = power.remainingCapacity/100.0;
 	sensors[PowerThermoOffset] = power.temperature/100.0;
@@ -449,7 +430,7 @@ void WorldState::read(const OPowerStatus& power, EventRouter* er) {
 	sensors[PowerCurrentOffset] = power.current;
 
 	//only generate status events when a change happens
-	for(unsigned int i=0; i<PowerSourceID::NumPowerSIDs; i++) {
+	for(unsigned int i=0; i<PowerSrcID::NumPowerSIDs; i++) {
 		if(actmasks[i]) { //now on
 			if(!powerFlags[i]) //was off: activation
 				er->postEvent(EventBase::powerEGID,i,EventBase::activateETID,0,actnames[i],1);
@@ -462,7 +443,7 @@ void WorldState::read(const OPowerStatus& power, EventRouter* er) {
 		powerFlags[i]=actmasks[i];
 	}
 
-	er->postEvent(EventBase::powerEGID,PowerSourceID::UpdatedSID,EventBase::statusETID,0,"PowerSourceID::UpdatedSID",1);
+	er->postEvent(EventBase::powerEGID,PowerSrcID::UpdatedSID,EventBase::statusETID,0,"PowerSrcID::UpdatedSID",1);
 }
 
 #else  //PLATFORM_LOCAL
@@ -471,8 +452,8 @@ void WorldState::read(const OPowerStatus& power, EventRouter* er) {
  *  (this variant is used by the simulator, different parts fill in different sections, the last one should trigger the event)
  *
  *  This function assumes that the pose (and any associated sensor readings)
- *  are for the current model robot, and that any calibration has already 
- *  been applied (so the values can be used unchanged)
+ *  are for the current model robot, and that no calibration has already 
+ *  been applied (so the values must be calibrated)
  */
 void WorldState::read(const PostureEngine& pose, WorldState* lastState, EventRouter* er) {
 	curtime=get_time();
@@ -481,19 +462,42 @@ void WorldState::read(const PostureEngine& pose, WorldState* lastState, EventRou
 
 	unsigned int newFrameNumber=(lastState!=NULL?lastState->frameNumber:frameNumber)+NumFrames;
 
-	for(unsigned int i=0; i<NumOutputs; i++)
-		if(pose(i).weight>0)
-			outputs[i]=pose(i).value;
-
-	if(frameNumber>=newFrameNumber)
+	if(frameNumber>=newFrameNumber) {
 		return; //sensors have already been filled in
+	}
+
+	if(lastState!=NULL && lastState!=this) {
+		// copy over previous value if weight is 0
+		//printf("this=%p, last=%p, ext=%p\n",this,lastState,ext);
+		for(unsigned int i=0; i<NumOutputs; i++) {
+			if (pose(i).weight>0) {
+				if (i>=PIDJointOffset && i<PIDJointOffset+NumPIDJoints) {
+					outputs[i] = pose(i).value / (config->motion.calibration_scale[i-PIDJointOffset])
+						- config->motion.calibration_offset[i-PIDJointOffset];
+				} else {
+					outputs[i] = pose(i).value;
+				}
+			} else {
+				outputs[i] = lastState->outputs[i];
+			}
+		}
+	} else {
+		// just ignore 0 weighted values
+		for(unsigned int i=0; i<NumOutputs; i++) {
+			if(pose(i).weight>0) {
+				outputs[i]=pose(i).value;
+			}
+		}
+		applyCalibration();
+	}
+
 	
 	if(lastState!=NULL && lastState!=this) {
 		alwaysGenerateStatus=lastState->alwaysGenerateStatus;
 		//pid and velocity values will be copied at "completion"
 		robotStatus=lastState->robotStatus;
 		batteryStatus=lastState->batteryStatus;
-		for(unsigned int i=0; i<PowerSourceID::NumPowerSIDs; i++)
+		for(unsigned int i=0; i<PowerSrcID::NumPowerSIDs; i++)
 			powerFlags[i]=lastState->powerFlags[i];
 
 		//important part -- copy over button_times before calls to chkEvent
@@ -533,12 +537,13 @@ void WorldState::read(const PostureEngine& pose, WorldState* lastState, EventRou
 	if(newFrameNumber!=-1U)
 		frameNumber=newFrameNumber;
 	framesProcessed=(lastState!=NULL?lastState->framesProcessed:framesProcessed)+1;
+
 	for(unsigned int i=0; i<evtBuf.size(); i++)
 		er->postEvent(evtBuf[i]);
-	
+
 	//this version of read doesn't post the sensor update event -- the caller should do that
 	// (this variant is used by the simulator, different parts fill in different sections, the last one should trigger the event)
-	//er->postEvent(EventBase::sensorEGID,SensorSourceID::UpdatedSID,EventBase::statusETID,dif,"SensorSourceID::UpdatedSID",1);
+	//er->postEvent(EventBase::sensorEGID,SensorSrcID::UpdatedSID,EventBase::statusETID,dif,"SensorSrcID::UpdatedSID",1);
 }
 
 #endif //platform-specific sensor updating
@@ -588,13 +593,19 @@ void WorldState::chkEvent(std::vector<EventBase>& evtBuf, WorldState* lastState)
 	}
 }
 
+void WorldState::applyCalibration() {
+	for (unsigned int i=PIDJointOffset; i<PIDJointOffset+NumPIDJoints; i++) {
+		outputs[i] = (outputs[i]/ (config->motion.calibration_scale[i-PIDJointOffset]) ) - config->motion.calibration_offset[i-PIDJointOffset];
+	}
+}
+
 /*! @file
  * @brief Implements WorldState, maintains information about the robot's environment, namely sensors and power status
  * @author ejt (Creator)
  *
- * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.40 $
+ * $Author: kcomer $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.51 $
  * $State: Exp $
- * $Date: 2006/09/29 16:56:09 $
+ * $Date: 2007/11/15 21:33:04 $
  */
