@@ -3,7 +3,6 @@
 #define INCLUDED_WorldState_h
 
 #ifdef PLATFORM_APERIOS
-#include "IPC/ProcessID.h"
 #include <OPENR/core_macro.h>
 #include <OPENR/ObjcommTypes.h>
 #include <OPENR/OPENR.h>
@@ -15,6 +14,7 @@ class PostureEngine;
 
 #include "Shared/RobotInfo.h"
 #include "Events/EventBase.h"
+#include "IPC/ProcessID.h"
 #include <math.h>
 #include <vector>
 
@@ -24,7 +24,7 @@ class EventBase;
 //The following SourceIDs are for events created by WorldState's event generators
 
 //! holds source ID types for sensor events; see EventBase, see #SensorSourceID_t
-namespace SensorSourceID {
+namespace SensorSrcID {
 	//! holds source ID types for sensor events
 	/*! May want to add a proximity alarm for IR distance?  Probably
 	 *  should do it from a separate generator to avoid screwing up
@@ -36,7 +36,7 @@ namespace SensorSourceID {
 }
 
 //! holds source ID types for power events; see EventBase, see #PowerSourceID_t
-namespace PowerSourceID {
+namespace PowerSrcID {
 	//! holds source ID types for power events
 	/*! Also serve as offsets into WorldState::powerFlags[].
 	 *
@@ -97,8 +97,33 @@ namespace PowerSourceID {
 }
 
 class WorldState;
-extern WorldState * state; //!< the global state object, is a shared memory region, created by MainObject
+#ifdef PLATFORM_APERIOS
+extern WorldState * state; //!< the global state object, points into a shared memory region, created by MainObject
+#else
+//! This class masquerades as a simple WorldState pointer, but actually checks the process ID of the referencing thread to allow each thread group to have a separate WorldState*
+/*! This is to support WorldStatePool functionality, so if a behavior in Main is blocking, it doesn't prevent Motion threads from getting updated sensors */
+class WorldStateLookup {
+public:
+	WorldStateLookup() { for(unsigned int i=0; i<ProcessID::NumProcesses; ++i) ws[i]=NULL; } //!< constructor
+	WorldState*& operator->() { return ws[ProcessID::getID()]; } //!< smart pointer to the underlying class
+	WorldState& operator*() { return *ws[ProcessID::getID()]; } //!< smart pointer to the underlying class
+	operator WorldState*&() { return ws[ProcessID::getID()]; } //!< pretend we're a simple pointer
+	WorldStateLookup& operator=(WorldState* p) { ws[ProcessID::getID()]=p; return *this; } //!< assign from a pointer as well
 	
+protected:
+	//! This holds a separate WorldState pointer for each process
+	/*! Note that under a multi-process model, each process is only ever going to reference one of these,
+	 *  (so we could get away with a single global pointer), but under a uni-process model, we wind up
+	 *  using the various entries to differentiate the thread groups */
+	WorldState* ws[ProcessID::NumProcesses];
+private:
+        WorldStateLookup(const WorldStateLookup&); //!< don't call this
+        WorldStateLookup& operator=(const WorldStateLookup&); //!< don't call this
+};
+//! the global state object, points into a shared memory region, created by MainObject
+extern WorldStateLookup state;
+#endif
+
 //! The state of the robot and its environment
 /*! Contains sensor readings, current joint positions, etc.  Notable members are:
  * - #outputs - joint positions and current LED values
@@ -149,7 +174,7 @@ public:
 
 	unsigned int robotStatus;       //!< bitmask, see OPENR/OPower.h
 	unsigned int batteryStatus;     //!< bitmask, see OPENR/OPower.h
-	unsigned int powerFlags[PowerSourceID::NumPowerSIDs]; //!< bitmasks of similarly-grouped items from previous two masks, corresponds to the PowerSourceID::PowerSourceID_t's
+	unsigned int powerFlags[PowerSrcID::NumPowerSIDs]; //!< bitmasks of similarly-grouped items from previous two masks, corresponds to the PowerSrcID::PowerSourceID_t's
 
 	unsigned int button_times[NumButtons]; //!< value is time of current press, 0 if not down
 	
@@ -183,22 +208,6 @@ public:
 	static WorldState* getCurrent() { return ::state; }
 #endif
 
-	//! bitmask corresponding to OPENR::GetRobotDesign()
-	/*! This allows you to efficiently test different combinations, like
-	 *  any 2x0 model vs. any 7 model or any 3xx model (when/if the
-	 *  3xx's are supported).
-	 *
-	 *  Testing this will give more accurate feedback as to whether
-	 *  features exist than checking RobotInfo values - to achieve dual
-	 *  booting, RobotInfo may, for instance, tell you there are two
-	 *  ears, but if you're running on a 220 the value you set them to
-	 *  will be ignored */
-	unsigned int robotDesign;  
-	static const unsigned int ERS210Mask=1<<0;  //!< use this to test for ERS-210 features
-	static const unsigned int ERS220Mask=1<<1;  //!< use this to test for ERS-220 features
-	static const unsigned int ERS2xxMask = ERS210Mask | ERS220Mask;  //!< use this to test for ERS-2xx features
-	static const unsigned int ERS7Mask=1<<2;  //!< use this to test for ERS-7 features
-
 protected:
 	unsigned int curtime; //!< set by read(OSensorFrameVectorData& sensor, EventRouter* er) for chkEvent() so each call doesn't have to
 
@@ -207,13 +216,16 @@ protected:
 	//! Tests to see if any button statuses have changed and post events as needed, bases comparison between already filled-in WorldStates 
 	void chkEvent(std::vector<EventBase>& evtBuf, WorldState* lastState);
 
+	//! Apply calibration to the sensors and joint positions (reversing motion calibration parameters)
+	void applyCalibration();
+
 	//! sets the names of the flags that will be generating events
 	/*! note that this function does not actually do the event posting,
 	 *  unlike chkEvent() */
 	void chkPowerEvent(unsigned int sid, unsigned int cur, unsigned int mask, const char* name, 
-										 std::string actname[PowerSourceID::NumPowerSIDs],
-										 std::string dename[PowerSourceID::NumPowerSIDs],
-										 unsigned int summask[PowerSourceID::NumPowerSIDs]) {
+										 std::string actname[PowerSrcID::NumPowerSIDs],
+										 std::string dename[PowerSrcID::NumPowerSIDs],
+										 unsigned int summask[PowerSrcID::NumPowerSIDs]) {
 		if(cur&mask) {
 			actname[sid]+=name;
 			summask[sid]|=mask;
@@ -249,11 +261,11 @@ private:
  * @brief Describes WorldState, maintains information about the robot's environment, namely sensors and power status
  * @author ejt (Creator)
  *
- * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.36 $
+ * $Author: kcomer $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.46 $
  * $State: Exp $
- * $Date: 2006/10/03 22:00:08 $
+ * $Date: 2007/11/15 21:33:04 $
  */
 
 #endif
