@@ -1,10 +1,11 @@
 #include "WorldStatePool.h"
 #include "Shared/MarkScope.h"
 #include "Shared/debuget.h"
+#include "Shared/Config.h"
 #include "IPC/RCRegion.h"
 #ifndef PLATFORM_APERIOS
 #  include "Events/EventRouter.h"
-#  include "local/LoadFileThread.h"
+#  include "local/LoadDataThread.h"
 #endif
 
 //better to put this here instead of the header
@@ -19,14 +20,14 @@ WorldStatePool::WorldStatePool() : order(), lock() {
 #ifdef PLATFORM_APERIOS
 		stateLookupMap[i]=NULL;
 #else
-		complete[i]=MutexLockBase::getSemaphoreManager()->getSemaphore();
+		complete[i]=MessageQueueBase::getSemaphoreManager()->getSemaphore();
 #endif
 		order.push_back(i);
 	}
 #ifdef PLATFORM_APERIOS
 	complete[order.size()-1].lock(ProcessID::getID());
 #else
-	MutexLockBase::getSemaphoreManager()->setValue(complete[order.size()-1],1);
+	MessageQueueBase::getSemaphoreManager()->setValue(complete[order.size()-1],1);
 #endif
 }
 
@@ -119,7 +120,7 @@ WorldStatePool::UpdateInfo* WorldStatePool::isUnread(const RCRegion& msg, unsign
 	//cout << ProcessID::getIDStr() << " checking tgtFr=" << curFrameNumber << " lastFr=" << lastFrameNumber << " fdbkAv=" << haveFeedback << " ovrd="<<motionOverride << endl;
 	
 	static UpdateInfo info; // avoiding heap allocation by using static here, but this means not threadsafe (shouldn't be a problem...)
-	info.payload=LoadFileThread::deserializeHeader(msg.Base(),msg.Size(),&info.verbose,&info.frameNumber,&info.filename,&info.dataInQueue,&info.payloadSize);
+	info.payload=LoadDataThread::deserializeHeader(msg.Base(),msg.Size(),&info.verbose,&info.frameNumber,&info.filename,&info.dataInQueue,&info.payloadSize);
 	if(info.payload==NULL)
 		throw std::runtime_error("deserialization of sensor update header failed");
 	if(info.frameNumber<curFrameNumber) {
@@ -135,15 +136,13 @@ WorldStatePool::UpdateInfo* WorldStatePool::isUnread(const RCRegion& msg, unsign
 #endif
 	if(toUse==-1U)
 		return NULL; //error occurred, should already be reported
-	if(info.verbose) {
-		if(info.payloadSize==0)
-			cout << ProcessID::getIDStr() << " received sensor heartbeat at " << get_time() << endl;
-		else
-			cout << ProcessID::getIDStr() << " received sensor data \"" << info.filename << "\" at " << get_time() << endl;
-	}
+	if(info.verbose>=3 && info.payloadSize==0)
+		cout << ProcessID::getIDStr() << " received sensor heartbeat at " << get_time() << endl;
+	else if(info.verbose>=2 && info.payloadSize!=0)
+		cout << ProcessID::getIDStr() << " received sensor data \"" << info.filename << "\" at " << get_time() << endl;
 	//cout << "Intending to use " << toUse << " holding frame " << frames[toUse] << " marked " << (isComplete(toUse)?"complete":"not complete") << " with status " << status[toUse] << " for frame " << info.frameNumber << endl;
 	if(frames[toUse]==info.frameNumber && isComplete(toUse)) {
-		if(info.frameNumber-lastFrameNumber!=1 && info.verbose)
+		if(info.frameNumber-lastFrameNumber!=1 && info.verbose>=1)
 			cout << ProcessID::getIDStr() << " dropped " << (info.frameNumber-lastFrameNumber-1) << " sensor frame(s)" << endl;
 		lastFrameNumber=info.frameNumber;
 		//cout << ProcessID::getIDStr() << " decided frame is complete or nothing to contribute" << endl;
@@ -178,6 +177,10 @@ bool WorldStatePool::read(const WorldStatePool::UpdateInfo& info, WriteRequest&
 					if(!isZeroPID(wsw.src,i))
 						state->outputs[i]=feedback->getOutputCmd(i).value;
 			}
+			//Apply calibration to the joints (this reverses the calibration from MotionManager
+			for (uint i=0; i<NumPIDJoints; i++)
+				state->outputs[i+PIDJointOffset] = state->outputs[i+PIDJointOffset] / config->motion.calibration_scale[i]
+					- config->motion.calibration_offset[i];
 			wsw.setStatus(wsw.getStatus() | FEEDBACK_APPLIED);
 		}
 	
@@ -222,8 +225,11 @@ bool WorldStatePool::read(const WorldStatePool::UpdateInfo& info, WriteRequest&
 			unsigned int stateFrame=state->frameNumber; //back up current frame number so we can restore it after the load 
 			// new sensor values are provided
 			pose.setLoadedSensors(state);
-			//cout << "Parsing sensor data" << endl;
-			if(!pose.loadBuffer(info.payload,info.payloadSize)) {
+			//cout << "Parsing sensor data " << info.payloadSize << " bytes" << endl;
+			//cout << string(info.payload,info.payloadSize) << endl;
+			size_t x=pose.loadBuffer(info.payload,info.payloadSize);
+			//cout << "read " << x << endl;
+			if(!x) {
 				cerr << "ERROR: Corrupted sensor readings received by Main" << endl;
 				return false;
 			}
@@ -235,9 +241,9 @@ bool WorldStatePool::read(const WorldStatePool::UpdateInfo& info, WriteRequest&
 			
 			if(!feedbackGenerated) {
 				// no feedback, so just use all of the values we just loaded
-				// weight should already be set to 1 from load (otherwise would need pose.setWeights(1) or assign wsw.src values)
-				for(unsigned int i=0; i<NumOutputs; ++i)
-					ASSERT(pose(i).weight>0,"zero weight found after loading"); // one would expect the compiler to no-op this loop ifndef DEBUG
+				// weight may be 0 if sensor which sent update doesn't provide joint positions
+				//for(unsigned int i=0; i<NumOutputs; ++i)
+				//ASSERT(pose(i).weight>0,"zero weight found after loading"); // one would expect the compiler to no-op this loop ifndef DEBUG
 			} else if(zeroPIDFeedback) {
 				// feedback is applied, regardless of PID settings
 				if(feedback!=NULL) {
@@ -252,22 +258,22 @@ bool WorldStatePool::read(const WorldStatePool::UpdateInfo& info, WriteRequest&
 					for(unsigned int i=0; i<NumPIDJoints; ++i)
 						if(!isZeroPID(wsw.src,i))
 							pose(i+PIDJointOffset)=feedback->getOutputCmd(i).value;
-						else
-							ASSERT(pose(i+PIDJointOffset).weight!=0,"zero weight found after loading");
+						/*else // this can happen validly if starting up with zero PID and unknown positions
+							ASSERT(pose(i+PIDJointOffset).weight!=0,"zero weight found after loading");*/
 					wsw.setStatus(wsw.getStatus() | FEEDBACK_APPLIED);
 				} else {
 					// this process doesn't have the feedback, only fill in the non-feedback
 					for(unsigned int i=0; i<NumPIDJoints; ++i)
 						if(!isZeroPID(wsw.src,i))
 							pose(i+PIDJointOffset).weight=0; // don't apply sensor values to non-zero pids (this will come from feedback later)
-						else
-							ASSERT(pose(i+PIDJointOffset).weight!=0,"zero weight found after loading");
+						/*else // this can happen validly if starting up with zero PID and unknown positions
+							ASSERT(pose(i+PIDJointOffset).weight!=0,"zero weight found after loading");*/
 				}
 			}
 		}
 		state->read(pose,wsw.src,erouter);
 		//ASSERT((state->frameNumber-5)/4==wsw.frame,"state frame number and message serial number are desynchronized " << state->frameNumber << " vs " << wsw.frame);
-		state->frameNumber=wsw.frame*4+5; //lets dropped messages be skipped
+		state->frameNumber=(wsw.frame+1)*NumFrames+1; //lets dropped messages be skipped
 		wsw.setStatus(wsw.getStatus() | SENSORS_APPLIED);
 	}
 	wsw.setComplete(feedbackGenerated && wsw.getStatus()==(SENSORS_APPLIED|FEEDBACK_APPLIED) || !feedbackGenerated && (wsw.getStatus()&SENSORS_APPLIED)!=0);
@@ -281,7 +287,7 @@ bool WorldStatePool::read(const WorldStatePool::UpdateInfo& info, WriteRequest&
 unsigned int WorldStatePool::getCurrentReadState(WorldState*& tgt, bool block) {
 	unsigned int toUse=-1U;
 	if(block) {
-		while(toUse!=order.end()) {
+		while(toUse!=order.back()) {
 			{
 				MarkScope l(lock);
 				if(toUse!=-1U) { //newer frame added while we were waiting
@@ -294,7 +300,7 @@ unsigned int WorldStatePool::getCurrentReadState(WorldState*& tgt, bool block) {
 #ifdef PLATFORM_APERIOS
 			MarkScope wl(complete[toUse]); //now block until writing lock is released
 #else
-			MutexLockBase::getSemaphoreManager()->testZero(complete[toUse],true); //block until complete semaphore is released (set to 0)
+			MessageQueueBase::getSemaphoreManager()->testZero(complete[toUse],true); //block until complete semaphore is released (set to 0)
 #endif
 		}
 	} else {
@@ -307,12 +313,23 @@ unsigned int WorldStatePool::getCurrentReadState(WorldState*& tgt, bool block) {
 		}
 		if(idx==order.end()) {
 			std::cerr << "ERROR: WorldStatePool unable to read state because none available" << std::endl;
-			return -1U;
+			//return -1U;
+			std::cerr << "       falling into most recent buffer" << std::endl;
+			toUse=order.prev(order.end());
 		}
 		reading[toUse]++;
 	}
 	//std::cout << ProcessID::getID() << " reading " << toUse << endl;
 	//ASSERTRETVAL(toUse!=-1U,"toUse was not chosen!",-1U);
+#ifdef DEBUG
+	if(toUse==-1U) {
+		std::cerr << "ERROR: WorldStatePool: toUse was not chosen!" << std::endl;
+		//return -1U;
+		std::cerr << "       falling into most recent buffer" << std::endl;
+		toUse=order.prev(order.end());
+		reading[toUse]++;
+	}
+#endif
 	tgt=&states[toUse];
 	return toUse;
 }
@@ -326,7 +343,7 @@ bool WorldStatePool::isComplete(unsigned int idx) const {
 #ifdef PLATFORM_APERIOS
 	return static_cast<unsigned int>(complete[idx].owner())==MutexLockBase::NO_OWNER;
 #else
-	return MutexLockBase::getSemaphoreManager()->testZero(complete[idx],false);
+	return MessageQueueBase::getSemaphoreManager()->testZero(complete[idx],false);
 #endif
 }
 
@@ -388,7 +405,7 @@ unsigned int WorldStatePool::getCurrentWriteState(WorldState*& tgt, unsigned int
 			complete[toUse].releaseAll(); //make sure it wasn't an incomplete frame that's being recycled
 			complete[toUse].lock(ProcessID::getID());
 #else
-			MutexLockBase::getSemaphoreManager()->setValue(complete[toUse],1);
+			MessageQueueBase::getSemaphoreManager()->setValue(complete[toUse],1);
 #endif
 		}
 	}
@@ -417,7 +434,7 @@ void WorldStatePool::doneWritingState(unsigned int i, bool completed) {
 		if(!isComplete(i))
 			complete[i].unlock();
 #else
-		MutexLockBase::getSemaphoreManager()->setValue(complete[i],0);
+		MessageQueueBase::getSemaphoreManager()->setValue(complete[i],0);
 #endif
 	}
 	writeLocks[i].unlock();
@@ -429,9 +446,9 @@ void WorldStatePool::doneWritingState(unsigned int i, bool completed) {
  * @brief 
  * @author Ethan Tira-Thompson (ejt) (Creator)
  *
- * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.21 $
+ * $Author: kcomer $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.30 $
  * $State: Exp $
- * $Date: 2006/09/28 20:42:51 $
+ * $Date: 2007/11/15 21:33:04 $
  */
