@@ -41,6 +41,7 @@ is also working on the same frame.
 */
 class WorldStatePool : public Resource {
 public:
+	//! common base class for ReadRequest or WriteRequest
 	class Request : public Resource::Data {
 	protected:
 		//! constructor, sets the WorldState point to be assigned, whether to block, and whether is an instance of ReadRequest
@@ -139,13 +140,14 @@ public:
 	//! returned by isUnread containing information parsed from the incoming message
 	class UpdateInfo {
 	public:
+		//! constructor
 		UpdateInfo()
 #ifdef DEBUG
-			: verbose(false), frameNumber(-1U), filename(), dataInQueue(false), payload(NULL), payloadSize(0), intendedBuf(-1U) {}
+			: verbose(0), frameNumber(-1U), filename(), dataInQueue(false), payload(NULL), payloadSize(0), intendedBuf(-1U) {}
 #else
-			: verbose(false), frameNumber(-1U), filename(), dataInQueue(false), payload(NULL), payloadSize(0) {}
+			: verbose(0), frameNumber(-1U), filename(), dataInQueue(false), payload(NULL), payloadSize(0) {}
 #endif
-		bool verbose; //!< status of processing the message should be displayed
+		unsigned int verbose; //!< status of processing the message should be displayed
 		unsigned int frameNumber; //!< serial number of the message
 		std::string filename; //!< source of the data in the message
 		bool dataInQueue; //!< sender indicates data is in the queue (if this is heartbeat, treat it as data)
@@ -207,7 +209,7 @@ protected:
 	order_t order;
 	
 	//! shorthand to test if all three P, I, and D values are 0 for the specified joint index (relative to 0, not PIDJointOffset)
-	static bool isZeroPID(WorldState* s, unsigned int i) { return s->pids[i][0]==0 && s->pids[i][1]==0 && s->pids[i][2]==0; }
+	static bool isZeroPID(WorldState* s, unsigned int i) { return i>=PIDJointOffset && i<PIDJointOffset+NumPIDJoints && s->pids[i][0]==0 && s->pids[i][1]==0 && s->pids[i][2]==0; }
 	
 	//! called when access to an entry for reading is requested
 	unsigned int getCurrentReadState(WorldState*& tgt, bool block);
@@ -273,10 +275,10 @@ private:
  * @author Ethan Tira-Thompson (ejt) (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.15 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.19 $
  * $State: Exp $
- * $Date: 2006/09/19 05:39:33 $
+ * $Date: 2007/11/11 23:57:26 $
  */
 
 #endif
