@@ -27,13 +27,13 @@ namespace debuget {
 	
 	#ifdef DEBUG
 	//! if the bool b is false, std::cout the string
-	#define ASSERT(b,msgstream) {if(!(b)) { std::stringstream ss; ss << msgstream; debuget::displayAssert(__FILE__,__LINE__,ss.str().c_str()); }}
+	#define ASSERT(b,msgstream) {if(!(b)) { std::stringstream DEBUGET_ss; DEBUGET_ss << msgstream; debuget::displayAssert(__FILE__,__LINE__,DEBUGET_ss.str().c_str()); }}
 	//! if the bool b is false, std::cout the string and return
-	#define ASSERTRET(b,msgstream) {if(!(b)) { std::stringstream ss; ss << msgstream; debuget::displayAssert(__FILE__,__LINE__,ss.str().c_str()); return; }}
+	#define ASSERTRET(b,msgstream) {if(!(b)) { std::stringstream DEBUGET_ss; DEBUGET_ss << msgstream; debuget::displayAssert(__FILE__,__LINE__,DEBUGET_ss.str().c_str()); return; }}
 	//! if the bool b is false, std::cout the string and return the value
-	#define ASSERTRETVAL(b,msgstream,v) {if(!(b)) { std::stringstream ss; ss << msgstream; debuget::displayAssert(__FILE__,__LINE__,ss.str().c_str()); return v; }}
+	#define ASSERTRETVAL(b,msgstream,v) {if(!(b)) { std::stringstream DEBUGET_ss; DEBUGET_ss << msgstream; debuget::displayAssert(__FILE__,__LINE__,DEBUGET_ss.str().c_str()); return v; }}
 	//! if the bool b is false, std::cout the string and exit(x)
-	#define ASSERTFATAL(b,msgstream,x) {if(!(b)) { std::stringstream ss; ss << msgstream; debuget::displayAssert(__FILE__,__LINE__,ss.str().c_str()); exit(x); }}
+	#define ASSERTFATAL(b,msgstream,x) {if(!(b)) { std::stringstream DEBUGET_ss; DEBUGET_ss << msgstream; debuget::displayAssert(__FILE__,__LINE__,DEBUGET_ss.str().c_str()); exit(x); }}
 	#else
 	//! if the bool b is false, std::cout the string
 	#define ASSERT(b,msgstream) {}
@@ -143,13 +143,13 @@ namespace debuget {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.14 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.15 $
  * $State: Exp $
- * $Date: 2006/09/27 21:12:31 $
- * $Revision: 1.14 $
+ * $Date: 2007/11/01 18:51:37 $
+ * $Revision: 1.15 $
  * $State: Exp $
- * $Date: 2006/09/27 21:12:31 $
+ * $Date: 2007/11/01 18:51:37 $
  */
 
 #endif
