@@ -1401,6 +1401,7 @@ protected:
    friend class GeneralMatrix;
    friend class GenericMatrix;
 public:
+   ShiftedMatrix(const ShiftedMatrix& im) : BaseMatrix(im), bm(im.bm), f(im.f) {}
    ~ShiftedMatrix() {}
    GeneralMatrix* Evaluate(MatrixType mt=MatrixTypeUnSp);
    friend ShiftedMatrix operator+(Real f, const BaseMatrix& BM);
@@ -1428,6 +1429,7 @@ class ScaledMatrix : public ShiftedMatrix
    friend class GeneralMatrix;
    friend class GenericMatrix;
 public:
+   ScaledMatrix(const ScaledMatrix& im) : ShiftedMatrix(im) {}
    ~ScaledMatrix() {}
    GeneralMatrix* Evaluate(MatrixType mt=MatrixTypeUnSp);
    MatrixBandWidth BandWidth() const;
@@ -1444,6 +1446,7 @@ protected:
 private:
    friend class BaseMatrix;
 public:
+   NegatedMatrix(const NegatedMatrix& im) : BaseMatrix(im), bm(im.bm) {}
    ~NegatedMatrix() {}
    GeneralMatrix* Evaluate(MatrixType mt=MatrixTypeUnSp);
    MatrixBandWidth BandWidth() const;
@@ -1809,6 +1812,17 @@ inline bool operator<(const BaseMatrix& A, const BaseMatrix&)
 inline bool operator>(const BaseMatrix& A, const BaseMatrix&)
    { A.IEQND(); return true; }
 
+// these had been prototypes via 'friend' declaration, but
+// apparently newer versions of gcc now require an explicit prototype
+bool Rectangular(MatrixType a, MatrixType b, MatrixType c);
+bool Compare(const MatrixType&, MatrixType&);
+Real DotProduct(const Matrix& A, const Matrix& B);
+SPMatrix SP(const BaseMatrix&, const BaseMatrix&);
+KPMatrix KP(const BaseMatrix&, const BaseMatrix&);
+ShiftedMatrix operator+(Real f, const BaseMatrix& BM);
+NegShiftedMatrix operator-(Real, const BaseMatrix&);
+ScaledMatrix operator*(Real f, const BaseMatrix& BM);
+
 bool IsZero(const BaseMatrix& A);
 
 Matrix CrossProduct(const Matrix& A, const Matrix& B);
