@@ -19,9 +19,9 @@ namespace NEWMAT {
 
 /**************************** input/output *****************************/
 
-ostream& operator<<(ostream&, const BaseMatrix&);
+std::ostream& operator<<(std::ostream&, const BaseMatrix&);
 
-ostream& operator<<(ostream&, const GeneralMatrix&);
+std::ostream& operator<<(std::ostream&, const GeneralMatrix&);
 
 /**************************** Matlab-code printer *****************************/
 
@@ -31,7 +31,7 @@ class printmat {
   printmat(const Matrix &m) : mat(m) {}
 };
 
-ostream& operator<<(ostream&, const printmat&);
+std::ostream& operator<<(std::ostream&, const printmat&);
 
 /**************************** Old stuff *****************************/
 
