@@ -46,9 +46,13 @@ void BufferedImageGenerator::processEvent(const EventBase & event) {
 			if(imgsrc.width!=getWidth(imgsrc.layer) || imgsrc.height!=getHeight(imgsrc.layer)) {
 				freeCaches();
 				setDimensions();
-				serr->printf("WARNING: the image dimensions don't match values predicted by RobotInfo consts, \"full\" layer now %dx%d\n",widths[ProjectInterface::fullLayer],heights[ProjectInterface::fullLayer]);
-			} else if(strides[numLayers-1]==0) {
-				// first frame, set it anyway
+				if(framesProcessed==0)
+					serr->printf("WARNING: the image dimensions don't match values predicted by RobotInfo consts, \"full\" layer now %dx%d\n",widths[ProjectInterface::fullLayer],heights[ProjectInterface::fullLayer]);
+				else
+					serr->printf("WARNING: the image dimensions have changed since last frame, \"full\" layer now %dx%d\n",widths[ProjectInterface::fullLayer],heights[ProjectInterface::fullLayer]);
+				erouter->postEvent(EventBase::cameraResolutionEGID,event.getSourceID(),EventBase::statusETID);
+			} else if(framesProcessed==0) {
+				// first frame, always set it anyway
 				setDimensions();
 			}
 		}
@@ -119,7 +123,7 @@ BufferedImageGenerator::saveBuffer(char buf[], unsigned int len) const {
 	}
 	unsigned char* img=images[selectedSaveLayer][selectedSaveChannel];
 	unsigned int used=widths[selectedSaveLayer]*heights[selectedSaveLayer];
-	ASSERTRETVAL(used<=len,"buffer too small",0);
+	ASSERTRETVAL(used<=len,"buffer too small " << len << ' ' <<  widths[selectedSaveLayer] << ' ' << heights[selectedSaveLayer],0);
 	unsigned int inc=getIncrement(selectedSaveLayer);
 	if(inc==1) {
 		//special case, straight copy
@@ -280,19 +284,25 @@ void BufferedImageGenerator::calcImage(unsigned int layer, unsigned int channel)
 void BufferedImageGenerator::setDimensions() {
 	if(imgsrc.img==NULL) //don't have an image to set from
 		return;
-	// set dimensions of layers below and including the input layer
+	// set dimensions of layers below the input layer
 	for(unsigned int i=0; i<=imgsrc.layer; i++) {
 		//s is the scaling factor -- 2 means *half* size
 		unsigned int s=(1<<(imgsrc.layer-i));
 		//width and height are scaled down (divide by s)
-		widths[i]=imgsrc.width/s;
+		widths[i]=strides[i]=imgsrc.width/s;
 		heights[i]=imgsrc.height/s;
-		//need to skip rows to make good on promised height (multiply by s)
-		strides[i]=imgsrc.width*imgsrc.channels*s;
-		skips[i]=strides[i]-imgsrc.width*imgsrc.channels;
+		//stride is same as width (set above) -- we allocate these layers, don't skip rows
+		skips[i]=0;
+		increments[i]=1;
 		//cout << "setDimensions() " << widths[i] << ' ' << skips[i] << ' ' << strides[i] << endl;
 	}
-	//set dimensions for layers above the input layer, these are not interleaved
+	// set dimensions of the input layer (interleaved -- note increment and stride)
+	increments[imgsrc.layer] = imgsrc.channels;
+	widths[imgsrc.layer]=imgsrc.width;
+	heights[imgsrc.layer]=imgsrc.height;
+	strides[imgsrc.layer]=imgsrc.width*imgsrc.channels;
+	skips[imgsrc.layer]=0;
+	//set dimensions for layers above the input layer
 	for(unsigned int i=imgsrc.layer+1; i<numLayers; i++) {
 		//s is the scaling factor -- 2 means *double* size
 		unsigned int s=(1<<(i-imgsrc.layer));
@@ -301,6 +311,7 @@ void BufferedImageGenerator::setDimensions() {
 		heights[i]=imgsrc.height*s;
 		//stride is same as width (set above) -- we allocate these layers, don't skip rows
 		skips[i]=0;
+		increments[i]=1;
 	}
 }
 void BufferedImageGenerator::destruct() {
@@ -458,10 +469,10 @@ void BufferedImageGenerator::calcDxDy(unsigned int layer) {
  * @author Ethan Tira-Thompson (ejt) (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.23 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.27 $
  * $State: Exp $
- * $Date: 2006/09/11 23:05:19 $
+ * $Date: 2007/08/20 21:21:27 $
  */
 
 #endif
