@@ -5,6 +5,7 @@
 #include "Wireless/Wireless.h"
 #include "Shared/Config.h"
 #include "Shared/Profiler.h"
+#include "Shared/ProjectInterface.h"
 
 #include "Shared/ODataFormats.h"
 #include "OFbkImage.h"
@@ -68,7 +69,7 @@ CDTGenerator::processEvent(const EventBase& event) {
 				//|| widths[numLayers-2-numRealLayers]*2!=widths[numNotRealLayers]
 				//|| heights[numLayers-2-numRealLayers]*2!=heights[numNotRealLayers]) {
 				//set the width and height of non-real layers (since they don't match what they should be)
-				serr->printf("WARNING: the image dimensions don't match values predicted by RobotInfo consts, now %dx%d\n",widths[numLayers-1],heights[numLayers-1]);
+				serr->printf("WARNING: the image dimensions don't match values predicted by RobotInfo consts, \"full\" layer now %dx%d\n",widths[ProjectInterface::fullLayer],heights[ProjectInterface::fullLayer]);
 				dimchange=true;
 			} else if(strides[0]==0) {
 				dimchange=true;
@@ -262,9 +263,9 @@ CDTGenerator::destruct() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.13 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.14 $
  * $State: Exp $
- * $Date: 2006/09/11 23:05:19 $
+ * $Date: 2007/06/05 21:56:00 $
  */
 
