@@ -3,6 +3,7 @@
 #include "Events/EventRouter.h"
 #include "Wireless/Socket.h"
 #include "Shared/RobotInfo.h"
+#include "Shared/ProjectInterface.h"
 
 using namespace std;
 
@@ -130,6 +131,7 @@ FilterBankGenerator::setDimensions() {
 		widths[i]=src->getWidth(i);
 		heights[i]=src->getHeight(i);
 	}
+	freeCaches();
 }
 
 void
@@ -177,8 +179,11 @@ bool FilterBankGenerator::refresh() {
 		return false;
 	}
 	if(src->getWidth(numLayers-1)!=getWidth(numLayers-1) || src->getHeight(numLayers-1)!=getHeight(numLayers-1)) {
-		serr->printf("WARNING: the image dimensions don't match values predicted by RobotInfo consts, now %dx%d",widths[numLayers-1],heights[numLayers-1]);
 		setDimensions();
+		if(framesProcessed==0)
+			serr->printf("WARNING: %s image dimensions don't match values predicted by RobotInfo consts, \"full\" layer now %dx%d\n",getName().c_str(),widths[ProjectInterface::fullLayer],heights[ProjectInterface::fullLayer]);
+		else
+			serr->printf("WARNING: %s image dimensions have changed since last frame, \"full\" layer now %dx%d\n",getName().c_str(),widths[ProjectInterface::fullLayer],heights[ProjectInterface::fullLayer]);
 	} else if(framesProcessed==0) {
 		setDimensions();
 	}
@@ -193,9 +198,9 @@ bool FilterBankGenerator::refresh() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.11 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.15 $
  * $State: Exp $
- * $Date: 2006/09/09 04:33:04 $
+ * $Date: 2007/08/20 21:21:27 $
  */
 
