@@ -6,10 +6,7 @@
 #include "Wireless/Wireless.h"
 #include "Shared/Config.h"
 #include "Shared/Profiler.h"
-
-#include "Shared/jpeg-6b/jpeg_mem_dest.h"
-
-#include "Shared/debuget.h"
+#include "Shared/ImageUtil.h"
 
 JPEGGenerator::JPEGGenerator(unsigned int mysid, FilterBankGenerator* fbg, EventBase::EventTypeID_t tid)
 	: FilterBankGenerator("JPEGGenerator","JPEGGenerator",EventBase::visJPEGEGID,mysid,fbg,tid), srcMode(SRC_AUTO), curMode(SRC_AUTO), bytesUsed(NULL), cinfo(), jerr(), quality(-1U)
@@ -88,7 +85,7 @@ JPEGGenerator::processEvent(const EventBase& event) {
 unsigned int
 JPEGGenerator::getBinSize() const {
 	unsigned int used=FilterBankGenerator::getBinSize();
-	char * type;
+	const char * type;
 	if(getCurrentSourceFormat()==SRC_COLOR)
 		type="JPEGColor";
 	else if(getCurrentSourceFormat()==SRC_GRAYSCALE)
@@ -142,7 +139,7 @@ JPEGGenerator::saveBuffer(char buf[], unsigned int len) const {
 	unsigned int origlen=len;
 	if(!checkInc(FilterBankGenerator::saveBuffer(buf,len),buf,len)) return 0;
 
-	char * type;
+	const char * type;
 	if(getCurrentSourceFormat()==SRC_COLOR)
 		type="JPEGColor";
 	else if(getCurrentSourceFormat()==SRC_GRAYSCALE)
@@ -194,97 +191,35 @@ JPEGGenerator::createImageCache(unsigned int layer, unsigned int /*chan*/) const
 	return new unsigned char[widths[layer]*heights[layer]*3+JPEG_HEADER_PAD];
 }
 
-/*! This function is taken pretty directly from the write_jpeg_mem()
- *  function from Sony's W3AIBO sample code.
- *
- *  I have adapted it for this object, and added the ability to
- *  process greyscale images as well as color.
- */
 void
 JPEGGenerator::calcImage(unsigned int layer, unsigned int chan) {
 	PROFSECTION("JPEGGenerator::calcImage(...)",*mainProfiler);
-try {
-	//pass the destination buffer and buffer size here
-	jpeg_mem_dest(&cinfo, images[layer][chan], widths[layer]*heights[layer]*3+JPEG_HEADER_PAD);
-
-	// mode setup
-	cinfo.image_width = widths[layer];
-	cinfo.image_height = heights[layer];
+	
+	// input configuration
+	char* inbuf = reinterpret_cast<char*>(src->getImage(layer,chan));
+	size_t inbufSize = src->getWidth(layer)*src->getIncrement(layer)*src->getHeight(layer);
+	size_t srcChans = src->getIncrement(layer);
+	
+	// output configuration
+	ASSERT(images[layer][chan]!=NULL,"image was not allocated");
+	char*& outbuf = reinterpret_cast<char*&>(images[layer][chan]);
+	size_t outbufSize = widths[layer]*heights[layer]*3+JPEG_HEADER_PAD;
+	size_t dstChans;
 	if(getCurrentSourceFormat()==SRC_COLOR ) {
-		cinfo.input_components = 3;		/* # of color components per pixel */
-		cinfo.in_color_space = JCS_YCbCr; /* colorspace of input image */
+		dstChans=3;
 	} else if(getCurrentSourceFormat()==SRC_GRAYSCALE) {
-		cinfo.input_components = 1;		/* # of color components per pixel */
-		cinfo.in_color_space = JCS_GRAYSCALE; /* colorspace of input image */
+		dstChans=1;
 	} else {
 		serr->printf("%s %s Compression failed - unsuitable or unknown mode/generator pair",getClassName().c_str(),getName().c_str());
-		jpeg_destroy_compress(&cinfo);
 		return;
 	}
-
-	// parameter setup
-	jpeg_set_defaults(&cinfo);
-	unsigned int qual=(quality==-1U?config->vision.rawcam_compress_quality:quality);
-	jpeg_set_quality(&cinfo, qual, false); /* limit to baseline-JPEG values */
-	cinfo.dct_method=config->vision.jpeg_dct_method;
-	if(cinfo.in_color_space==JCS_GRAYSCALE && src->getIncrement(layer)!=1) {
-		//special case, need to remove interleaved channels as we compress (single channel, grayscale)
-		jpeg_start_compress(&cinfo, TRUE);
-		unsigned int row_stride = src->getStride(layer);	/* JSAMPLEs per row in image_buffer */
-		JSAMPROW row_pointer[1] = { new JSAMPLE[src->getWidth(layer)] };
-		unsigned char * curpos=src->getImage(layer,chan);
-		const unsigned int inc=src->getIncrement(layer);
-		while (cinfo.next_scanline < cinfo.image_height) {
-			for(unsigned int x=0; x<src->getWidth(layer); x++)
-				row_pointer[0][x] = curpos[x*inc];
-			jpeg_write_scanlines(&cinfo, row_pointer, 1);
-			curpos+=row_stride;
-		}
-		jpeg_finish_compress(&cinfo);
-		
-	} else	{
-		if(cinfo.in_color_space==JCS_YCbCr) {
-			unsigned int ysamp=1;
-			unsigned int uvsamp=1;
-			const unsigned int maxsamp=2;  // according to jpeg docs, this should be able to go up to 4, but I get error: "Sampling factors too large for interleaved scan"
-			if(config->vision.rawcam_y_skip>config->vision.rawcam_uv_skip) {
-				uvsamp=config->vision.rawcam_y_skip-config->vision.rawcam_uv_skip+1;
-				if(uvsamp>maxsamp)
-					uvsamp=maxsamp;
-			} else {
-				ysamp=config->vision.rawcam_uv_skip-config->vision.rawcam_y_skip+1;
-				if(ysamp>maxsamp)
-					ysamp=maxsamp;
-			}
-			cinfo.comp_info[0].h_samp_factor=ysamp;
-			cinfo.comp_info[0].v_samp_factor=ysamp;
-			cinfo.comp_info[1].h_samp_factor=uvsamp;
-			cinfo.comp_info[1].v_samp_factor=uvsamp;
-			cinfo.comp_info[2].h_samp_factor=uvsamp;
-			cinfo.comp_info[2].v_samp_factor=uvsamp;
-		}
-
-		// compression
-		jpeg_start_compress(&cinfo, TRUE);
-		unsigned int row_stride = src->getStride(layer);	/* JSAMPLEs per row in image_buffer */
-		JSAMPROW row_pointer[1] = { const_cast<JSAMPROW>(src->getImage(layer,chan)) };
-		while (cinfo.next_scanline < cinfo.image_height) {
-			jpeg_write_scanlines(&cinfo, row_pointer, 1);
-			row_pointer[0]+=row_stride;
-		}
-		jpeg_finish_compress(&cinfo);
-	}
-
-	// results
-	bytesUsed[layer][chan]=jpeg_mem_size(&cinfo);
-	imageValids[layer][chan]=true;
-} catch(const std::exception& ex) {
-	std::cerr << "Exception while compressing JPEG: " << ex.what() << std::endl; //really, can only be bad_alloc
-	std::cerr << "layer==" << layer << " channel==" << chan << " image==" << (void*)images[layer][chan] << std::endl;
-	std::cerr << "width==" << widths[layer] << " height==" << heights[layer] << std::endl;
-	std::cerr << "row_stride==" << src->getStride(layer) << " next_scanline==" << reinterpret_cast<void*>(cinfo.next_scanline) << " image_height==" << cinfo.image_height << std::endl;
-	jpeg_destroy_compress(&cinfo);
-}
+	unsigned int qual = (quality==-1U?*config->vision.rawcam.compress_quality:quality);
+	unsigned int yskip = config->vision.rawcam.y_skip;
+	unsigned int uvskip = config->vision.rawcam.uv_skip;
+	
+	// do it!
+	bytesUsed[layer][chan] = image_util::encodeJPEG(inbuf,inbufSize,widths[layer],heights[layer],srcChans,outbuf,outbufSize,dstChans,qual,yskip,uvskip,cinfo);
+	imageValids[layer][chan] = (bytesUsed[layer][chan]!=0);
 }
 
 void
@@ -301,9 +236,9 @@ JPEGGenerator::destruct() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.19 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.22.2.1 $
  * $State: Exp $
- * $Date: 2006/09/11 23:05:20 $
+ * $Date: 2009/02/08 03:34:42 $
  */
 
