@@ -3,7 +3,6 @@
 #define INCLUDED_JPEGGenerator_h_
 
 #include "Vision/FilterBankGenerator.h"
-
 extern "C" {
 #include <jpeglib.h>
 }
@@ -102,7 +101,7 @@ protected:
 	struct jpeg_compress_struct cinfo; //!< used to interface with libjpeg - holds compression parameters and state
 	struct jpeg_error_mgr jerr;        //!< used to interface with libjpeg - gives us access to error information
 
-	unsigned int quality; //!< quality level to pass to libjpeg; -1U causes Config::vision_config::rawcam_compress_quality to be used
+	unsigned int quality; //!< quality level to pass to libjpeg; -1U causes Config::vision_config::RawCamBehavior::compress_quality to be used
 	
 private:
 	JPEGGenerator(const JPEGGenerator& fbk); //!< don't call
@@ -114,10 +113,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.13 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.15 $
  * $State: Exp $
- * $Date: 2006/09/16 17:32:40 $
+ * $Date: 2007/04/09 22:22:04 $
  */
 
 #endif
