@@ -5,6 +5,7 @@
 #include "Wireless/Wireless.h"
 #include "Shared/Config.h"
 #include "Shared/Profiler.h"
+#include "Shared/ProjectInterface.h"
 
 #include "Shared/ODataFormats.h"
 #include "OFbkImage.h"
@@ -69,7 +70,7 @@ RawCameraGenerator::processEvent(const EventBase& event) {
 			//|| widths[numLayers-2-numRealLayers]*2!=widths[numNotRealLayers]
 			//|| heights[numLayers-2-numRealLayers]*2!=heights[numNotRealLayers]) {
 			//set the width and height of non-real layers (since they don't match what they should be)
-			serr->printf("WARNING: the image dimensions don't match values predicted by RobotInfo consts, now %dx%d\n",widths[numLayers-1],heights[numLayers-1]);
+			serr->printf("WARNING: the image dimensions don't match values predicted by RobotInfo consts, \"full\" layer now %dx%d\n",widths[ProjectInterface::fullLayer],heights[ProjectInterface::fullLayer]);
 			freeCaches();
 			dimchange=true;
 		} else if(strides[numLayers-1]==0) {
@@ -80,7 +81,7 @@ RawCameraGenerator::processEvent(const EventBase& event) {
 			setDimensions();
 		float testaspect=widths[numLayers-2]/(float)heights[numLayers-2];
 		if(fabs(testaspect-config->vision.aspectRatio)>FLT_EPSILON) {
-			serr->printf("WARNING: the image aspect ratio changed, was %g, now %g (diff %g)\n",config->vision.aspectRatio,testaspect,testaspect-config->vision.aspectRatio);
+			serr->printf("WARNING: the image aspect ratio changed, was %g, now %g (diff %g)\n",*config->vision.aspectRatio,testaspect,testaspect-*config->vision.aspectRatio);
 			config->vision.aspectRatio=testaspect;
 			if(testaspect>1) {
 				config->vision.x_range=1;
@@ -469,9 +470,9 @@ RawCameraGenerator::reconstructImage() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.25 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.27 $
  * $State: Exp $
- * $Date: 2006/09/11 23:05:22 $
+ * $Date: 2007/06/05 21:56:00 $
  */
 
