@@ -117,6 +117,10 @@ public:
 		return getColorRGB(name.c_str());
 	}
 
+        //! returns the name of a color given its index
+       const char* getColorName(const unsigned int index) const {
+	             return (index>=numColors ? NULL : getColors()[index].name);
+	}
 
 	virtual unsigned int getBinSize() const;
 	virtual unsigned int loadBuffer(const char buf[], unsigned int len);
@@ -169,11 +173,11 @@ private:
  * @author alokl (Creator)
  * @author ejt (reorganized)
  *
- * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.16 $
+ * $Author: dst $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.17 $
  * $State: Exp $
- * $Date: 2006/09/22 22:31:44 $
+ * $Date: 2006/11/12 09:08:05 $
  */
 
 #endif
