@@ -1,20 +1,19 @@
-/*========================================================================
-    cmv_region.h : Region and connected component support for CMVision2
-  ------------------------------------------------------------------------
-    Copyright (C) 1999-2002  James R. Bruce
-    School of Computer Science, Carnegie Mellon University
-  ------------------------------------------------------------------------
-    This software is distributed under the GNU General Public License,
-    version 2.  If you do not have a copy of this licence, visit
-    www.gnu.org, or write: Free Software Foundation, 59 Temple Place,
-    Suite 330 Boston, MA 02111-1307 USA.  This program is distributed
-    in the hope that it will be useful, but WITHOUT ANY WARRANTY,
-    including MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-		========================================================================*/
-
 #ifndef __CMV_REGION_H__
 #define __CMV_REGION_H__
 
+/*! @file
+* @brief Region and connected component support for #CMVision
+* @author James R. Bruce, School of Computer Science, Carnegie Mellon University
+*
+* Licensed under the <a href="../gpl-2.0.txt">GNU GPL version 2</a>
+*
+* $Author: ejt $
+* $Name: tekkotsu-4_0-branch $
+* $Revision: 1.11 $
+* $State: Exp $
+* $Date: 2007/11/11 23:57:27 $
+*/
+
 //@todo this should go away - ET
 const unsigned int MAX_COLORS=20;
 
@@ -1062,10 +1061,8 @@ int find(data *arr,int start,int end,data key)
   return(end);
 }
 
-using namespace __gnu_cxx;
-
 template <class color_class_state_t>
-int LoadColorInformation(color_class_state_t *color,int max,const char *filename, hash_map<const char*, unsigned int, hash<const char*>, hashcmp_eqstr> &color_names)
+int LoadColorInformation(color_class_state_t *color,int max,const char *filename, __gnu_cxx::hash_map<const char*, unsigned int, __gnu_cxx::hash<const char*>, hashcmp_eqstr> &color_names)
 {
   char buf[512];
   FILE *in;
