@@ -129,7 +129,7 @@ Socket::init()
 	if ( ::setsockopt ( endpoint, SOL_SOCKET, SO_REUSEADDR, ( const char* ) &on, sizeof ( on ) ) == -1 ) {
 		perror("Socket::init(): SO_REUSEADDR setsockopt");
 	}
-	if(trType==SocketNS::SOCK_DGRAM) {
+	if(trType==Socket::SOCK_DGRAM) {
 		if ( ::setsockopt ( endpoint, SOL_SOCKET, SO_BROADCAST, ( const char* ) &on, sizeof ( on ) ) == -1 ) {
 			perror("Socket::init(): SO_BROADCAST setsockopt");
 		}
@@ -275,9 +275,9 @@ std::string Socket::getPeerAddressAsString() const {
  * @author alokl (Creator)
  * 
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.26 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.27 $
  * $State: Exp $
- * $Date: 2006/07/04 01:36:46 $
+ * $Date: 2007/05/21 20:51:21 $
  */
 
