@@ -6,57 +6,53 @@
 #  include <ant.h>
 #  include <Types.h>
 #else
+#  include <sys/types.h>
 #  include <sys/socket.h>
+typedef unsigned char byte;
 #endif
 #include <stdarg.h>
 #include <stdlib.h>
 #include <string>
 
-//! holds socket enumerations and constants
-namespace SocketNS {
-	
+class SocketListener;
+
+// Sigh... I hate when people define constants via macros...
 #ifdef PLATFORM_APERIOS
-	const int _SYS_SOCK_STREAM=1; //!< aperios doesn't provide SOCK_STREAM, so we will initialize them to these values
-	const int _SYS_SOCK_DGRAM=2;  //!< aperios doesn't provide SOCK_DGRAM, so we will initialize them to these values
-#else
-	//this is why you shouldn't use #define to declare constant values... grrr
-	const int _SYS_SOCK_STREAM=SOCK_STREAM;
-	const int _SYS_SOCK_DGRAM=SOCK_DGRAM;
-#  ifdef SOCK_STREAM
-#    undef SOCK_STREAM
-#  endif
-#  ifdef SOCK_DGRAM
-#    undef SOCK_DGRAM
-#  endif
-#endif
-  //! Specifies transport type. TCP is usually a good idea
-  enum TransportType_t {
-    SOCK_STREAM=_SYS_SOCK_STREAM, //!< TCP: guaranteed delivery, higher overhead
-    SOCK_DGRAM=_SYS_SOCK_DGRAM     //!< UDP: no guarantees, low overhead
-  };
-
-  //! Internal TCP/UDP Connection State
-  enum ConnectionState {
-    CONNECTION_CLOSED,
-    CONNECTION_CONNECTING,
-    CONNECTION_CONNECTED,
-    CONNECTION_LISTENING,
-    CONNECTION_CLOSING,
-    CONNECTION_ERROR
-  };
-
-  //! Chooses between blocking and non-blocking Wireless Input, Output. Blocking wireless output from the main process will affect the performance of the Aibo, and should only be used for debugging purposes
-  enum FlushType_t {
-    FLUSH_NONBLOCKING=0, //!< Writes and Reads return immediately, and are processed by another process, so Main can continue to run. Non-blocking reads require specifying a callback function to handle data received
-    FLUSH_BLOCKING       //!< Blocking writes are a good idea for debugging - a blocking write will be transmitted before execution continues to the next statement. Blocking reads should be avoided, since they'll cause a significant slow down in the main process
-  };
-
+// no socket stuff at all, define it ourselves!
+enum {
+	SOCK_STREAM, //!< aperios doesn't provide SOCK_STREAM, so we will initialize them to these values
+	SOCK_DGRAM //!< aperios doesn't provide SOCK_DGRAM, so we will initialize them to these values
 };
 
-using namespace SocketNS;
+#elif !defined(__DOXYGEN__)
+
+// some platforms give both a 'real' definition and a macro of the same name... need to detect that
+#define doTestSelfRef(foo) defined(x##foo)
+#define testSelfRef(foo) doTestSelfRef(foo)
+
+#define xSOCK_STREAM
+#if defined(SOCK_STREAM) && !testSelfRef(SOCK_STREAM)
+// looks like a macro-only definition, reset it
+enum { _SYS_SOCK_STREAM=SOCK_STREAM };
+#undef SOCK_STREAM
+enum { SOCK_STREAM=_SYS_SOCK_STREAM };
+#define SOCK_STREAM SOCK_STREAM
+#endif
+#undef xSOCK_STREAM
+
+#define xSOCK_DGRAM
+#if defined(SOCK_DGRAM) && !testSelfRef(SOCK_DGRAM)
+// looks like a macro-only definition, reset it
+enum { _SYS_SOCK_DGRAM=SOCK_DGRAM };
+#undef SOCK_DGRAM
+enum { SOCK_DGRAM=_SYS_SOCK_DGRAM };
+#define SOCK_DGRAM SOCK_DGRAM
+#endif
+#undef xSOCK_DGRAM
+
+#undef testSelfRef
+#undef doTestSelfRef
 
-#ifndef PLATFORM_APERIOS
-  typedef unsigned char byte;
 #endif
 
 //! Tekkotsu wireless Socket class
@@ -79,6 +75,28 @@ class Socket {
 public:
   int sock; //!< unique non-negative integer representing socket. Serves as index into socket Objects array
 
+  //! Specifies transport type. TCP is usually a good idea
+  enum TransportType_t {
+    SOCK_STREAM=::SOCK_STREAM, //!< TCP: guaranteed delivery, higher overhead
+    SOCK_DGRAM=::SOCK_DGRAM     //!< UDP: no guarantees, low overhead
+  };
+	
+  //! Internal TCP/UDP Connection State
+  enum ConnectionState {
+    CONNECTION_CLOSED,
+    CONNECTION_CONNECTING,
+    CONNECTION_CONNECTED,
+    CONNECTION_LISTENING,
+    CONNECTION_CLOSING,
+    CONNECTION_ERROR
+  };
+	
+  //! Chooses between blocking and non-blocking Wireless Input, Output. Blocking wireless output from the main process will affect the performance of the Aibo, and should only be used for debugging purposes
+  enum FlushType_t {
+    FLUSH_NONBLOCKING=0, //!< Writes and Reads return immediately, and are processed by another process, so Main can continue to run. Non-blocking reads require specifying a callback function to handle data received
+    FLUSH_BLOCKING       //!< Blocking writes are a good idea for debugging - a blocking write will be transmitted before execution continues to the next statement. Blocking reads should be avoided, since they'll cause a significant slow down in the main process
+  };
+	
 public:
   //! constructor
   explicit Socket(int sockn)
@@ -88,7 +106,7 @@ public:
 			tx(false), rx(false), sendBuffer(), sendData(NULL), writeData(NULL), 
 			recvBuffer(), recvData(NULL), readData(NULL), server_port(0), 
       rcvcbckfn(NULL), peer_addr(-1), peer_port(-1), textForward(false), textForwardBuf(NULL),
-      forwardSock(NULL), daemon(false)
+		  forwardSock(NULL), daemon(false), sckListener(NULL)
 	{
 #ifndef PLATFORM_APERIOS
 		endpoint=-1;
@@ -267,7 +285,8 @@ protected:
   Socket * forwardSock; //!< if non-NULL, output will be sent to this socket if the current socket is not otherwise connected (overrides #textForward)
 
   bool daemon; //!< if true, the socket will automatically be reopened after any closure (manual or otherwise)
- 
+
+	SocketListener *sckListener; //!< if non-null, class based callback interface to provide notification when new data is available for reading
 protected:
   Socket(const Socket&); //!< copy constructor, don't call
   Socket& operator= (const Socket&); //!< assignment operator, don't call
@@ -281,10 +300,10 @@ extern Socket* serr;  //!< the standard tekkotsu error output (default port 1000
  * @author alokl (Creator)
  * 
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.27 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.32 $
  * $State: Exp $
- * $Date: 2006/10/03 22:32:49 $
+ * $Date: 2007/11/10 22:58:11 $
  */
 
 #endif
