@@ -3,6 +3,8 @@
 #include <cstring>
 #include "Shared/ProjectInterface.h"
 
+#include "SocketListener.h"
+
 Wireless *wireless=NULL;
 
 #ifdef PLATFORM_APERIOS
@@ -14,7 +16,6 @@ Wireless *wireless=NULL;
 #  include <UDPEndpointMsg.h>
 #  include "aperios/MMCombo/entry.h"
 
-using namespace SocketNS;
 using namespace std;
 
 Wireless::Wireless ()
@@ -43,12 +44,12 @@ Wireless::~Wireless ()
 	}
 }
 
-Socket* Wireless::socket(TransportType_t ttype)
+Socket* Wireless::socket(Socket::TransportType_t ttype)
 {
 	return socket(ttype, WIRELESS_DEF_RECV_SIZE, WIRELESS_DEF_SEND_SIZE);
 }
 
-Socket* Wireless::socket(TransportType_t ttype, int recvsize, int sendsize)
+Socket* Wireless::socket(Socket::TransportType_t ttype, int recvsize, int sendsize)
 {
 	if (freeSockets.empty()
 			|| (recvsize + sendsize) <= 256) return sockets[0];
@@ -88,12 +89,12 @@ Socket* Wireless::socket(TransportType_t ttype, int recvsize, int sendsize)
 int Wireless::listen(int sock, int port)
 {
 	if ( port <= 0 || port >= 65535 || sock <= 0 || sock >= WIRELESS_MAX_SOCKETS || sockets[sock] == NULL
-			 || sockets[sock]->state != CONNECTION_CLOSED )return -1;
+			 || sockets[sock]->state != Socket::CONNECTION_CLOSED )return -1;
 
 	sockets[sock]->server_port = port;
 	sockets[sock]->init();
 
-	if (sockets[sock]->trType==SocketNS::SOCK_STREAM) {
+	if (sockets[sock]->trType==Socket::SOCK_STREAM) {
 		// create endpoint
 		antEnvCreateEndpointMsg tcpCreateMsg( EndpointType_TCP, ( sockets[sock]->recvBufSize + sockets[sock]->sendBufSize ) * 3 );
 		tcpCreateMsg.Call( ipstackRef, sizeof( tcpCreateMsg ) );
@@ -106,9 +107,9 @@ int Wireless::listen(int sock, int port)
 
 		listenMsg.Send( ipstackRef, myOID, Extra_Entry[entryListenCont], sizeof( listenMsg ) );
 
-		sockets[sock]->state = CONNECTION_LISTENING;
+		sockets[sock]->state = Socket::CONNECTION_LISTENING;
 		return 0;
-	} else if (sockets[sock]->trType==SOCK_DGRAM) {
+	} else if (sockets[sock]->trType==Socket::SOCK_DGRAM) {
 		// create endpoint
 		antEnvCreateEndpointMsg udpCreateMsg( EndpointType_UDP, ( sockets[sock]->recvBufSize + sockets[sock]->sendBufSize ) * 3 );
 		udpCreateMsg.Call( ipstackRef, sizeof( udpCreateMsg ) );
@@ -120,7 +121,7 @@ int Wireless::listen(int sock, int port)
 		bindMsg.Call( ipstackRef, sizeof( bindMsg ) );
 		bindMsg.continuation = ( void * ) sock;
 
-		sockets[sock]->state = CONNECTION_CONNECTING;
+		sockets[sock]->state = Socket::CONNECTION_CONNECTING;
 
 		receive( sock );
 
@@ -137,10 +138,10 @@ int Wireless::listen(int sock, int port)
 int Wireless::connect( int sock, const char * ipaddr, int port )
 {
 	if ( port <= 0 || port >= 65535 || sock <= 0 || sock >= WIRELESS_MAX_SOCKETS || sockets[sock] == NULL
-			 || ( sockets[sock]->trType == SOCK_STREAM && sockets[sock]->state != CONNECTION_CLOSED ) ) return -1;
+			 || ( sockets[sock]->trType == Socket::SOCK_STREAM && sockets[sock]->state != Socket::CONNECTION_CLOSED ) ) return -1;
 
 	sockets[sock]->init();
-	if (sockets[sock]->trType==SOCK_STREAM) {
+	if (sockets[sock]->trType==Socket::SOCK_STREAM) {
 		// create endpoint
 		antEnvCreateEndpointMsg tcpCreateMsg( EndpointType_TCP, ( sockets[sock]->recvBufSize + sockets[sock]->sendBufSize ) * 3 );
 		tcpCreateMsg.Call( ipstackRef, sizeof( tcpCreateMsg ) );
@@ -155,11 +156,11 @@ int Wireless::connect( int sock, const char * ipaddr, int port )
 		sockets[sock]->peer_addr=connectMsg.fAddress.Address();
 		sockets[sock]->peer_port=connectMsg.fPort;
 
-		sockets[sock]->state = CONNECTION_CONNECTING;
+		sockets[sock]->state = Socket::CONNECTION_CONNECTING;
 		return 0;
 	}
 
-	else if ( sockets[sock]->trType == SOCK_DGRAM )
+	else if ( sockets[sock]->trType == Socket::SOCK_DGRAM )
 		{
 			// connect
 			UDPEndpointConnectMsg connectMsg( sockets[sock]->endpoint, ipaddr, port );
@@ -170,7 +171,7 @@ int Wireless::connect( int sock, const char * ipaddr, int port )
 			sockets[sock]->peer_addr=connectMsg.address.Address();
 			sockets[sock]->peer_port=connectMsg.port;
 
-			sockets[sock]->state = CONNECTION_CONNECTED;
+			sockets[sock]->state = Socket::CONNECTION_CONNECTED;
 			//std::cout << "Sock " << sock << " connected via UDP to IP " << ipaddr << " port " << port << std::flush << std::endl;
 
 			return 0;
@@ -189,13 +190,13 @@ try {
 	antEnvMsg * Msg = ( antEnvMsg * ) msg;
 	int sock = ( int )( Msg->continuation );
 
-	if ( sockets[sock]->trType == SOCK_STREAM )
+	if ( sockets[sock]->trType == Socket::SOCK_STREAM )
 		{
 			TCPEndpointListenMsg * listenMsg = ( TCPEndpointListenMsg * ) antEnvMsg::Receive( msg );
 
 			if ( listenMsg->error != TCP_SUCCESS )
 				{
-					sockets[sock]->state = CONNECTION_ERROR;
+					sockets[sock]->state = Socket::CONNECTION_ERROR;
 
 					// no use recycling since its a resource issue
 					return;
@@ -203,7 +204,7 @@ try {
 			sockets[sock]->peer_addr=listenMsg->fAddress.Address();
 			sockets[sock]->peer_port=listenMsg->fPort;
 
-			sockets[sock]->state = CONNECTION_CONNECTED;
+			sockets[sock]->state = Socket::CONNECTION_CONNECTED;
 			//sockets[sock]->local_ipaddr = listenMsg->lAddress.Address();
 			//cout << "Listen set lip: " << local_ipaddr << endl;
 			receive( sock );
@@ -225,16 +226,16 @@ try {
 	antEnvMsg * Msg = ( antEnvMsg * ) msg;
 	int sock = ( int )( Msg->continuation );
 
-	if ( sockets[sock]->trType == SOCK_STREAM )
+	if ( sockets[sock]->trType == Socket::SOCK_STREAM )
 		{
 			TCPEndpointConnectMsg * connectMsg = ( TCPEndpointConnectMsg * ) antEnvMsg::Receive( msg );
 			if ( connectMsg->error != TCP_SUCCESS )
 				{
-					sockets[sock]->state = CONNECTION_ERROR;
+					sockets[sock]->state = Socket::CONNECTION_ERROR;
 					return;
 				}
 
-			sockets[sock]->state = CONNECTION_CONNECTED;
+			sockets[sock]->state = Socket::CONNECTION_CONNECTED;
 			//sockets[sock]->local_ipaddr = connectMsg->lAddress.Address();
 			//cout << "Connect set lip: " << local_ipaddr << endl;
 			receive( sock );
@@ -257,11 +258,11 @@ try {
 	int sock = (int)bindMsg->continuation;
 
 	if (bindMsg->error != UDP_SUCCESS) {
-		sockets[sock]->state = CONNECTION_ERROR;
+		sockets[sock]->state = Socket::CONNECTION_ERROR;
 		return;
 	}
 
-	sockets[sock]->state = CONNECTION_CONNECTED;
+	sockets[sock]->state = Socket::CONNECTION_CONNECTED;
 	/*	if(bindMsg->address.Address()!=0) {
 		//sockets[sock]->local_ipaddr = bindMsg->address.Address();
 		//cout << "Bind set lip: " << local_ipaddr << endl;
@@ -281,10 +282,10 @@ try {
 void
 Wireless::send(int sock)
 {
-	if ( sock <= 0 || sock >= WIRELESS_MAX_SOCKETS || sockets[sock] == NULL || sockets[sock]->state != CONNECTION_CONNECTED
+	if ( sock <= 0 || sock >= WIRELESS_MAX_SOCKETS || sockets[sock] == NULL || sockets[sock]->state != Socket::CONNECTION_CONNECTED
 			 || sockets[sock]->sendSize <= 0 ) return;
 
-	if ( sockets[sock]->trType == SOCK_STREAM )
+	if ( sockets[sock]->trType == Socket::SOCK_STREAM )
 		{
 			TCPEndpointSendMsg sendMsg( sockets[sock]->endpoint, sockets[sock]->sendData, sockets[sock]->sendSize );
 			sendMsg.continuation = ( void * ) sock;
@@ -294,7 +295,7 @@ Wireless::send(int sock)
 			sockets[sock]->sendSize = 0;
 		}
 
-	else if ( sockets[sock]->trType == SOCK_DGRAM )
+	else if ( sockets[sock]->trType == Socket::SOCK_DGRAM )
 		{
 			UDPEndpointSendMsg sendMsg( sockets[sock]->endpoint, sockets[sock]->sendData, sockets[sock]->sendSize );
 
@@ -314,25 +315,25 @@ try {
 	antEnvMsg * Msg = ( antEnvMsg * ) msg;
 	int sock = ( int )( Msg->continuation );
 
-	if ( sockets[sock]->trType == SOCK_STREAM )
+	if ( sockets[sock]->trType == Socket::SOCK_STREAM )
 		{
 			TCPEndpointSendMsg * sendMsg = ( TCPEndpointSendMsg * ) antEnvMsg::Receive( msg );
 			sockets[sock]->tx = false;
 			if ( sendMsg->error != TCP_SUCCESS )
 				{
-					sockets[sock]->state = CONNECTION_ERROR;
+					sockets[sock]->state = Socket::CONNECTION_ERROR;
 					close( sock );
 					return;
 				}
 		}
 
-	else if ( sockets[sock]->trType == SOCK_DGRAM )
+	else if ( sockets[sock]->trType == Socket::SOCK_DGRAM )
 		{
 			UDPEndpointSendMsg * sendMsg = ( UDPEndpointSendMsg * ) antEnvMsg::Receive( msg );
 			sockets[sock]->tx = false;
 			if ( sendMsg->error != UDP_SUCCESS )
 				{
-					sockets[sock]->state = CONNECTION_ERROR;
+					sockets[sock]->state = Socket::CONNECTION_ERROR;
 					close( sock );
 					return;
 				}
@@ -357,10 +358,10 @@ try {
 void
 Wireless::blockingSend(int sock)
 {
-	if ( sock <= 0 || sock >= WIRELESS_MAX_SOCKETS || sockets[sock] == NULL || sockets[sock]->state != CONNECTION_CONNECTED
+	if ( sock <= 0 || sock >= WIRELESS_MAX_SOCKETS || sockets[sock] == NULL || sockets[sock]->state != Socket::CONNECTION_CONNECTED
 			 || sockets[sock]->sendSize <= 0 ) return;
 
-	if ( sockets[sock]->trType == SOCK_STREAM )
+	if ( sockets[sock]->trType == Socket::SOCK_STREAM )
 		{
 			TCPEndpointSendMsg sendMsg( sockets[sock]->endpoint, sockets[sock]->sendData, sockets[sock]->sendSize );
 			sendMsg.continuation = ( void * ) sock;
@@ -382,21 +383,28 @@ Wireless::setReceiver(int sock, int (*rcvcbckfn) (char*, int) )
 	sockets[sock]->rcvcbckfn=rcvcbckfn;
 }
 
+void Wireless::setReceiver(int sock, SocketListener *listener) {
+	if (sock <= 0 || sock >= WIRELESS_MAX_SOCKETS || sockets[sock] == NULL)
+		return;
+	
+	sockets[sock]->sckListener = listener;
+}
+
 void
 Wireless::receive(int sock)
 {
 	if ( sock <= 0 || sock >= WIRELESS_MAX_SOCKETS || sockets[sock] == NULL
-			 || ( sockets[sock]->trType == SOCK_STREAM && sockets[sock]->state != CONNECTION_CONNECTED ) )
+			 || ( sockets[sock]->trType == Socket::SOCK_STREAM && sockets[sock]->state != Socket::CONNECTION_CONNECTED ) )
 		return;
 
-	if ( sockets[sock]->trType == SOCK_STREAM )
+	if ( sockets[sock]->trType == Socket::SOCK_STREAM )
 		{
 			TCPEndpointReceiveMsg receiveMsg( sockets[sock]->endpoint, sockets[sock]->recvData, 1, sockets[sock]->recvBufSize );
 			receiveMsg.continuation = ( void * ) sock;
 			receiveMsg.Send( ipstackRef, myOID, Extra_Entry[entryReceiveCont], sizeof( receiveMsg ) );
 		}
 
-	else if ( sockets[sock]->trType == SOCK_DGRAM )
+	else if ( sockets[sock]->trType == Socket::SOCK_DGRAM )
 		{
 			UDPEndpointReceiveMsg receiveMsg( sockets[sock]->endpoint, sockets[sock]->recvData, sockets[sock]->recvBufSize );
 			receiveMsg.continuation = ( void * ) sock;
@@ -410,18 +418,18 @@ void
 Wireless::receive(int sock, int (*rcvcbckfn) (char*, int) )
 {
 	if (sock<=0 || sock>=WIRELESS_MAX_SOCKETS || sockets[sock]==NULL
-			|| sockets[sock]->state != CONNECTION_CONNECTED) return;
+			|| sockets[sock]->state != Socket::CONNECTION_CONNECTED) return;
 
 	sockets[sock]->rcvcbckfn = rcvcbckfn;
 
-	if ( sockets[sock]->trType == SOCK_STREAM )
+	if ( sockets[sock]->trType == Socket::SOCK_STREAM )
 		{
 			TCPEndpointReceiveMsg receiveMsg( sockets[sock]->endpoint, sockets[sock]->recvData, 1, sockets[sock]->recvBufSize );
 			receiveMsg.continuation = ( void * ) sock;
 			receiveMsg.Send( ipstackRef, myOID, Extra_Entry[entryReceiveCont], sizeof( receiveMsg ) );
 		}
 
-	else if ( sockets[sock]->trType == SOCK_DGRAM )
+	else if ( sockets[sock]->trType == Socket::SOCK_DGRAM )
 		{
 			UDPEndpointReceiveMsg receiveMsg( sockets[sock]->endpoint, sockets[sock]->recvData, sockets[sock]->recvBufSize );
 			receiveMsg.continuation = ( void * ) sock;
@@ -440,27 +448,34 @@ try {
 	int sock = ( int )( Msg->continuation );
 
 	if ( sock <= 0 || sock >= WIRELESS_MAX_SOCKETS || sockets[sock] == NULL
-			 || ( sockets[sock]->state != CONNECTION_CONNECTED && sockets[sock]->state != CONNECTION_CONNECTING ) )
+			 || ( sockets[sock]->state != Socket::CONNECTION_CONNECTED && sockets[sock]->state != Socket::CONNECTION_CONNECTING ) )
 		return;
 
-	if ( sockets[sock]->trType == SOCK_STREAM )
+	if ( sockets[sock]->trType == Socket::SOCK_STREAM )
 		{
 			TCPEndpointReceiveMsg * receiveMsg = ( TCPEndpointReceiveMsg * ) antEnvMsg::Receive( msg );
 			if ( receiveMsg->error != TCP_SUCCESS )
 				{
-					sockets[sock]->state = CONNECTION_ERROR;
+					sockets[sock]->state = Socket::CONNECTION_ERROR;
 					close( sock );
 					return;
 				}
 
 			sockets[sock]->recvSize = receiveMsg->sizeMin;
-			if ( sockets[sock]->rcvcbckfn != NULL )
-				sockets[sock]->rcvcbckfn( ( char * ) sockets[sock]->recvData, sockets[sock]->recvSize );
+			
+			if (sockets[sock]->sckListener != NULL) {
+				sockets[sock]->sckListener->processData((char *)sockets[sock]->recvData,
+														sockets[sock]->recvSize);
+				
+			} else if (sockets[sock]->rcvcbckfn != NULL) {
+				sockets[sock]->rcvcbckfn((char *)sockets[sock]->recvData,
+										 sockets[sock]->recvSize);
+			}
 			sockets[sock]->recvSize = 0;
 
 		}
 
-	else if ( sockets[sock]->trType == SOCK_DGRAM )
+	else if ( sockets[sock]->trType == Socket::SOCK_DGRAM )
 		{
 			UDPEndpointReceiveMsg * receiveMsg;
 			receiveMsg = ( UDPEndpointReceiveMsg * ) antEnvMsg::Receive( msg );
@@ -475,22 +490,22 @@ try {
 
 					sockets[sock]->peer_addr=receiveMsg->address.Address();
 					sockets[sock]->peer_port=receiveMsg->port;
-					if ( !strncmp( "connection request", ( char * ) sockets[sock]->recvData, 18 ) )
-						{
-							// clear this message from the receiving buffer
-							sockets[sock]->recvData += sockets[sock]->recvSize;
-
-							if ( sockets[sock]->state != CONNECTION_CONNECTED )
-								{
-									char caller[14];
-									receiveMsg->address.GetAsString( caller );
-									connect( sock, caller, receiveMsg->port );
-								}
+					if ( !strncmp( "connection request", ( char * ) sockets[sock]->recvData, 18 ) ) {
+						// clear this message from the receiving buffer
+						sockets[sock]->recvData += sockets[sock]->recvSize;
+						
+						if ( sockets[sock]->state != Socket::CONNECTION_CONNECTED ) {
+							char caller[14];
+							receiveMsg->address.GetAsString( caller );
+							connect( sock, caller, receiveMsg->port );
 						}
-
-					else if ( sockets[sock]->rcvcbckfn != NULL )
+						
+					} else if (sockets[sock]->sckListener != NULL) {
+						sockets[sock]->sckListener->processData((char *)sockets[sock]->recvData, sockets[sock]->recvSize);
+						
+					} else if ( sockets[sock]->rcvcbckfn != NULL )
 						sockets[sock]->rcvcbckfn( ( char * ) sockets[sock]->recvData, sockets[sock]->recvSize );
-
+					
 				}
 
 			sockets[sock]->recvSize = 0;
@@ -511,8 +526,8 @@ try {
 void
 Wireless::close(int sock)
 {
-	if (sockets[sock]->state == CONNECTION_CLOSED ||
-			sockets[sock]->state == CONNECTION_CLOSING) return;
+	if (sockets[sock]->state == Socket::CONNECTION_CLOSED ||
+			sockets[sock]->state == Socket::CONNECTION_CLOSING) return;
 
 	if (!(sockets[sock]->server_port>0 && sockets[sock]->daemon)) {
 		sockets[sock]->recvBuffer.UnMap();
@@ -523,14 +538,14 @@ Wireless::close(int sock)
 		sendBufferMsg.Call(ipstackRef, sizeof(antEnvDestroySharedBufferMsg));
 	}
 
-	if ( sockets[sock]->trType == SOCK_STREAM )
+	if ( sockets[sock]->trType == Socket::SOCK_STREAM )
 		{
 			TCPEndpointCloseMsg closeMsg( sockets[sock]->endpoint );
 			closeMsg.continuation = ( void * ) sock;
 			closeMsg.Send( ipstackRef, myOID, Extra_Entry[entryCloseCont], sizeof( closeMsg ) );
 		}
 
-	else if ( sockets[sock]->trType == SOCK_DGRAM )
+	else if ( sockets[sock]->trType == Socket::SOCK_DGRAM )
 		{
 			UDPEndpointCloseMsg closeMsg( sockets[sock]->endpoint );
 			closeMsg.continuation = ( void * ) sock;
@@ -539,7 +554,7 @@ Wireless::close(int sock)
 
 	sockets[sock]->peer_addr=sockets[sock]->peer_port=-1;
 
-	sockets[sock]->state = CONNECTION_CLOSING;
+	sockets[sock]->state = Socket::CONNECTION_CLOSING;
 }
 
 uint32
@@ -574,7 +589,7 @@ try {
 	if ( sockets[sock] == NULL )
 		return;
 
-	sockets[sock]->state = CONNECTION_CLOSED;
+	sockets[sock]->state = Socket::CONNECTION_CLOSED;
 	sockets[sock]->peer_addr=sockets[sock]->peer_port=-1;
 	if ( sockets[sock]->server_port > 0 && sockets[sock]->daemon )
 		{
@@ -663,6 +678,10 @@ void Wireless::setReceiver(int sock, int (*rcvcbckfn) (char*, int) ) {
 	sockets[sock]->rcvcbckfn=rcvcbckfn;
 }
 
+void Wireless::setReceiver(int sock, SocketListener *listener) {
+	sockets[sock]->sckListener = listener;
+}
+
 void Wireless::close(int sock) {
 	MarkScope l(getLock());
 	if ( sock <= 0 || sock >= WIRELESS_MAX_SOCKETS || sockets[sock] == NULL)
@@ -695,7 +714,7 @@ void Wireless::close(int sock) {
 int Wireless::connect(int sock, const char* ipaddr, int port) {
 	MarkScope l(getLock());
 	if ( port <= 0 || port >= 65535 || sock <= 0 || sock >= WIRELESS_MAX_SOCKETS
-			 || sockets[sock] == NULL || sockets[sock]->state != CONNECTION_CLOSED && sockets[sock]->trType!=SocketNS::SOCK_DGRAM )
+			 || sockets[sock] == NULL || sockets[sock]->state != Socket::CONNECTION_CLOSED && sockets[sock]->trType!=Socket::SOCK_DGRAM )
 		return -1;
 	
 	if(sockets[sock]->endpoint==-1)
@@ -722,9 +741,9 @@ int Wireless::connect(int sock, const char* ipaddr, int port) {
 	
 	int status = ::connect ( endpoint, ( sockaddr * ) &m_addr, sizeof ( m_addr ) );
 	if ( status == 0 )
-		sockets[sock]->state=CONNECTION_CONNECTED;
+		sockets[sock]->state=Socket::CONNECTION_CONNECTED;
 	else if(errno==EINPROGRESS)
-		sockets[sock]->state=CONNECTION_CONNECTING;
+		sockets[sock]->state=Socket::CONNECTION_CONNECTING;
 	else {
 		perror("Wireless::connect(): connect");
 		return -1;
@@ -740,7 +759,7 @@ int Wireless::connect(int sock, const char* ipaddr, int port) {
 int Wireless::listen(int sock, int port) {
   MarkScope l(getLock());
   if ( port <= 0 || port >= 65535 || sock <= 0 || sock >= WIRELESS_MAX_SOCKETS
-       || sockets[sock] == NULL || sockets[sock]->state != CONNECTION_CLOSED )
+       || sockets[sock] == NULL || sockets[sock]->state != Socket::CONNECTION_CLOSED )
 		return -1;
   sockets[sock]->server_port = port;
   sockets[sock]->init();
@@ -757,23 +776,23 @@ int Wireless::listen(int sock, int port) {
 		perror("Wireless::listen: bind");
 		return -1;
 	}
-	if(sockets[sock]->trType==SocketNS::SOCK_STREAM) {
+	if(sockets[sock]->trType==Socket::SOCK_STREAM) {
 		int listen_return = ::listen ( endpoint, MAXCONNECTIONS );
 		if ( listen_return == -1 ) {
 			perror("Wireless::listen: listen");
 			return -1;
 		}
 	}
-	sockets[sock]->state = CONNECTION_LISTENING;
+	sockets[sock]->state = Socket::CONNECTION_LISTENING;
 	//this will allow sock to be added to rfds so we can tell when a connection is available
 	wakeup();
 	return 0;
 }
 
-Socket* Wireless::socket(TransportType_t ttype) {
+Socket* Wireless::socket(Socket::TransportType_t ttype) {
 	return socket(ttype, WIRELESS_DEF_RECV_SIZE, WIRELESS_DEF_SEND_SIZE);
 }
-Socket* Wireless::socket(TransportType_t ttype, int recvsize, int sendsize) {
+Socket* Wireless::socket(Socket::TransportType_t ttype, int recvsize, int sendsize) {
 	MarkScope l(getLock());
 	if (freeSockets.empty()
 			|| (recvsize + sendsize) <= 256) return sockets[0];
@@ -824,7 +843,7 @@ Wireless::send(int sock)
 {
 	MarkScope l(getLock());
 	if ( sock <= 0 || sock >= WIRELESS_MAX_SOCKETS || sockets[sock] == NULL
-	    || sockets[sock]->state != CONNECTION_CONNECTED || sockets[sock]->sendSize <= 0 )
+	    || sockets[sock]->state != Socket::CONNECTION_CONNECTED || sockets[sock]->sendSize <= 0 )
 		return;
 	
 	//we could defer all sending to the poll, but let's give a shot at sending it out right away to reduce latency
@@ -859,7 +878,7 @@ Wireless::blockingSend(int sock)
 {
 	MarkScope l(getLock());
 	if ( sock <= 0 || sock >= WIRELESS_MAX_SOCKETS || sockets[sock] == NULL
-	    || sockets[sock]->state != CONNECTION_CONNECTED || sockets[sock]->sendSize <= 0 )
+	    || sockets[sock]->state != Socket::CONNECTION_CONNECTED || sockets[sock]->sendSize <= 0 )
 		return;
 	
 	while(sockets[sock]->sentSize<sockets[sock]->sendSize) {
@@ -909,9 +928,9 @@ void Wireless::pollSetup() {
 			cerr << "ERROR Wireless::pollSetup() encountered bad endpoint " << *it << endl;
 			continue;
 		}
-		if(sockets[*it]->state!=CONNECTION_CLOSED && sockets[*it]->state!=CONNECTION_ERROR)
+		if(sockets[*it]->state!=Socket::CONNECTION_CLOSED && sockets[*it]->state!=Socket::CONNECTION_ERROR)
 			FD_SET(sockets[*it]->endpoint, &rfds);
-		if(sockets[*it]->state==CONNECTION_CONNECTING || sockets[*it]->tx)
+		if(sockets[*it]->state==Socket::CONNECTION_CONNECTING || sockets[*it]->tx)
 			FD_SET(sockets[*it]->endpoint, &wfds);
 		FD_SET(sockets[*it]->endpoint, &efds);
 		if(sockets[*it]->endpoint>fdsMax)
@@ -956,12 +975,12 @@ void Wireless::pollProcess() {
 		int s=sockets[*it]->endpoint;
 		if(FD_ISSET(s,&rfds)) {
 			//cout << *it << " set in read" << endl;
-			if(sockets[*it]->state==CONNECTION_CONNECTING) {
+			if(sockets[*it]->state==Socket::CONNECTION_CONNECTING) {
 				//cout << "Wireless::pollProcess(): read set on connecting" << endl;
-				sockets[*it]->state=CONNECTION_CONNECTED;
+				sockets[*it]->state=Socket::CONNECTION_CONNECTED;
 			}
-			if(sockets[*it]->state==CONNECTION_LISTENING) {
-				if(sockets[*it]->trType==SocketNS::SOCK_STREAM) {
+			if(sockets[*it]->state==Socket::CONNECTION_LISTENING) {
+				if(sockets[*it]->trType==Socket::SOCK_STREAM) {
 					sockaddr_in m_addr;
 					socklen_t addrlen=sizeof(m_addr);
 					int n=accept(s,(sockaddr*)&m_addr,&addrlen);
@@ -976,7 +995,7 @@ void Wireless::pollProcess() {
 					if(::close(s)==-1)
 						perror("Wireless::pollProcess(): close");
 					s=sockets[*it]->endpoint=n;
-					sockets[*it]->state=CONNECTION_CONNECTED;
+					sockets[*it]->state=Socket::CONNECTION_CONNECTED;
 					//cout << "Accepted connection" << endl;
 				} else {
 					//cout << "UDP accept" << endl;
@@ -1003,8 +1022,19 @@ void Wireless::pollProcess() {
 						//cout << "Read " << sockets[*it]->recvSize << " bytes " << sockets[*it]->rcvcbckfn << endl;
 						if ( !strncmp( "connection request", ( char * ) sockets[*it]->recvData, 18 ) ) {
 							// clear this message from the receiving buffer
-							if ( sockets[*it]->state != CONNECTION_CONNECTED )
+							if ( sockets[*it]->state != Socket::CONNECTION_CONNECTED )
 								connect( *it, sockets[*it]->getPeerAddressAsString().c_str(), sockets[*it]->getPeerPort() );
+						} else if (sockets[*it]->sckListener != NULL) {
+							try {
+								sockets[*it]->sckListener->processData((char *)sockets[*it]->recvData,
+																	   sockets[*it]->recvSize);
+							} catch(const std::exception& ex) {
+								if(!ProjectInterface::uncaughtException(__FILE__,__LINE__,"Occurred during networking received data callback",&ex))
+									throw;
+							} catch(...) {
+								if(!ProjectInterface::uncaughtException(__FILE__,__LINE__,"Occurred during networking received data callback",NULL))
+									throw;
+							}
 						} else if ( sockets[*it]->rcvcbckfn != NULL ) {
 							try {
 								sockets[*it]->rcvcbckfn( ( char * ) sockets[*it]->recvData, sockets[*it]->recvSize );
@@ -1019,7 +1049,7 @@ void Wireless::pollProcess() {
 						sockets[*it]->recvSize = 0;
 					}
 				}
-			} else if(sockets[*it]->state==CONNECTION_CONNECTED || sockets[*it]->state==CONNECTION_CLOSING) {
+			} else if(sockets[*it]->state==Socket::CONNECTION_CONNECTED || sockets[*it]->state==Socket::CONNECTION_CLOSING) {
 				sockets[*it]->recvSize = recvfrom(s,sockets[*it]->recvData,sockets[*it]->recvBufSize,0,NULL,NULL);
 				if(sockets[*it]->recvSize==-1) {
 					if(errno!=EAGAIN) { //may have just completed connection, not a problem
@@ -1041,7 +1071,18 @@ void Wireless::pollProcess() {
 					continue;
 				} else {
 					//cout << "Read " << sockets[*it]->recvSize << " bytes " << sockets[*it]->rcvcbckfn << endl;
-					if ( sockets[*it]->rcvcbckfn != NULL ) {
+					if (sockets[*it]->sckListener != NULL) {
+						try {
+							sockets[*it]->sckListener->processData((char *)sockets[*it]->recvData,
+																	   sockets[*it]->recvSize);
+						} catch(const std::exception& ex) {
+							if(!ProjectInterface::uncaughtException(__FILE__,__LINE__,"Occurred during networking received data callback",&ex))
+								throw;
+						} catch(...) {
+							if(!ProjectInterface::uncaughtException(__FILE__,__LINE__,"Occurred during networking received data callback",NULL))
+								throw;
+						}
+					} else if ( sockets[*it]->rcvcbckfn != NULL ) {
 						try {
 							sockets[*it]->rcvcbckfn( ( char * ) sockets[*it]->recvData, sockets[*it]->recvSize );
 						} catch(const std::exception& ex) {
@@ -1070,9 +1111,9 @@ void Wireless::pollProcess() {
 		}
 		if(FD_ISSET(s,&wfds)) {
 			//cout << *it << " set in write" << endl;
-			if(sockets[*it]->state==CONNECTION_CONNECTING) {
-				sockets[*it]->state=CONNECTION_CONNECTED;
-			} else if(sockets[*it]->state==CONNECTION_CONNECTED) {
+			if(sockets[*it]->state==Socket::CONNECTION_CONNECTING) {
+				sockets[*it]->state=Socket::CONNECTION_CONNECTED;
+			} else if(sockets[*it]->state==Socket::CONNECTION_CONNECTED) {
 				if(!sockets[*it]->tx) {
 					//cerr << "Wireless::pollProcess(): write available on non-tx socket??" << endl;
 					//can happen on a refused connection
@@ -1137,9 +1178,9 @@ void Wireless::clearCallbackLock() {
  * @verbinclude CMPack_license.txt
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.37 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.41 $
  * $State: Exp $
- * $Date: 2006/06/26 16:24:17 $
+ * $Date: 2007/10/16 17:37:22 $
  */
 
