@@ -3,6 +3,7 @@
 #include "Shared/Profiler.h"
 #include "Shared/debuget.h"
 #include "Shared/Config.h"
+#include "Shared/zignor.h"
 #include "IPC/SharedObject.h"
 #include "Events/EventRouter.h"
 #include "Events/EventTranslator.h"
@@ -33,22 +34,23 @@
 
 using namespace std;
 
+//#define NO_PROFILING
+#ifdef NO_PROFILING
+#undef PROFSECTION
+#define PROFSECTION(...) {}
+#endif
+
 MMCombo::MMCombo()
 	: OObject(), motmanMemRgn(NULL), motionProfilerMemRgn(NULL), soundProfilerMemRgn(NULL),
 		worldStatePoolMemRgn(NULL), soundManagerMemRgn(NULL), processMapMemRgn(NULL),
-		runLevel(0), num_open(0), etrans(NULL), wspool(NULL), entryPt(), isStopped(true)
+		runLevel(0), num_open(0), etrans(NULL), wspool(NULL), entryPt(), isStopped(true),
+		gainListener(), shutterListener(), wbListener()
 {
 try {
 	for(unsigned int i=0; i<NumOutputs; i++) {
 		primIDs[i]=oprimitiveID_UNDEF;
 		open[i]=false;
 	}
-
-	//need to register any events which we might be sending or receiving
-	EventTranslator::registerPrototype<EventBase>();
-	EventTranslator::registerPrototype<LocomotionEvent>();
-	EventTranslator::registerPrototype<TextMsgEvent>();
-	EventTranslator::registerPrototype<VisionObjectEvent>();
 } catch(const std::exception& ex) {
 	if(!ProjectInterface::uncaughtException(__FILE__,__LINE__,"Occurred during MMCombo construction",&ex))
 		throw;
@@ -58,7 +60,6 @@ try {
 }
 }
 
-
 OStatus
 MMCombo::DoInit(const OSystemEvent&)
 {
@@ -117,10 +118,20 @@ try {
 	
 	
 	//Read config file
-	config=new Config("/ms/config/tekkotsu.cfg");
-
+	::config = new Config();
+	::config->setFileSystemRoot("/ms");
+	::config->vision.gain.addPrimitiveListener(&gainListener);
+	::config->vision.shutter_speed.addPrimitiveListener(&shutterListener);
+	::config->vision.white_balance.addPrimitiveListener(&wbListener);
+	if(::config->loadFile("config/tekkotsu.xml")==0) {
+		if(::config->loadFile("config/tekkotsu.cfg")==0)
+			std::cerr << std::endl << " *** ERROR: Could not load configuration file config/tekkotsu.xml *** " << std::endl << std::endl;
+		else
+			std::cerr << "Successfully imported settings from old-format tekkotsu.cfg" << std::endl;
+	}
+	
 	erouter = new EventRouter;
-
+	
 	if(strcmp(objectName,"MainObj")==0) {
 		bool isSlowOutput[NumOutputs];
 		for(unsigned int i=0; i<NumOutputs; i++)
@@ -140,14 +151,18 @@ try {
 		
 		//Setup wireless
 		wireless = new Wireless();
-		sout=wireless->socket(SocketNS::SOCK_STREAM,Wireless::WIRELESS_DEF_RECV_SIZE,Wireless::WIRELESS_DEF_SEND_SIZE*12);
-		serr=wireless->socket(SocketNS::SOCK_STREAM,Wireless::WIRELESS_DEF_RECV_SIZE,Wireless::WIRELESS_DEF_SEND_SIZE*4);
+		sout=wireless->socket(Socket::SOCK_STREAM,Wireless::WIRELESS_DEF_RECV_SIZE,Wireless::WIRELESS_DEF_SEND_SIZE*12);
+		serr=wireless->socket(Socket::SOCK_STREAM,Wireless::WIRELESS_DEF_RECV_SIZE,Wireless::WIRELESS_DEF_SEND_SIZE*4);
 		wireless->setDaemon(sout);
 		wireless->setDaemon(serr);
-			serr->setFlushType(SocketNS::FLUSH_BLOCKING);
+			serr->setFlushType(Socket::FLUSH_BLOCKING);
 		sout->setTextForward();
 		serr->setForward(sout);
 		
+		//Have erouter listen for incoming stuff
+		cout << "Telling erouter to serve remote event requests" << endl;
+		erouter->serveRemoteEventRequests();
+		
 		//worldStatePoolMemRgn -> state setup
 		worldStatePoolMemRgn = InitRegion(sizeof(WorldStatePool));
 		wspool=new ((WorldStatePool*)worldStatePoolMemRgn->Base()) WorldStatePool;
@@ -166,11 +181,11 @@ try {
 
 		//Setup wireless
 		wireless = new Wireless();
-		sout=wireless->socket(SocketNS::SOCK_STREAM,Wireless::WIRELESS_DEF_RECV_SIZE,Wireless::WIRELESS_DEF_SEND_SIZE*6);
-		serr=wireless->socket(SocketNS::SOCK_STREAM,Wireless::WIRELESS_DEF_RECV_SIZE,Wireless::WIRELESS_DEF_SEND_SIZE*2);
+		sout=wireless->socket(Socket::SOCK_STREAM,Wireless::WIRELESS_DEF_RECV_SIZE,Wireless::WIRELESS_DEF_SEND_SIZE*6);
+		serr=wireless->socket(Socket::SOCK_STREAM,Wireless::WIRELESS_DEF_RECV_SIZE,Wireless::WIRELESS_DEF_SEND_SIZE*2);
 		wireless->setDaemon(sout);
 		wireless->setDaemon(serr);
-		serr->setFlushType(SocketNS::FLUSH_BLOCKING);
+		serr->setFlushType(Socket::FLUSH_BLOCKING);
 		sout->setTextForward();
 		serr->setForward(sout);
 		
@@ -454,7 +469,7 @@ try {
 		// there's new sensor info, but we didn't get the event
 		//(Motion drops event if there's anything else already in the queue, might not have been a sensor event in the queue though)
 		unsigned int t=get_time();
-		erouter->postEvent(EventBase::sensorEGID,SensorSourceID::UpdatedSID,EventBase::statusETID,t-lastSensorTime,"SensorSouceID::UpdatedSID",1);
+		erouter->postEvent(EventBase::sensorEGID,SensorSrcID::UpdatedSID,EventBase::statusETID,t-lastSensorTime,"SensorSouceID::UpdatedSID",1);
 		lastSensorTime=t;
 		//if(state->frameNumber-lastSensorFrame!=NumFrames && lastSensorFrame!=-1U)
 		//cout << ProcessID::getIDStr() << " dropped " << (state->frameNumber-lastSensorFrame-NumFrames)/NumFrames << " sensor frames" << endl;
@@ -537,6 +552,7 @@ try {
 		return;
 	}
 
+#ifndef NO_PROFILING
 	static unsigned int id=-1U;
 	Profiler::Timer timer;
 	if(ProcessID::getID()==ProcessID::MotionProcess) {
@@ -548,6 +564,7 @@ try {
 			id=mainProfiler->getNewID("ReadySendJoints()");
 		timer.setID(id,&mainProfiler->prof);
 	}
+#endif
 
 	if(num_open==0) //If we don't have any joints to open, leave now. (i.e. MainObj on a 220, has no ears)
 		return;
@@ -572,24 +589,31 @@ try {
 	
 	// Update the outputs (note that Main is doing the ears)
 	//I'm using an id compare instead of the slightly more readable strcmp for a tiny bit of speed
-	bool isERS7;
-	if(state!=NULL)
-		isERS7=state->robotDesign&WorldState::ERS7Mask;
-	else {
-		char robotDesignStr[orobotdesignNAME_MAX + 1];
-		memset(robotDesignStr, 0, sizeof(robotDesignStr));
-		if (OPENR::GetRobotDesign(robotDesignStr) != oSUCCESS) {
-			cout << objectName << "::SetupOutputs - OPENR::GetRobotDesign() failed." << endl;
-			return;
-		}
-		isERS7=(strcmp(robotDesignStr,"ERS-7")==0);
-	}		
+	bool isERS7=(RobotName == ERS7Info::TargetName);
 	if(ProcessID::getID()==ProcessID::MotionProcess) {
 		float outputs[NumFrames][NumOutputs];
 		if(state!=NULL) {
+			static bool seededRNG=false;
+			if(!seededRNG) {
+				seededRNG=true;
+				initRNG();
+			}
 			motman->getOutputs(outputs);
 			motman->updatePIDs(primIDs);
-			motman->updateWorldState();
+			
+			//cout << "updateWorldState" << endl;
+			for(uint output=LEDOffset; output<LEDOffset+NumLEDs; output++)
+				state->outputs[output]=motman->getOutputCmd(output).value;
+			for(uint output=BinJointOffset; output<BinJointOffset+NumBinJoints; output++)
+				state->outputs[output]=motman->getOutputCmd(output).value;
+			
+			// these parts check to see if there are "fake" joints, and sets their "sensed" values
+			// to be the current target value, just in case a behavior is waiting for a non-existant
+			// non-existant joint to move to a certain position.
+			const std::set<unsigned int>& fakes = RobotInfo::capabilities.getFakeOutputs();
+			for(std::set<unsigned int>::const_iterator it=fakes.begin(); it!=fakes.end(); ++it)
+				state->outputs[*it]=motman->getOutputCmd(*it).value;
+			
 		} else {
 			for(unsigned int f=0; f<NumFrames; f++)
 				for(unsigned int i=0; i<NumOutputs; i++)
@@ -600,10 +624,9 @@ try {
 		unsigned int used=0; //but only copy open joints (so main does ears on 210, motion does everything else)
 		for(unsigned int i=PIDJointOffset; i<PIDJointOffset+NumPIDJoints; i++)
 			if(open[i]) {
-				float cal=config->motion.calibration[i-PIDJointOffset];
 				OJointCommandValue2* jval = reinterpret_cast<OJointCommandValue2*>(cmdVecData->GetData(used)->value);
 				for(unsigned int frame=0; frame<NumFrames; frame++)
-					jval[frame].value = (slongword)(outputs[frame][i]/cal*1.0e6f);
+					jval[frame].value = (slongword)(outputs[frame][i]*1.0e6f);
 				used++;
 			}
 		if(isERS7) {
@@ -715,6 +738,7 @@ try {
 		return;
 	}
 
+#ifndef NO_PROFILING
 	static unsigned int id=-1U;
 	Profiler::Timer timer;
 	if(ProcessID::getID()==ProcessID::MotionProcess) {
@@ -726,7 +750,8 @@ try {
 			id=mainProfiler->getNewID("GotSensorFrame()");
 		timer.setID(id,&mainProfiler->prof);
 	}
-	TimeET t;
+#endif
+	//TimeET t;
 
 	OSensorFrameVectorData* rawsensor = reinterpret_cast<OSensorFrameVectorData*>(event.RCData(0)->Base());
 	static unsigned int lastFrameNumber=-1U;
@@ -768,30 +793,10 @@ try {
 		//if(wsw.frame-lastFrameNumber!=NumFrames)
 		//	cout << objectName << " dropped " << (wsw.frame-lastFrameNumber-NumFrames)/NumFrames << " sensor frame(s)" << endl;
 		lastFrameNumber=wsw.frame;
-		//seed the random number generator with time value and sensor noise
-		if(wasLastThrowAway && config->main.seed_rng) {
-			double tv=TimeET().Value(); //current time with nanosecond resolution
-			unsigned int * tm=reinterpret_cast<unsigned int*>(&tv);
-			unsigned int seed=tm[0]+tm[1];
-			for(unsigned int i=0; i<NumPIDJoints; i++) { //joint positions
-				unsigned int * x=reinterpret_cast<unsigned int*>(&state->outputs[i]);
-				seed+=(*x)<<((i%sizeof(unsigned int))*8);
-			}
-			for(unsigned int i=0; i<NumPIDJoints; i++) { //joint forces
-				unsigned int * x=reinterpret_cast<unsigned int*>(&state->pidduties[i]);
-				seed+=(*x)<<((i%sizeof(unsigned int))*8);
-			}
-			for(unsigned int i=0; i<NumSensors; i++) {
-				unsigned int * x=reinterpret_cast<unsigned int*>(&state->sensors[i]);
-				seed+=(*x)<<((i%sizeof(unsigned int))*8); //sensor values
-			}
-			cout << "RNG seed=" << seed << endl;;
-			srand(seed);
-		}
 		//cout << objectName << " done updating sensors " << info->frameNumber << " at " << TimeET() << " (" << (t.Age()*1000) << "ms)" << endl;
 	}
 	if(info!=NULL) { // notify main of update, but only if there's no backlog
-		etrans->encodeEvent(EventBase(EventBase::sensorEGID,SensorSourceID::UpdatedSID,EventBase::statusETID,0,"SensorSouceID::UpdatedSID",1),true);
+		etrans->encodeEvent(EventBase(EventBase::sensorEGID,SensorSrcID::UpdatedSID,EventBase::statusETID,0,"SensorSouceID::UpdatedSID",1),true);
 	}
 		
 	observer[obsSensorFrame]->AssertReady();
@@ -927,7 +932,7 @@ try {
 	// i'm leaving this low-level because there's not much else you can do anyway...
 	// the hardware kills power to the motors, and as far as we can tell, you can't
 	// turn them back on.
-	if(state->powerFlags[PowerSourceID::PauseSID]) {
+	if(state->powerFlags[PowerSrcID::PauseSID]) {
 		cout << "%%%%%%%  Pause button was pushed! %%%%%%%" << endl;
 		OBootCondition bc(0);
 		OPENR::Shutdown(bc);
@@ -1033,26 +1038,9 @@ MMCombo::OpenPrimitives()
 void
 MMCombo::SetupOutputs(const bool to_open[NumOutputs])
 {
-	char robotDesignStr[orobotdesignNAME_MAX + 1];
-	memset(robotDesignStr, 0, sizeof(robotDesignStr));
-	if (OPENR::GetRobotDesign(robotDesignStr) != oSUCCESS) {
-		cout << objectName << "::SetupOutputs - OPENR::GetRobotDesign() failed." << endl;
-		return;
-	} else {
-		if(strcmp(robotDesignStr,"ERS-210")==0) {
-			for(unsigned int j=0; j<NumOutputs; j++)
-				open[j]=to_open[j] && ERS210Info::IsRealERS210[j];
-		} else if(strcmp(robotDesignStr,"ERS-220")==0) {
-			for(unsigned int j=0; j<NumOutputs; j++)
-				open[j]=to_open[j] && ERS220Info::IsRealERS220[j];
-		} else if(strcmp(robotDesignStr,"ERS-7")==0) {
-			for(unsigned int j=0; j<NumOutputs; j++)
-				open[j]=to_open[j] && ERS7Info::IsRealERS7[j];
-		} else {
-			cout << "MMCombo::SetupOutputs - ERROR: Unrecognized model: "<<robotDesignStr<<"\nSorry..."<<endl;
-			return;
-		}
-	}
+	const std::set<unsigned int>& fakes = RobotInfo::capabilities.getFakeOutputs();
+	for(unsigned int j=0; j<NumOutputs; j++)
+		open[j] = to_open[j] && fakes.find(j)==fakes.end();
 	
 	// count how many we're opening
 	for(unsigned int j=0; j<NumOutputs; j++)
@@ -1082,7 +1070,7 @@ MMCombo::SetupOutputs(const bool to_open[NumOutputs])
 				OCommandInfo* info = cmdVecData->GetInfo(used++);
 				info->Set(odataJOINT_COMMAND2, primIDs[j], NumFrames);
 			}
-		if(strcmp(robotDesignStr,"ERS-7")==0) {
+		if(RobotName == ERS7Info::TargetName) {
 			// this part's the same as usual, except stop when we get to face leds
 			for(unsigned int j=LEDOffset; j<ERS7Info::FaceLEDPanelOffset; j++)
 				if(open[j]) {
@@ -1144,11 +1132,42 @@ MMCombo::InitRegion(unsigned int size) {
 	return new RCRegion(pages*pagesize);
 }
 
+void
+MMCombo::initRNG() {
+	//seed the random number generator with time value and sensor noise
+	if(config->main.seed_rng) {
+		double tv=TimeET().Value(); //current time with nanosecond resolution
+		unsigned int * tm=reinterpret_cast<unsigned int*>(&tv);
+		unsigned int seed=tm[0]+tm[1];
+		for(unsigned int i=0; i<NumPIDJoints; i++) { //joint positions
+			unsigned int * x=reinterpret_cast<unsigned int*>(&state->outputs[i]);
+			seed+=(*x)<<((i%sizeof(unsigned int))*8);
+		}
+		for(unsigned int i=0; i<NumPIDJoints; i++) { //joint forces
+			unsigned int * x=reinterpret_cast<unsigned int*>(&state->pidduties[i]);
+			seed+=(*x)<<((i%sizeof(unsigned int))*8);
+		}
+		for(unsigned int i=0; i<NumSensors; i++) {
+			unsigned int * x=reinterpret_cast<unsigned int*>(&state->sensors[i]);
+			seed+=(*x)<<((i%sizeof(unsigned int))*8); //sensor values
+		}
+		cout << ProcessID::getIDStr() << " RNG seed=" << seed << ", zignor seeds: " << *tm << ',' << seed << endl;
+		srand(seed);
+		RanNormalSetSeedZig32((int*)&seed,1);
+		RanNormalSetSeedZig((int*)&seed,1);
+	} else {
+		int s=12345;
+		RanNormalSetSeedZig32(&s,1);
+		RanNormalSetSeedZig(&s,1);
+	}
+}
+
 void
 MMCombo::addRunLevel() {
 	runLevel++;
 	if(runLevel==readyLevel) {
 		try {
+			initRNG();
 			cout << "START UP BEHAVIOR..." << flush;
 			ProjectInterface::startupBehavior().DoStart();
 			cout << "START UP BEHAVIOR-DONE" << endl;
@@ -1162,16 +1181,61 @@ MMCombo::addRunLevel() {
 	}
 }
 
+void MMCombo::GainSettingListener::plistValueChanged(const plist::PrimitiveBase& pl) {
+	typedef plist::NamedEnumeration<Config::vision_config::gain_levels> GainSetting;
+	OPrimitiveID fbkID = 0;
+	if(OPENR::OpenPrimitive(CameraLocator, &fbkID) != oSUCCESS){
+		std::cout << "Open FbkImageSensor failure." << std::endl;
+	} else if(const GainSetting* v=dynamic_cast<const GainSetting*>(&pl)) {
+		OPrimitiveControl_CameraParam ogain(*v);
+		if(OPENR::ControlPrimitive(fbkID, oprmreqCAM_SET_GAIN, &ogain, sizeof(ogain), 0, 0) != oSUCCESS)
+			std::cout << "CAM_SET_GAIN : Failed!" << std::endl;
+		OPENR::ClosePrimitive(fbkID);
+	} else {
+		std::cerr << "GainSettingListener got a value changed notification for a non-gain_levels primitive, ignoring..." << std::endl;
+	}
+}
+
+void MMCombo::ShutterSettingListener::plistValueChanged(const plist::PrimitiveBase& pl) {
+	typedef plist::NamedEnumeration<Config::vision_config::shutter_speeds> SpeedSetting;
+	OPrimitiveID fbkID = 0;
+	if(OPENR::OpenPrimitive(CameraLocator, &fbkID) != oSUCCESS){
+		std::cout << "Open FbkImageSensor failure." << std::endl;
+	} else if(const SpeedSetting* v=dynamic_cast<const SpeedSetting*>(&pl)) {
+		OPrimitiveControl_CameraParam oshutter(*v);
+		if(OPENR::ControlPrimitive(fbkID,oprmreqCAM_SET_SHUTTER_SPEED, &oshutter, sizeof(oshutter), 0, 0) != oSUCCESS)
+			std::cout << "CAM_SET_SHUTTER_SPEED : Failed!" << std::endl;
+		OPENR::ClosePrimitive(fbkID);
+	} else {
+		std::cerr << "ShutterSettingListener got a value changed notification for a non-shutter_speeds primitive, ignoring..." << std::endl;
+	}
+}
+
+void MMCombo::WhiteBalanceSettingListener::plistValueChanged(const plist::PrimitiveBase& pl) {
+	typedef plist::NamedEnumeration<Config::vision_config::white_balance_levels> WBSetting;
+	OPrimitiveID fbkID = 0;
+	if(OPENR::OpenPrimitive(CameraLocator, &fbkID) != oSUCCESS){
+		std::cerr << "Open FbkImageSensor failure." << std::endl;
+	} else if(const WBSetting* v=dynamic_cast<const WBSetting*>(&pl)) {
+		OPrimitiveControl_CameraParam owb(*v);
+		if(OPENR::ControlPrimitive(fbkID, oprmreqCAM_SET_WHITE_BALANCE, &owb, sizeof(owb), 0, 0) != oSUCCESS)
+			std::cerr << "CAM_SET_WHITE_BALANCE : Failed!" << std::endl;
+		OPENR::ClosePrimitive(fbkID);
+	} else {
+		std::cerr << "WhiteBalanceSettingListener got a value changed notification for a non-white_balance_levels primitive, ignoring..." << std::endl;
+	}
+}
+
 
 /*! @file
  * @brief Implements MMCombo, the OObject which "forks" (sort of) into Main and Motion processes
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.20 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.34 $
  * $State: Exp $
- * $Date: 2006/09/19 20:10:33 $
+ * $Date: 2007/11/21 21:15:07 $
  */
 
 
