@@ -1,7 +1,9 @@
 #include "StartupBehavior.h"
 
 #include "Behaviors/Controller.h"
-#include "Behaviors/Controls/BatteryCheckControl.h"
+#ifdef TGT_HAS_POWER_STATUS
+#  include "Behaviors/Controls/BatteryCheckControl.h"
+#endif
 #include "Behaviors/Controls/ControlBase.h"
 #include "Behaviors/Controls/HelpControl.h"
 #include "Behaviors/Controls/RebootControl.h"
@@ -66,12 +68,14 @@ void StartupBehavior::DoStart() {
 	stop_id=motman->addPersistentMotion(stop,MotionManager::kEmergencyPriority);
 	spawnedMC.push_back(stop_id);
 	
+#ifdef TGT_HAS_POWER_STATUS
 	//This displays the current battery conditions on the console
 	BatteryCheckControl batchk;
 	//	const SharedObject<LedMC> led;
 	//	batchk.activate(motman->addPrunableMotion(led,MotionManager::kEmergencyPriority+1),NULL);
 	batchk.activate(MotionManager::invalid_MC_ID,NULL);
 	batchk.deactivate();
+#endif
 
 	//This is what runs the menu system
 	Controller * controller=new Controller;
@@ -83,23 +87,18 @@ void StartupBehavior::DoStart() {
 	
 	sndman->playFile("roar.wav");
 
+#ifdef TGT_HAS_MOUTH
 	//This will close the mouth so it doesn't look stupid or get in the
 	//way of head motions (ERS-210 or ERS-7 only)
-	unsigned int mouthOffset=-1U;
-	if(state->robotDesign & WorldState::ERS210Mask)
-		mouthOffset=ERS210Info::MouthOffset;
-	if(state->robotDesign & WorldState::ERS7Mask)
-		mouthOffset=ERS7Info::MouthOffset;
-	if(mouthOffset!=-1U) {
-		SharedObject<TinyMotionSequenceMC> closeMouth;
-		closeMouth->advanceTime(3000); //take 3 seconds to close the mouth
-		closeMouth->setOutputCmd(mouthOffset,outputRanges[mouthOffset][MaxRange]);
-		closeMouth->advanceTime(500); //and hold it for another .5 seconds
-		closeMouth->setOutputCmd(mouthOffset,outputRanges[mouthOffset][MaxRange]);
-		MotionManager::MC_ID id=motman->addPrunableMotion(closeMouth,MotionManager::kEmergencyPriority+1);
-		erouter->addTimer(this,1,3250,false);
-		spawnedMC.push_back(id);
-	}
+	SharedObject<TinyMotionSequenceMC> closeMouth;
+	closeMouth->advanceTime(3000); //take 3 seconds to close the mouth
+	closeMouth->setOutputCmd(MouthOffset,outputRanges[MouthOffset][MaxRange]);
+	closeMouth->advanceTime(500); //and hold it for another .5 seconds
+	closeMouth->setOutputCmd(MouthOffset,outputRanges[MouthOffset][MaxRange]);
+	MotionManager::MC_ID id=motman->addPrunableMotion(closeMouth,MotionManager::kEmergencyPriority+1);
+	erouter->addTimer(this,1,3250,false);
+	spawnedMC.push_back(id);
+#endif
 	
 	//! we want to know if one of our MCs autoprunes (or is otherwise removed)
 	for(unsigned int i=0; i<spawnedMC.size(); i++)
@@ -155,20 +154,17 @@ void StartupBehavior::processEvent(const EventBase& event) {
 				//when this goes through, it will trigger the event handler below to follow through cleanup of the id
 				motman->removeMotion(pid_id);
 			}
+#ifdef TGT_HAS_MOUTH
 		} else if(event.getSourceID()==1) {
 			//we're done closing the mouth... set the mouth to closed in the estop too
 			//otherwise it might twitch a little when the MotionSequence expires and the estop takes over
 			// (little == +/-.1 radians, aka estop's threshold for resetting an "out of place" joint) (details, details)
-			unsigned int mouthOffset=-1U;
-			if(state->robotDesign & WorldState::ERS210Mask)
-				mouthOffset=ERS210Info::MouthOffset;
-			if(state->robotDesign & WorldState::ERS7Mask)
-				mouthOffset=ERS7Info::MouthOffset;
-			if(mouthOffset!=-1U) {
-				MMAccessor<EmergencyStopMC> estop(stop_id);
-				float weight=estop->getOutputCmd(mouthOffset).weight;
-				estop->setOutputCmd(mouthOffset,OutputCmd(outputRanges[mouthOffset][MaxRange],weight));
-			}
+			MMAccessor<EmergencyStopMC> estop(stop_id);
+			float weight=estop->getOutputCmd(MouthOffset).weight;
+			estop->setOutputCmd(MouthOffset,OutputCmd(outputRanges[MouthOffset][MaxRange],weight));
+#endif
+		} else {
+			cerr << "Warning: StartupBehavior got unknown timer event: " << event.getName() << endl;
 		}
 		
 	} else if(event.getGeneratorID()==EventBase::motmanEGID) {
