@@ -1,23 +1,33 @@
 #include "StartupBehavior.h"
+#include "Shared/RobotInfo.h"
 
 #include "Behaviors/Controls/ControlBase.h"
 #include "Behaviors/Controls/BehaviorSwitchControl.h"
 
-#include "Behaviors/Services/FlashIPAddrBehavior.h"
+#ifdef TGT_HAS_ACCELEROMETERS
+#  include "Behaviors/Services/AutoGetupBehavior.h"
+#endif
+#ifdef TGT_HAS_LEDS
+#  include "Behaviors/Services/FlashIPAddrBehavior.h"
+#endif
 #include "Behaviors/Demos/SimpleChaseBallBehavior.h"
 #include "Behaviors/Demos/StareAtBallBehavior.h"
-#include "Behaviors/Services/AutoGetupBehavior.h"
-#include "Behaviors/Services/BatteryMonitorBehavior.h"
-#include "Behaviors/Demos/HeadLevelBehavior.h"
+#ifdef TGT_HAS_POWER_STATUS
+#  include "Behaviors/Services/BatteryMonitorBehavior.h"
+#endif
 #include "Behaviors/Demos/ToggleHeadLightBehavior.h"
 #include "Behaviors/Demos/CrashTestBehavior.h"
 #include "Behaviors/Demos/FreezeTestBehavior.h"
 #include "Behaviors/Demos/RelaxBehavior.h"
 #include "Behaviors/Services/WorldStateVelDaemon.h"
 #include "Behaviors/Demos/CameraBehavior.h"
-#include "Behaviors/Demos/MotionStressTestBehavior.h"
+#ifdef TGT_HAS_LEGS
+#  include "Behaviors/Demos/MotionStressTestBehavior.h"
+#endif
 #include "Behaviors/Demos/ASCIIVisionBehavior.h"
-#include "Behaviors/Nodes/TailWagNode.h"
+#ifdef TGT_HAS_TAIL
+#  include "Behaviors/Nodes/TailWagNode.h"
+#endif
 #include "Sound/PitchDetector.h"
 
 #include "Behaviors/Demos/TestBehaviors.h"
@@ -29,17 +39,20 @@ StartupBehavior::SetupBackgroundBehaviors() {
 	{ 
 		addItem(new BehaviorSwitchControl<SimpleChaseBallBehavior>("Simple Chase Ball",false));
 		addItem(new BehaviorSwitchControl<StareAtBallBehavior>("Stare at Ball",false));
-		addItem(new BehaviorSwitchControl<HeadLevelBehavior>("Head Level",false));
-		if(state->robotDesign & WorldState::ERS220Mask)
+		if(RobotName==ERS220Info::TargetName)
 			addItem(new BehaviorSwitchControl<ToggleHeadLightBehavior>("Toggle Head Light",false));
+#ifdef TGT_HAS_TAIL
 		addItem(new BehaviorSwitchControl<TailWagNode>("Wag Tail",false));
+#endif
 		addItem(new BehaviorSwitchControl<RelaxBehavior>("Relax",false));
 		addItem(new BehaviorSwitchControl<CameraBehavior>("Camera",false));
 		addItem((new BehaviorSwitchControl<ASCIIVisionBehavior>("ASCIIVision",false)));
 		addItem(new ControlBase("Debugging Tests","Stress tests"));
 		startSubMenu();
 		{
+#ifdef TGT_HAS_LEGS
 			addItem(new BehaviorSwitchControl<MotionStressTestBehavior>("Motion Stress Test",false));
+#endif
 			addItem(new BehaviorSwitchControl<CrashTestBehavior>("Crash Test",false));
 			addItem(new BehaviorSwitchControl<FreezeTestBehavior>("Freeze Test",false));
 			// these following behaviors are all found in TestBehaviors.h, too small to warrant individual files
@@ -54,10 +67,16 @@ StartupBehavior::SetupBackgroundBehaviors() {
 		addItem(new ControlBase("System Daemons","Provide some common sensor or event processing"));
 		startSubMenu();
 		{
+#ifdef TGT_HAS_ACCELEROMETERS
 			addItem((new BehaviorSwitchControl<AutoGetupBehavior>("Auto Getup",false)));
+#endif
+#ifdef TGT_HAS_LEDS
 			addItem((new BehaviorSwitchControl<FlashIPAddrBehavior>("Flash IP Address",false))->start());
+#endif
 			addItem((new BehaviorSwitchControl<WorldStateVelDaemon>("World State Vel Daemon",false))->start());
+#ifdef TGT_HAS_POWER_STATUS
 			addItem((new BehaviorSwitchControl<BatteryMonitorBehavior>("Battery Monitor",false))->start());
+#endif
 			addItem((new BehaviorSwitchControl<PitchDetector>("Pitch Detection",false))->start());
 		}
 		endSubMenu();
