@@ -1,8 +1,11 @@
 #include "StartupBehavior.h"
+#include "Shared/RobotInfo.h"
 
 #include "Behaviors/Controls/ControlBase.h"
 
-#include "Behaviors/Controls/BatteryCheckControl.h"
+#ifdef TGT_HAS_POWER_STATUS
+#  include "Behaviors/Controls/BatteryCheckControl.h"
+#endif
 #include "Behaviors/Controls/FreeMemReportControl.h"
 #include "Behaviors/Controls/ProfilerCheckControl.h"
 #include "Behaviors/Controls/EventLogger.h"
@@ -16,7 +19,9 @@ StartupBehavior::SetupStatusReports() {
 	startSubMenu();
 	{
 		addItem(new BehaviorReportControl());
+#ifdef TGT_HAS_POWER_STATUS
 		addItem(new BatteryCheckControl());
+#endif
 		addItem(new ProfilerCheckControl());
 		addItem(new EventLogger());
 		addItem(new SensorObserverControl());
