@@ -1,4 +1,5 @@
 #include "StartupBehavior.h"
+#include "Shared/RobotInfo.h"
 
 #include "Shared/ProjectInterface.h"
 #include "Shared/Config.h"
@@ -23,7 +24,9 @@
 #include "Vision/CDTGenerator.h"
 
 #include "Behaviors/Demos/DrawVisObjBoundBehavior.h"
+#ifdef TGT_HAS_LEGS
 #include "Behaviors/Demos/DrawSkeletonBehavior.h"
+#endif
 
 using namespace ProjectInterface;
 
@@ -31,7 +34,7 @@ BallDetectionGenerator * pball=NULL;
 BallDetectionGenerator * bball=NULL;
 BallDetectionGenerator * gball=NULL;
 BallDetectionGenerator * yball=NULL;
-BallDetectionGenerator * handball=NULL; //aka orange
+BallDetectionGenerator * oball=NULL; //aka orange
 
 /*! We set the default vision generators and source IDs here.
  *
@@ -106,7 +109,7 @@ StartupBehavior::initVision() {
 
 	// these names match up with /ms/config/default.col - the default
 	// color information... if that changes, these should change too
-	unsigned int threshChan=config->vision.segcam_channel;
+	unsigned int threshChan=config->vision.segcam.channel;
 
 	// higher value reduce false events, but increase reaction time [0-inf]
 	unsigned int noiseFiltering=1;
@@ -136,8 +139,8 @@ StartupBehavior::initVision() {
 	}
 	unsigned int skinIdx=segcol->getColorIndex("orange");
 	if(skinIdx!=-1U) {
-		handball = new BallDetectionGenerator(visHandSID,defRegionGenerator,skinIdx,threshChan,noiseFiltering,confidenceThreshold);
-		handball->setName("HandBallDetectionGenerator");
+		oball = new BallDetectionGenerator(visOrangeSID,defRegionGenerator,skinIdx,threshChan,noiseFiltering,confidenceThreshold);
+		oball->setName("OrangeBallDetectionGenerator");
 	}
 }
 
@@ -147,7 +150,9 @@ StartupBehavior::SetupVision() {
 	startSubMenu();
 	{ 
 		addItem((new BehaviorSwitchControl<DrawVisObjBoundBehavior>("Draw Object Boundaries",false)));
+#ifdef TGT_HAS_LEGS
 		addItem((new BehaviorSwitchControl<DrawSkeletonBehavior>("Draw Skeleton",false)));
+#endif
 #ifndef PLATFORM_APERIOS		
 		addItem(new SimulatorAdvanceFrameControl("Advance Frame"));
 #endif
@@ -205,10 +210,10 @@ StartupBehavior::SetupVision() {
 		else
 			addItem(new NullControl("Error: BlueBallDetectionGenerator","Color \"yellow\" is undefined"));
 
-		if(handball)
-			addItem((new BehaviorSwitchControlBase(handball))->start());
+		if(oball)
+			addItem((new BehaviorSwitchControlBase(oball))->start());
 		else
-			addItem(new NullControl("Error: HandBallDetectionGenerator","Color \"orange\" is undefined"));
+			addItem(new NullControl("Error: OrangeBallDetectionGenerator","Color \"orange\" is undefined"));
 	}
 	return endSubMenu();
 }
