@@ -9,13 +9,14 @@
  * @author PA Gov. School for the Sciences 2003 Team Project - Motion group: Haoqian Chen, Yantian Martin, Jon Stahlman (creators)
  * 
  * $Author: ejt $
- * $Name: tekkotsu-3_0 $
- * $Revision: 1.9 $
+ * $Name: tekkotsu-4_0-branch $
+ * $Revision: 1.15 $
  * $State: Exp $
- * $Date: 2005/09/22 21:54:17 $
+ * $Date: 2007/11/21 22:53:19 $
  */
 
 #include "StartupBehavior.h"
+#include "Shared/RobotInfo.h"
 
 #include "Behaviors/Controls/ControlBase.h"
 
@@ -32,6 +33,13 @@ StartupBehavior::SetupWalkEdit() {
 	addItem(new ControlBase("Walk Edit","Edit the walk parameters"));
 	startSubMenu();
 	{ 
+#if defined(TGT_ERS210) || defined(TGT_ERS220) || defined(TGT_ERS2xx)
+		// Replace this if section with an #if 1 to re-enable
+		// This functionality takes about 1MB of memory on the Aibo between loading the binary
+		// code and the actual control memory usage.
+		addItem(new ControlBase("Disabled to conserve memory"));
+#else
+		
 		//Use this instance of the GUI to try out changes you have made to parameters within this editor
 		//(the one in TekkotsuMon will load fresh parameters from walk.prm on disk and won't know about changes made here)
 		WalkControllerBehavior * walker = new WalkControllerBehavior();
@@ -46,8 +54,8 @@ StartupBehavior::SetupWalkEdit() {
 			addItem(new ValueEditControl<double>("Body Angle",&walker->getWalkMC()->getWP().body_angle));
 			addItem(new ValueEditControl<double>("Hop",&walker->getWalkMC()->getWP().hop));
 			addItem(new ValueEditControl<double>("Sway",&walker->getWalkMC()->getWP().sway));
-			addItem(new ValueEditControl<long>("Period",&walker->getWalkMC()->getWP().period));
-			addItem(new ValueEditControl<long>("Use Diff Drive",&walker->getWalkMC()->getWP().useDiffDrive));
+			addItem(new ValueEditControl<int>("Period",&walker->getWalkMC()->getWP().period));
+			addItem(new ValueEditControl<int>("Use Diff Drive",&walker->getWalkMC()->getWP().useDiffDrive));
 			addItem(new ValueEditControl<float>("Sag",&walker->getWalkMC()->getWP().sag));
 		}
 		endSubMenu();
@@ -144,6 +152,7 @@ StartupBehavior::SetupWalkEdit() {
 
 		addItem(new LoadWalkControl("Load Walk",walker->getWalkMC()));
 		addItem(new SaveWalkControl("Save Walk",walker->getWalkMC()));
+#endif
 	}
 	return endSubMenu();
 }
