@@ -26,11 +26,10 @@ public:
 	virtual void DoStop() {
 		// <your shutdown code here>
 
-		erouter->removeListener(this); //generally a good idea, unsubscribe all
 		BehaviorBase::DoStop(); // do this last (required)
 	}
 
-	virtual void processEvent(const EventBase& e) {
+	virtual void processEvent(const EventBase& event) {
 		// <your event processing code here>
 		// you can delete this function if you don't use any events...
 		// (in which case, you may want to call DoStop() at the end of DoStart()
