@@ -116,7 +116,14 @@ unsigned int skip=1;
 int main(unsigned int argc, const char** argv) {
 	if(argc<3)
 		return usage(argc,argv);
-	config=new Config("tekkotsu.cfg");
+	::config = new Config();
+	::config->setFileSystemRoot("");
+	if(::config->loadFile("tekkotsu.xml")==0) {
+		if(::config->loadFile("tekkotsu.cfg")==0)
+			std::cerr << std::endl << " *** ERROR: Could not load configuration file tekkotsu.xml *** " << std::endl << std::endl;
+		else
+			std::cerr << "Successfully imported settings from old-format tekkotsu.cfg" << std::endl;
+	}
 	unsigned int used=1;
 	bool isRad=true;
 	while(used<argc) {
