@@ -18,9 +18,6 @@ import javax.imageio.stream.MemoryCacheImageInputStream;
 public class UDPVisionListener extends UDPListener implements VisionListener {
   DatagramSocket mysock;
 	
-  byte[] buf = new byte[200000];
-  DatagramPacket incoming = new DatagramPacket(buf, buf.length);
-	
   InputStream in;
 
 	boolean updatedFlag;
@@ -30,7 +27,7 @@ public class UDPVisionListener extends UDPListener implements VisionListener {
 	protected Vector listeners = new Vector();
 	protected boolean updating;
 	
-	public void addListener(VisionUpdatedListener l) { listeners.add(l); }
+	public void addListener(VisionUpdatedListener l) { listeners.add(l); needConnection(); }
 	public void removeListener(VisionUpdatedListener l) { listeners.remove(l); }
 	public void fireVisionUpdate() {
 		updating=true;
@@ -38,6 +35,12 @@ public class UDPVisionListener extends UDPListener implements VisionListener {
 			((VisionUpdatedListener)listeners.get(i)).visionUpdated(this);
 		updating=false;
 	}
+	public void fireSensorUpdate() {
+		updating=true;
+		for(int i=0; i<listeners.size() && updating; i++)
+			((VisionUpdatedListener)listeners.get(i)).sensorsUpdated(this);
+		updating=false;
+	}
 
 	public Date getTimeStamp() { return timestamp; }
 	public long getFrameNum() { return frameNum; }
@@ -65,6 +68,7 @@ public class UDPVisionListener extends UDPListener implements VisionListener {
 	byte[] _tmp=new byte[pktSize*2];
 	byte[] _jpeg=new byte[pktSize*2];
 	byte[] _newjpeg=new byte[pktSize*2];
+	String sensors;
 	boolean isJPEG=false;
 	int jpegLen=0;
 	int newjpegLen=0;
@@ -76,17 +80,22 @@ public class UDPVisionListener extends UDPListener implements VisionListener {
 	boolean convertRGB=true;
 	IndexColorModel cmodel;
 
+	public String getSensors() { return sensors; }
+
 	public boolean hasRawJPEG() { return isJPEG; }
 	public byte[] getJPEG() { return _jpeg; }
 	public int getJPEGLen() { return jpegLen; }
 	
 	public String readLoadSaveString(InputStream in) throws java.io.IOException {
 		int creatorLen=readInt(in);
-		if(!_isConnected) return ""; 
+		if(!_isConnected) return ""; //System.out.println("creatorLen=="+creatorLen);
 		String creator=new String(readBytes(in,creatorLen));
 		if(!_isConnected) return "";
-		if(readChar(in)!='\0')
-			System.err.println("Misread LoadSave string? "+creator);
+		if(readChar(in)!='\0') {
+			System.err.println("Misread LoadSave string? len="+creatorLen+" str="+creator);
+			Throwable th=new Throwable();
+			th.printStackTrace();
+		}
 		return creator;
 	}
 
@@ -264,8 +273,8 @@ public class UDPVisionListener extends UDPListener implements VisionListener {
 			for(int y=0; y<chanH; y++)
 				for(int x=0; x<chanW; x++) {
 					_data[off++]=(byte)decoded.getSample(x,y,0);
-					_data[off++]=(byte)decoded.getSample(x,y,2);
 					_data[off++]=(byte)decoded.getSample(x,y,1);
+					_data[off++]=(byte)decoded.getSample(x,y,2);
 				}
 		} catch(Exception ex) { ex.printStackTrace(); }
 		return true;
@@ -346,23 +355,94 @@ public class UDPVisionListener extends UDPListener implements VisionListener {
 		return true;
 	}
 
-	public void connected(DatagramSocket UDPsocket) {
+	
+	public boolean readRegions(InputStream in, int chanW, int chanH) throws java.io.IOException {
+		//clear the _data array
+		for(int h=0; h<chanH; h++) {
+			for(int w =0; w<chanW; w++) {
+				_data[chanW*h+w]=0;
+			}
+		}
+  
+		int numColors=readInt(in);
+		if(!_isConnected) return false;
+		for(int curColor = 0; curColor < numColors; curColor++) {
+			int numRegions = readInt(in);
+			if(!_isConnected) return false;
+            
+			readBytes(_tmp,in,36*numRegions);
+			if(!_isConnected) return false;
+            	
+			int dpos=0;
+			for (int i = 0; i<numRegions; i++) {
+				byte color= _tmp[dpos];
+				dpos +=4;
+				int x1 = byteToInt(_tmp,dpos);
+				dpos +=4;
+				int y1 = byteToInt(_tmp,dpos);
+				dpos +=4;
+				int x2 = byteToInt(_tmp,dpos);
+				dpos +=4;
+				int y2 = byteToInt(_tmp,dpos);
+				//The  data of the centroid, area and run_start are ignored
+				dpos +=20; //isn't nessescary, but now it nicely adds up to 36
+				if (  x1 > chanW || y1 > chanH || x2 > chanW || y2 > chanH
+							|| x1 > x2 || y1 > y2
+							|| x1 < 0 || x2 < 0 || y1 < 0 || y2 < 0
+							)
+					return false;
+				
+				//Fill the data array with the bounding boxes..
+				//..the top and bottom lines
+				for (int tb = x1; tb <= x2; tb++) {
+					_data[y1*width+tb]=color;
+					_data[y2*width+tb]=color;
+				}
+				//..the left and right lines
+				for (int lr = y1; lr <= y2; lr++) {
+					_data[lr*width+x1]=color;
+					_data[lr*width+x2]=color;
+				}
+			}
+			readBytes(_tmp,in,12); //read out the min_area, total_area and merge_threshhold and ignore them:)
+		}
+		if(!readColorModel(in)) return false;
+		if(!_isConnected) return false;
+		isIndex=true;
+		return true;
+	}
+
+
+	public void connected(DatagramSocket UDPsocket, DatagramPacket incoming) {
 		_isConnected=true;
 		mysock = UDPsocket;
-		while(listeners==null) //fixes a race condition, since Listener constructor spawns thread, subclass constructors may not be finished
+		while(listeners==null) {
+			System.out.println("Assert: Bad race condition -- shouldn't be happening");
 			Thread.yield();
-		fireVisionUpdate();
+		}
 		try {
+			fireConnected();
 			while(!mysock.isClosed()) {
-				mysock.receive(incoming);
 				in = new ByteArrayInputStream(incoming.getData());
 				String type = readLoadSaveString(in);
 				if(!_isConnected) break; //System.out.println("Got type="+type);
 				if(!type.equals("TekkotsuImage")) {
-					System.err.println("Unrecognized type: "+type);
+					if(type.startsWith("#POS\n")) {
+						sensors=type;
+						//System.out.println("got sensors");
+						fireSensorUpdate();
+						if(destroy)
+							break;
+						mysock.receive(incoming);
+						continue;
+					} else if(!type.equals("CloseConnection"))
+						System.err.println("Unrecognized type: "+type);
+					else {
+						System.out.println("Got Close connection packet");
+						_isConnected=false;
+					}
 					break;
 				}
-        fireConnected();
 				format=readInt(in);
 				if(!_isConnected) break; //System.out.println("Got format="+format);
 				compression=readInt(in);
@@ -468,6 +548,10 @@ public class UDPVisionListener extends UDPListener implements VisionListener {
 							isJPEG=false;
 							isIndex=true;
 							if(!readRLE(in,chanwidth,chanheight)) { failed=true; System.err.println("UDPVisionListener RLEImage read failed"); break; }
+						} else if(fmt.equals("RegionImage")) {
+							isJPEG=false;
+							isIndex=true;
+							if(!readRegions(in,chanwidth,chanheight)) { failed=true; System.err.println("UDPVisionListener RegionImage read failed"); break; }
 						} else {
 							isJPEG=false;
 							isIndex=false;
@@ -497,6 +581,9 @@ public class UDPVisionListener extends UDPListener implements VisionListener {
 				}
 				updatedFlag=true;
 				fireVisionUpdate();
+				if(destroy) //close requested
+					close(); //try to request final sensor frame again (might've dropped packet)
+				mysock.receive(incoming);
 			}
 		} catch (Exception ex) {
     } finally {
@@ -504,6 +591,11 @@ public class UDPVisionListener extends UDPListener implements VisionListener {
     }
 		
 		try { mysock.close(); } catch (Exception ex) { }
+		if(!_isConnected) {
+			if(!destroy)
+				System.out.println("Waiting 5 seconds to reconnect");
+			try { Thread.sleep(5000); } catch (Exception ex) {}
+		}
 		_isConnected=false;
 		fireVisionUpdate();
 	}
@@ -584,15 +676,14 @@ public class UDPVisionListener extends UDPListener implements VisionListener {
 
 	static final int pixelYUV2RGB(int y, int u, int v) {
 		u=u*2-255;
-		v=v*2-255;
-		int r=y+u;
-		int b=y+v;
-		u=u>>1;
-		v=(v>>2)-(v>>4);
+		v=v-128;
+		int b=y+u;
+		int r=y+v;
+		v=v>>1;
+		u=(u>>2)-(u>>4);
 		int g=y-u-v;
 		if (r<0) r=0; if (g<0) g=0; if (b<0) b=0;
 		if (r>255) r=255; if (g>255) g=255; if (b>255) b=255;
-
 		return (255<<24) | (r<<16) | (g<<8) | b;
 	}
 
@@ -607,20 +698,44 @@ public class UDPVisionListener extends UDPListener implements VisionListener {
 				img=new BufferedImage(width,height,BufferedImage.TYPE_BYTE_INDEXED,cmodel);
 			img.getRaster().setDataElements(0,0,width,height,data);
 		} else {
-			updatedFlag=false;
 			int[] pix;
-			if(img.getWidth()!=width || img.getHeight()!=height || img.getType()!=BufferedImage.TYPE_BYTE_INDEXED)
+			if(img.getWidth()!=width || img.getHeight()!=height || img.getType()!=BufferedImage.TYPE_INT_RGB)
 				img=new BufferedImage(width,height,BufferedImage.TYPE_INT_RGB);
-			if(format==ENCODE_COLOR)
-				pix=getConvertRGB()?getRGBPixels():getYUVPixels();
-			else
-				pix=getIntensityPixels();
-			img.setRGB(0,0,width,height,pix,0,width);
+			synchronized(_outd) {
+				if(format==ENCODE_COLOR)
+					pix=getConvertRGB()?getRGBPixels():getYUVPixels();
+				else
+					pix=getIntensityPixels();
+				img.setRGB(0,0,width,height,pix,0,width);
+			}
 		}
 		return img;
 	}
 
+	public void close() {
+		if(mysock==null || mysock.isClosed())
+			return;
+		destroy=true;
+		byte[] buf = (new String("refreshSensors\n")).getBytes();
+		try {
+			mysock.send(new DatagramPacket(buf,buf.length));
+		} catch(Exception e) { e.printStackTrace(); }
+		//wait until the final sensors comes in so if user hits save image we can save the corresponding sensors too
+	}
 
+	public void startSensors() {
+		byte[] buf = (new String("startSensors\n")).getBytes();
+		try {
+			mysock.send(new DatagramPacket(buf,buf.length));
+		} catch(Exception e) { e.printStackTrace(); }
+	}
+
+	public void stopSensors() {
+		byte[] buf = (new String("stopSensors\n")).getBytes();
+		try {
+			mysock.send(new DatagramPacket(buf,buf.length));
+		} catch(Exception e) { e.printStackTrace(); }
+	}
 
 	public UDPVisionListener() { super(); }
 	public UDPVisionListener(int port) { super(port); }
