@@ -83,7 +83,6 @@ public class SketchGUI extends JFrame implements ActionListener,
     SketchOrShapeInfo curObject;
     String panelTitle;
     int panelCount = 1;
-    static SketchGUI gui;
 
     public static void main(String args[]) {
 	if(args.length<2)
@@ -109,7 +108,7 @@ public class SketchGUI extends JFrame implements ActionListener,
 	}
 	else usage();
 
-        gui = new SketchGUI(args[0], _listingPort, _sketchPort, _space);
+	SketchGUI gui = new SketchGUI(args[0], _listingPort, _sketchPort, _space);
 	gui.addWindowListener(new WindowAdapter() {
 		 public void windowClosing(WindowEvent e) {System.exit(0);}});
 	gui.setVisible(true);
@@ -250,7 +249,7 @@ public class SketchGUI extends JFrame implements ActionListener,
 	String inputLine;
 	
 	if (!panelBoundsSet){
-	    // Get image bounds from the dog
+	    // Get image bounds from the robot
 	    netout.println("size");
 	    System.out.println(inputLine = readLine());
 	    while((inputLine=readLine()).compareTo("size end") != 0) {
@@ -637,6 +636,15 @@ public class SketchGUI extends JFrame implements ActionListener,
 	    return new PyramidShapeInfo(id, parentId, name, color, cx, cy, cz,
 				      FLx, FLy, FRx, FRy, BLx, BLy, BRx, BRy,
 				      Topx, Topy);
+	} else if(shapetype == 10) { // localzationparticleshape
+	    inputLine = readLine();
+	    st = new StringTokenizer(inputLine, ": ");
+	    st.nextToken();
+	    float orient = Float.parseFloat(st.nextToken());
+	    float weight = Float.parseFloat(st.nextToken());
+	    System.out.println("  orient: " + orient + "   weight: " + weight);
+	    return new LocalizationParticleShapeInfo(id, parentId, name, color, cx, cy, cz,
+						orient, weight);
 	} else {
 	    System.out.println("Invalid shape!");
 	    return new ShapeInfo(id, parentId, name, color, cx, cy, cz);
@@ -654,13 +662,15 @@ public class SketchGUI extends JFrame implements ActionListener,
 	st = new StringTokenizer(inputLine,": ");
 	st.nextToken();
 	float area = Float.parseFloat(st.nextToken());
-	System.out.println("area: "+area);
+	System.out.println(" area: "+area);
 
 	inputLine = readLine();
 	st = new StringTokenizer(inputLine,": ");
 	st.nextToken();
 	int orient = Integer.parseInt(st.nextToken());
-	System.out.println("orient: "+orient);
+	System.out.println(" orient: "+orient);
+	if ( space == Space.cam )
+	    orient = 0; // always display cam-space blobs as lieing in the camera plane
 
 	inputLine = readLine();
 	st = new StringTokenizer(inputLine,": ");
@@ -668,7 +678,7 @@ public class SketchGUI extends JFrame implements ActionListener,
 	float topLeft_x = Float.parseFloat(st.nextToken());
 	float topLeft_y = Float.parseFloat(st.nextToken());
 	float topLeft_z = Float.parseFloat(st.nextToken());
-	System.out.println("topLeft: " + topLeft_x + " " + 
+	System.out.println(" topLeft: " + topLeft_x + " " + 
 			   topLeft_y + " " + topLeft_z);
 
 	inputLine = readLine();
@@ -677,7 +687,7 @@ public class SketchGUI extends JFrame implements ActionListener,
 	float topRight_x = Float.parseFloat(st.nextToken());
 	float topRight_y = Float.parseFloat(st.nextToken());
 	float topRight_z = Float.parseFloat(st.nextToken());
-	System.out.println("topRight: " + topRight_x + " " + 
+	System.out.println(" topRight: " + topRight_x + " " + 
 			   topRight_y + " " + topRight_z);
 
 	inputLine = readLine();
@@ -686,7 +696,7 @@ public class SketchGUI extends JFrame implements ActionListener,
 	float bottomLeft_x = Float.parseFloat(st.nextToken());
 	float bottomLeft_y = Float.parseFloat(st.nextToken());
 	float bottomLeft_z = Float.parseFloat(st.nextToken());
-	System.out.println("bottomLeft: " + bottomLeft_x + " " + 
+	System.out.println(" bottomLeft: " + bottomLeft_x + " " + 
 			   bottomLeft_y + " " + bottomLeft_z);
 
 	inputLine = readLine();
@@ -695,7 +705,7 @@ public class SketchGUI extends JFrame implements ActionListener,
 	float bottomRight_x = Float.parseFloat(st.nextToken());
 	float bottomRight_y = Float.parseFloat(st.nextToken());
 	float bottomRight_z = Float.parseFloat(st.nextToken());
-	System.out.println("bottomRight: " + bottomRight_x + " " + 
+	System.out.println(" bottomRight: " + bottomRight_x + " " + 
 			   bottomRight_y + " " + bottomRight_z);
 
 	return new BlobShapeInfo(id,parentId,name,color,cx,cy,cz,area,orient,
@@ -780,18 +790,15 @@ public class SketchGUI extends JFrame implements ActionListener,
 	getContentPane().add(Box.createVerticalStrut(strutsize),BorderLayout.NORTH);
 	getContentPane().add(Box.createHorizontalStrut(strutsize),BorderLayout.WEST);
 	getContentPane().add(Box.createHorizontalStrut(strutsize),BorderLayout.EAST);
-		
-	//	setTitle(((space==1) ? "Cam" : ((space==2) ? "Local" : "World"))+"Space "+host);
-	setTitle(space.name()+": "+host);
+	setTitle(space.name()+" GUI: "+host);
 
 	sketchPanel.setMinimumSize(new Dimension(imageWidth/2, imageHeight/2));
 	sketchPanel.setPreferredSize(new Dimension(imageWidth*2, imageHeight*2));
 	sketchPanel.setLockAspectRatio(true);
 
 	curSketchPanel = sketchPanel;
-	//	panelTitle = ((space==1) ? "Cam" : ((space==2) ? "Local" : "World")) + "Img";
-	panelTitle = space.name() + " view: ";
-	sketchPanel.makeSketchFrame(sketchPanel, panelTitle+" "+host);
+	panelTitle = space.name() + " view"; // don't append host here because of clones
+	sketchPanel.makeSketchFrame(sketchPanel, panelTitle+": "+host);
 	{
 
 	    Box tmp1 = Box.createHorizontalBox();
@@ -907,7 +914,7 @@ public class SketchGUI extends JFrame implements ActionListener,
 
     class CloseSketchGUIAdapter extends WindowAdapter {
 	SketchGUI gui;
-	CloseSketchGUIAdapter(SketchGUI gui) {this.gui=gui;}
+	CloseSketchGUIAdapter(SketchGUI _gui) { gui = _gui; }
 	public void windowClosing(WindowEvent e) {
 	    gui.close();
 	}
